@@ -76,8 +76,10 @@ OC.L10N.register(
     "Nextcloud Group" : "Grupo Nextcloud",
     "Email address" : "Endereço de e-mail",
     "Contact" : "Contato",
-    "Circle" : "Círculo",
+    "Team" : "Equipe",
     "Nextcloud App" : "Aplicativo Nextcloud",
+    "Teams App" : "Aplicativo Equipes",
+    "Admin Command Line" : "Linha de Comando do Administrador",
     "Member" : "Membro",
     "Moderator" : "Moderador",
     "Admin" : "Administrador",
@@ -134,6 +136,8 @@ OC.L10N.register(
     "You have no permission to create a new team" : "Você não tem permissão para criar uma nova equipe",
     "%s shared a file with \"%s\"." : "%s compartilhou um arquivo com \"%s\".",
     "%s shared a file with you." : "%s compartilhou um arquivo com você.",
+    "%1$s shared %2$s with %3$s" : "%1$s compartilhou %2$s com %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s compartilhou %2$s com \"%3$s\"",
     "Open %s" : "Abrir %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou algum conteúdo com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-lo.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
@@ -142,6 +146,13 @@ OC.L10N.register(
     "This item is already shared with this team" : "Este item já está compartilhado com esta equipe",
     "Bring cloud-users closer together." : "Reúna os usuários da nuvem.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "O Equipes permite que as pessoas criem seus próprios grupos de pessoas/colegas/amigos. \nEsses grupos de pessoas podem então ser usados ​​por qualquer outro aplicativo para fins de compartilhamento.",
+    "Failed to load teams" : "Falha ao carregar equipes",
+    "Try again" : "Tentar novamente",
+    "No teams found" : "Nenhuma equipe encontrada",
+    "Join or create teams to see them here." : "Junte-se ou crie equipes para vê-las aqui.",
+    "Create your first team" : "Crie sua primeira equipe",
+    "Loading…" : "Carregando…",
+    "More teams" : "Mais equipes",
     "No files in here" : "Nenhum arquivo aqui",
     "No entries found in this folder" : "Sem entradas nesta pasta",
     "Name" : "Nome",
@@ -149,9 +160,9 @@ OC.L10N.register(
     "Modified" : "Modificado",
     "Teams' files" : "Arquivos das equipes",
     "Select team to filter by" : "Selecione uma equipe para filtrar",
-    "No teams found" : "Nenhuma equipe encontrada",
     "Please select teams to filter by" : "Selecione equipes para filtrar",
     "No files found for the selected teams" : "Nenhum arquivo encontrado para as equipes selecionadas",
-    "Shared to Circles" : "Compartilhado com Círculos"
+    "Shared to Circles" : "Compartilhado com Círculos",
+    "Circle" : "Círculo"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
