@@ -76,7 +76,7 @@ OC.L10N.register(
     "Nextcloud Group" : "Група Nextcloud",
     "Email address" : "Адреса ел.пошти",
     "Contact" : "Контакт",
-    "Circle" : "Коло",
+    "Team" : "Команда",
     "Nextcloud App" : "Застосунок Nextcloud",
     "Member" : "Учасник",
     "Moderator" : "Модератор",
@@ -134,6 +134,9 @@ OC.L10N.register(
     "You have no permission to create a new team" : "У вас відсутні дозволи створювати нові команди",
     "%s shared a file with \"%s\"." : "%s поділив(-ла-)ся файлом з \"%s\".",
     "%s shared a file with you." : "%s поділив(-ла-)ся з вами файлом.",
+    "%1$s shared %2$s with %3$s" : "%1$s спільний %2$s з %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s спільний %2$s з «%3$s»",
+    "Open %s" : "Відкрити %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поділив(-ла-)ся з вами деяким вмістом. \nНа вашу ел.скриньку було надіслано лист із посиланням для доступу до вмісту.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поділив(-ла-)ся з вами деяким вмістом. На вашу ел.скриньку було надіслано лист із посиланням для доступу до вмісту.",
     "Password to access content shared with you by %1$s" : "Пароль для доступу до вмісту, яким з вами поділив(-ла-)ся %1$s",
@@ -141,6 +144,13 @@ OC.L10N.register(
     "This item is already shared with this team" : "Цей ресурс вже у спільному доступі з цією командою",
     "Bring cloud-users closer together." : "Зближіть користувачів хмари.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Команди дозволяють користувачам створювати власні групи з друзів, колег, знайомих.\nЗ цими групами людей подалі можна буде обмінюватися даними в різних застосунках.",
+    "Failed to load teams" : "Не вдалося завантажити команди",
+    "Try again" : "Спробуйте ще раз",
+    "No teams found" : "Жодної команди не знайдено",
+    "Join or create teams to see them here." : "Приєднуйте або створюйте команди, щоби побачитии їх тут.",
+    "Create your first team" : "Створити першу команду",
+    "Loading…" : "Завантаження…",
+    "More teams" : "Більше команд",
     "No files in here" : "Тут немає файлів",
     "No entries found in this folder" : "У цьому каталозі нічого немає",
     "Name" : "Ім'я",
@@ -148,9 +158,9 @@ OC.L10N.register(
     "Modified" : "Змінено",
     "Teams' files" : "Файли команд",
     "Select team to filter by" : "Виберіть команду для відфільтрування",
-    "No teams found" : "Жодної команди не знайдено",
     "Please select teams to filter by" : "Виберіть команди для відфільтрування",
     "No files found for the selected teams" : "Жодних файлів не знайдено для вибраних команд",
-    "Shared to Circles" : "Опубліковано в Колах"
+    "Shared to Circles" : "Опубліковано в Колах",
+    "Circle" : "Коло"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
