@@ -130,8 +130,8 @@ OC.L10N.register(
     "{actor} unshared address book {addressbook} from themselves" : "{actor} не го споделува адресар {addressbook} со себе",
     "You shared address book {addressbook} with group {group}" : "Споделивте адресар {addressbook} со група {group}",
     "{actor} shared address book {addressbook} with group {group}" : "{actor} сподели адресар {addressbook} со група {group}",
-    "You unshared address book {addressbook} from group {group}" : "Остранивте од споделување адресар {addressbook} со група{group}",
-    "{actor} unshared address book {addressbook} from group {group}" : "{actor} острани од споделување адресар {addressbook} од група {group}",
+    "You unshared address book {addressbook} from group {group}" : "Отстранивте од споделување адресар {addressbook} со група{group}",
+    "{actor} unshared address book {addressbook} from group {group}" : "{actor} отстрани од споделување адресар {addressbook} од група {group}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Контракт</strong> или <strong>адресар</strong> е променет",
     "Accounts" : "Сметки",
     "System address book which holds all accounts" : "Системски адресар кој ги содржи сите сметки",
