@@ -281,7 +281,6 @@ OC.L10N.register(
     "Failed to load availability" : "Nepodarilo sa načítať dostupnosť",
     "Saved availability" : "Dostupnosť bola uložená",
     "Failed to save availability" : "Nepodarilo sa uložiť dostupnosť",
-    "Time zone:" : "Časová zóna:",
     "to" : "do",
     "Delete slot" : "Odstrániť slot",
     "No working hours set" : "Nenastavená pracovná doba",
@@ -290,6 +289,17 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Vyberte začiatočný čas pre {dayName}",
     "Pick a end time for {dayName}" : "Vyberte koncový čas pre {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Automaticky nastaviť stav používateľa na „Nerušiť“ ak nie ste dostupný,  pre stlmenie všetkých upozornení.",
+    "Cancel" : "Zrušiť",
+    "Import" : "Import",
+    "Error while saving settings" : "Chyba pri ukladaní nastavení",
+    "Contact reset successfully" : "Kontakt bol úspešne resetovaný",
+    "Error while resetting contact" : "Chyba počas resetovania kontaktu ",
+    "Contact imported successfully" : "Kontakt bol úspešne importovaný",
+    "Error while importing contact" : "Chyba pri importovaní kontaktu",
+    "Import contact" : "Importovať kontakt",
+    "Reset to default" : "Nastaviť predvolené",
+    "Import contacts" : "Importovať kontakty",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importovaním nového súboru .vcf sa vymaže existujúci predvolený kontakt a nahradí sa novým. Chcete pokračovať?",
     "Availability" : "Dostupnosť",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ak nakonfigurujete svoj pracovný čas, ostatní užívatelia vás uvidia ako neprítomného, keď si rezervujete schôdzku",
     "Absence" : "Neprítomnosť",
@@ -306,27 +316,11 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Posielať upozornenia na pripomienky aj zdieľaným osobám v kalendári",
     "Reminders are always sent to organizers and attendees." : "Upozornenia sa vždy posielajú organizátorom a účastníkom.",
     "Enable notifications for events via push" : "Zapnúť oznámenia o udalostiach prostredníctvom technológie push.",
-    "Cancel" : "Zrušiť",
-    "Import" : "Import",
-    "Error while saving settings" : "Chyba pri ukladaní nastavení",
-    "Contact reset successfully" : "Kontakt bol úspešne resetovaný",
-    "Error while resetting contact" : "Chyba počas resetovania kontaktu ",
-    "Contact imported successfully" : "Kontakt bol úspešne importovaný",
-    "Error while importing contact" : "Chyba pri importovaní kontaktu",
-    "Example Content" : "Príklad Obsahu",
-    "Set example content to be created on new user first login." : "Nastavte vzorový obsah, ktorý sa vytvorí pri prvom prihlásení nového používateľa.",
-    "Import contact" : "Importovať kontakt",
-    "Reset to default contact" : "Resetovať na predvolený kontakt",
-    "Import contacts" : "Importovať kontakty",
-    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importovaním nového súboru .vcf sa vymaže existujúci predvolený kontakt a nahradí sa novým. Chcete pokračovať?",
     "There was an error updating your attendance status." : "Nastal problém pri aktualizácii Vašej účasti.",
     "Please contact the organizer directly." : "Prosím kontaktujte priamo organizátora.",
     "Are you accepting the invitation?" : "Príjmate pozvánku?",
     "Tentative" : "Neistý",
     "Your attendance was updated successfully." : "Vaša účasť bola aktualizovaná úspešne.",
-    "Time:" : "Čas:",
-    "Could not open file" : "Súbor sa nepodarilo otvoriť",
-    "Invalid chunk name" : "Neplatný názov bloku",
-    "Could not rename part file assembled from chunks" : "Nepodarilo sa premenovať dočasný súbor vytvorený z blokov"
+    "Time zone:" : "Časová zóna:"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
