@@ -10,13 +10,14 @@ namespace OCA\DAV\CardDAV;
 use OCA\DAV\Db\PropertyMapper;
 use OCP\Constants;
 use OCP\IAddressBookEnabled;
+use OCP\ICreateContactFromString;
 use OCP\IURLGenerator;
 use Sabre\VObject\Component\VCard;
 use Sabre\VObject\Property;
 use Sabre\VObject\Reader;
 use Sabre\VObject\UUIDUtil;
 
-class AddressBookImpl implements IAddressBookEnabled {
+class AddressBookImpl implements IAddressBookEnabled, ICreateContactFromString {
 
 	/**
 	 * AddressBookImpl constructor.
@@ -41,7 +42,7 @@ class AddressBookImpl implements IAddressBookEnabled {
 	 * @since 5.0.0
 	 */
 	public function getKey() {
-		return $this->addressBookInfo['id'];
+		return (string)$this->addressBookInfo['id'];
 	}
 
 	/**
@@ -152,6 +153,10 @@ class AddressBookImpl implements IAddressBookEnabled {
 		$permissions = $this->addressBook->getACL();
 		$result = 0;
 		foreach ($permissions as $permission) {
+			if ($this->addressBookInfo['principaluri'] !== $permission['principal']) {
+				continue;
+			}
+
 			switch ($permission['privilege']) {
 				case '{DAV:}read':
 					$result |= Constants::PERMISSION_READ;
@@ -307,8 +312,8 @@ class AddressBookImpl implements IAddressBookEnabled {
 	 */
 	public function isSystemAddressBook(): bool {
 		return $this->addressBookInfo['principaluri'] === 'principals/system/system' && (
-			$this->addressBookInfo['uri'] === 'system' ||
-			$this->addressBookInfo['{DAV:}displayname'] === $this->urlGenerator->getBaseUrl()
+			$this->addressBookInfo['uri'] === 'system'
+			|| $this->addressBookInfo['{DAV:}displayname'] === $this->urlGenerator->getBaseUrl()
 		);
 	}
 
@@ -324,7 +329,7 @@ class AddressBookImpl implements IAddressBookEnabled {
 			$user = str_replace('principals/users/', '', $this->addressBookInfo['principaluri']);
 			$uri = $this->addressBookInfo['uri'];
 		}
-		
+
 		$path = 'addressbooks/users/' . $user . '/' . $uri;
 		$properties = $this->propertyMapper->findPropertyByPathAndName($user, $path, '{http://owncloud.org/ns}enabled');
 		if (count($properties) > 0) {
@@ -332,4 +337,8 @@ class AddressBookImpl implements IAddressBookEnabled {
 		}
 		return true;
 	}
+
+	public function createFromString(string $name, string $vcfData): void {
+		$this->backend->createCard($this->getKey(), $name, $vcfData);
+	}
 }
