@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
  * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
@@ -8,13 +9,20 @@
 namespace OCA\DAV\DAV;
 
 use Exception;
+use OCA\DAV\CalDAV\CalDavBackend;
 use OCA\DAV\CalDAV\Calendar;
+use OCA\DAV\CalDAV\CalendarHome;
+use OCA\DAV\CalDAV\CalendarObject;
 use OCA\DAV\CalDAV\DefaultCalendarValidator;
+use OCA\DAV\CalDAV\Integration\ExternalCalendar;
+use OCA\DAV\CalDAV\Outbox;
+use OCA\DAV\CalDAV\Trashbin\TrashbinHome;
 use OCA\DAV\Connector\Sabre\Directory;
-use OCA\DAV\Connector\Sabre\FilesPlugin;
+use OCA\DAV\Db\PropertyMapper;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 use OCP\IUser;
+use Sabre\CalDAV\Schedule\Inbox;
 use Sabre\DAV\Exception as DavException;
 use Sabre\DAV\PropertyStorage\Backend\BackendInterface;
 use Sabre\DAV\PropFind;
@@ -65,33 +73,16 @@ class CustomPropertiesBackend implements BackendInterface {
 		'{DAV:}getetag',
 		'{DAV:}quota-used-bytes',
 		'{DAV:}quota-available-bytes',
-		'{http://owncloud.org/ns}permissions',
-		'{http://owncloud.org/ns}downloadURL',
-		'{http://owncloud.org/ns}dDC',
-		'{http://owncloud.org/ns}size',
-		'{http://nextcloud.org/ns}is-encrypted',
+	];
 
-		// Currently, returning null from any propfind handler would still trigger the backend,
-		// so we add all known Nextcloud custom properties in here to avoid that
-
-		// text app
-		'{http://nextcloud.org/ns}rich-workspace',
-		'{http://nextcloud.org/ns}rich-workspace-file',
-		// groupfolders
-		'{http://nextcloud.org/ns}acl-enabled',
-		'{http://nextcloud.org/ns}acl-can-manage',
-		'{http://nextcloud.org/ns}acl-list',
-		'{http://nextcloud.org/ns}inherited-acl-list',
-		'{http://nextcloud.org/ns}group-folder-id',
-		// files_lock
-		'{http://nextcloud.org/ns}lock',
-		'{http://nextcloud.org/ns}lock-owner-type',
-		'{http://nextcloud.org/ns}lock-owner',
-		'{http://nextcloud.org/ns}lock-owner-displayname',
-		'{http://nextcloud.org/ns}lock-owner-editor',
-		'{http://nextcloud.org/ns}lock-time',
-		'{http://nextcloud.org/ns}lock-timeout',
-		'{http://nextcloud.org/ns}lock-token',
+	/**
+	 * Allowed properties for the oc/nc namespace, all other properties in the namespace are ignored
+	 *
+	 * @var string[]
+	 */
+	private const ALLOWED_NC_PROPERTIES = [
+		'{http://owncloud.org/ns}calendar-enabled',
+		'{http://owncloud.org/ns}enabled',
 	];
 
 	/**
@@ -113,11 +104,17 @@ class CustomPropertiesBackend implements BackendInterface {
 	];
 
 	/**
-	 * Properties cache
-	 *
-	 * @var array
+	 * Map of well-known property names to default values
 	 */
-	private $userCache = [];
+	private const PROPERTY_DEFAULT_VALUES = [
+		'{http://owncloud.org/ns}calendar-enabled' => '1',
+	];
+
+	/**
+	 * Properties cache
+	 */
+	private array $userCache = [];
+	private array $publishedCache = [];
 	private XmlService $xmlService;
 
 	/**
@@ -130,6 +127,7 @@ class CustomPropertiesBackend implements BackendInterface {
 		private Tree $tree,
 		private IDBConnection $connection,
 		private IUser $user,
+		private PropertyMapper $propertyMapper,
 		private DefaultCalendarValidator $defaultCalendarValidator,
 	) {
 		$this->xmlService = new XmlService();
@@ -149,14 +147,9 @@ class CustomPropertiesBackend implements BackendInterface {
 	public function propFind($path, PropFind $propFind) {
 		$requestedProps = $propFind->get404Properties();
 
-		// these might appear
-		$requestedProps = array_diff(
-			$requestedProps,
-			self::IGNORED_PROPERTIES,
-		);
 		$requestedProps = array_filter(
 			$requestedProps,
-			fn ($prop) => !str_starts_with($prop, FilesPlugin::FILE_METADATA_PREFIX),
+			$this->isPropertyAllowed(...),
 		);
 
 		// substr of calendars/ => path is inside the CalDAV component
@@ -218,6 +211,18 @@ class CustomPropertiesBackend implements BackendInterface {
 			$this->cacheDirectory($path, $node);
 		}
 
+		if ($node instanceof CalendarHome && $propFind->getDepth() !== 0) {
+			$backend = $node->getCalDAVBackend();
+			if ($backend instanceof CalDavBackend) {
+				$this->cacheCalendars($node, $requestedProps);
+			}
+		}
+
+		if ($node instanceof CalendarObject) {
+			// No custom properties supported on individual events
+			return;
+		}
+
 		// First fetch the published properties (set by another user), then get the ones set by
 		// the current user. If both are set then the latter as priority.
 		foreach ($this->getPublishedProperties($path, $requestedProps) as $propName => $propValue) {
@@ -238,6 +243,16 @@ class CustomPropertiesBackend implements BackendInterface {
 		}
 	}
 
+	private function isPropertyAllowed(string $property): bool {
+		if (in_array($property, self::IGNORED_PROPERTIES)) {
+			return false;
+		}
+		if (str_starts_with($property, '{http://owncloud.org/ns}') || str_starts_with($property, '{http://nextcloud.org/ns}')) {
+			return in_array($property, self::ALLOWED_NC_PROPERTIES);
+		}
+		return true;
+	}
+
 	/**
 	 * Updates properties for a path
 	 *
@@ -277,8 +292,8 @@ class CustomPropertiesBackend implements BackendInterface {
 	 */
 	public function move($source, $destination) {
 		$statement = $this->connection->prepare(
-			'UPDATE `*PREFIX*properties` SET `propertypath` = ?' .
-			' WHERE `userid` = ? AND `propertypath` = ?'
+			'UPDATE `*PREFIX*properties` SET `propertypath` = ?'
+			. ' WHERE `userid` = ? AND `propertypath` = ?'
 		);
 		$statement->execute([$this->formatPath($destination), $this->user->getUID(), $this->formatPath($source)]);
 		$statement->closeCursor();
@@ -322,6 +337,10 @@ class CustomPropertiesBackend implements BackendInterface {
 			return [];
 		}
 
+		if (isset($this->publishedCache[$path])) {
+			return $this->publishedCache[$path];
+		}
+
 		$qb = $this->connection->getQueryBuilder();
 		$qb->select('*')
 			->from(self::TABLE_NAME)
@@ -332,6 +351,7 @@ class CustomPropertiesBackend implements BackendInterface {
 			$props[$row['propertyname']] = $this->decodeValueFromDatabase($row['propertyvalue'], $row['valuetype']);
 		}
 		$result->closeCursor();
+		$this->publishedCache[$path] = $props;
 		return $props;
 	}
 
@@ -350,7 +370,10 @@ class CustomPropertiesBackend implements BackendInterface {
 			)),
 			)
 			->where($query->expr()->eq('parent', $query->createNamedParameter($node->getInternalFileId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('p.userid', $query->createNamedParameter($this->user->getUID())));
+			->andWhere($query->expr()->orX(
+				$query->expr()->eq('p.userid', $query->createNamedParameter($this->user->getUID())),
+				$query->expr()->isNull('p.userid'),
+			));
 		$result = $query->executeQuery();
 
 		$propsByPath = [];
@@ -367,6 +390,62 @@ class CustomPropertiesBackend implements BackendInterface {
 		$this->userCache = array_merge($this->userCache, $propsByPath);
 	}
 
+	private function cacheCalendars(CalendarHome $node, array $requestedProperties): void {
+		$calendars = $node->getChildren();
+
+		$users = [];
+		foreach ($calendars as $calendar) {
+			if ($calendar instanceof Calendar) {
+				$user = str_replace('principals/users/', '', $calendar->getPrincipalURI());
+				if (!isset($users[$user])) {
+					$users[$user] = ['calendars/' . $user];
+				}
+				$users[$user][] = 'calendars/' . $user . '/' . $calendar->getUri();
+			} elseif ($calendar instanceof Inbox || $calendar instanceof Outbox || $calendar instanceof TrashbinHome || $calendar instanceof ExternalCalendar) {
+				if ($calendar->getOwner()) {
+					$user = str_replace('principals/users/', '', $calendar->getOwner());
+					if (!isset($users[$user])) {
+						$users[$user] = ['calendars/' . $user];
+					}
+					$users[$user][] = 'calendars/' . $user . '/' . $calendar->getName();
+				}
+			}
+		}
+
+		// user properties
+		$properties = $this->propertyMapper->findPropertiesByPathsAndUsers($users);
+
+		$propsByPath = [];
+		foreach ($users as $paths) {
+			foreach ($paths as $path) {
+				$propsByPath[$path] = [];
+			}
+		}
+
+		foreach ($properties as $property) {
+			$propsByPath[$property->getPropertypath()][$property->getPropertyname()] = $this->decodeValueFromDatabase($property->getPropertyvalue(), $property->getValuetype());
+		}
+		$this->userCache = array_merge($this->userCache, $propsByPath);
+
+		// published properties
+		$allowedProps = array_intersect(self::PUBLISHED_READ_ONLY_PROPERTIES, $requestedProperties);
+		if (empty($allowedProps)) {
+			return;
+		}
+		$paths = [];
+		foreach ($users as $nestedPaths) {
+			$paths = array_merge($paths, $nestedPaths);
+		}
+		$paths = array_unique($paths);
+
+		$propsByPath = array_fill_keys(array_values($paths), []);
+		$properties = $this->propertyMapper->findPropertiesByPaths($paths, $allowedProps);
+		foreach ($properties as $property) {
+			$propsByPath[$property->getPropertypath()][$property->getPropertyname()] = $this->decodeValueFromDatabase($property->getPropertyvalue(), $property->getValuetype());
+		}
+		$this->publishedCache = array_merge($this->publishedCache, $propsByPath);
+	}
+
 	/**
 	 * Returns a list of properties for the given path and current user
 	 *
@@ -413,6 +492,14 @@ class CustomPropertiesBackend implements BackendInterface {
 		return $props;
 	}
 
+	private function isPropertyDefaultValue(string $name, mixed $value): bool {
+		if (!isset(self::PROPERTY_DEFAULT_VALUES[$name])) {
+			return false;
+		}
+
+		return self::PROPERTY_DEFAULT_VALUES[$name] === $value;
+	}
+
 	/**
 	 * @throws Exception
 	 */
@@ -429,8 +516,8 @@ class CustomPropertiesBackend implements BackendInterface {
 					'propertyName' => $propertyName,
 				];
 
-				// If it was null, we need to delete the property
-				if (is_null($propertyValue)) {
+				// If it was null or set to the default value, we need to delete the property
+				if (is_null($propertyValue) || $this->isPropertyDefaultValue($propertyName, $propertyValue)) {
 					if (array_key_exists($propertyName, $existing)) {
 						$deleteQuery = $deleteQuery ?? $this->createDeleteQuery();
 						$deleteQuery
