@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Sie haben nicht die Berechtigung, eine Datei am angegebenen Speicherort zu erstellen",
     "The file could not be converted." : "Die Datei konnte nicht konvertiert werden.",
     "Could not get relative path to converted file" : "Relativer Pfad zur konvertierten Datei konnte nicht ermittelt werden",
+    "Limit must be a positive integer." : "Der Grenzwert muss eine positive Ganzzahl sein.",
+    "The replacement character may only be a single character." : "Das Ersatzzeichen darf nur ein einzelnes Zeichen sein.",
+    "Filename sanitization already started." : "Die Dateinamenbereinigung hat bereits begonnen.",
+    "No filename sanitization in progress." : "Es läuft keine Dateinamenbereinigung.",
     "Favorite files" : "Favorisierte Dateien",
     "No favorites" : "Keine Favoriten",
     "More favorites" : "Weitere Favoriten",
-    "Upload (max. %s)" : "Hochladen (max. %s)",
     "Accept" : "Akzeptieren",
     "Reject" : "Ablehnen",
     "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
     "in %s" : "in %s",
     "Transferred from %1$s on %2$s" : "Übertragen von %1$s an %2$s",
-    "Files compatibility" : "Dateikompatibilität",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
-    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "File Management" : "Dateiverwaltung",
     "Home" : "Home",
     "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
@@ -95,20 +94,28 @@ OC.L10N.register(
     "Invalid filename." : "Ungültiger Dateiname.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
     "Rename file" : "Datei umbenennen",
+    "Folder" : "Ordner",
+    "Unknown file type" : "Unbekannter Dateityp",
+    "{ext} image" : "{ext}-Bild",
+    "{ext} video" : "{ext}-Video",
+    "{ext} audio" : "{ext}-Audio",
+    "{ext} text" : "{ext}-Text",
     "Pending" : "Ausstehend",
     "Unknown date" : "Unbekanntes Datum",
     "Clear filter" : "Filter zurücksetzen",
     "Modified" : "Geändert",
+    "Search everywhere" : "Überall suchen",
     "Type" : "Typ",
     "Active filters" : "Aktive Filter",
     "Remove filter" : "Filter entfernen",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
     "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
     "Name" : "Name",
+    "File type" : "Dateityp",
     "Size" : "Größe",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
-    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
-    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
+    "{displayName}: failed on some elements" : "{displayName}: Ist bei einigen Elementen fehlgeschlagen",
+    "{displayName}: done" : "{displayName}: Abgeschlossen",
+    "{displayName}: failed" : "{displayName}: Fehlgeschlagen",
     "Actions" : "Aktionen",
     "(selected)" : "(ausgewählt)",
     "List of files and folders." : "Liste der Dateien und Ordner.",
@@ -116,10 +123,14 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
     "File not found" : "Datei nicht gefunden",
-    "{count} selected" : "{count} ausgewählt",
+    "_{count} selected_::_{count} selected_" : ["{count} ausgewählt","{count} ausgewählt"],
+    "Search everywhere …" : "Überall suchen …",
+    "Search here …" : "Hier suchen …",
+    "Search scope options" : "Suchbereichsoptionen",
+    "Search here" : "Hier suchen",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
     "{used} of {quota} used" : "{used} von {quota} verwendet",
-    "{relative}% used" : "{relative}% verwendet",
+    "{relative}% used" : "{relative} % verwendet",
     "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
     "Your storage is full, files can not be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
     "Storage information" : "Speicherinformation",
@@ -128,6 +139,25 @@ OC.L10N.register(
     "Create new folder" : "Neuen Ordner erstellen",
     "This name is already in use." : "Dieser Name wird bereits verwendet.",
     "Create" : "Erstellen",
+    "Files starting with a dot are hidden by default" : "Dateien, die mit einem Punkt beginnen, sind standardmäßig ausgeblendet",
+    "Failed to start filename sanitization." : "Dateinamenbereinigung konnte nicht gestartet werden.",
+    "Failed to refresh filename sanitization status." : "Der Status der Dateinamenbereinigung konnte nicht aktualisiert werden.",
+    "Filename sanitization in progress." : "Dateinamenbereinigung läuft.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Es wurden bereits {processedUsers} von {totalUsers} Konten bearbeitet.",
+    "Preparing …" : "Bereite vor …",
+    "Refresh" : "Aktualisieren",
+    "All files have been santized for Windows filename support." : "Alle Dateien wurden für die Windows-Dateinamenunterstützung bereinigt.",
+    "Some files could not be sanitized, please check your logs." : "Einige Dateien konnten nicht bereinigt werden. Bitte überprüfen Sie Ihre Protokolle.",
+    "Sanitization errors" : "Bereinigungsfehler",
+    "Not sanitized filenames" : "Nicht bereinigte Dateinamen",
+    "Windows filename support has been enabled." : "Windows Dateinamenunterstützung wurde aktiviert.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Dies hindert Benutzer zwar daran, neue Dateien mit nicht unterstützten Dateinamen zu erstellen, vorhandene Dateien werden jedoch noch nicht umbenannt und können daher unter Windows immer noch die Synchronisierung behindern.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Sie können eine Umbenennung von Dateien mit ungültigen Dateinamen starten. Dies geschieht im Hintergrund und kann einige Zeit dauern.",
+    "Please note that this may cause high workload on the sync clients." : "Bitte beachten, dass dies zu einer hohen Auslastung der Synchronisierungsclients führen kann.",
+    "Limit" : "Limit",
+    "This allows to configure how many users should be processed in one background job run." : "Dadurch kann konfiguriert werden, wie viele Benutzer in einem Hintergrundjoblauf verarbeitet werden.",
+    "Sanitize filenames" : "Dateinamen bereinigen",
+    "(starting)" : "(Starte)",
     "Fill template fields" : "Vorlagenfelder ausfüllen",
     "Submitting fields …" : "Felder werden übermittelt …",
     "Submit" : "Übermitteln",
@@ -165,60 +195,72 @@ OC.L10N.register(
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
     "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "Unbekannter Fehler beim Hochladen",
-    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
     "Loading current folder" : "Lade aktuellen Ordner",
     "Retry" : "Wiederholen",
     "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie Ihre Geräte!",
     "Go back" : "Zurückgehen",
-    "Filter file names …" : "Dateinamen filtern …",
     "Views" : "Ansichten",
     "Files settings" : "Dateien-Einstellungen",
     "Your files" : "Ihre Dateien",
     "Open in files" : "In Dateien öffnen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Sie haben keine Berechtigungen, um sie anzuzeigen. Bitten Sie den Absender, die Datei zu teilen.",
+    "No search results for “{query}”" : "Keine Suchergebnisse für \"{query}\"",
+    "Search for files" : "Nach Dateien suchen",
     "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
-    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
+    "WebDAV URL copied" : "WebDAV-URL kopiert",
+    "General" : "Allgemein",
+    "Default view" : "Standardansicht",
+    "All files" : "Alle Dateien",
+    "Personal files" : "Persönliche Dateien",
     "Sort favorites first" : "Favoriten zuerst sortieren",
     "Sort folders before files" : "Ordner vor Dateien sortieren",
+    "Folder tree" : "Ordnerbaum",
+    "Appearance" : "Aussehen",
     "Show hidden files" : "Versteckte Dateien anzeigen",
+    "Show file type column" : "Dateityp-Spalte anzeigen",
+    "Show file extensions" : "Dateierweiterungen anzeigen",
     "Crop image previews" : "Bildvorschauen zuschneiden",
-    "Enable the grid view" : "Kachelansicht aktivieren",
-    "Enable folder tree" : "Ordnerstruktur aktivieren",
     "Additional settings" : "Zusätzliche Einstellungen",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV-URL",
-    "Copy to clipboard" : "In die Zwischenablage kopieren",
-    "Use this address to access your Files via WebDAV" : "Benutzen Sie diese Adresse, um via WebDAV auf Ihre Dateien zuzugreifen",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn Sie 2FA aktiviert haben, müssen Sie ein neues App-Passwort erstellen und verwenden, indem Sie hier klicken.",
+    "Copy" : "Kopieren",
+    "How to access files using WebDAV" : "So greifen Sie mit WebDAV auf Dateien zu",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Für Ihr Konto ist die Zwei-Faktor-Authentifizierung aktiviert. Zur Verbindung eines externen WebDAV-Clients ist daher die Verwendung eines App-Passwortes erforderlich.",
     "Warnings" : "Warnungen",
-    "Prevent warning dialogs from open or reenable them." : "Öffnen von Warndialogen verhindern oder diese erneut aktivieren.",
-    "Show a warning dialog when changing a file extension." : "Beim Ändern einer Dateierweiterung einen Warndialog anzeigen.",
+    "Warn before changing a file extension" : "Vor der Änderung einer Dateierweiterung warnen",
+    "Warn before deleting files" : "Vor dem Löschen von Dateien warnen",
     "Keyboard shortcuts" : "Tastaturkürzel",
-    "Speed up your Files experience with these quick shortcuts." : "Arbeiten Sie schneller mit Dateien mit diesen Schnellzugriffen.",
-    "Open the actions menu for a file" : "Öffnen Sie das Aktionsmenü für eine Datei",
-    "Rename a file" : "Eine Datei umbenennen",
-    "Delete a file" : "Eine Datei löschen",
-    "Favorite or remove a file from favorites" : "Datei favorisieren oder aus den Favoriten entfernen",
-    "Manage tags for a file" : "Schlagworte für eine Datei verwalten",
+    "File actions" : "Dateiaktionen",
+    "Rename" : "Umbenennen",
+    "Delete" : "Löschen",
+    "Add or remove favorite" : "Favorit hinzufügen oder entfernen",
+    "Manage tags" : "Schlagworte verwalten",
     "Selection" : "Auswahl",
     "Select all files" : "Alle Dateien auswählen",
-    "Deselect all files" : "Auswahl aller Dateien aufheben",
-    "Select or deselect a file" : "Auswählen oder Auswahl einer Datei aufheben",
-    "Select a range of files" : "Einen Bereich von Dateien auswählen",
+    "Deselect all" : "Auswahl aufheben",
+    "Select or deselect" : "Aus- oder abwählen",
+    "Select a range" : "Einen Bereich auswählen",
     "Navigation" : "Navigation",
-    "Navigate to the parent folder" : "In den übergeordneten Ordner navigieren",
-    "Navigate to the file above" : "Zur obigen Datei navigieren",
-    "Navigate to the file below" : "Zur unteren Datei navigieren",
-    "Navigate to the file on the left (in grid mode)" : "Zur Datei links navigieren (In der Kachelansicht)",
-    "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (In der Kachelansicht)",
+    "Go to parent folder" : "Zum übergeordneten Ordner wechseln",
+    "Go to file above" : "Zur Datei darüber wechseln",
+    "Go to file below" : "Zur Datei darunter wechseln",
+    "Go left in grid" : "Im Raster nach links gehen",
+    "Go right in grid" : "Im Raster nach rechts gehen",
     "View" : "Ansicht",
-    "Toggle the grid view" : "Kachelansicht umschalten",
-    "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen",
+    "Toggle grid view" : "Kachelansicht umschalten",
+    "Open file sidebar" : "Datei-Seitenleiste öffnen",
     "Show those shortcuts" : "Diese Tastaturkürzel anzeigen",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
+    "Failed to toggle Windows filename support" : "Windows Dateinamenunterstützung konnte nicht umgeschaltet werden",
+    "Files compatibility" : "Dateikompatibilität",
+    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "You" : "Sie",
     "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
+    "Unable to change the favorite state of the file" : "Der Favoriten-Status der Datei kann nicht geändert werden",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
     "Owner" : "Besitzer",
     "Remove from favorites" : "Von Favoriten entfernen",
@@ -236,14 +278,13 @@ OC.L10N.register(
     "All files failed to be converted" : "Alle Dateien konnten nicht konvertiert werden",
     "One file could not be converted: {message}" : "Eine Datei konnte nicht konvertiert werden: {message}",
     "_One file could not be converted_::_%n files could not be converted_" : ["Eine Datei konnte nicht konvertiert werden","%n Dateien konnten nicht konvertiert werden"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Eine Datei erfolgreich konvertiert","%n Dateien erfolgreich konvertiert"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Eine Datei konvertiert","%n Dateien konvertiert"],
     "Files successfully converted" : "Dateien konvertiert",
     "Failed to convert files" : "Dateien konnten nicht konvertiert werden",
     "Converting file …" : "Datei wird konvertiert …",
-    "File successfully converted" : "Datei erfolgreich konvertiert",
+    "File successfully converted" : "Datei konvertiert",
     "Failed to convert file: {message}" : "Fehler beim Konvertieren der Datei: {message}",
     "Failed to convert file" : "Datei konnte nicht konvertiert werden",
-    "Deletion cancelled" : "Löschen abgebrochen",
     "Leave this share" : "Diese Freigabe verlassen",
     "Leave these shares" : "Diese Freigaben verlassen",
     "Disconnect storage" : "Speicher trennen",
@@ -254,39 +295,38 @@ OC.L10N.register(
     "Delete files" : "Dateien löschen",
     "Delete folder" : "Ordner löschen",
     "Delete folders" : "Ordner löschen",
-    "Delete" : "Löschen",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sie sind dabei, {count} Element endgültig zu löschen","Sie sind dabei, {count} Elemente endgültig zu löschen"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Sie sind dabei, {count} Elemente zu löschen"],
     "Confirm deletion" : "Löschen bestätigen",
     "Cancel" : "Abbrechen",
+    "Download" : "Herunterladen",
+    "The requested file is not available." : "Die angeforderte Datei ist nicht verfügbar.",
+    "The requested files are not available." : "Die angeforderten Dateien sind nicht verfügbar.",
     "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
+    "Destination is not a folder" : "Ziel ist kein Ordner",
+    "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden",
     "(copy)" : "(Kopie)",
     "(copy %n)" : "(Kopie %n)",
-    "Move cancelled" : "Verschieben abgebrochen",
     "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
     "The files are locked" : "Die Dateien sind gesperrt",
     "The file does not exist anymore" : "Diese Datei existiert nicht mehr",
     "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
-    "Copy" : "Kopieren",
     "Move to {target}" : "Nach {target} verschieben",
     "Move" : "Verschieben",
     "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
     "Move or copy" : "Verschieben oder kopieren",
-    "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
-    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
     "Open in Files" : "In Dateien öffnen",
+    "Open locally" : "Lokal öffnen",
+    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
     "Open file locally" : "Datei lokal öffnen",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf Ihrem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfen Sie, ob Sie die Desktop-App installiert haben.",
     "Retry and close" : "Erneut versuchen und schließen",
     "Open online" : "Online öffnen",
-    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
-    "Open locally" : "Lokal öffnen",
-    "Rename" : "Umbenennen",
-    "Open details" : "Details öffnen",
+    "Details" : "Details",
     "View in folder" : "In Ordner anzeigen",
     "Today" : "Heute",
     "Last 7 days" : "Die letzten 7 Tage",
@@ -299,15 +339,15 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Ordner",
     "Audio" : "Audio",
-    "Photos and images" : "Fotos und Bilder",
+    "Images" : "Bilder",
     "Videos" : "Videos",
-    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
     "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
     "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
     "Create templates folder" : "Vorlagenordner erstellen",
     "Templates" : "Vorlagen",
     "New template folder" : "Neuer Vorlagenordner",
     "In folder" : "Im Ordner",
+    "Search in all files" : "In allen Dateien suchen",
     "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
     "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ihr Browser unterstützt die Dateisystem-API nicht. Verzeichnisse werden nicht hochgeladen",
@@ -322,16 +362,16 @@ OC.L10N.register(
     "Files moved successfully" : "Dateien verschoben",
     "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
     "Upload cancelled" : "Hochladen abgebrochen",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte einen anderen Namen wählen.",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden",
     "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Protokolldateien oder kontaktieren Sie die Administration",
+    "This folder is unavailable, please try again later or contact the administration" : "Dieser Ordner ist nicht verfügbar. Bitte später erneut versuchen oder an die Administration wenden",
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Unexpected error: {error}" : "Unerwarteter Fehler: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
-    "_(%n hidden)_::_ (%n hidden)_" : ["(%n versteckt)","(%n versteckt)"],
+    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
+    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
+    "_%n hidden_::_%n hidden_" : ["%n versteckt","%n versteckt"],
     "Filename must not be empty." : "Dateiname darf nicht leer sein.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" ist innerhalb eines Dateinamens nicht zulässig.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ist ein reservierter Name und für Dateinamen nicht zulässig.",
@@ -340,10 +380,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Liste der favorisierten Ordner und Dateien.",
     "No favorites yet" : "Noch keine Favoriten vorhanden",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
-    "All files" : "Alle Dateien",
     "List of your files and folders." : "Liste Ihrer Dateien und Ordner.",
-    "All folders" : "Alle Ordner",
-    "Personal files" : "Persönliche Dateien",
     "List of your files and folders that are not shared." : "Liste Ihrer Dateien und Ordner, die nicht geteilt wurden.",
     "No personal files found" : "Keine persönlichen Dateien gefunden",
     "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
@@ -351,12 +388,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner.",
     "No recently modified files" : "Keine kürzlich geänderten Dateien",
     "Files and folders you recently modified will show up here." : "Die von Ihnen kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
+    "Search" : "Suche",
+    "Search results within your files." : "Suchergebnisse innerhalb Ihrer Dateien.",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
     "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
     "File could not be found" : "Datei konnte nicht gefunden werden",
-    "Download" : "Herunterladen",
     "Show list view" : "Listenansicht anzeigen",
     "Show grid view" : "Kachelansicht anzeigen",
     "Close" : "Schließen",
@@ -381,12 +419,12 @@ OC.L10N.register(
     "Edit locally" : "Lokal bearbeiten",
     "Open" : "Öffnen",
     "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
-    "Details" : "Details",
     "Please select tag(s) to add to the selection" : "Bitte wählen Sie das/die Schlagwort(e) aus, das/die Sie zur Auswahl hinzufügen möchten",
     "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
     "Select directory \"{dirName}\"" : "Ordner \"{dirName}\" auswählen",
     "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
     "Unable to determine date" : "Datum konnte nicht ermittelt werden",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte überprüfen Sie die Protokolldateien oder kontaktieren Sie die Administration",
     "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
     "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
     "copy" : "Kopie",
@@ -395,9 +433,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
     "{newName} already exists" : "{newName} existiert bereits",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{targetName}\" wird bereits im Ordner \"{dir}\" benutzt. Bitte wählen Sie einen anderen Namen.",
-    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
     "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert",
     "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden, da dieser bereits existiert",
@@ -405,8 +440,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Geben Sie mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen",
-    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
-    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
     "{dirs} and {files}" : "{dirs} und {files}",
     "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
     "You do not have permission to upload or create files here" : "Sie haben keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
@@ -414,7 +447,7 @@ OC.L10N.register(
     "New" : "Neu",
     "New file/folder menu" : "Menü für neue Datei/Ordner",
     "Select file range" : "Dateibereich auswählen",
-    "{used}%" : "{used}%",
+    "{used}%" : "{used} %",
     "{used} used" : "{used} verwendet",
     "\"{name}\" is an invalid file name." : "\"{name}\" ist kein gültiger Dateiname.",
     "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
@@ -432,30 +465,63 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
     "Path" : "Pfad",
     "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
-    "Favorited" : "Favorisiert",
+    "Favored" : "Favorisiert",
+    "Favor" : "Favorisieren",
     "Copy direct link (only works for people who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei bzw. den Ordner haben)",
     "Upload file" : "Datei hochladen",
-    "Not favorited" : "Nicht favorisiert",
+    "Not favored" : "Nicht favorisiert",
     "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Schlagworte aufgetreten",
-    "You don't have permission to upload or create files here." : "Keine Berechtigung, hier Dateien hochzuladen oder zu erstellen.",
-    "Storage informations" : "Speicherinformationen",
-    "Choose file" : "Datei auswählen",
-    "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
-    "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
-    "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei kann nicht geändert werden",
-    "Edit file locally" : "Datei lokal bearbeiten",
-    "Edit online" : "Online bearbeiten",
-    "Create new templates folder" : "Neuen Vorlagenordner erstellen",
-    "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien.",
+    "Upload (max. %s)" : "Hochladen (max. %s)",
+    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" ausgeführt",
+    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
+    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" ausgeführt",
+    "Submitting fields…" : "Felder werden übermittelt…",
+    "Filter filenames…" : "Dateinamen filtern…",
+    "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
+    "Enable the grid view" : "Kachelansicht aktivieren",
+    "Enable folder tree" : "Ordnerstruktur aktivieren",
+    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "Use this address to access your Files via WebDAV" : "Benutzen Sie diese Adresse, um via WebDAV auf Ihre Dateien zuzugreifen.",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn Sie 2FA aktiviert haben, müssen Sie ein neues App-Passwort erstellen und verwenden, indem Sie hier klicken.",
+    "Deletion cancelled" : "Löschen abgebrochen",
+    "Move cancelled" : "Verschieben abgebrochen",
+    "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
+    "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
+    "Open details" : "Details öffnen",
+    "Photos and images" : "Fotos und Bilder",
+    "New folder creation cancelled" : "Erstellung des neuen Ordners abgebrochen",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} Datei und 1 Ordner","{fileCount} Dateien und 1 Ordner"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} Dateien und {folderCount} Ordner",
+    "All folders" : "Alle Ordner",
     "Personal Files" : "Persönliche Dateien",
     "Text file" : "Textdatei",
     "New text file.txt" : "Neue Textdatei file.txt",
-    "Favored" : "Favorisiert",
-    "Favor" : "Favorisieren",
-    "Not favored" : "Nicht favorisiert",
-    "Submitting fields…" : "Felder werden übermittelt…",
-    "Filter filenames…" : "Dateinamen filtern…",
-    "{count} files could not be converted" : "{count} Dateien konnten nicht konvertiert werden",
-    "{count} files successfully converted" : "{count} Dateien erfolgreich konvertiert"
+    "%1$s (renamed)" : "%1$s (umbenannt)",
+    "renamed file" : "Umbenannte Datei",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Nach Aktivierung der Windows-kompatiblen Dateinamen können vorhandene Dateien nicht mehr geändert, aber von ihrem Besitzer in gültige neue Namen umbenannt werden.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Nach dem Aktivieren dieser Einstellung ist es auch möglich, Dateien automatisch zu migrieren. Weitere Informationen finden sich in der Dokumentation zum Befehl \"occ“.",
+    "Filter file names …" : "Dateinamen filtern …",
+    "Prevent warning dialogs from open or reenable them." : "Öffnen von Warndialogen verhindern oder diese erneut aktivieren.",
+    "Show a warning dialog when changing a file extension." : "Beim Ändern einer Dateierweiterung einen Warndialog anzeigen.",
+    "Speed up your Files experience with these quick shortcuts." : "Arbeiten Sie schneller mit Dateien mit diesen Schnellzugriffen.",
+    "Open the actions menu for a file" : "Aktionsmenü für eine Datei öffnen",
+    "Rename a file" : "Eine Datei umbenennen",
+    "Delete a file" : "Eine Datei löschen",
+    "Favorite or remove a file from favorites" : "Datei favorisieren oder aus den Favoriten entfernen",
+    "Manage tags for a file" : "Schlagworte für eine Datei verwalten",
+    "Deselect all files" : "Auswahl aller Dateien aufheben",
+    "Select or deselect a file" : "Auswählen oder Auswahl einer Datei aufheben",
+    "Select a range of files" : "Einen Bereich von Dateien auswählen",
+    "Navigate to the parent folder" : "Zum übergeordneten Ordner navigieren",
+    "Navigate to the file above" : "Zur obigen Datei navigieren",
+    "Navigate to the file below" : "Zur unteren Datei navigieren",
+    "Navigate to the file on the left (in grid mode)" : "Zur Datei links navigieren (in der Kachelansicht)",
+    "Navigate to the file on the right (in grid mode)" : "Zur Datei rechts navigieren (in der Kachelansicht)",
+    "Toggle the grid view" : "Kachelansicht umschalten",
+    "Open the sidebar for a file" : "Seitenleiste für eine Datei öffnen"
 },
 "nplurals=2; plural=(n != 1);");
