@@ -51,6 +51,10 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Níl cead agat comhad a chruthú ag an suíomh sonraithe",
     "The file could not be converted." : "Níorbh fhéidir an comhad a thiontú.",
     "Could not get relative path to converted file" : "Níorbh fhéidir cosán coibhneasta a fháil chuig an gcomhad tiontaithe",
+    "Limit must be a positive integer." : "Ní mór don teorainn a bheith ina slánuimhir dhearfach.",
+    "The replacement character may only be a single character." : "Ní fhéadfaidh ach carachtar amháin a bheith sa charachtar athsholáthair.",
+    "Filename sanitization already started." : "Tá glanadh ainm comhaid tosaithe cheana féin.",
+    "No filename sanitization in progress." : "Níl aon ghlanadh ainm comhaid ar siúl.",
     "Favorite files" : "Comhaid is fearr leat",
     "No favorites" : "Gan aon cheanáin",
     "More favorites" : "Gan aon cheanáin",
@@ -68,12 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Tá aistriú úinéireachta {path} ó {user} críochnaithe.",
     "in %s" : "i %s",
     "Transferred from %1$s on %2$s" : "Aistrithe ó %1$s ar %2$s",
-    "Files compatibility" : "Comhoiriúnacht comhaid",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ceadaigh comhaid a shrianadh lena chinntiú gur féidir comhaid a shioncronú le gach cliant. De réir réamhshocraithe ceadaítear gach comhadainm atá bailí ar POSIX (m.sh. Linux nó macOS).",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Is féidir comhaid a aistriú go huathoibríoch freisin tar éis an socrú seo a chumasú, féach ar an doiciméadú faoin ordú occ.",
-    "Enforce Windows compatibility" : "Comhoiriúnacht Windows a fhorfheidhmiú",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cuirfidh sé seo bac ar ainmneacha comhaid nach bhfuil bailí ar chórais Windows, ar nós ainmneacha forchoimeádta nó carachtair speisialta a úsáid. Ach ní chuirfidh sé seo i bhfeidhm comhoiriúnacht íogaireacht cáis.",
     "File Management" : "Bainistíocht Comhad",
     "Home" : "Baile",
     "Target folder does not exist any more" : "Níl an spriocfhillteán ann a thuilleadh",
@@ -115,9 +113,9 @@ OC.L10N.register(
     "Name" : "Ainm",
     "File type" : "Cineál comhaid",
     "Size" : "Méid",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" theip ar roinnt gnéithe",
-    "\"{displayName}\" batch action executed successfully" : "D'éirigh le beart baisce \"{displayName}\" a rith",
-    "\"{displayName}\" action failed" : "Theip ar an ngníomh \"{displayName}\".",
+    "{displayName}: failed on some elements" : "{displayName}: theip ar roinnt eilimintí",
+    "{displayName}: done" : "{displayName}: déanta",
+    "{displayName}: failed" : "{displayName}: theip air",
     "Actions" : "Gníomhartha",
     "(selected)" : "(roghnaithe)",
     "List of files and folders." : "Liosta de chomhaid agus fillteáin.",
@@ -126,10 +124,10 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Níl an liosta seo le fáil go hiomlán ar chúiseanna feidhmíochta. Déanfar na comhaid a rindreáil agus tú ag dul tríd an liosta.",
     "File not found" : "Comhad gan aimsiú",
     "_{count} selected_::_{count} selected_" : ["{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe","{count} roghnaithe"],
-    "Search globally by filename …" : "Cuardaigh go domhanda de réir ainm comhaid …",
-    "Search here by filename …" : "Cuardaigh anseo de réir ainm comhaid …",
+    "Search everywhere …" : "Cuardaigh i ngach áit…",
+    "Search here …" : "Cuardaigh anseo…",
     "Search scope options" : "Roghanna raon feidhme cuardaigh",
-    "Search globally" : "Cuardaigh go domhanda",
+    "Search here" : "Cuardaigh anseo",
     "{usedQuotaByte} used" : "{usedQuotaByte} úsáidte",
     "{used} of {quota} used" : "{used} de {quota} in úsáid",
     "{relative}% used" : "{relative}% in úsáid",
@@ -141,6 +139,25 @@ OC.L10N.register(
     "Create new folder" : "Cruthaigh fillteán nua",
     "This name is already in use." : "Tá an t-ainm seo in úsáid cheana féin.",
     "Create" : "Cruthaigh",
+    "Files starting with a dot are hidden by default" : "Bíonn comhaid a thosaíonn le ponc i bhfolach de réir réamhshocraithe",
+    "Failed to start filename sanitization." : "Theip ar shláintiú ainm comhaid a thosú.",
+    "Failed to refresh filename sanitization status." : "Theip ar stádas sláintíochta ainm comhaid a athnuachan.",
+    "Filename sanitization in progress." : "Glanadh ainm comhaid ar siúl.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Tá {processedUsers} de {totalUsers} cuntas próiseáilte cheana féin faoi láthair.",
+    "Preparing …" : "Ag ullmhú …",
+    "Refresh" : "Athnuaigh",
+    "All files have been santized for Windows filename support." : "Tá gach comhad glanta chun tacú le hainmneacha comhad Windows.",
+    "Some files could not be sanitized, please check your logs." : "Níorbh fhéidir roinnt comhad a shláintiú, seiceáil do logaí le do thoil.",
+    "Sanitization errors" : "Earráidí sláintíochta",
+    "Not sanitized filenames" : "Ainmneacha comhad gan sláintíocht",
+    "Windows filename support has been enabled." : "Tá tacaíocht d’ainmneacha comhad Windows cumasaithe.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Cé go gcuireann sé seo bac ar úsáideoirí comhaid nua a chruthú le hainmneacha comhad nach dtacaítear leo, níl ainm nua tugtha ar chomhaid atá ann cheana féin agus dá bhrí sin d’fhéadfadh siad briseadh i sioncrónú ar Windows fós.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Is féidir leat athainmniú comhad a bhfuil ainmneacha comhad neamhbhailí orthu a spreagadh, déanfar é seo sa chúlra agus d’fhéadfadh sé tamall a thógáil.",
+    "Please note that this may cause high workload on the sync clients." : "Tabhair faoi deara go bhféadfadh sé seo ualach oibre ard a chur ar na cliaint sioncrónaithe.",
+    "Limit" : "Teorainn",
+    "This allows to configure how many users should be processed in one background job run." : "Ligeann sé seo duit a chumrú cé mhéad úsáideoir ba chóir a phróiseáil in aon rith poist chúlra amháin.",
+    "Sanitize filenames" : "Glanadh ainmneacha comhad",
+    "(starting)" : "(ag tosú)",
     "Fill template fields" : "Líon réimsí teimpléid",
     "Submitting fields …" : "Réimsí á gcur isteach…",
     "Submit" : "Cuir isteach",
@@ -178,7 +195,6 @@ OC.L10N.register(
     "Error during upload: {message}" : "Earráid le linn uaslódála: {message}",
     "Error during upload, status code {status}" : "Earráid le linn uaslódála, cód stádais {status}",
     "Unknown error during upload" : "Earráid anaithnid le linn uaslódála",
-    "\"{displayName}\" action executed successfully" : "Cuireadh an gníomh \"{displayName}\" i gcrích go rathúil",
     "Loading current folder" : "An fillteán reatha á lódáil",
     "Retry" : "Bain triail eile as",
     "No files in here" : "Níl aon chomhaid istigh anseo",
@@ -193,47 +209,55 @@ OC.L10N.register(
     "No search results for “{query}”" : "Gan aon torthaí cuardaigh le haghaidh ”{query}”",
     "Search for files" : "Cuardaigh comhaid",
     "Clipboard is not available" : "Níl fáil ar an ngearrthaisce",
-    "WebDAV URL copied to clipboard" : "URL WebDAV cóipeáilte chuig an ngearrthaisce",
+    "WebDAV URL copied" : "URL WebDAV cóipeáilte",
+    "General" : "Ginearálta",
     "Default view" : "Amharc réamhshocraithe",
     "All files" : "Gach comhad",
     "Personal files" : "Comhaid phearsanta",
     "Sort favorites first" : "Sórtáil na cinn is ansa leat ar dtús",
     "Sort folders before files" : "Sórtáil fillteáin roimh chomhaid",
+    "Folder tree" : "Crann fillteán",
+    "Appearance" : "Dealramh",
     "Show hidden files" : "Taispeáin comhaid i bhfolach",
     "Show file type column" : "Taispeáin colún cineál comhaid",
+    "Show file extensions" : "Taispeáin síntí comhaid",
     "Crop image previews" : "Réamhamhairc íomhá barr",
-    "Enable folder tree" : "Cumasaigh crann fillteáin",
     "Additional settings" : "Socruithe breise",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "URL WebDAV",
-    "Copy to clipboard" : "Cóipeáil chuig an ngearrthaisce",
-    "Use this address to access your Files via WebDAV" : "Úsáid an seoladh seo chun do Chomhaid a rochtain trí WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Má tá 2FA cumasaithe agat, ní mór duit pasfhocal aip nua a chruthú agus a úsáid trí chliceáil anseo.",
+    "Copy" : "Cóipeáil",
+    "How to access files using WebDAV" : "Conas rochtain a fháil ar chomhaid ag baint úsáide as WebDAV",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Tá Fíordheimhniú Dhá Fhachtóir cumasaithe do do chuntas, agus dá bhrí sin ní mór duit pasfhocal aipe a úsáid chun cliant seachtrach WebDAV a nascadh.",
     "Warnings" : "Rabhaidh",
-    "Prevent warning dialogs from open or reenable them." : "Cosc a chur ar dialóga rabhaidh ó iad a oscailt nó iad a athchumasú.",
-    "Show a warning dialog when changing a file extension." : "Taispeáin dialóg rabhaidh nuair a athraítear síneadh comhad.",
+    "Warn before changing a file extension" : "Tabhair rabhadh sula n-athraítear síneadh comhaid",
+    "Warn before deleting files" : "Rabhadh roimh scriosadh comhad",
     "Keyboard shortcuts" : "Aicearraí méarchláir",
-    "Speed up your Files experience with these quick shortcuts." : "Déan do thaithí Comhaid a bhrostú leis na haicearraí tapa seo.",
-    "Open the actions menu for a file" : "Oscail an roghchlár gníomhartha le haghaidh comhad",
-    "Rename a file" : "Athainmnigh comhad",
-    "Delete a file" : "Scrios comhad",
-    "Favorite or remove a file from favorites" : "Is ansa leat nó bain comhad ó cheanáin",
-    "Manage tags for a file" : "Bainistigh clibeanna le haghaidh comhaid",
+    "File actions" : "Gníomhartha comhaid",
+    "Rename" : "Athainmnigh",
+    "Delete" : "Scrios",
+    "Add or remove favorite" : "Cuir leis nó bain an rogha is fearr leat",
+    "Manage tags" : "Bainistigh clibeanna",
     "Selection" : "Roghnú",
     "Select all files" : "Roghnaigh gach comhad",
-    "Deselect all files" : "Díroghnaigh gach comhad",
-    "Select or deselect a file" : "Roghnaigh nó díroghnaigh comhad",
-    "Select a range of files" : "Roghnaigh raon comhad",
+    "Deselect all" : "Díroghnaigh go léir",
+    "Select or deselect" : "Roghnaigh nó díroghnaigh",
+    "Select a range" : "Roghnaigh raon",
     "Navigation" : "Loingseoireacht",
-    "Navigate to the parent folder" : "Déan nascleanúint go dtí an fillteán tuismitheora",
-    "Navigate to the file above" : "Déan nascleanúint go dtí an comhad thuas",
-    "Navigate to the file below" : "Déan nascleanúint go dtí an comhad thíos",
-    "Navigate to the file on the left (in grid mode)" : "Déan nascleanúint go dtí an comhad ar chlé (i mód greille)",
-    "Navigate to the file on the right (in grid mode)" : "Déan nascleanúint go dtí an comhad ar dheis (i mód greille)",
+    "Go to parent folder" : "Téigh go dtí an fillteán tuismitheora",
+    "Go to file above" : "Téigh go dtí an comhad thuas",
+    "Go to file below" : "Téigh go dtí an comhad thíos",
+    "Go left in grid" : "Téigh ar chlé sa ghreille",
+    "Go right in grid" : "Téigh ar dheis sa ghreille",
     "View" : "Amharc",
-    "Toggle the grid view" : "Scoránaigh an radharc greille",
-    "Open the sidebar for a file" : "Oscail an barra taoibh le haghaidh comhad",
+    "Toggle grid view" : "Scoránaigh amharc greille",
+    "Open file sidebar" : "Oscail barra taoibh an chomhaid",
     "Show those shortcuts" : "Taispeáin na haicearraí sin",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ceadaigh comhaid a shrianadh lena chinntiú gur féidir comhaid a shioncronú le gach cliant. De réir réamhshocraithe ceadaítear gach comhadainm atá bailí ar POSIX (m.sh. Linux nó macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
+    "Failed to toggle Windows filename support" : "Theip ar thacaíocht d'ainmneacha comhaid Windows a athrú",
+    "Files compatibility" : "Comhoiriúnacht comhaid",
+    "Enforce Windows compatibility" : "Comhoiriúnacht Windows a fhorfheidhmiú",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Cuirfidh sé seo bac ar ainmneacha comhaid nach bhfuil bailí ar chórais Windows, ar nós ainmneacha forchoimeádta nó carachtair speisialta a úsáid. Ach ní chuirfidh sé seo i bhfeidhm comhoiriúnacht íogaireacht cáis.",
     "You" : "tú",
     "Shared multiple times with different people" : "Roinnte go minic le daoine éagsúla",
     "Unable to change the favorite state of the file" : "Ní féidir staid an chomhaid is fearr leat a athrú",
@@ -261,7 +285,6 @@ OC.L10N.register(
     "File successfully converted" : "D'éirigh leis an gcomhad a thiontú",
     "Failed to convert file: {message}" : "Theip ar an gcomhad a thiontú: {message}",
     "Failed to convert file" : "Theip ar thiontú an chomhaid",
-    "Deletion cancelled" : "Scriosadh cealaithe",
     "Leave this share" : "Fág an sciar seo",
     "Leave these shares" : "Fág na scaireanna seo",
     "Disconnect storage" : "Déan stóráil a dhícheangal",
@@ -272,12 +295,13 @@ OC.L10N.register(
     "Delete files" : "Scrios comhaid",
     "Delete folder" : "Scrios fillteán",
     "Delete folders" : "Scrios fillteáin",
-    "Delete" : "Scrios",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan","Tá tú ar tí {count} mír a scriosadh go buan"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh","Tá tú ar tí {count} mír a scriosadh"],
     "Confirm deletion" : "Deimhnigh scriosadh",
     "Cancel" : "Cealaigh",
     "Download" : "Íoslódáil",
+    "The requested file is not available." : "Níl an comhad iarrtha ar fáil.",
+    "The requested files are not available." : "Níl na comhaid iarrtha ar fáil.",
     "Moving \"{source}\" to \"{destination}\" …" : "Ag bogadh \"{source}\" go \"{destination}\" ...",
     "Copying \"{source}\" to \"{destination}\" …" : "“{source}” á chóipeáil go “{destination}”…",
     "Destination is not a folder" : "Ní fillteán é ceann scríbe",
@@ -285,19 +309,15 @@ OC.L10N.register(
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ní féidir leat comhad/fillteán a bhogadh isteach ann féin nó isteach i bhfofhillteán de féin",
     "(copy)" : "(cóip)",
     "(copy %n)" : "(cóip %n)",
-    "Move cancelled" : "Bogadh ar ceal",
     "A file or folder with that name already exists in this folder" : "Tá comhad nó fillteán leis an ainm sin san fhillteán seo cheana",
     "The files are locked" : "Tá na comhaid faoi ghlas",
     "The file does not exist anymore" : "Níl an comhad ann a thuilleadh",
     "Choose destination" : "Roghnaigh ceann scríbe",
     "Copy to {target}" : "Cóipeáil chuig {target}",
-    "Copy" : "Cóipeáil",
     "Move to {target}" : "Bog go {target}",
     "Move" : "Bog",
     "Move or copy operation failed" : "Theip ar an oibríocht a bhogadh nó a chóipeáil",
     "Move or copy" : "Bog nó cóipeáil",
-    "Cancelled move or copy of \"{filename}\"." : "Cealaíodh bogadh nó cóip de \"{filename}\".",
-    "Cancelled move or copy operation" : "Oibríocht aistrithe nó cóipeála curtha ar ceal",
     "Open folder {displayName}" : "Oscail fillteán {displayName}",
     "Open in Files" : "Oscail i Comhaid",
     "Open locally" : "Oscail go háitiúil",
@@ -306,8 +326,7 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Ba cheart an comhad a oscailt anois ar do ghléas. Mura ndéanann sé, seiceáil le do thoil go bhfuil an aip deisce suiteáilte agat.",
     "Retry and close" : "Bain triail eile as agus dún",
     "Open online" : "Oscail ar líne",
-    "Rename" : "Athainmnigh",
-    "Open details" : "Sonraí oscailte",
+    "Details" : "Sonraí",
     "View in folder" : "Amharc san fhillteán",
     "Today" : "Inniu",
     "Last 7 days" : "7 lá seo caite",
@@ -320,15 +339,15 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Fillteáin",
     "Audio" : "Fuaime",
-    "Photos and images" : "Grianghraif agus íomhánna",
+    "Images" : "Íomhánna",
     "Videos" : "Físeáin",
-    "New folder creation cancelled" : "Cruthú fillteán nua curtha ar ceal",
     "Created new folder \"{name}\"" : "Cruthaíodh fillteán nua \"{name}\"",
     "Unable to initialize the templates directory" : "Ní féidir eolaire na dteimpléad a thúsú",
     "Create templates folder" : "Cruthaigh fillteán teimpléid",
     "Templates" : "Teimpléid",
     "New template folder" : "Fillteán teimpléid nua",
     "In folder" : "I bhfillteán",
+    "Search in all files" : "Cuardaigh i ngach comhad",
     "Search in folder: {folder}" : "Cuardaigh i bhfillteán: {folder}",
     "One of the dropped files could not be processed" : "Níorbh fhéidir ceann de na comhaid a thit a phróiseáil",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ní thacaíonn do bhrabhsálaí leis an API System File. Ní dhéanfar eolaire a uaslódáil",
@@ -347,7 +366,7 @@ OC.L10N.register(
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tá an t-ainm \"{newName}\" in úsáid cheana féin san fhillteán \"{dir}\". Roghnaigh ainm eile le do thoil.",
     "Could not rename \"{oldName}\"" : "Níorbh fhéidir \"{oldName}\" a athainmniú",
     "This operation is forbidden" : "Tá an oibríocht seo toirmiscthe",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Níl an t-eolaire seo ar fáil, seiceáil na logaí nó déan teagmháil leis an riarthóir le do thoil",
+    "This folder is unavailable, please try again later or contact the administration" : "Níl an fillteán seo ar fáil, déan iarracht arís ar ball nó déan teagmháil leis an riarachán",
     "Storage is temporarily not available" : "Níl stóráil ar fáil go sealadach",
     "Unexpected error: {error}" : "Earráid gan choinne: {error}",
     "_%n file_::_%n files_" : ["%n comhad","%n comhaid","%n comhaid","%n comhaid","%n comhaid"],
@@ -362,7 +381,6 @@ OC.L10N.register(
     "No favorites yet" : "Níl aon cheanáin go fóill",
     "Files and folders you mark as favorite will show up here" : "Taispeánfar comhaid agus fillteáin a mharcálann tú mar is fearr leat anseo",
     "List of your files and folders." : "Liosta de do chuid comhad agus fillteáin.",
-    "All folders" : "Gach fillteáin",
     "List of your files and folders that are not shared." : "Liosta de do chuid comhad agus fillteáin nach bhfuil roinnte.",
     "No personal files found" : "Níor aimsíodh aon chomhaid phearsanta",
     "Files that are not shared will show up here." : "Taispeánfar comhaid nach bhfuil roinnte anseo.",
@@ -401,12 +419,12 @@ OC.L10N.register(
     "Edit locally" : "Cuir in eagar go háitiúil",
     "Open" : "Oscail",
     "Could not load info for file \"{file}\"" : "Níorbh fhéidir faisnéis don chomhad \"{file}\" a lódáil",
-    "Details" : "Sonraí",
     "Please select tag(s) to add to the selection" : "Roghnaigh clib(í) le cur leis an rogha le do thoil",
     "Apply tag(s) to selection" : "Cuir clib(í) i bhfeidhm ar an roghnúchán",
     "Select directory \"{dirName}\"" : "Roghnaigh eolaire \"{dirName}\"",
     "Select file \"{fileName}\"" : "Roghnaigh comhad \"{fileName}\"",
     "Unable to determine date" : "Ní féidir an dáta a chinneadh",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Níl an t-eolaire seo ar fáil, seiceáil na logaí nó déan teagmháil leis an riarthóir le do thoil",
     "Could not move \"{file}\", target exists" : "Níorbh fhéidir \"{file}\" a bhogadh, tá an sprioc ann",
     "Could not move \"{file}\"" : "Níorbh fhéidir \"{file}\" a bhogadh",
     "copy" : "cóip",
@@ -454,20 +472,56 @@ OC.L10N.register(
     "Not favored" : "Ní bail ar fónamh orthu",
     "An error occurred while trying to update the tags" : "Tharla earráid agus iarracht á déanamh na clibeanna a nuashonrú",
     "Upload (max. %s)" : "Uaslódáil (%s ar a mhéad)",
+    "\"{displayName}\" action executed successfully" : "Cuireadh an gníomh \"{displayName}\" i gcrích go rathúil",
+    "\"{displayName}\" action failed" : "Theip ar an ngníomh \"{displayName}\".",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" theip ar roinnt gnéithe",
+    "\"{displayName}\" batch action executed successfully" : "D'éirigh le beart baisce \"{displayName}\" a rith",
     "Submitting fields…" : "Réimsí á gcur isteach…",
     "Filter filenames…" : "Scag ainmneacha comhaid…",
+    "WebDAV URL copied to clipboard" : "URL WebDAV cóipeáilte chuig an ngearrthaisce",
     "Enable the grid view" : "Cumasaigh an radharc greille",
+    "Enable folder tree" : "Cumasaigh crann fillteáin",
+    "Copy to clipboard" : "Cóipeáil chuig an ngearrthaisce",
+    "Use this address to access your Files via WebDAV" : "Úsáid an seoladh seo chun do Chomhaid a rochtain trí WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Má tá 2FA cumasaithe agat, ní mór duit pasfhocal aip nua a chruthú agus a úsáid trí chliceáil anseo.",
+    "Deletion cancelled" : "Scriosadh cealaithe",
+    "Move cancelled" : "Bogadh ar ceal",
+    "Cancelled move or copy of \"{filename}\"." : "Cealaíodh bogadh nó cóip de \"{filename}\".",
+    "Cancelled move or copy operation" : "Oibríocht aistrithe nó cóipeála curtha ar ceal",
+    "Open details" : "Sonraí oscailte",
+    "Photos and images" : "Grianghraif agus íomhánna",
+    "New folder creation cancelled" : "Cruthú fillteán nua curtha ar ceal",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} fillteán","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin","{folderCount} fillteáin"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} comhad","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid","{fileCount} comhaid"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 chomhad agus {folderCount} fillteán","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin","1 chomhad agus {folderCount} fillteáin"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} comhad agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán","{fileCount} comhaid agus 1 fillteán"],
     "{fileCount} files and {folderCount} folders" : "comhaid {fileCount} agus fillteáin {folderCount}",
+    "All folders" : "Gach fillteáin",
     "Personal Files" : "Comhaid Phearsanta",
     "Text file" : "Comhad téacs",
     "New text file.txt" : "Comhad téacs nua.txt",
     "%1$s (renamed)" : "%1$s (athainmnithe)",
     "renamed file" : "comhad athainmnithe",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Tar éis na hainmneacha comhad atá comhoiriúnach le Windows a chumasú, ní féidir comhaid atá ann cheana a mhodhnú a thuilleadh ach is féidir lena n-úinéir iad a athainmniú go hainmneacha nua bailí.",
-    "Filter file names …" : "Scag ainmneacha na gcomhad…"
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Is féidir comhaid a aistriú go huathoibríoch freisin tar éis an socrú seo a chumasú, féach ar an doiciméadú faoin ordú occ.",
+    "Filter file names …" : "Scag ainmneacha na gcomhad…",
+    "Prevent warning dialogs from open or reenable them." : "Cosc a chur ar dialóga rabhaidh ó iad a oscailt nó iad a athchumasú.",
+    "Show a warning dialog when changing a file extension." : "Taispeáin dialóg rabhaidh nuair a athraítear síneadh comhad.",
+    "Speed up your Files experience with these quick shortcuts." : "Déan do thaithí Comhaid a bhrostú leis na haicearraí tapa seo.",
+    "Open the actions menu for a file" : "Oscail an roghchlár gníomhartha le haghaidh comhad",
+    "Rename a file" : "Athainmnigh comhad",
+    "Delete a file" : "Scrios comhad",
+    "Favorite or remove a file from favorites" : "Is ansa leat nó bain comhad ó cheanáin",
+    "Manage tags for a file" : "Bainistigh clibeanna le haghaidh comhaid",
+    "Deselect all files" : "Díroghnaigh gach comhad",
+    "Select or deselect a file" : "Roghnaigh nó díroghnaigh comhad",
+    "Select a range of files" : "Roghnaigh raon comhad",
+    "Navigate to the parent folder" : "Déan nascleanúint go dtí an fillteán tuismitheora",
+    "Navigate to the file above" : "Déan nascleanúint go dtí an comhad thuas",
+    "Navigate to the file below" : "Déan nascleanúint go dtí an comhad thíos",
+    "Navigate to the file on the left (in grid mode)" : "Déan nascleanúint go dtí an comhad ar chlé (i mód greille)",
+    "Navigate to the file on the right (in grid mode)" : "Déan nascleanúint go dtí an comhad ar dheis (i mód greille)",
+    "Toggle the grid view" : "Scoránaigh an radharc greille",
+    "Open the sidebar for a file" : "Oscail an barra taoibh le haghaidh comhad"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
