@@ -42,7 +42,6 @@ OC.L10N.register(
     "Files" : "Archìvios",
     "A file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong> un'archìviu o una cartella",
     "A favorite file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong>un'archìviu o una cartella preferida",
-    "Upload (max. %s)" : "Càrriga (max. %s)",
     "Accept" : "Atzeta",
     "Reject" : "Refuda",
     "Incoming ownership transfer from {user}" : "Tràmuda de propriedade in intrada dae {user}",
@@ -66,6 +65,7 @@ OC.L10N.register(
     "Folder name" : "Nùmene de sa cartella",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" s'est torradu a numenare comente \"{newName}\"",
     "Rename file" : "Torra a numenare s'archìviu",
+    "Folder" : "Cartella",
     "Pending" : "In suspesu",
     "Clear filter" : "Lìmpia filtru",
     "Modified" : "Modificadu",
@@ -76,7 +76,6 @@ OC.L10N.register(
     "(selected)" : "(seletzionados)",
     "List of files and folders." : "Lista de archìvios e cartellas.",
     "File not found" : "Archìviu no agatadu",
-    "{count} selected" : "seletzionados: {count}",
     "{usedQuotaByte} used" : "{usedQuotaByte} impreadu",
     "{used} of {quota} used" : "{used} de {quota} impreadu",
     "{relative}% used" : "{relative}% impreadu",
@@ -85,6 +84,7 @@ OC.L10N.register(
     "New folder" : "Cartella noa",
     "Create new folder" : "Crea cartella noa",
     "Create" : "Crea",
+    "Refresh" : "Agiorna",
     "Submit" : "Imbia",
     "Choose a file or folder to transfer" : "Sèbera un'archìviu o una cartella de tramudare",
     "Transfer" : "Tràmuda",
@@ -115,22 +115,26 @@ OC.L10N.register(
     "Views" : "Visualizatziones",
     "Files settings" : "Cunfiguratziones de archìvios",
     "File cannot be accessed" : "Impossìbile atzèdere a s'archìviu",
-    "WebDAV URL copied to clipboard" : "URL WebDAV copiadu in punta de billete.",
+    "All files" : "Totu is archìvios",
+    "Personal files" : "Archìvios personales",
     "Sort favorites first" : "Assenta cun is preferidos in antis",
     "Sort folders before files" : "Assenta cun is cartellas in antis de is archìvios",
+    "Appearance" : "Aspetu",
     "Show hidden files" : "Mustra archìvios cuados",
     "Crop image previews" : "Retàllia anteprimas de s'immàgine",
-    "Enable the grid view" : "Ativa sa visualizatzione de mosàicu",
     "Additional settings" : "Cunfiguratziones in agiunta",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "URL WebDAV",
-    "Copy to clipboard" : "Còpia in is punta de billete",
-    "Use this address to access your Files via WebDAV" : "Imprea custu indiritzu pro intrare in archìvios tràmite WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si as ativadu 2FA, depes creare e impreare una crae de s'aplicatzione noa incarchende inoghe.",
+    "Copy" : "Còpia",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
+    "Rename" : "Torra a numenare",
+    "Delete" : "Cantzella",
+    "Manage tags" : "Gesti etichetas",
     "Selection" : "Seletzione",
+    "Deselect all" : "Deseletziona totu",
     "Navigation" : "Navigatzione",
     "View" : "Visualiza",
+    "Toggle grid view" : "Càmbia a visualizatzione in mosàicu",
     "You" : "Tue",
     "Error while loading the file data" : "Errore in su carrigamentu de is datos de s'archìviu",
     "Remove from favorites" : "Boga dae preferidos",
@@ -146,59 +150,59 @@ OC.L10N.register(
     "Delete and unshare" : "Cantzella e firma sa cumpartzidura",
     "Delete file" : "Cantzella archìviu",
     "Delete folder" : "Cantzella sa cartella",
-    "Delete" : "Cantzella",
     "Cancel" : "Annulla",
+    "Download" : "Iscàrriga",
+    "Destination is not a folder" : "Sa destinatzione no est una cartella",
+    "This file/folder is already in that directory" : "Custu archìviu o cartella est giai in cussu diretòriu",
     "The file does not exist anymore" : "S'archìviu no esistit prus",
     "Choose destination" : "Sèbera unu destinu",
     "Copy to {target}" : "Còpia a {target}",
-    "Copy" : "Còpia",
     "Move to {target}" : "Tràmuda a {target}",
     "Move" : "Tràmuda",
     "Move or copy operation failed" : "Errore in s'operatzione de tràmuda o de còpia",
     "Move or copy" : "Tràmuda o còpia",
-    "Cancelled move or copy of \"{filename}\"." : "Operatzione de tràmuda o de còpia annullada pro s'archìviu: \"{filename}\".",
-    "Cancelled move or copy operation" : "Operatzione de tràmuda o còpia annullada",
     "Open folder {displayName}" : "Aberi sa cartella {displayName}",
     "Open in Files" : "Aberi in Archìvios",
-    "Open file locally" : "Aberi s'archìviu in locale",
     "Open locally" : "Aberi in locale",
-    "Rename" : "Torra a numenare",
-    "Open details" : "Aberi is detàllios",
+    "Open file locally" : "Aberi s'archìviu in locale",
+    "Details" : "Detàllios",
     "View in folder" : "Visualiza in sa cartella",
     "Today" : "Oe ",
     "Last 7 days" : "Ùrtimas 7 dies",
     "Last 30 days" : "Ùrtimas 30 dies",
     "Documents" : "Documentos",
     "Folders" : "Cartellas",
+    "Images" : "Immàgines",
     "Videos" : "Vìdeos",
     "Created new folder \"{name}\"" : "Cartella noa \"{name}\" creada",
     "Unable to initialize the templates directory" : "Non faghet a initzializare sa cartella de is modellos",
     "Templates" : "Modellos",
+    "No files to upload" : "Perunu archìviu de carrigare",
+    "Some files could not be uploaded" : "No at fatu a carrigare unos cantos archìvios",
+    "Files uploaded successfully" : "Archìvios carrigados",
     "Some files could not be moved" : "No at fatu a tramudare carchi archìviu",
+    "Upload cancelled" : "Carrigamentu annulladu",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Impossìbile torrare a numenare \"{oldName}\", dae chi no esistit prus",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Su nùmene \"{newName}\" est giai impreadu in sa cartella \"{dir}\". Sèbera unu nùmene diferente.",
+    "Could not rename \"{oldName}\"" : "Impossìbile torrare a numenare \"{oldName}\"",
     "This operation is forbidden" : "Custa operatzione no est permìtida",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Custa cartella no est a disponimentu, controlla is informes o cuntata s'amministratzione",
     "Storage is temporarily not available" : "S'archiviatzione immoe no est a disponimentu",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartellas"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archìviu","{fileCount} archìvios"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archìviu e {folderCount} cartella","1 archìviu e {folderCount} cartellas"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archìviu e 1 cartella","{fileCount} archìvios e 1 cartella"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} archìvios e {folderCount} cartellas",
+    "_%n file_::_%n files_" : ["%n archìviu","%n archìvios"],
+    "_%n folder_::_%n folders_" : ["%n cartella","%n cartellas"],
     "No favorites yet" : "Ancora perunu preferidu",
     "Files and folders you mark as favorite will show up here" : "Is archìvios e is cartellas chi marcas comente preferidos ant a aparèssere inoghe",
-    "All files" : "Totu is archìvios",
     "List of your files and folders." : "Lista de is cartellas e is archìvios tuos.",
-    "Personal files" : "Archìvios personales",
     "No personal files found" : "Perunu archìviu personale agatadu",
     "Recent" : "Reghente",
     "List of recently modified files and folders." : "Lista de cartellas e archìvios modificados de reghente.",
     "No recently modified files" : "Nissunu archìviu modificadu de reghente",
     "Files and folders you recently modified will show up here." : "Is cartellas e is archìvios chi apas modificadu de reghente ant a èssere mustrados inoghe.",
+    "Search" : "Chirca",
     "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
     "Select all" : "Seletziona totu",
     "Upload too large" : "Carrigamentu tropu mannu",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Is archìvios chi boles carrigare passant sa mannària màssima de carrigamentu de archìvios in custu serbidore.",
     "File could not be found" : "No at fatu a agatare s'archìviu",
-    "Download" : "Iscàrriga",
     "Show list view" : "Mustra sa visualizatzione de lista",
     "Show grid view" : "Mustra sa visualizatzione de mosàicu",
     "Close" : "Serra",
@@ -223,12 +227,12 @@ OC.L10N.register(
     "Edit locally" : "Modìfica in locale",
     "Open" : "Aberi",
     "Could not load info for file \"{file}\"" : "No at fatu a carrigare informatziones de s'archìviu \"{file}\"",
-    "Details" : "Detàllios",
     "Please select tag(s) to add to the selection" : "Seletziona eticheta(s) pro agiùnghere a sa seletzione",
     "Apply tag(s) to selection" : "Àplica eticheta(s) a sa seletzione",
     "Select directory \"{dirName}\"" : "Seletziona sa cartella \"{dirName}\"",
     "Select file \"{fileName}\"" : "Seletziona s'archìviu \"{fileName}\"",
     "Unable to determine date" : "Non faghet a determinare sa data",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Custa cartella no est a disponimentu, controlla is informes o cuntata s'amministratzione",
     "Could not move \"{file}\", target exists" : "No at fatu a tramudare \"{file}\", sa destinatzione esistit giai",
     "Could not move \"{file}\"" : "No at fatu a tramudare \"{file}\"",
     "copy" : "còpia",
@@ -237,9 +241,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin} copiadu a intro de {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} àteros archìvios a intro de {destination}",
     "{newName} already exists" : "{newName} esistit giai",
-    "Could not rename \"{fileName}\", it does not exist any more" : "No at fatu a torrare a numenare \"{fileName}\", ca no esistit prus",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Su nùmene \"{targetName}\" est giai impreadu in sa cartella \"{dir}\". Sèbera un'àteru nùmene.",
-    "Could not rename \"{fileName}\"" : "No at fatu a torrare a numenare \"{fileName}\"",
     "Could not create file \"{file}\"" : "No at fatu a creare s'archìviu \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "No at fatu a creare s'archìviu \"{file}\" ca esitit giai",
     "Could not create folder \"{dir}\" because it already exists" : "No at fatu a creare sa cartella \"{dir}\" ca esistit giai",
@@ -247,8 +248,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Errore cantzellende s'archìviu \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Perunu resurtadu de chirca in àteras cartellas pro {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Inserta prus de duos caràteres pro chircare in àteras cartellas",
-    "_%n folder_::_%n folders_" : ["%n cartella","%n cartellas"],
-    "_%n file_::_%n files_" : ["%n archìviu","%n archìvios"],
     "{dirs} and {files}" : "{dirs} e {files}",
     "_including %n hidden_::_including %n hidden_" : ["inclùdidu %n cuadu","inclùdidos %n cuados"],
     "You do not have permission to upload or create files here" : "Non tenes permissu pro carrigare o creare archìvios inoghe",
@@ -274,18 +273,25 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Ligòngiu diretu copiadu (funtzionat isceti pro gente chi tenet atzessu a custu archìviu o cartella)",
     "Path" : "Percursu",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Preferidu",
     "Copy direct link (only works for people who have access to this file/folder)" : "Còpia su ligòngiu diretu (funtzionat isceti pro gente chi tenet atzessu a custu archìviu o cartella)",
-    "Upload file" : "Carriga archìviu",
-    "Not favorited" : "Non preferidu",
+    "Upload file" : "Càrriga archìviu",
     "An error occurred while trying to update the tags" : "B'at àpidu un'errore proende a agiornare is etichetas",
-    "Storage informations" : "Informatziones de s'archiviatzione",
-    "Choose file" : "Sèbera un'archìviu",
-    "Go to the previous folder" : "Bae a sa cartella pretzedente",
-    "Open the files app settings" : "Aberi sa cunfiguratzione de s'aplicatzione de archìvios",
-    "Unable to change the favourite state of the file" : "Non faghet a cambiare s'istadu de preferidu de s'archìviu",
-    "Create new templates folder" : "Crea una cartella de modellos noa",
-    "List of favorites files and folders." : "Lista de cartellas e de archìvios preferidos.",
+    "Upload (max. %s)" : "Càrriga (max. %s)",
+    "Filter filenames…" : "Filtra nùmenes de archìviu...",
+    "WebDAV URL copied to clipboard" : "URL WebDAV copiadu in punta de billete.",
+    "Enable the grid view" : "Ativa sa visualizatzione de mosàicu",
+    "Copy to clipboard" : "Còpia in is punta de billete",
+    "Use this address to access your Files via WebDAV" : "Imprea custu indiritzu pro intrare in archìvios tràmite WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si as ativadu 2FA, depes creare e impreare una crae de s'aplicatzione noa incarchende inoghe.",
+    "Cancelled move or copy of \"{filename}\"." : "Operatzione de tràmuda o de còpia annullada pro s'archìviu: \"{filename}\".",
+    "Cancelled move or copy operation" : "Operatzione de tràmuda o còpia annullada",
+    "Open details" : "Aberi is detàllios",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartellas"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archìviu","{fileCount} archìvios"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archìviu e {folderCount} cartella","1 archìviu e {folderCount} cartellas"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archìviu e 1 cartella","{fileCount} archìvios e 1 cartella"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} archìvios e {folderCount} cartellas",
+    "All folders" : "Totu is cartellas",
     "Personal Files" : "Archìvios personales",
     "Text file" : "Archìviu de testu",
     "New text file.txt" : "Archìviu de testu .txt nou"
