@@ -6,11 +6,11 @@ OC.L10N.register(
     "View file" : "Zobrazit soubor",
     "View folder" : "Zobrazit složku",
     "Files reminder" : "Připomínka souboru",
-    "This files_reminder can work properly." : "Tento files_reminder může fungovat správně.",
-    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikace files_reminder potřebuje, aby aplikace notifikace správně fungovala. Buď byste měli zapnout notifikace, nebo vypnout files_reminder.",
+    "The \"files_reminders\" app can work properly." : "Aplikace „files_reminder“ může fungovat správně.",
+    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikace „files_reminder“ potřebuje, aby aplikace notifikace správně fungovala. Buď byste měli zapnout notifikace, nebo vypnout files_reminder.",
     "Set file reminders" : "Nastavit připomínky souborů",
     "Set reminder for \"{fileName}\"" : "Nastavit připomínku pro „{fileName}",
-    "Set reminder at custom date & time" : "Nastavit připomínku na uživatelsky určené datum a čas",
+    "Reminder at custom date & time" : "Připomínka v uživatelsky určený datum a čas",
     "Clear reminder" : "Vyčistit připomínku",
     "Please choose a valid date & time" : "Zvolte platný datum a čas",
     "Reminder set for \"{fileName}\"" : "Nastavena připomínka ohledně „{fileName}“",
@@ -21,7 +21,7 @@ OC.L10N.register(
     "Cancel" : "Storno",
     "Set reminder" : "Nastavit připomínku",
     "Reminder set" : "Nastavit připomínku",
-    "Set custom reminder" : "Nastavit uživatelsky určenou připomínku",
+    "Custom reminder" : "Uživatelsky určená připomínka",
     "Later today" : "Později dnes",
     "Set reminder for later today" : "Nastavit připomínku na později dnes",
     "Tomorrow" : "Zítra",
@@ -29,6 +29,10 @@ OC.L10N.register(
     "This weekend" : "Tento víkend",
     "Set reminder for this weekend" : "Nastavit připomínku na tento víkend",
     "Next week" : "Příští týden",
-    "Set reminder for next week" : "Nastavit připomínku pro příští týden"
+    "Set reminder for next week" : "Nastavit připomínku pro příští týden",
+    "This files_reminder can work properly." : "Tento files_reminder může fungovat správně.",
+    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikace files_reminder potřebuje, aby aplikace notifikace správně fungovala. Buď byste měli zapnout notifikace, nebo vypnout files_reminder.",
+    "Set reminder at custom date & time" : "Nastavit připomínku na uživatelsky určené datum a čas",
+    "Set custom reminder" : "Nastavit uživatelsky určenou připomínku"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
