@@ -6,7 +6,9 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Hamkasblaringiz va do'stlaringizni shaxsiy ma'lumotlarini oshkor qilmasdan bir joyda saqlang.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Oddiy elektron pochta ilovasi fayllar, kontaktlar va taqvim bilan yaxshi birlashtirilgan.",
     "App recommendation: Group folders" : "App recommendation: Group folders",
-    "Close" : "Close",
-    "Server address" : "Server address"
+    "Close" : "Yopish",
+    "Share via email" : "Elektron pochta orqali ulashing",
+    "Server address" : "Server manzili",
+    "Read more" : "Ko'proq o'qish"
 },
 "nplurals=1; plural=0;");
