@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "Означи изабрано као омиљено",
     "Add selection to favorites" : "Додај изабрано у омиљено",
     "Remove selection from favorites" : "Уклони изабрано из омиљених",
+    "This name is already in use." : "Ово име се већ користи.",
+    "\"{char}\" is not allowed inside a filename." : "„{char}“ није дозвољен карактер у имену фајла.",
+    "Invalid filename." : "Неисправно име фајла.",
     "Name of the album" : "Назив албума",
     "Location of the album" : "Локација албума",
     "Back" : "Назад",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Додај људе или групе које могу да уређују ваш албум",
     "Search people or groups" : "Претрага људи и група",
     "No recommendations. Start typing." : "Нема препорука. Започните куцање.",
-    "Group" : "Група",
-    "Remove {collaboratorLabel} from the collaborators list" : "Уклони {collaboratorLabel} из листе сарадника",
     "Copy the public link" : "Копирај јавни линк",
     "Public link copied!" : "Јавни линк је корипан!",
     "Copy public link" : "Копирај јавни линк",
@@ -52,15 +53,18 @@ OC.L10N.register(
     "No picture for this day" : "Нема слика за данашњи дан",
     "Picture taken on this day will show up here." : "Овде ће се појавити слика направљена на данашњи дан.",
     "More photos from this day" : "Још слика за данас",
+    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n недодељена фотографија","%n недодељене фотографије","%n недодељених фотографија"],
     "Favorite" : "Омиљени",
     "Favorite image, open the full size \"{name}\" image" : "Омиљена слика, отвори слику „{name}” у пуној величини",
     "Open the full size \"{name}\" image" : "Отвори слику „{name}” у пуној величини",
     "Select image {imageName}" : "Изабери слику {imageName}",
     "Open the \"{name}\" folder" : "Отвори „{name}” директоријум",
-    "Back to {folder}" : "Назад у {folder}",
     "Go back" : "Иди назад",
-    "Share this folder" : "Дели ову фасциклу",
+    "Select a custom date range" : "Изаберите произвољни опсег датума",
+    "Select a date range" : "Изаберите опсег датума",
+    "Date range" : "Опсег датума",
+    "Select filters" : "Изаберите филтере",
     "Dates" : "Датуми",
     "Jump to specific date in list" : "Скок на одређени датум у листи",
     "Jump to {date}" : "Скочи на {date}",
@@ -115,7 +119,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "У зависности од величине ваше фото библиотеке, ово може да потраје неко време.",
     "Recognized people will show up here" : "Овде ће се појавити препознате особе",
     "This folder does not exist" : "Овај фолдер не постоји",
-    "Loading folders …" : "Учитавање фолдера ...",
+    "Loading folders…" : "Учитавам фасцикле…",
     "No photos in here" : "Овде нема слика",
     "Taken on {date} at {time}" : "Сликано дана {date} у {time}",
     "This place does not have any photos or videos yet!" : "Ово место још увек нема ниједну фотографију или видео снимак!",
@@ -129,12 +133,12 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Слике са ознакама ће се појавити овде",
     "Popular tags" : "Популарне ознаке",
     "All tags" : "Све ознаке",
+    "Create new album from filters" : "Креирај нови албум из филтера",
     "One of the source folders does not exist" : "Један од изворних фолдера не постоји",
     "Add to album" : "Додај у албум",
     "Delete selection" : "Обриши одабир",
     "No photos or videos in here" : "Овде нема фотографија или видео снимака",
     "Unassigned faces" : "Недодељена лица",
-    "_%n photos_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
     "Failed to fetch collection." : "Није успело добављање колекције.",
     "Failed to fetch collections list." : "Није успело добављање листе колекција.",
     "Failed to fetch faces list." : "Није успело добављање листе лица.",
@@ -147,8 +151,19 @@ OC.L10N.register(
     "Tagged photos" : "Слике са ознаком",
     "Tagged photo {title}" : "Означена фотографија {title}",
     "{title}'s face" : "лице {title}",
+    "Last week" : "Прошле недеље",
+    "Last Month" : "Последњи месец",
+    "Custom…" : "Произвољно",
     "{startDate} to {endDate}" : "{startDate} до {endDate}",
     "Details" : "Детаљи",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "{fileBaseName} није могао да се дода у колекцију {collectionFileName}",
+    "Failed to delete {fileBaseName}" : "Није успело брисање {fileBaseName}",
+    "Failed to create {collectionFileName}" : "Није могла да се креира {collectionFileName}",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Није успела промена имена {currentCollectionFileName} у {newCollectionFileName}",
+    "Failed to update properties of {collectionFileName} with {properties}" : "Није успело ажурирање особина {collectionFileName} са {properties}",
+    "Failed to delete {collectionFileName}" : "Није успело брисање {collectionFileName}",
+    "Failed to move {fileBaseName} to person {faceName}" : "Није успело премештање {fileBaseName} особи {faceName}",
+    "Failed to remove {fileBaseName}" : "Није успело уклањање {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "Није успела промена имена {oldName} у {faceName}",
     "Failed to delete {faceName}" : "Није успело брисање {faceName}",
     "Failed to delete {fileId}" : "Није успело брисање {fileId}",
@@ -156,6 +171,11 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Није успело постављање стања омиљено за {fileId}",
     "Failed to set favorite state for {fileName}" : "Није успело постављање стања омиљено за {fileName}",
     "Could not load photos folder" : "Не може да се учита фолдер фотографија",
+    "Group" : "Група",
+    "Remove {collaboratorLabel} from the collaborators list" : "Уклони {collaboratorLabel} из листе сарадника",
+    "Back to {folder}" : "Назад у {folder}",
+    "Share this folder" : "Дели ову фасциклу",
+    "Loading folders …" : "Учитавање фолдера ...",
     "One of the source folders does not exists" : "Један од изворних фолдера не постоји",
     "Add" : "Додај"
 },
