@@ -21,6 +21,9 @@ OC.L10N.register(
     "Mark selection as favorite" : "將已選擇的標記為最愛",
     "Add selection to favorites" : "將選擇添加至最愛",
     "Remove selection from favorites" : "從最愛移除已選擇的範圍",
+    "This name is already in use." : "這個用戶名稱已經有人使用了。",
+    "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
+    "Invalid filename." : "檔案名稱無效。",
     "Name of the album" : "相簿名稱",
     "Location of the album" : "相簿位置",
     "Back" : "返回",
@@ -39,8 +42,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "添加可以編輯您的相簿的用戶或群組",
     "Search people or groups" : "搜尋人或群組",
     "No recommendations. Start typing." : "沒有建議。開始輸入。",
-    "Group" : "群組",
-    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單中移除 {collaboratorLabel}",
     "Copy the public link" : "複製公開連結",
     "Public link copied!" : "公開連結已複製！",
     "Copy public link" : "複製公開連結",
@@ -52,15 +53,18 @@ OC.L10N.register(
     "No picture for this day" : "這天沒有照片",
     "Picture taken on this day will show up here." : "這天拍攝的照片將會顯示在此處。",
     "More photos from this day" : "更多這天的照片",
+    "_%n photos_::_%n photos_" : ["%n 張照片"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n 個未指派的照片"],
     "Favorite" : "我的最愛",
     "Favorite image, open the full size \"{name}\" image" : "收藏影像，開啟「{name}」的原始尺寸影像",
     "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
     "Select image {imageName}" : "選擇圖像 {imageName}",
     "Open the \"{name}\" folder" : "開啟「{name}」資料夾",
-    "Back to {folder}" : "回到 {folder}",
     "Go back" : "返回",
-    "Share this folder" : "分享這個資料夾",
+    "Select a custom date range" : "選擇自訂日期範圍",
+    "Select a date range" : "選取日期範圍",
+    "Date range" : "日期範圍",
+    "Select filters" : "選擇過濾器",
     "Dates" : "日期",
     "Jump to specific date in list" : "跳至清單中的特定日期",
     "Jump to {date}" : "跳到 {date}",
@@ -115,7 +119,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "這可能需要花一點時間，取決於您照片庫的大小。",
     "Recognized people will show up here" : "被識別的人將會出現在此處",
     "This folder does not exist" : "此資料夾不存在",
-    "Loading folders …" : "載入資料夾 …",
+    "Loading folders…" : "載入資料夾…",
     "No photos in here" : "無照片檔案",
     "Taken on {date} at {time}" : "攝於 {date} {time}",
     "This place does not have any photos or videos yet!" : "此處還沒有任何照片或影片！",
@@ -129,15 +133,16 @@ OC.L10N.register(
     "Photos with tags will show up here" : "此處會顯示照片的標籤",
     "Popular tags" : "熱門標籤",
     "All tags" : "全部標籤",
+    "Create new album from filters" : "從過濾器創建新相簿",
     "One of the source folders does not exist" : "其中一個來源資料夾不存在",
     "Add to album" : "添加至相簿",
     "Delete selection" : "刪除所選",
     "No photos or videos in here" : "此處沒有照片或視像",
     "Unassigned faces" : "未指派的臉孔",
-    "_%n photos_::_%n photos_" : ["%n 張照片"],
     "Failed to fetch collection." : "擷取收藏品失敗。",
     "Failed to fetch collections list." : "擷取收藏品清單失敗。",
     "Failed to fetch faces list." : "擷取臉部清單失敗。",
+    "Error fetching files" : "擷取檔案時發生錯誤",
     "All your media" : "所有媒體",
     "Album {title}" : "相簿 {title}",
     "Shared Albums" : "已分享了的相簿",
@@ -146,8 +151,19 @@ OC.L10N.register(
     "Tagged photos" : "有標籤的照片",
     "Tagged photo {title}" : "有標籤的照片 {title}",
     "{title}'s face" : "{title} 的臉",
+    "Last week" : "上星期",
+    "Last Month" : "上個月",
+    "Custom…" : "自訂 ...",
     "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
     "Details" : "細節",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "無法將 {fileBaseName} 添加到收藏 {collectionFileName}",
+    "Failed to delete {fileBaseName}" : "刪除 {fileBaseName} 失敗",
+    "Failed to create {collectionFileName}" : "無法創建 {collectionFileName}",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "重新命名 {currentCollectionFileName} 為 {newCollectionFileName} 失敗",
+    "Failed to update properties of {collectionFileName} with {properties}" : "無法使用 {properties} 更新 {collectionFileName} 的屬性",
+    "Failed to delete {collectionFileName}" : "刪除 {collectionFileName} 失敗",
+    "Failed to move {fileBaseName} to person {faceName}" : "無法將 {fileBaseName} 移動至人物 {faceName}",
+    "Failed to remove {fileBaseName}" : "無法移除 {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "重新命名 {oldName} 為 {faceName} 失敗",
     "Failed to delete {faceName}" : "刪除 {faceName} 失敗",
     "Failed to delete {fileId}" : "刪除 {fileId} 失敗",
@@ -155,6 +171,11 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "未能為 {fileId} 設置收藏狀態",
     "Failed to set favorite state for {fileName}" : "未能為 {fileName} 設置收藏狀態",
     "Could not load photos folder" : "無法載入照片資料夾",
+    "Group" : "群組",
+    "Remove {collaboratorLabel} from the collaborators list" : "從協作者清單中移除 {collaboratorLabel}",
+    "Back to {folder}" : "回到 {folder}",
+    "Share this folder" : "分享這個資料夾",
+    "Loading folders …" : "載入資料夾 …",
     "One of the source folders does not exists" : "其中一個來源資料夾不存在",
     "Add" : "添加"
 },
