@@ -2,6 +2,8 @@ OC.L10N.register(
     "profile",
     {
     "Profile" : "Profiel",
+    "This application provides the profile" : "Deze applicatie biedt het profiel",
+    "Provides a customisable user profile interface." : "Biedt een aanpasbare gebruikersprofielinterface.",
     "You have not added any info yet" : "Je hebt nog geen info toegevoegd",
     "{user} has not added any info yet" : "{user} heeft nog geen info toegevoegd",
     "Error opening the user status modal, try hard refreshing the page" : "Fout bij het openen van het gebruiker status model, probeer een harde refresh van de pagina",
