@@ -4,28 +4,8 @@ declare(strict_types=1);
 
 
 /**
- * Nextcloud - Related Resources
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2022
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
@@ -40,6 +20,7 @@ class TalkRoom implements IQueryRow, JsonSerializable {
 
 	private int $roomId = 0;
 	private string $roomName = '';
+	private int $roomType = 0;
 	private string $token = '';
 
 	public function __construct() {
@@ -83,6 +64,24 @@ class TalkRoom implements IQueryRow, JsonSerializable {
 		return $this->roomName;
 	}
 
+	/**
+	 * @param int $roomType
+	 *
+	 * @return TalkRoom
+	 */
+	public function setRoomType(int $roomType): self {
+		$this->roomType = $roomType;
+
+		return $this;
+	}
+
+	/**
+	 * @return int
+	 */
+	public function getRoomType(): int {
+		return $this->roomType;
+	}
+
 
 	/**
 	 * @param string $token
@@ -108,8 +107,9 @@ class TalkRoom implements IQueryRow, JsonSerializable {
 	 */
 	public function importFromDatabase(array $data): IQueryRow {
 		$this->setRoomId($this->getInt('id', $data))
-			 ->setRoomName($this->get('name', $data))
-			 ->setToken($this->get('token', $data));
+			->setRoomName($this->get('name', $data))
+			->setRoomType($this->getInt('type', $data))
+			->setToken($this->get('token', $data));
 
 		return $this;
 	}
@@ -121,6 +121,7 @@ class TalkRoom implements IQueryRow, JsonSerializable {
 		return [
 			'roomId' => $this->getRoomId(),
 			'roomName' => $this->getRoomName(),
+			'roomType' => $this->getRoomType(),
 			'token' => $this->getToken()
 		];
 	}
