@@ -447,7 +447,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 	public function exprLimitEmpty(
 		string $field,
 		bool $orNull = false,
-		string $alias = ''
+		string $alias = '',
 	): ICompositeExpression {
 		if ($this->getType() === DBALQueryBuilder::SELECT) {
 			$field = (($alias === '') ? $this->getDefaultSelectAlias() : $alias) . '.' . $field;
@@ -473,7 +473,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 	public function exprLimitNull(
 		string $field,
 		bool $orEmpty = false,
-		string $alias = ''
+		string $alias = '',
 	): ICompositeExpression {
 		if ($this->getType() === DBALQueryBuilder::SELECT) {
 			$field = (($alias === '') ? $this->getDefaultSelectAlias() : $alias) . '.' . $field;
@@ -502,7 +502,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 		string $field,
 		array $values,
 		string $alias = '',
-		bool $cs = true
+		bool $cs = true,
 	): ICompositeExpression {
 		if ($this->getType() === DBALQueryBuilder::SELECT) {
 			$field = (($alias === '') ? $this->getDefaultSelectAlias() : $alias) . '.' . $field;
@@ -789,7 +789,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 	public function exprFilterEmpty(
 		string $field,
 		bool $norNull = false,
-		string $alias = ''
+		string $alias = '',
 	): ICompositeExpression {
 		if ($this->getType() === DBALQueryBuilder::SELECT) {
 			$field = (($alias === '') ? $this->getDefaultSelectAlias() : $alias) . '.' . $field;
@@ -815,7 +815,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 	public function exprFilterNull(
 		string $field,
 		bool $norEmpty = false,
-		string $alias = ''
+		string $alias = '',
 	): ICompositeExpression {
 		if ($this->getType() === DBALQueryBuilder::SELECT) {
 			$field = (($alias === '') ? $this->getDefaultSelectAlias() : $alias) . '.' . $field;
@@ -844,7 +844,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 		string $field,
 		array $values,
 		string $alias = '',
-		bool $cs = true
+		bool $cs = true,
 	): ICompositeExpression {
 		if ($this->getType() === DBALQueryBuilder::SELECT) {
 			$field = (($alias === '') ? $this->getDefaultSelectAlias() : $alias) . '.' . $field;
@@ -965,7 +965,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 		array $data,
 		ExtendedQueryBuilder $qb,
 		string $object,
-		array $params
+		array $params,
 	): IQueryRow {
 		$fromField = $this->get('modelFromField', $params);
 		if ($fromField !== '') {
@@ -1048,7 +1048,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 	public function generateSelect(
 		string $table,
 		array $fields,
-		string $alias = ''
+		string $alias = '',
 	): self {
 		if ($alias === '') {
 			$alias = $table;
@@ -1061,8 +1061,8 @@ class ExtendedQueryBuilder extends QueryBuilder {
 		);
 
 		$this->select($selectFields)
-			 ->from($table, $alias)
-			 ->setDefaultSelectAlias($alias);
+			->from($table, $alias)
+			->setDefaultSelectAlias($alias);
 
 		return $this;
 	}
@@ -1080,7 +1080,7 @@ class ExtendedQueryBuilder extends QueryBuilder {
 		array $fields,
 		string $alias,
 		string $prefix,
-		array $default = []
+		array $default = [],
 	): self {
 		$prefix = trim($prefix) . '_';
 		foreach ($default as $k => $v) {
