@@ -133,7 +133,6 @@ OC.L10N.register(
     "Enforce password protection" : "Nametni zaštitu zaporkom",
     "Enforce expiration date" : "Primijeni datum isteka",
     "Set default expiration date for shares to other servers" : "Postavi zadani datum isteka dijeljenja na druge poslužitelje",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ako je omogućeno automatsko dovršavanje „ista grupa” i „integracija telefonskog broja”, bilo koje od tih podudaranja dovoljno je za prikaz korisnika.",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Prikaži tekst izjave o odricanju od odgovornosti na stranici za otpremanje javnih poveznica (prikazuje se samo kad je popis datoteka skriven)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Ovaj će tekst biti prikazan na stranici za otpremanje javnih poveznica kad je popis datoteka skriven.",
     "Default share permissions" : "Zadana dopuštenja za dijeljenje",
@@ -146,6 +145,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Dvofaktorska autentifikacija ne primjenjuje se na članove sljedećih grupa.",
     "Excluded groups" : "Izuzete grupe",
     "Save changes" : "Spremi promjene",
+    "Default" : "Zadani",
     "Update to {update}" : "Ažuriraj na {update}",
     "Remove" : "Ukloni",
     "Featured" : "Istaknuto",
@@ -179,8 +179,6 @@ OC.L10N.register(
     "Limit app usage to groups" : "Ograničite primjenu aplikacije na grupe",
     "No results" : "Nema rezultata",
     "Update to {version}" : "Ažuriraj na {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ovoj aplikaciji nije dodijeljena najmanja inačica Nextclouda. To će biti pogreška u budućnosti.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ovoj aplikaciji nije dodijeljena najveća inačica Nextclouda. To će biti pogreška u budućnosti.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Aplikaciju nije moguće instalirati jer nisu ispunjene sljedeće ovisnosti:",
     "Author" : "Autor",
     "Categories" : "Kategorije",
@@ -259,6 +257,7 @@ OC.L10N.register(
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Na profilu se primjenjuje stroža postavka vidljivosti ili opsega. Na primjer, ako je vidljivost postavljena na „Prikaži svima”, a opseg je postavljen na „Privatno”, primjenjuje se „Privatno”.",
     "Unable to update visibility of {displayId}" : "Nije moguće ažurirati vidljivost za {displayId}",
     "Your role" : "Vaša uloga",
+    "Timezone" : "Vremenska zona",
     "Unable to update federation scope of the primary {property}" : "Nije moguće ažurirati opseg udruženja primarnog {property}",
     "Unable to update federation scope of additional {property}" : "Nije moguće ažurirati opseg udruženja dodatnog {property}",
     "Add" : "Dodaj",
@@ -266,6 +265,7 @@ OC.L10N.register(
     "Change" : "Promijeni",
     "Delete" : "Izbriši",
     "Reshare" : "Dijeli ponovno",
+    "School" : "Škola",
     "Default language" : "Zadani jezik",
     "Common languages" : "Česti jezici",
     "Other languages" : "Drugi jezici",
@@ -282,7 +282,6 @@ OC.L10N.register(
     "{size} used" : "Iskorišteno {size}",
     "Delete account" : "Izbriši račun",
     "Resend welcome email" : "Ponovno pošalji poruku dobrodošlice",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "U slučaju gubitka uređaja ili napuštanja organizacije, može daljinski izbrisati Nextcloudove podatke sa svih uređaja kojima se koristi {userid}. Brisanje je moguće samo ako su uređaji povezani na internet.",
     "Remote wipe of devices" : "Daljinsko brisanje podataka s uređaja",
     "Wipe {userid}'s devices" : "Izbriši podatke sa svih uređaja koji pripadaju {userid}",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "U potpunosti izbriši račun koji pripada {userid}, uključujući sve osobne datoteke, aplikacije itd.",
@@ -307,8 +306,13 @@ OC.L10N.register(
     "No devices configured." : "Nema konfiguriranih uređaja.",
     "The following devices are configured for your account:" : "Sljedeći su uređaji konfigurirani za vaš račun:",
     "Your browser does not support WebAuthn." : "Vaš preglednik ne podržava WebAuthn.",
+    "Security & setup warnings" : "Upozorenja o sigurnosti i postavljanju",
+    "All checks passed." : "Sve su provjere uspješno dovršene.",
+    "There are some errors regarding your setup." : "Postoje neke pogreške u vezi s vašim postavom.",
+    "There are some warnings regarding your setup." : "Postoje neka upozorenja u vezi s vašim postavom.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administrator možete detaljnije podešavati dijeljenja. Pogledajte odgovarajuću dokumentaciju za više informacija.",
     "You need to enable the File sharing App." : "Morate omogućiti aplikaciju za dijeljenje datoteka.",
+    "Apply" : "Potvrdi",
     "Admins" : "Administratori",
     "Sending…" : "Slanje…",
     "Email sent" : "E-pošta je poslana",
@@ -336,7 +340,6 @@ OC.L10N.register(
     "Download and enable" : "Preuzmi i omogući",
     "Disable" : "Onemogući",
     "The app will be downloaded from the App Store" : "Aplikacija će se preuzeti iz trgovine aplikacijama",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ova aplikacija nije označena kao kompatibilna s vašom inačicom Nextclouda. Ako odlučite nastaviti, moći ćete instalirati aplikaciju. Imajte na umu da aplikacija možda neće raditi kako očekujete.",
     "Unknown" : "Nepoznata pogreška",
     "Never" : "Nikad",
     "Error: This app cannot be enabled because it makes the server unstable" : "Pogreška: ova aplikacija ne može biti omogućena jer čini poslužitelj nestabilnim",
@@ -365,14 +368,6 @@ OC.L10N.register(
     "Credentials" : "Vjerodajnice",
     "SMTP Password" : "SMTP zaporka",
     "Save" : "Spremi",
-    "Security & setup warnings" : "Upozorenja o sigurnosti i postavljanju",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pravilna konfiguracija iznimno je važna za sigurnost i performanse vaše instance. Kako bismo vam pomogli pravilno konfigurirati sustav, provest ćemo neke automatske provjere. Za više informacija pogledajte navedenu dokumentaciju.",
-    "All checks passed." : "Sve su provjere uspješno dovršene.",
-    "There are some errors regarding your setup." : "Postoje neke pogreške u vezi s vašim postavom.",
-    "There are some warnings regarding your setup." : "Postoje neka upozorenja u vezi s vašim postavom.",
-    "Checking for system and security issues." : "Provjera sustava i sigurnosnih postavki.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Pažljivo pročitajte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">upute za instalaciju ↗</a> i potražite postoje li ikakve pogreške ili upozorenja u <a href=\"%2$s\">zapisima</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Provjerite sigurnost svojeg Nextclouda s pomoću <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">sigurnosnog skeniranja ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Razlozi za uporabu Nextclouda u vašoj organizaciji",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{githubopen}Izvorni kôd{linkclose} je razvila {communityopen}Nextcloudova zajednica korisnika{linkclose} i licenciran je sukladno {licenseopen}AGPL-u{linkclose}.",
     "Like our Facebook page" : "Pratite našu Facebook stranicu",
@@ -383,7 +378,16 @@ OC.L10N.register(
     "Use a second factor besides your password to increase security for your account." : "Koristite se i drugim faktorom pored zaporke kako biste povećali sigurnost svog računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ako se za povezivanje s Nextcloudom koristite aplikacijama treće strane, stvorite i konfigurirajte lozinku za svaku aplikaciju prije omogućavanja drugog faktora za provođenje autentifikacije.",
     "Set default expiration date for shares" : "Postavi zadani datum isteka dijeljenja",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ako je omogućeno automatsko dovršavanje „ista grupa” i „integracija telefonskog broja”, bilo koje od tih podudaranja dovoljno je za prikaz korisnika.",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ovoj aplikaciji nije dodijeljena najmanja inačica Nextclouda. To će biti pogreška u budućnosti.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ovoj aplikaciji nije dodijeljena najveća inačica Nextclouda. To će biti pogreška u budućnosti.",
     "Your biography" : "Vaša biografija",
-    "You are using <strong>{usage}</strong>" : "Koristite <strong>{usage}</strong>"
+    "You are using <strong>{usage}</strong>" : "Koristite <strong>{usage}</strong>",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "U slučaju gubitka uređaja ili napuštanja organizacije, može daljinski izbrisati Nextcloudove podatke sa svih uređaja kojima se koristi {userid}. Brisanje je moguće samo ako su uređaji povezani na internet.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ova aplikacija nije označena kao kompatibilna s vašom inačicom Nextclouda. Ako odlučite nastaviti, moći ćete instalirati aplikaciju. Imajte na umu da aplikacija možda neće raditi kako očekujete.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pravilna konfiguracija iznimno je važna za sigurnost i performanse vaše instance. Kako bismo vam pomogli pravilno konfigurirati sustav, provest ćemo neke automatske provjere. Za više informacija pogledajte navedenu dokumentaciju.",
+    "Checking for system and security issues." : "Provjera sustava i sigurnosnih postavki.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Pažljivo pročitajte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">upute za instalaciju ↗</a> i potražite postoje li ikakve pogreške ili upozorenja u <a href=\"%2$s\">zapisima</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Provjerite sigurnost svojeg Nextclouda s pomoću <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">sigurnosnog skeniranja ↗</a>."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
