@@ -104,13 +104,12 @@ OC.L10N.register(
     "Set your password" : "Stilltu lykilorðið þitt",
     "Go to %s" : "Farðu í %s",
     "Install Client" : "Setja upp biðlaraforrit",
-    "Logged in account must be a subadmin" : "Innskráður aðgangur verður að vera undirstjórnandi (subadmin)",
     "Apps" : "Forrit",
     "Personal" : "Einka",
     "Administration" : "Stjórnun",
     "Users" : "Notendur",
     "Additional settings" : "Valfrjálsar stillingar",
-    "Artificial Intelligence" : "Gervigreind",
+    "Assistant" : "Meðhjálpari",
     "Administration privileges" : "Kerfisstjórnunarheimildir",
     "Groupware" : "Hópvinnukerfi",
     "Overview" : "Yfirlit",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Calendar" : "Dagatal",
     "Personal info" : "Persónulegar upplýsingar",
     "Mobile & desktop" : "Farsímar og borðtölvur",
+    "Artificial Intelligence" : "Gervigreind",
     "Email server" : "Póstþjónn",
     "Mail Providers" : "Þjónustuveitur",
     "Send emails using" : "Senda tölvupósta með",
@@ -206,7 +206,6 @@ OC.L10N.register(
     "Profile information" : "Persónuupplýsingar",
     "Nextcloud settings" : "Stillingar Nextcloud",
     "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI-gervigreind verka getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota fyrir hvaða verk.",
-    "Task:" : "Verk:",
     "Enable" : "Virkja",
     "Machine translation" : "Vélræn þýðing",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Vélþýðingar geta verið framkvæmdar af mismunandi forritum. Hér geturðu skilgreint forgangsröðun þeirra vélþýðingarforrita sem eru uppsett í augnablikinu.",
@@ -214,6 +213,7 @@ OC.L10N.register(
     "Image generation can be implemented by different apps. Here you can set which app should be used." : "Gerð mynda getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota.",
     "Text processing" : "Textavinnsla",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Textavinnsla verka getur verið framkvæmd af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota fyrir hvaða verk.",
+    "Task:" : "Verk:",
     "Unable to modify setting" : "Ekki gekk að breyta stillingu",
     "None" : "Ekkert",
     "Changed disclaimer text" : "Breyttur texti fyrirvara",
@@ -248,7 +248,6 @@ OC.L10N.register(
     "Privacy settings for sharing" : "Stillingar á friðhelgi deilingar",
     "Allow account name autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
     "Restrict account name autocompletion and system address book access to users within the same groups" : "Takmarka sjálfklárun á heiti notendaaðganga og aðgang að kerfisnafnaskrá við notendur innan sömu hópa",
-    "Restrict account name autocompletion to users based on phone number integration" : "Leyfa sjálfklárun á heiti notendaaðganga á notendum byggt á samþættingu símanúmera",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Birta fyrirvara á opinberu innsendingasíðunni (birtist einungis þegar listi yfir skrár er falinn)",
     "Disclaimer text" : "Texti fyrirvara",
     "This text will be shown on the public link upload page when the file list is hidden." : "Þessi texti birtist á opinberu upphleðslusíðunni þegar listi yfir skrár er falinn.",
@@ -264,6 +263,7 @@ OC.L10N.register(
     "Excluded groups" : "Útilokaðir hópar",
     "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Þegar hópar eru valdir/útilokaðir, styðjast þeir við eftirfarandi röksemdafærslu til að ákvarða hvort notandaaðgangur sé með þvingaða/virka tveggja-þrepa auðkenningu: tveggja-þrepa auðkenning er virk fyrir alla nema meðlimi útilokaðra hópa. Ef hópar eru valdir, er tveggja-þrepa auðkenning virk fyrir alla meðlimi þessara hópa. Ef notandi er bæði í völdum og í útilokuðum hópum, ræður valið og því er tveggja-þrepa auðkenning virk.",
     "Save changes" : "Vista breytingar",
+    "Default" : "Sjálfgefið",
     "Show details for {appName} app" : "Birta ítarlegri upplýsingar fyrir {appName} forritið",
     "Update to {update}" : "Uppfæra í {update}",
     "Remove" : "Fjarlægja",
@@ -283,6 +283,12 @@ OC.L10N.register(
     "No apps found for your version" : "Engin forrit fundust fyrir útgáfuna þína",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n forrit er með tiltæka uppfærslu","%n forrit eru með tiltæka uppfærslu"],
     "_Update_::_Update all_" : ["Uppfæra","Uppfæra allt"],
+    "Failed to create group" : "Mistókst að búa til hóp",
+    "Creating group…" : "Bý til hóp …",
+    "Create group" : "Búa til hóp",
+    "Group name" : "Heiti hóps",
+    "Please enter a valid group name" : "Settu inn gilt nafn á hópi",
+    "Loading groups…" : "Hleð inn hópum…",
     "Nothing to show" : "Ekkert til að sýna",
     "Loading" : "Hleð inn",
     "Fetching the latest news…" : "Sæki nýjustu fréttir…",
@@ -327,8 +333,6 @@ OC.L10N.register(
     "No results" : "Engar niðurstöður",
     "Update to {version}" : "Uppfæra í {version}",
     "Delete data on remove" : "Eyða gögnum við fjarlægingu",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ekki var hægt að setja upp forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar:",
     "Latest updated" : "Síðast uppfært",
     "Author" : "Höfundur",
@@ -394,6 +398,7 @@ OC.L10N.register(
     "Unable to update profile default setting" : "Tókst ekki að uppfæra sjálfgefna stillingu notandasniðs",
     "Profile" : "Notandasnið",
     "Enable or disable profile by default for new accounts." : "Virkja eða gera notandasnið óvirkt sjálfgefið fyrir nýja notendaaðganga.",
+    "Password confirmation is required" : "Þörf á staðfestingu lykilorðs",
     "Failed to save setting" : "Mistókst að vista stillingu",
     "Unable to update server side encryption config" : " Get ekki uppfært uppsetningu fyrir dulritun á þjóni",
     "Server-side encryption" : "Dulritun á þjóni",
@@ -409,15 +414,11 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Hafðu í huga að dulritun eykur alltaf skráastærð.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Það er góður siður að taka regluleg öryggisafrit af gögnunum þínum; ef um dulrituð gögn er að ræða, gakktu úr skugga um að einnig sé tekið öryggisafrit af dulritunarlyklum ásamt gögnunum.",
     "This is the final warning: Do you really want to enable encryption?" : "Þetta er lokaaðvörun: Viltu örugglega virkja dulritun?",
-    "Failed to remove group \"{group}\"" : "Mistókst að fjarlægja hópinn \"{group}\"",
     "Please confirm the group removal" : "Staðfestu fjarlægingu hópsins",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn \"{group}\". Notendaaðgöngunum verður EKKI eytt.",
     "Submit" : "Senda inn",
     "Rename group" : "Endurnefna hóp",
-    "Remove group" : "Fjarlægja hóp",
     "Current password" : "Núverandi lykilorð",
     "New password" : "Nýtt lykilorð",
-    "Change password" : "Breyta lykilorði",
     "Choose your profile picture" : "Veldu auðkennismynd fyrir þig",
     "Please select a valid png or jpg file" : "Veldu gilda PNG eða JPG-skrá",
     "Error setting profile picture" : "Villa kom upp við að setja auðkennismyndina",
@@ -479,6 +480,7 @@ OC.L10N.register(
     "he/him" : "hann",
     "they/them" : "hán/þau",
     "Your role" : "Hlutverk þitt",
+    "Timezone" : "Tímabelti",
     "Your X (formerly Twitter) handle" : "X (fyrrum Twitter) notandanafnið þitt",
     "Your website" : "Vefsvæðið þitt",
     "Invalid value" : "Ógilt gildi",
@@ -493,6 +495,7 @@ OC.L10N.register(
     "Change" : "Breyta",
     "Delete" : "Eyða",
     "Reshare" : "Endurdeila",
+    "School" : "Skóli",
     "Default language" : "Sjálfgefið tungumál",
     "Common languages" : "Algeng tungumál",
     "Other languages" : "Önnur tungumál",
@@ -536,7 +539,6 @@ OC.L10N.register(
     "Disable account" : "Gera notandaaðgang óvirkan",
     "Enable account" : "Virkja notandaaðgang",
     "Resend welcome email" : "Endursenda kveðjupóst",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
     "Remote wipe of devices" : "Fjartengd útþurrkun af tækjum",
     "Wipe {userid}'s devices" : "Þurrka út af tækjum {userid}",
     "Wiped {userid}'s devices" : "Þurrkaði út af tækjum {userid}",
@@ -586,6 +588,10 @@ OC.L10N.register(
     "No devices configured." : "Engin tæki skilgreind.",
     "The following devices are configured for your account:" : "Eftirfarandi tæki eru uppsett fyrir notandaaðganginn þinn:",
     "Your browser does not support WebAuthn." : "Vafrinn þinn styður ekki WebAuthn.",
+    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
+    "All checks passed." : "Stóðst allar prófanir.",
+    "There are some errors regarding your setup." : "Það komu upp villur varðandi uppsetninguna þína.",
+    "There are some warnings regarding your setup." : "Það komu upp viðvaranir varðandi uppsetninguna þína.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Sem stjórnandi geturðu fínstillt hegðun við deilingu. Endilega kíktu á hjálparskjölin til að sjá ítarlegri upplýsingar.",
     "You need to enable the File sharing App." : "Þú verður að virkja skráardeilingarforritið.",
     "App Store" : "Forritasafn",
@@ -594,15 +600,11 @@ OC.L10N.register(
     "Developer documentation ↗" : "Hjálparskjöl þróunaraðila↗",
     "Version {version}, {license}-licensed" : "Útgáfa {version}, {license}-notkunarleyfi",
     "Version {version}" : "Útgáfa {version}",
+    "Apply" : "Virkja",
     "All accounts" : "Allir aðgangar",
     "Admins" : "Kerfisstjórar",
     "Account group: {group}" : "Hópur notendaaðganga: {group}",
-    "Failed to create group" : "Mistókst að búa til hóp",
     "Account management" : "Umsýsla notandaaðgangs",
-    "Creating group…" : "Bý til hóp …",
-    "Create group" : "Búa til hóp",
-    "Group name" : "Heiti hóps",
-    "Please enter a valid group name" : "Settu inn gilt nafn á hópi",
     "Sending…" : "Sendi...",
     "Email sent" : "Tölvupóstur sendur",
     "Location" : "Staðsetning",
@@ -642,7 +644,6 @@ OC.L10N.register(
     "Disable" : "Gera óvirkt",
     "Allow untested app" : "Leyfa óprófuð forrit",
     "The app will be downloaded from the App Store" : "Forritið verður sótt úr forritabúðinni",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
     "Unknown" : "Óþekkt",
     "Never" : "Aldrei",
     "An error occurred during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
@@ -678,14 +679,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP-lykilorð",
     "Save" : "Vista",
     "Test and verify email settings" : "Prófa og staðfesta tölvupóststillingar",
-    "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
-    "All checks passed." : "Stóðst allar prófanir.",
-    "There are some errors regarding your setup." : "Það komu upp villur varðandi uppsetninguna þína.",
-    "There are some warnings regarding your setup." : "Það komu upp viðvaranir varðandi uppsetninguna þína.",
-    "Checking for system and security issues." : "Athuga með kerfis- og öryggisvandamál.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%2$s\">annálnum</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Athugaðu öryggi Nextcloud-skýsins með <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">öryggisskönnun okkar ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Ástæður til að nota Nextcloud á vinnustaðnum þínum",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
     "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
@@ -696,38 +689,22 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
     "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ef þú notaðir utanaðkomandi forrit til að tengjast við Nextcloud, skaltu ganga úr skugga um að þú útbúir lykilorð fyrir hvert slíkt forrit áður en þú virkjar 2FA tveggja-þrepa auðkenningu.",
-    "Missing optional index \"%s\" in table \"%s\"." : "Vantar valkvæða vísinn \"s\" í töflunni \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
+    "Logged in account must be a subadmin" : "Innskráður aðgangur verður að vera undirstjórnandi (subadmin)",
     "File locking" : "Skráalæsing",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál.",
     "The PHP memory limit is below the recommended value of %s." : "Minnismörk PHP eru lægri en gildið sem mælt er með; %s.",
-    "Speech-To-Text" : "Tal-í-texta",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Tal-í-texta getur verið framkvæmt af mismunandi forritum. Hér geturðu stillt hvaða forrit ætti að nota.",
     "Set default expiration date for shares" : "Setja sjálfgefinn gildistíma fyrir sameignir",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Leyfa sjálfklárun notandanafns í deilingarglugga og heimila aðgang að nafnaskrá kerfisins",
+    "Restrict account name autocompletion to users based on phone number integration" : "Leyfa sjálfklárun á heiti notendaaðganga á notendum byggt á samþættingu símanúmera",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
     "Your biography" : "Æviágrip þitt",
     "You are using <strong>{usage}</strong>" : "Þú ert að nota <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Þú ert að nota <strong>{usage}</strong> af <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Settu stjórnanda notenda",
-    "Username will be autogenerated" : "Notandanafn verður útbúið sjálfvirkt",
-    "Username (required)" : "Notandanafn (nauðsynlegt)",
-    "New user" : "Nýr notandi",
-    "Groups (required)" : "Hópar (nauðsynlegt)",
-    "Set user groups" : "Setja notendahópa",
-    "Administered groups" : "Stýrðir hópar",
-    "Set user as admin for …" : "Setja notanda sem stjórnanda fyrir …",
-    "Set user quota" : "Settu kvóta notandans",
-    "Add new user" : "Bæta við nýjum notanda",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} notandi …","{userCount} notendur …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} notandi","{userCount} notendur"],
-    "Loading users …" : "Hleð inn notendum …",
-    "Username" : "Notandanafn",
-    "User backend" : "Bakendi notanda",
-    "User actions" : "Aðgerðir notanda",
-    "Add user to group" : "Bæta notanda í hóp",
-    "Server error while trying to add WebAuthn device" : "Villa á þjóni við að bæta við WebAuthn-tæki",
-    "Name your device" : "Gefðu tækinu þínu nafn",
-    "Active accounts" : "Virkir aðgangar",
-    "Follow us on Twitter" : "Fylgstu með okkur á Twitter"
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
+    "Checking for system and security issues." : "Athuga með kerfis- og öryggisvandamál.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%2$s\">annálnum</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Athugaðu öryggi Nextcloud-skýsins með <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">öryggisskönnun okkar ↗</a>."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
