@@ -104,13 +104,12 @@ OC.L10N.register(
     "Set your password" : "Imposta la tua password",
     "Go to %s" : "Vai a %s",
     "Install Client" : "Installa client",
-    "Logged in account must be a subadmin" : "L'account che ha eseguito l'accesso deve essere un sotto-amministratore",
     "Apps" : "Applicazioni",
     "Personal" : "Personale",
     "Administration" : "Amministrazione",
     "Users" : "Utenti",
     "Additional settings" : "Impostazioni aggiuntive",
-    "Artificial Intelligence" : "Intelligenza artificiale",
+    "Assistant" : "Assistente",
     "Administration privileges" : "Privilegi di amministratore",
     "Groupware" : "Groupware",
     "Overview" : "Riepilogo",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Calendar" : "Calendario",
     "Personal info" : "Informazioni personali",
     "Mobile & desktop" : "Mobile e desktop",
+    "Artificial Intelligence" : "Intelligenza artificiale",
     "Email server" : "Server di posta",
     "Mail Providers" : "Provider di Posta Elettronica",
     "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Il provider di posta elettronica consente l'invio di e-mail direttamente tramite l'account e-mail personale dell'utente. Al momento, questa funzionalità è limitata agli inviti del calendario. Richiede Nextcloud Mail 4.1 e un account e-mail in Nextcloud Mail che corrisponda all'indirizzo e-mail dell'utente in Nextcloud.",
@@ -257,6 +257,7 @@ OC.L10N.register(
     "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache non funziona come dovrebbe, opcache_get_status() restituisce false, controlla la configurazione.",
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Il numero massimo di chiavi OPcache è stato quasi superato. Per garantire che tutti gli script possano essere mantenuti nella cache, si consiglia di applicare \"opcache.max_accelerated_files\" alla configurazione PHP con un valore superiore a \"%s\".",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "Il buffer OPcache è quasi pieno. Per garantire che tutti gli script possano essere conservati nella cache, si consiglia di applicare \"opcache.memory_consumption\" alla configurazione PHP con un valore superiore a \"%s\".",
+    "The PHP OPcache module is not properly configured. %s." : "Il modulo PHP OPcache non è correttamente configurato. %s.",
     "Correctly configured" : "Configurato correttamente",
     "PHP version" : "Versione PHP",
     "You are currently running PHP %s." : "Attualmente stai usando PHP %s.",
@@ -280,7 +281,6 @@ OC.L10N.register(
     "Profile information" : "Informazioni del profilo",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Immagine del profilo, nome e cognome, email, numero di telefono, indirizzo, sito web, Twitter, organizzazione, ruolo, titolo, biografia e se il tuo profilo è attivo o meno",
     "Nextcloud settings" : "Impostazioni di Nextcloud",
-    "Task:" : "Compito:",
     "Enable" : "Abilita",
     "Machine translation" : "Traduzione automatica",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "La traduzione automatica può essere implementata da diverse applicazioni. Qui puoi definire la priorità delle applicazioni di traduzione automatica che sono installate al momento.",
@@ -289,6 +289,7 @@ OC.L10N.register(
     "None of your currently installed apps provide image generation functionality" : "Nessuna delle tue applicazioni attualmente installate fornisce funzionalità di generazione di immagini",
     "Text processing" : "Elaborazione del testo",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "L'elaborazione del testo può essere implementata da diverse applicazioni. Qui puoi impostare quale applicazioni usare per quale compito.",
+    "Task:" : "Compito:",
     "Here you can decide which group can access certain sections of the administration settings." : "Qui puoi decidere quali gruppi possono accedere ad alcune sezioni delle impostazioni di amministrazione.",
     "Unable to modify setting" : "Impossibile modificare l'impostazione",
     "None" : "Nessuno",
@@ -305,7 +306,16 @@ OC.L10N.register(
     "Enforce password protection" : "Imponi la protezione con password",
     "Exclude groups from password requirements" : "Escludi gruppi dai requisiti della password",
     "Exclude groups from creating link shares" : "Escludi gruppi dalla creazione dei collegamenti di condivisione",
+    "Allow users to set custom share link tokens" : "Consenti agli utenti di impostare token di collegamento personalizzati",
+    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Le condivisioni con token personalizzati continueranno a essere accessibili dopo aver disabilitato questa impostazione",
+    "Shares with guessable tokens may be accessed easily" : "Le condivisioni con token indovinabili sono facilmente accessibili",
+    "Limit sharing based on groups" : "Limita la condivisione in base ai gruppi",
+    "Exclude some groups from sharing" : "Escludi alcuni gruppi dalla condivisione",
+    "Limit sharing to some groups" : "Limita la condivisione ad alcuni gruppi",
+    "Groups allowed to share" : "Gruppi autorizzati a condividere",
     "Groups excluded from sharing" : "Gruppi esclusi dalla condivisione",
+    "Not allowed groups will still be able to receive shares, but not to initiate them." : "I gruppi non autorizzati potranno comunque ricevere condivisioni, ma non avviarle.",
+    "Set default expiration date for internal shares" : "Imposta la data di scadenza predefinita per le condivisioni interne",
     "Enforce expiration date" : "Forza la data di scadenza",
     "Default expiration time of new shares in days" : "Scadenza predefinita delle nuove condivisioni in giorni",
     "Expire shares after x days" : "Scadenza delle condivisioni dopo x giorni",
@@ -316,8 +326,7 @@ OC.L10N.register(
     "Set default expiration date for shares via link or mail" : "Imposta la data di scadenza predefinita per le condivisioni tramite link o posta",
     "Default expiration time of shares in days" : "Scadenza predefinita delle condivisioni in giorni",
     "Privacy settings for sharing" : "Impostazioni sulla privacy per la condivisione",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Se completamento di \"stesso gruppo\" e \"integrazione numero di telefono\" sono attivi, una corrispondenza in uno dei due è sufficiente per mostrare l'utente.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Consenti il completamento automatico quando inserisci il nome completo o l'indirizzo email (ignorando la corrispondenza della rubrica mancante e l'appartenenza allo stesso gruppo)",
+    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Consenti il ​​completamento automatico del nome dell'account nella finestra di dialogo di condivisione e consenti l'accesso alla rubrica di sistema",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostra il testo della liberatoria sulla pagina di caricamento del collegamento pubblico (visualizzato solo quando l'elenco dei file è nascosto)",
     "Disclaimer text" : "Testo della clausola",
     "This text will be shown on the public link upload page when the file list is hidden." : "Questo testo sarà mostrato sulla pagina di caricamento del collegamento pubblico quando l'elenco dei file è nascosto.",
@@ -331,6 +340,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "L'autenticazione a due fattori non è applicata per i membri dei gruppi seguenti.",
     "Excluded groups" : "Gruppi esclusi",
     "Save changes" : "Salva le modifiche",
+    "Default" : "Predefinito",
     "Show details for {appName} app" : "Mostra dettagli per l'applicazione {appName}",
     "Update to {update}" : "Aggiorna a {update}",
     "Remove" : "Rimuovi",
@@ -349,6 +359,12 @@ OC.L10N.register(
     "No apps found for your version" : "Nessuna applicazione trovata per la tua versione",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n applicazione ha un aggiornamento disponibile","%n applicazioni hanno un aggiornamento disponibile","%n applicazioni hanno un aggiornamento disponibile"],
     "_Update_::_Update all_" : ["Aggiorna","Aggiorna","Aggiorna tutto"],
+    "Failed to load groups" : "Impossibile caricare i gruppi",
+    "Failed to create group" : "Creazione gruppo fallita",
+    "Create group" : "Crea gruppo",
+    "Group name" : "Nome del gruppo",
+    "Please enter a valid group name" : "Inserisci un nome di gruppo valido",
+    "Loading groups…" : "Caricamento gruppi...",
     "Nothing to show" : "Niente da mostrare",
     "Loading" : "Caricamento",
     "Carousel" : "Carosello",
@@ -359,7 +375,7 @@ OC.L10N.register(
     "Confirm" : "Conferma",
     "Cancel" : "Annulla",
     "Description" : "Descrizione",
-    "View in store" : "Visualizza nell'archivio",
+    "View in store" : "Visualizza nel negozio",
     "Visit website" : "Visita il sito web",
     "Usage documentation" : "Manuale d'uso",
     "Admin documentation" : "Documentazione di amministrazione",
@@ -369,8 +385,6 @@ OC.L10N.register(
     "Limit app usage to groups" : "Limita l'utilizzo dell'applicazione a gruppi",
     "No results" : "Nessun risultato",
     "Update to {version}" : "Aggiorna a {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione minima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione massima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Questa applicazione non può essere installata perché le seguenti dipendenze non sono soddisfatte:",
     "Author" : "Autore",
     "Categories" : "Categorie",
@@ -406,7 +420,7 @@ OC.L10N.register(
     "Last activity" : "Ultima attività",
     "Devices & sessions" : "Dispositivi e sessioni",
     "Web, desktop and mobile clients currently logged in to your account." : "Client web, desktop e mobile attualmente connessi al tuo account.",
-    "Error while creating device token" : "Errore durante la creazione del token di dispositivo",
+    "Error while creating device token" : "Errore durante la creazione del token",
     "App name" : "Nome applicazione",
     "Create new app password" : "Crea nuova password di applicazione",
     "App password copied!" : "Password dell'applicazione copiata!",
@@ -419,6 +433,7 @@ OC.L10N.register(
     "Password" : "Password",
     "Show QR code for mobile apps" : "Mostra il codice QR per le applicazioni mobili",
     "Use system cron service to call the cron.php file every 5 minutes." : "Usa il servizio cron di sistema per invocare il file cron.php ogni 5 minuti.",
+    "The cron.php needs to be executed by the system account \"{user}\"." : "Il cron.php deve essere eseguito dall'account di sistema \"{user}\".",
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "È necessaria l'estensione POSIX di PHP. Vedi la {linkstart}documentazione di PHP{linkend} per maggiori dettagli.",
     "Unable to update background job mode" : "Impossibile aggiornare la modalità delle operazioni in background",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Per un buon funzionamento del server, è importante configurare le operazioni in background correttamente. \"Cron\" è l'impostazione consigliata. Vedi la documentazione per ulteriori informazioni.",
@@ -430,6 +445,7 @@ OC.L10N.register(
     "Cron (Recommended)" : "Cron (Consigliato)",
     "Unable to update profile default setting" : "Impossibile aggiornare l'impostazione predefinita del profilo",
     "Profile" : "Profilo",
+    "Password confirmation is required" : "La conferma della password è richiesta",
     "Unable to update server side encryption config" : "Impossibile aggiornare la configurazione della crittografia lato server",
     "Server-side encryption" : "Cifratura lato server",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La cifratura lato server rende possibile cifrare i file caricati sul server. Ciò presenta dei limiti, come una riduzione delle prestazioni, perciò abilita questa funzione solo se necessario.",
@@ -444,11 +460,9 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Considera che la cifratura incrementa sempre la dimensione dei file.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Ti consigliamo di creare copie di sicurezza dei tuoi dati con regolarità, in caso di utilizzo della cifratura, assicurati di creare una copia delle chiavi di cifratura insieme ai tuoi dati.",
     "This is the final warning: Do you really want to enable encryption?" : "Questo è l'ultimo avviso: vuoi davvero abilitare la cifratura?",
-    "Failed to remove group \"{group}\"" : "Rimozione del gruppo \"{group}\" fallita",
     "Please confirm the group removal" : "Conferma la rimozione del gruppo",
     "Submit" : "Invia",
     "Rename group" : "Rinomina gruppo",
-    "Remove group" : "Rimuovi gruppo",
     "Current password" : "Password attuale",
     "New password" : "Nuova password",
     "Change password" : "Modifica password",
@@ -493,12 +507,12 @@ OC.L10N.register(
     "No locale set" : "Nessuna lingua impostata",
     "Your city" : "La tua città",
     "Your organisation" : "La tua organizzazione",
-    "Your phone number" : "Il tuo numero di telefono",
     "Edit your Profile visibility" : "Modifica la visibilità del profilo",
     "Unable to update profile enabled state" : "Impossibile aggiornare lo stato di attivazione del profilo",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "L'impostazione più restrittiva di visibilità o ambito è rispettata sul tuo profilo. Ad esempio, quando la visibilità è su \"Mostra a tutti\" e l'ambito è su \"Privato\", verrà rispettato \"Privato\".",
     "Unable to update visibility of {displayId}" : "Impossibile aggiornare la visibilità di {displayId}",
     "Your role" : "Il tuo ruolo",
+    "Timezone" : "Fuso orario",
     "Your X (formerly Twitter) handle" : "Il tuo handle di X (ex Twitter)",
     "Your website" : "Il tuo sito web",
     "Invalid value" : "Valore non valido",
@@ -513,18 +527,21 @@ OC.L10N.register(
     "Change" : "Modifica",
     "Delete" : "Elimina",
     "Reshare" : "Ri-condividi",
+    "School" : "Scuola",
     "Default language" : "Lingua predefinita",
     "Common languages" : "Lingue comuni",
     "Other languages" : "Altre lingue",
     "Password change is disabled because the master key is disabled" : "La modifica della password è disabilitata poiché la chiave principale è disabilitata",
     "Loading accounts …" : "Caricamento account in corso...",
     "Manager" : "Responsabile",
+    "Failed to search groups" : "Impossibile cercare i gruppi",
     "New account" : "Nuovo account",
     "Display name" : "Nome visualizzato",
     "Either password or email is required" : "La password o l'email è necessaria",
     "Password (required)" : "Password (richiesta)",
     "Email (required)" : "Email (richiesta)",
     "Email" : "Posta elettronica",
+    "Member of the following groups" : "Membro dei seguenti gruppi",
     "Quota" : "Quote",
     "Language" : "Lingua",
     "Set default language" : "Imposta lingua predefinita",
@@ -542,7 +559,6 @@ OC.L10N.register(
     "Disable account" : "Disabilita account",
     "Enable account" : "Abilita account",
     "Resend welcome email" : "Invia nuovamente email di benvenuto",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In caso di smarrimento di un dispositivo o uscita dall'organizzazione, questa funzione può cancellare a distanza i dati di Nextcloud da tutti i dispositivi associati a {userid}. Funziona solo se i dispositivi sono connessi a Internet.",
     "Remote wipe of devices" : "Cancellazione remota dei dispositivi",
     "Wipe {userid}'s devices" : "Cancella i dispositivi di {userid}",
     "Wiped {userid}'s devices" : "Dispositivi di {userid} cancellati",
@@ -575,21 +591,23 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "L'autenticazione senza password richiede una connessione sicura.",
     "Add WebAuthn device" : "Aggiungi dispositivo WebAuthn",
     "Please authorize your WebAuthn device." : "Autorizza il tuo dispositivo WebAuthn.",
-    "Adding your device …" : "Aggiunta del tuo dispositivo…",
+    "Adding your device …" : "Aggiunta del tuo dispositivo …",
     "Unnamed device" : "Dispositivo senza nome",
     "Passwordless Authentication" : "Autenticazione senza password",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura il tuo account per l'autenticazione senza password seguendo lo standard FIDO2.",
     "No devices configured." : "Nessun dispositivo configurato.",
     "The following devices are configured for your account:" : "I seguenti dispositivi sono configurati per il tuo account:",
     "Your browser does not support WebAuthn." : "Il tuo browser non supporta WebAuthn.",
+    "Security & setup warnings" : "Avvisi di sicurezza e di configurazione",
+    "Try again" : "Riprova",
+    "All checks passed." : "Tutti i controlli passati.",
+    "There are some errors regarding your setup." : "Sono presenti degli errori relativi alla tua configurazione.",
+    "There are some warnings regarding your setup." : "Sono presenti degli avvisi relativi alla tua configurazione.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "In qualità di amministratore puoi configurare in modo granulare il comportamento della condivisione. Vedi la documentazione per ulteriori informazioni.",
     "You need to enable the File sharing App." : "Devi attivare l'applicazione Condivisione file.",
     "App Store" : "App Store",
+    "Apply" : "Applica",
     "Admins" : "Amministratori",
-    "Failed to create group" : "Creazione gruppo fallita",
-    "Create group" : "Crea gruppo",
-    "Group name" : "Nome del gruppo",
-    "Please enter a valid group name" : "Inserisci un nome di gruppo valido",
     "Sending…" : "Invio in corso...",
     "Email sent" : "Email inviata",
     "Location" : "Posizione",
@@ -622,7 +640,6 @@ OC.L10N.register(
     "Disable" : "Disabilita",
     "Allow untested app" : "Consenti applicazione non verificata",
     "The app will be downloaded from the App Store" : "L'applicazione sarà scaricata dal negozio delle applicazioni",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Questa applicazione non è marcata come compatibile con la tua versione di Nextcloud. Se continui sarai ancora in grado di installare l'applicazione. Nota che l'applicazione potrebbe non funzionare come previsto.",
     "Unknown" : "Sconosciuto",
     "Never" : "Mai",
     "An error occurred during the request. Unable to proceed." : "Si è verificato un errore durante la richiesta. Impossibile continuare.",
@@ -658,14 +675,6 @@ OC.L10N.register(
     "SMTP Password" : "Password SMTP",
     "Save" : "Salva",
     "Test and verify email settings" : "Prova e verifica impostazioni email",
-    "Security & setup warnings" : "Avvisi di sicurezza e di configurazione",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "È importante per la sicurezza e le prestazioni della tua istanza che tutto sia configurato correttamente. Per aiutarti in questo senso, stiamo eseguendo alcuni controlli automatici. Vedi la documentazione collegata per ulteriori informazioni.",
-    "All checks passed." : "Tutti i controlli passati.",
-    "There are some errors regarding your setup." : "Sono presenti degli errori relativi alla tua configurazione.",
-    "There are some warnings regarding your setup." : "Sono presenti degli avvisi relativi alla tua configurazione.",
-    "Checking for system and security issues." : "Verifica di problemi di sistema e sicurezza.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Leggi attentamente le <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"%2$s\">log</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controlla la sicurezza del tuo Nextcloud con la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nostra scansione di sicurezza ↗</a>",
     "Reasons to use Nextcloud in your organization" : "Motivi per utilizzare Nextcloud nella tua organizzazione",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sviluppato dalla {communityopen}comunità di Nextcloud{linkclose}, il {githubopen}codice sorgente{linkclose} è rilasciato nei termini della licenza {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Mi piace sulla nostra pagina di Facebook!",
@@ -675,44 +684,23 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Questa versione di Nextcloud della community non è supportata e le notifiche istantanee non sono disponibili.",
     "Use a second factor besides your password to increase security for your account." : "Utilizza un secondo fattore oltre alla tua password per aumentare la sicurezza per il tuo account.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Se utilizzi applicazioni di terze parti per connetterti a Nextcloud, assicurati di creare e configurare una password per ciascuna applicazione prima di abilitare l'autenticazione a due fattori.",
-    "Missing optional index \"%s\" in table \"%s\"." : "Manca l'indice facoltativo \"%s\" nella tabella \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Nel database mancano alcuni indici. Poiché l'aggiunta di indici su tabelle grandi può richiedere del tempo, non sono stati aggiunti automaticamente. Eseguendo \"occ db:add-missing-indices\", gli indici mancanti possono essere aggiunti manualmente mentre l'istanza è in esecuzione. Una volta che gli indici sono stati aggiunti, le interrogazioni a tali tabelle sono solitamente più veloci.",
+    "Logged in account must be a subadmin" : "L'account che ha eseguito l'accesso deve essere un sotto-amministratore",
     "File locking" : "Blocco dei file",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Il blocco di file transazionale è disattivato, ciò potrebbe comportare problemi di race condition. Attiva \"filelocking.enabled\" nel config.php per evitare questi problemi.",
     "The PHP memory limit is below the recommended value of %s." : "Il limite di memoria di PHP è inferiore al valore consigliato di %s.",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Attualmente stai usando PHP %s. PHP 8.0 è deprecato in Nextcloud 27. Nextcloud 28 potrebbe richiedere almeno PHP 8.1. Aggiorna ad una delle versioni di PHP supportate ufficialmente fornite dal Gruppo PHP il prima possibile.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Stai usando la versione \"%s\" di MariaDB. Nextcloud 21 e successivi non supportano questa versione e richiedono MariaDB 10.2 o successivi.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Stai usando la versione \"%s\" di MySQL. Nextcloud 21 e successivi non supportano questa versione e richiedono MySQL 8.0 o MariaDB 10.2 o successivi.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Stai usando la versione \"%s\" di PostgreSQL. Nextcloud 21 e successivi non supportano questa versione e richiedono PostgreSQL 9.6 o successivi.",
-    "Speech-To-Text" : "Riconoscimento vocale",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Il riconoscimento vocale può essere implementato da diverse applicazioni. Qui puoi impostare quale applicazioni usare.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "Nessuna delle applicazioni installate integra la funzionalità di riconoscimento vocale",
-    "None of your currently installed apps provide Text processing functionality" : "Nessuna delle applicazioni installate integra la funzionalità elaborazione del testo",
     "Set default expiration date for shares" : "Imposta data di scadenza predefinita per le condivisioni",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Permetti l'autocompletamento dei nomi utente nella finestra di condivisione e l'accesso alla rubrica di sistema",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Se completamento di \"stesso gruppo\" e \"integrazione numero di telefono\" sono attivi, una corrispondenza in uno dei due è sufficiente per mostrare l'utente.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Consenti il completamento automatico quando inserisci il nome completo o l'indirizzo email (ignorando la corrispondenza della rubrica mancante e l'appartenenza allo stesso gruppo)",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione minima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione massima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
     "Your biography" : "La tua biografia",
     "You are using <strong>{usage}</strong>" : "Stai utilizzando <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Stai utilizzando <strong>{usage}</strong> di <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Imposta responsabile utente",
-    "Username will be autogenerated" : "Il nome utente verrà autogenerato",
-    "Username (required)" : "Nome utente (richiesto)",
-    "New user" : "Nuovo utente",
-    "Groups (required)" : "Gruppi (richiesto)",
-    "Set user groups" : "Imposta gruppi utente",
-    "Administered groups" : "Gruppi amministrati",
-    "Set user as admin for …" : "Imposta utente come admin di …",
-    "Set user quota" : "Imposta quota utente",
-    "Add new user" : "Aggiungi nuovo utente",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} utente …","{userCount} utenti …","{userCount} utenti …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} utente","{userCount} utenti","{userCount} utenti"],
-    "Loading users …" : "Caricamento utenti …",
-    "Username" : "Nome utente",
-    "User backend" : "Motore utente",
-    "User actions" : "Azioni utente",
-    "Add user to group" : "Aggiungi utente al gruppo",
-    "Server error while trying to add WebAuthn device" : "Errore del server durante il tentativo di aggiungere il dispositivo WebAuthn",
-    "Name your device" : "Nome del tuo dispositivo",
-    "Active accounts" : "Account attivi",
-    "Follow us on Twitter" : "Seguici su Twitter!"
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In caso di smarrimento di un dispositivo o uscita dall'organizzazione, questa funzione può cancellare a distanza i dati di Nextcloud da tutti i dispositivi associati a {userid}. Funziona solo se i dispositivi sono connessi a Internet.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Questa applicazione non è marcata come compatibile con la tua versione di Nextcloud. Se continui sarai ancora in grado di installare l'applicazione. Nota che l'applicazione potrebbe non funzionare come previsto.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "È importante per la sicurezza e le prestazioni della tua istanza che tutto sia configurato correttamente. Per aiutarti in questo senso, stiamo eseguendo alcuni controlli automatici. Vedi la documentazione collegata per ulteriori informazioni.",
+    "Checking for system and security issues." : "Verifica di problemi di sistema e sicurezza.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Leggi attentamente le <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"%2$s\">log</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controlla la sicurezza del tuo Nextcloud con la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nostra scansione di sicurezza ↗</a>"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
