@@ -101,7 +101,6 @@ OC.L10N.register(
     "Administration" : "Administration",
     "Users" : "Users",
     "Additional settings" : "Additional settings",
-    "Artificial Intelligence" : "Artificial Intelligence",
     "Administration privileges" : "Administration privileges",
     "Groupware" : "Groupware",
     "Overview" : "Overview",
@@ -111,6 +110,7 @@ OC.L10N.register(
     "Calendar" : "Calendar",
     "Personal info" : "Personal info",
     "Mobile & desktop" : "Mobile & desktop",
+    "Artificial Intelligence" : "Artificial Intelligence",
     "Email server" : "Email server",
     "Background jobs" : "Background jobs",
     "Unlimited" : "Unlimited",
@@ -187,7 +187,6 @@ OC.L10N.register(
     "Profile information" : "Profile information",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled",
     "Nextcloud settings" : "Nextcloud settings",
-    "Task:" : "Task:",
     "Enable" : "Enable",
     "Machine translation" : "Machine translation",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
@@ -196,6 +195,7 @@ OC.L10N.register(
     "None of your currently installed apps provide image generation functionality" : "None of your currently installed apps provide image generation functionality",
     "Text processing" : "Text processing",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
+    "Task:" : "Task:",
     "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
     "Unable to modify setting" : "Unable to modify setting",
     "None" : "None",
@@ -223,8 +223,6 @@ OC.L10N.register(
     "Set default expiration date for shares via link or mail" : "Set default expiration date for shares via link or mail",
     "Default expiration time of shares in days" : "Default expiration time of shares in days",
     "Privacy settings for sharing" : "Privacy settings for sharing",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Show disclaimer text on the public link upload page (only shown when the file list is hidden)",
     "Disclaimer text" : "Disclaimer text",
     "This text will be shown on the public link upload page when the file list is hidden." : "This text will be shown on the public link upload page when the file list is hidden.",
@@ -238,6 +236,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
     "Excluded groups" : "Excluded groups",
     "Save changes" : "Save changes",
+    "Default" : "Default",
     "Show details for {appName} app" : "Show details for {appName} app",
     "Update to {update}" : "Update to {update}",
     "Remove" : "Remove",
@@ -256,8 +255,13 @@ OC.L10N.register(
     "No apps found for your version" : "No apps found for your version",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app has an update available","%n apps have an update available"],
     "_Update_::_Update all_" : ["Update","Update all"],
+    "Failed to create group" : "Failed to create group",
+    "Create group" : "Create group",
+    "Group name" : "Group name",
+    "Please enter a valid group name" : "Please enter a valid group name",
+    "Loading groups…" : "Loading groups…",
     "Loading" : "Loading",
-    "Type" : "Type",
+    "Type" : "სახე",
     "Confirm" : "Confirm",
     "Cancel" : "Cancel",
     "Description" : "Description",
@@ -270,8 +274,6 @@ OC.L10N.register(
     "Limit app usage to groups" : "Limit app usage to groups",
     "No results" : "No results",
     "Update to {version}" : "Update to {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will be an error in the future.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will be an error in the future.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
     "Author" : "Author",
     "Categories" : "Categories",
@@ -345,11 +347,9 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Be aware that encryption always increases the file size.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data.",
     "This is the final warning: Do you really want to enable encryption?" : "This is the final warning: Do you really want to enable encryption?",
-    "Failed to remove group \"{group}\"" : "Failed to remove group \"{group}\"",
     "Please confirm the group removal" : "Please confirm the group removal",
     "Submit" : "Submit",
     "Rename group" : "Rename group",
-    "Remove group" : "Remove group",
     "Current password" : "Current password",
     "New password" : "New password",
     "Change password" : "Change password",
@@ -407,11 +407,12 @@ OC.L10N.register(
     "Unable to update federation scope of the primary {property}" : "Unable to update federation scope of the primary {property}",
     "Unable to update federation scope of additional {property}" : "Unable to update federation scope of additional {property}",
     "Add additional email" : "Add additional email",
-    "Add" : "Add",
+    "Add" : "დამატება",
     "Create" : "Create",
     "Change" : "Change",
-    "Delete" : "Delete",
+    "Delete" : "წაშლა",
     "Reshare" : "Reshare",
+    "School" : "School",
     "Default language" : "Default language",
     "Common languages" : "Common languages",
     "Other languages" : "Other languages",
@@ -429,6 +430,7 @@ OC.L10N.register(
     "Scroll to load more rows" : "Scroll to load more rows",
     "Password or insufficient permissions message" : "Password or insufficient permissions message",
     "Avatar" : "Avatar",
+    "Account name" : "ექაუნთის სახელი",
     "Group admin for" : "Group admin for",
     "Storage location" : "Storage location",
     "Last login" : "Last login",
@@ -436,7 +438,6 @@ OC.L10N.register(
     "{size} used" : "{size} used",
     "Delete account" : "Delete account",
     "Resend welcome email" : "Resend welcome email",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet.",
     "Remote wipe of devices" : "Remote wipe of devices",
     "Wipe {userid}'s devices" : "Wipe {userid}'s devices",
     "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
@@ -451,7 +452,7 @@ OC.L10N.register(
     "Set new password" : "Set new password",
     "Set new email address" : "Set new email address",
     "Set the language" : "Set the language",
-    "Done" : "Done",
+    "Done" : "დასრულდა",
     "Edit" : "Edit",
     "Visibility" : "Visibility",
     "Show language" : "Show language",
@@ -473,13 +474,13 @@ OC.L10N.register(
     "No devices configured." : "No devices configured.",
     "The following devices are configured for your account:" : "The following devices are configured for your account:",
     "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
+    "Security & setup warnings" : "Security & setup warnings",
+    "All checks passed." : "All checks passed.",
+    "There are some errors regarding your setup." : "There are some errors regarding your setup.",
+    "There are some warnings regarding your setup." : "There are some warnings regarding your setup.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "As admin you can fine-tune the sharing behavior. Please see the documentation for more information.",
     "You need to enable the File sharing App." : "You need to enable the File sharing App.",
     "Admins" : "Admins",
-    "Failed to create group" : "Failed to create group",
-    "Create group" : "Create group",
-    "Group name" : "Group name",
-    "Please enter a valid group name" : "Please enter a valid group name",
     "Sending…" : "Sending…",
     "Email sent" : "Email sent",
     "Location" : "Location",
@@ -510,7 +511,6 @@ OC.L10N.register(
     "Disable" : "Disable",
     "Allow untested app" : "Allow untested app",
     "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected.",
     "Unknown" : "Unknown",
     "Never" : "Never",
     "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
@@ -546,14 +546,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP Password",
     "Save" : "Save",
     "Test and verify email settings" : "Test and verify email settings",
-    "Security & setup warnings" : "Security & setup warnings",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information.",
-    "All checks passed." : "All checks passed.",
-    "There are some errors regarding your setup." : "There are some errors regarding your setup.",
-    "There are some warnings regarding your setup." : "There are some warnings regarding your setup.",
-    "Checking for system and security issues." : "Checking for system and security issues.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Reasons to use Nextcloud in your organization",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Like our Facebook page",
@@ -563,43 +555,22 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
     "Use a second factor besides your password to increase security for your account." : "Use a second factor besides your password to increase security for your account.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
-    "Missing optional index \"%s\" in table \"%s\"." : "Missing optional index \"%s\" in table \"%s\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
     "File locking" : "File locking",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems.",
     "The PHP memory limit is below the recommended value of %s." : "The PHP memory limit is below the recommended value of %s.",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher.",
-    "Speech-To-Text" : "Speech-To-Text",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
-    "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
     "Set default expiration date for shares" : "Set default expiration date for shares",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Allow username autocompletion in share dialog and allow access to the system address book",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will be an error in the future.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will be an error in the future.",
     "Your biography" : "Your biography",
     "You are using <strong>{usage}</strong>" : "You are using <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Set user manager" : "Set user manager",
-    "Username will be autogenerated" : "Username will be autogenerated",
-    "Username (required)" : "Username (required)",
-    "New user" : "New user",
-    "Groups (required)" : "Groups (required)",
-    "Set user groups" : "Set user groups",
-    "Administered groups" : "Administered groups",
-    "Set user as admin for …" : "Set user as admin for …",
-    "Set user quota" : "Set user quota",
-    "Add new user" : "Add new user",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} user …","{userCount} users …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} user","{userCount} users"],
-    "Loading users …" : "Loading users …",
-    "Username" : "Username",
-    "User backend" : "User backend",
-    "User actions" : "User actions",
-    "Add user to group" : "Add user to group",
-    "Server error while trying to add WebAuthn device" : "Server error while trying to add WebAuthn device",
-    "Name your device" : "Name your device",
-    "Follow us on Twitter" : "Follow us on Twitter"
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information.",
+    "Checking for system and security issues." : "Checking for system and security issues.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>."
 },
 "nplurals=2; plural=(n!=1);");
