@@ -104,13 +104,12 @@ OC.L10N.register(
     "Set your password" : "내 암호 설정하기",
     "Go to %s" : "%s(으)로 이동",
     "Install Client" : "클라이언트 설치",
-    "Logged in account must be a subadmin" : "로그인한 계정은 부관리자여야 합니다.",
     "Apps" : "앱",
     "Personal" : "개인",
     "Administration" : "관리",
     "Users" : "사용자",
     "Additional settings" : "고급 설정",
-    "Artificial Intelligence" : "인공지능",
+    "Assistant" : "어시스턴트",
     "Administration privileges" : "관리 권한",
     "Groupware" : "그룹웨어",
     "Overview" : "개요",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Calendar" : "달력",
     "Personal info" : "개인 정보",
     "Mobile & desktop" : "모바일 & 데스크톱",
+    "Artificial Intelligence" : "인공지능",
     "Email server" : "이메일 서버",
     "Mail Providers" : "메일 제공자",
     "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "메일 제공자는 사용자의 개인 이메일 계정을 통해 이메일을 직접 보낼 수 있도록 합니다. 현재 이 기능은 달력 초대에만 가능합니다. Nextcloud 메일 4.1이 필요하며, Nextcloud에 등록된 사용자의 이메일 주소와 일치하는 이메일 계정이 Nextcloud 메일에 있어야 합니다.",
@@ -227,8 +227,6 @@ OC.L10N.register(
     "PHP modules" : "PHP 모듈",
     "increases language translation performance and fixes sorting of non-ASCII characters" : ": 번역 성능을 개선과 비ASCII 문자의 바른 정렬을 위해 사용",
     "for Argon2 for password hashing" : ": Argon2의 암호 해싱을 위해 사용",
-    "for WebAuthn passwordless login" : ": WebAuthn 무암호 인증을 위해 사용",
-    "for WebAuthn passwordless login, and SFTP storage" : ": WebAuthn 무암호 인증 및 SFTP 저장소를 위해 사용",
     "for picture rotation in server and metadata extraction in the Photos app" : ": 서버에서의 이미지 회전과 Photos 앱의 메타데이터 추출을 위해 사용",
     "This instance is missing some required PHP modules. It is required to install them: %s." : "이 인스턴스에 필수 PHP 모듈 중 일부가 존재하지 않습니다. 다음 모듈을 설치하십시오: %s",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "이 인스턴스에 권장 PHP 모듈 중 일부가 존재하지 않습니다. 성능 향상과 호환성을 위하여 다음 PHP 모듈을 설치하는 것이 좋습니다: %s",
@@ -277,7 +275,6 @@ OC.L10N.register(
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "프로필 사진, 전체 이름, 이메일, 전화번호, 주소, 웹사이트, 트위터, 조직, 직책, 표제, 소개문구 및 프로필 활성화 여부",
     "Nextcloud settings" : "Nextcloud 환경설정",
     "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI 작업을 다양한 앱들을 통해 구현할 수 있습니다. 이곳에서 어떤 작업에 어떤 앱을 사용할지 설정할 수 있습니다.",
-    "Task:" : "작업:",
     "Enable" : "사용함",
     "None of your currently installed apps provide Task processing functionality" : "설치된 앱들 중 작업 처리 기능을 제공하는 것이 없습니다.",
     "Machine translation" : "기계 번역",
@@ -287,6 +284,7 @@ OC.L10N.register(
     "None of your currently installed apps provide image generation functionality" : "현재 설치된 앱 중 이미지 생성 기능을 제공하는 것이 없습니다",
     "Text processing" : "문장 처리",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "문장처리 기술을 채용한 앱이 이곳에 표시됩니다. 문장처리 기술을 사용할 앱과 해당 기술이 사용될 작업을 설정하십시오.",
+    "Task:" : "작업:",
     "None of your currently installed apps provide text processing functionality using the Text Processing API." : "설치된 앱들 중 텍스트 처리 API를 사용하여 텍스트 처리 기능을 제공하는 것이 없습니다.",
     "Here you can decide which group can access certain sections of the administration settings." : "이곳에서 각 설정 메뉴별로 해당 메뉴에 접근 가능한 그룹을 지정할 수 있습니다.",
     "Unable to modify setting" : "설정을 수정할 수 없습니다.",
@@ -324,10 +322,7 @@ OC.L10N.register(
     "Default expiration time of shares in days" : "공유에 대한 기본 유효기간 (일 단위)",
     "Privacy settings for sharing" : "공유에 대한 개인정보 보호 설정",
     "Allow account name autocompletion in share dialog and allow access to the system address book" : "공유 대화 상자에서 계정 이름 자동 완성을 허용하고 시스템 주소록에 접근 허가하기",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "\"같은 그룹\" 또는 \"전화번호 기반\" 자동 채우기가 활성화되었을 경우 각 항목에 일치하는 사용자가 자동으로 표시됩니다.",
     "Restrict account name autocompletion and system address book access to users within the same groups" : "계정 이름 자동 완성과 시스템 주소록 접근 권한을 같은 그룹의 사용자에게로 제한",
-    "Restrict account name autocompletion to users based on phone number integration" : "계정 이름 자동 완성을 전화번호 통합이 된 사용자에게로 제한",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "전체 이름 또는 이메일 주소를 입력했을 때 사용자 이름 자동 채우기를 허용 (전화번호 일치/소속 그룹 일치 여부에 대한 설정값을 무시)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "공개 링크 업로드 페이지에 고지 사항 문구를 표시 (파일 목록이 숨겨져 있는 경우에만 표시)",
     "Disclaimer text" : "고지 사항 문구",
     "This text will be shown on the public link upload page when the file list is hidden." : "파일 목록이 숨겨져 있으면 이 텍스트는 공개 링크 업로드 페이지에 표시됩니다.",
@@ -343,6 +338,10 @@ OC.L10N.register(
     "Excluded groups" : "제외된 그룹",
     "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹을 선택하거나 제외하면 이들의 계정에 2FA를 강제할지 다음 로직을 통해 결정합니다: 아무 그룹도 선택하지 않으면, 제외된 그룹의 사용자들을 제외한 모두에게 2FA가 활성화됩니다. 그룹을 선택했다면, 그 그룹(들)의 모든 멤버들에게 2FA가 활성화됩니다. 하나의 계정이 선택한 그룹과 제외한 그룹에 동시에 있다면, 선택한 그룹이 우선순위를 가져 2FA가 강제됩니다.",
     "Save changes" : "변경 사항 저장",
+    "Default" : "디폴트",
+    "Registered Deploy daemons list" : "등록된 배포 데몬 목록",
+    "No Deploy daemons configured" : "배포 데몬이 구성되지 않았습니다.",
+    "Register a custom one or setup from available templates" : "사용자 정의 항목을 등록하거나 사용 가능한 템플릿에서 설정",
     "Show details for {appName} app" : "{appName} 앱에 대한 상세 정보 보기",
     "Update to {update}" : "{update}(으)로 업데이트",
     "Remove" : "삭제",
@@ -362,6 +361,13 @@ OC.L10N.register(
     "No apps found for your version" : "설치된 버전에 대한 앱 없음",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n개의 앱을 업데이트 할 수 있습니다."],
     "_Update_::_Update all_" : ["모두 업데이트"],
+    "Failed to create group" : "그룹을 만들 수 없음",
+    "Creating group…" : "그룹 생성 ...",
+    "Create group" : "그룹 생성",
+    "Group name" : "그룹 이름",
+    "Please enter a valid group name" : "올바른 그룹 이름을 입력하세요",
+    "Search groups…" : "그룹 검색",
+    "Loading groups…" : "그룹 불러오는 중...",
     "Could not load app discover section" : "앱 검색 섹션을 불러올 수 없음",
     "Could not render element" : "요소를 렌더할 수 없음",
     "Nothing to show" : "표시할 항목 없음",
@@ -380,6 +386,8 @@ OC.L10N.register(
     "GPUs support" : "GPU 지원<br>",
     "Compute device" : "컴퓨팅 장치",
     "Learn more" : "자세히 알아보기",
+    "Environment variables" : "환경 변수",
+    "Read-only" : "읽기 전용",
     "Confirm" : "확인",
     "Cancel" : "취소",
     "Description" : "설명",
@@ -388,15 +396,13 @@ OC.L10N.register(
     "Usage documentation" : "사용법 문서",
     "Admin documentation" : "관리 문서",
     "Developer documentation" : "개발자 문서",
-    "Details" : "자세히",
+    "Details" : "세부사항",
     "All" : "모두",
     "Limit app usage to groups" : "앱 사용을 그룹으로 제한합니다.",
-    "No results" : "결과 없음",
+    "No results" : "검색 결과 없음",
     "Update to {version}" : "{version}(으)로 업데이트",
     "Default Deploy daemon is not accessible" : "기본 배포 데몬에 액세스할 수 없음",
     "Delete data on remove" : "제거 시 데이터 삭제",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
     "Latest updated" : "최신 업데이트됨",
     "Author" : "저자",
@@ -404,7 +410,7 @@ OC.L10N.register(
     "Resources" : "자원",
     "Documentation" : "문서",
     "Interact" : "상호작용",
-    "Report a bug" : "버그 신고",
+    "Report a bug" : "버그 보고",
     "Request feature" : "기능 요청",
     "Ask questions or discuss" : "질문 및 토론",
     "Rate the app" : "앱 평가하기",
@@ -461,6 +467,7 @@ OC.L10N.register(
     "Unable to update profile default setting" : "프로필 기본 설정을 업데이트 할 수 없음",
     "Profile" : "프로필",
     "Enable or disable profile by default for new accounts." : "신규 계정에 대한 프로필 기본 사용 여부를 설정하십시오.",
+    "Password confirmation is required" : "암호 확인이 필요합니다",
     "Failed to save setting" : "설정 저장 실패",
     "Unable to update server side encryption config" : "서버 측 암호화 설정을 갱신할 수 없음",
     "Server-side encryption" : "서버 측 암호화",
@@ -476,15 +483,11 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "암호화된 파일의 크기는 항상 커집니다.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "데이터를 주기적으로 백업하는 것을 추천하며, 암호화를 사용하고 있다면 데이터와 더불어 암호화 키도 백업하십시오.",
     "This is the final warning: Do you really want to enable encryption?" : "마지막 경고입니다. 암호화를 활성화하시겠습니까?",
-    "Failed to remove group \"{group}\"" : "그룹 \"{group}\"을(를) 삭제할 수 없음",
     "Please confirm the group removal" : "그룹 지우기를 확인해 주십시오",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "그룹 \"{group}\"을(를) 지우려고 합니다. 그룹의 계정은 삭제되지 않습니다.",
     "Submit" : "제출",
     "Rename group" : "그룹 이름 바꾸기",
-    "Remove group" : "그룹 지우기",
     "Current password" : "현재 암호",
     "New password" : "새 암호",
-    "Change password" : "암호 변경",
     "Choose your profile picture" : "프로필 사진을 선택하십시오",
     "Please select a valid png or jpg file" : "올바른 PNG 또는 JPG 파일을 선택하십시오",
     "Error setting profile picture" : "프로필 사진 설정 중 오류 발생",
@@ -518,11 +521,14 @@ OC.L10N.register(
     "Primary email for password reset and notifications" : "암호 초기화 및 알림 수신용 주 이메일 주소",
     "No email address set" : "이메일 주소가 설정되지 않음",
     "Your handle" : "내 아이디",
+    "Derived from your locale ({weekDayName})" : "지역의 규정을 바탕으로 함({weekDayName})",
     "Your headline" : "내 표제",
     "Unable to update language" : "언어를 갱신할 수 없음",
+    "Languages" : "언어",
     "Help translate" : "번역 돕기",
     "No language set" : "언어가 설정되지 않음",
     "Unable to update locale" : "지역을 갱신할 수 없음",
+    "Locales" : "지역",
     "Week starts on {firstDayOfWeek}" : "일주일이 {firstDayOfWeek}에 시작함",
     "No locale set" : "지역이 설정되지 않음",
     "Your city" : "내 도시",
@@ -534,6 +540,7 @@ OC.L10N.register(
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "표시 여부나 표시 범위 설정은 더 좁은 쪽이 우선 적용됩니다. 예를 들어, 표시 여부는 \"전체 공개\", 표시 범위는 \"개인\"으로 설정되어 있다면, 해당 항목은 \"개인\"에게만 보여집니다.",
     "Unable to update visibility of {displayId}" : "{displayId}의 표시 여부를 갱신할 수 없음",
     "Your role" : "내 직책",
+    "Timezone" : "시간대",
     "Your X (formerly Twitter) handle" : "내 X (구 Twitter) 아이디",
     "Your website" : "내 웹 사이트",
     "Invalid value" : "잘못된 값",
@@ -545,6 +552,7 @@ OC.L10N.register(
     "Change" : "변경",
     "Delete" : "삭제",
     "Reshare" : "재공유",
+    "School" : "학교",
     "Default language" : "기본 언어",
     "Common languages" : "공통 언어",
     "Other languages" : "다른 언어",
@@ -575,7 +583,6 @@ OC.L10N.register(
     "Disable account" : "계정 비활성화",
     "Enable account" : "계정 활성화",
     "Resend welcome email" : "환영 메일 다시 보내기",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "기기를 분실했거나 조직에서 이탈할 경우, 이를 통해 모든 기기에 있는 {userid} 관련 Nextcloud 데이터를 원격으로 삭제할 수 있습니다. 해당 기기들이 인터넷에 연결된 경우에 한하여 작동합니다.",
     "Remote wipe of devices" : "기기 원격 제거",
     "Wipe {userid}'s devices" : "{userid}의 기기 제거",
     "Wiped {userid}'s devices" : "{userid}의 기기를 제거함",
@@ -621,22 +628,24 @@ OC.L10N.register(
     "No devices configured." : "설정된 기기가 없습니다.",
     "The following devices are configured for your account:" : "다음의 기기가 계정에 설정되었습니다:",
     "Your browser does not support WebAuthn." : "WebAuthn이 현재 브라우저를 지원하지 않습니다.",
+    "Security & setup warnings" : "보안 및 설치 경고",
+    "Try again" : "다시 시도",
+    "All checks passed." : "모든 검사를 통과했습니다.",
+    "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 오류가 있습니다.",
+    "There are some warnings regarding your setup." : "설정을 살펴본 결과 몇 가지 경고할 것이 있습니다.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "You need to enable the File sharing App." : "파일 공유 앱을 활성화해야 합니다.",
     "Developer documentation ↗" : "개발자 문서 ↗",
+    "Apply" : "적용",
     "Admins" : "관리자",
     "Account group: {group}" : "계정 그룹: {group}",
-    "Failed to create group" : "그룹을 만들 수 없음",
     "Account management" : "계정 관리",
-    "Creating group…" : "그룹 생성 ...",
-    "Create group" : "그룹 생성",
-    "Group name" : "그룹 이름",
-    "Please enter a valid group name" : "올바른 그룹 이름을 입력하세요",
     "Sending…" : "보내는 중…",
     "Email sent" : "이메일 보냄",
     "Location" : "위치",
     "Profile picture" : "프로필 사진",
     "About" : "정보",
+    "Date of birth" : "생일",
     "Full name" : "전체 이름",
     "Additional email" : "추가 이메일",
     "Fediverse (e.g. Mastodon)" : "Fediverse (예: Mastodon)",
@@ -648,6 +657,7 @@ OC.L10N.register(
     "Website" : "웹사이트",
     "Profile visibility" : "프로필 표시 여부",
     "Locale" : "지역",
+    "First day of week" : "주 시작 요일",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "이 설정은 파일 공유, 달력 초대 등 핵심 기능에 필요하므로 비울 수 없습니다",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "이 계정에 대한 연합이 비활성화되어 현재 사용할 수 없는 상태입니다. 시스템 관리자에게 문의하십시오.",
     "Your apps" : "내 앱",
@@ -665,7 +675,6 @@ OC.L10N.register(
     "Disable" : "사용 안함",
     "Allow untested app" : "확인되지 않은 앱 허용",
     "The app will be downloaded from the App Store" : "이 앱이 앱 스토어에서 다운로드됩니다.",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
     "Unknown" : "알 수 없음",
     "Never" : "하지 않음",
     "Could not register device: Network error" : "기기를 등록할 수 없음: 네트워크 오류",
@@ -705,14 +714,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP 암호",
     "Save" : "저장",
     "Test and verify email settings" : "이메일 설정 테스트 및 검증",
-    "Security & setup warnings" : "보안 및 설치 경고",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "정확한 설정은 인스턴스의 보안과 성능에 중요합니다. 아래의 자동 진단 결과를 참조하여 최적의 설정으로 조정하십시오. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
-    "All checks passed." : "모든 검사를 통과했습니다.",
-    "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 오류가 있습니다.",
-    "There are some warnings regarding your setup." : "설정을 살펴본 결과 몇 가지 경고할 것이 있습니다.",
-    "Checking for system and security issues." : "시스템과 보안에 대한 문제를 확인하는 중",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">설치 가이드 ↗</a>를 다시 한 번 확인한 다음 <a href=\"%2$s\">로그</a>의 경고나 오류를 확인하세요.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">우리의 보안 검사 ↗</a>에서 이 Nextcloud의 보안을 점검하세요.",
     "Reasons to use Nextcloud in your organization" : "당신의 조직에서 Nextcloud를 사용해야 할 이유",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud 커뮤니티{linkclose}에서 개발, {githubopen}소스 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스를 따릅니다.",
     "Like our Facebook page" : "Facebook 페이지에서 좋아요 누르기",
@@ -722,43 +723,26 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "이 Nextcloud 커뮤니티 릴리즈는 지원되지 않으며 즉각적인 알림을 사용할 수 없습니다.",
     "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud에 연결하기 위해 서드파티 애플리케이션을 사용할 경우 2차 인증을 활성화하기 앞서 각 애플리케이션에 대한 앱 암호를 생성, 설정하십시오.",
-    "Missing optional index \"%s\" in table \"%s\"." : "표 \"%s\"의 optional index \"%s\"이(가) 사라졌습니다",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "데이터베이스에 일부 인덱스가 없습니다. 큰 테이블에 인덱스를 추가하는 데 시간이 걸리기 때문에 자동으로 추가하지 않았습니다. 명령행에서 \"occ db:add-missing-indices\" 명령을 실행하여 인스턴스를 실행하는 동안 수동으로 인덱스를 추가할 수 있습니다. 해당 테이블에 인덱스를 추가하면 질의 속도가 다시 빨라집니다.",
+    "Logged in account must be a subadmin" : "로그인한 계정은 부관리자여야 합니다.",
     "File locking" : "파일 잠금",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "트랜잭션 파일 잠금이 비활성화되어 있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 \"filelocking.enabled\"를 활성화하여 이 문제를 방지하십시오.",
     "The PHP memory limit is below the recommended value of %s." : "PHP 메모리 제한이 추천값인 %s보다 작습니다.",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "현재 PHP %s이(가) 동작 중입니다. Nextcloud 27에서 PHP 8.0의 지원이 중단되었습니다. Nextcloud 28은 최소 PHP 8.1이 요구됩니다. 가능한 빨리 PHP Group에서 제공하는 공식 지원 PHP 버전으로 업그레이드 하십시오.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "현재 MariaDB \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MariaDB 10.2 이상을 사용하십시오.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "현재 MySQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. MySQL 8.0 혹은 MariaDB 10.2 이상을 사용하십시오.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "현재 PostgreSQL \"%s\" 버전이 사용되고 있습니다. Nextcloud 21 및 그 이상의 버전은 이를 지원하지 않습니다. PostgreSQL 9.6 이상을 사용하십시오.",
-    "Speech-To-Text" : "음성인식",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "음성인식 기능을 채용한 앱이 이곳에 표시됩니다. 음성인식 기능을 사용할 앱을 선택하십시오. ",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "현재 설치된 앱 중 음성인식 기능을 제공하는 것이 없습니다",
-    "None of your currently installed apps provide Text processing functionality" : "현재 설치된 앱 중 문장처리 기술을 제공하는 것이 없습니다",
+    "for WebAuthn passwordless login" : ": WebAuthn 무암호 인증을 위해 사용",
+    "for WebAuthn passwordless login, and SFTP storage" : ": WebAuthn 무암호 인증 및 SFTP 저장소를 위해 사용",
     "Set default expiration date for shares" : "공유에 대한 기본 만료 날짜 설정",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "공유 대화창에서 시스템 주소록에 있는 사용자 이름을 자동으로 채울 수 있도록 허용",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "\"같은 그룹\" 또는 \"전화번호 기반\" 자동 채우기가 활성화되었을 경우 각 항목에 일치하는 사용자가 자동으로 표시됩니다.",
+    "Restrict account name autocompletion to users based on phone number integration" : "계정 이름 자동 완성을 전화번호 통합이 된 사용자에게로 제한",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "전체 이름 또는 이메일 주소를 입력했을 때 사용자 이름 자동 채우기를 허용 (전화번호 일치/소속 그룹 일치 여부에 대한 설정값을 무시)",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
     "Your biography" : "내 소개문구",
     "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong>를 사용하고 있습니다.",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "전체 <strong>{totalSpace}</strong> 중 <strong>{usage}</strong>(<strong>{usageRelative}%</strong>)를 사용하고 있습니다.",
-    "Set user manager" : "사용자 담당 관리자 지정",
-    "Username will be autogenerated" : "사용자 이름이 자동으로 생성됩니다",
-    "Username (required)" : "사용자 이름 (필수)",
-    "New user" : "새 사용자",
-    "Groups (required)" : "그룹 (필수)",
-    "Set user groups" : "사용자 그룹 설정",
-    "Set user as admin for …" : "사용자를 다음에 대한 관리자로 설정 ...",
-    "Set user quota" : "사용자 할당량 지정",
-    "Add new user" : "새 사용자 추가",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount}명의 사용자 ..."],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount}명의 사용자"],
-    "Loading users …" : "사용자 불러오는 중 ...",
-    "Username" : "사용자 이름",
-    "User backend" : "사용자 백엔드",
-    "User actions" : "사용자 동작",
-    "Add user to group" : "사용자를 그룹에 추가",
-    "Server error while trying to add WebAuthn device" : "WebAuthn 기기 추가 시도 중 서버 오류 발생",
-    "Name your device" : "장치 이름 설정",
-    "Active accounts" : "활성화된 계정",
-    "Follow us on Twitter" : "트위터에서 팔로하기"
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "기기를 분실했거나 조직에서 이탈할 경우, 이를 통해 모든 기기에 있는 {userid} 관련 Nextcloud 데이터를 원격으로 삭제할 수 있습니다. 해당 기기들이 인터넷에 연결된 경우에 한하여 작동합니다.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "정확한 설정은 인스턴스의 보안과 성능에 중요합니다. 아래의 자동 진단 결과를 참조하여 최적의 설정으로 조정하십시오. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
+    "Checking for system and security issues." : "시스템과 보안에 대한 문제를 확인하는 중",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">설치 가이드 ↗</a>를 다시 한 번 확인한 다음 <a href=\"%2$s\">로그</a>의 경고나 오류를 확인하세요.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">우리의 보안 검사 ↗</a>에서 이 Nextcloud의 보안을 점검하세요."
 },
 "nplurals=1; plural=0;");
