@@ -109,7 +109,7 @@ OC.L10N.register(
     "Administration" : "Administrasjon",
     "Users" : "Brukere",
     "Additional settings" : "Flere innstillinger",
-    "Artificial Intelligence" : "Kunstig intelligens",
+    "Assistant" : "Assistent",
     "Administration privileges" : "Administratorrettigheter",
     "Groupware" : "Gruppevare",
     "Overview" : "Oversikt",
@@ -119,6 +119,7 @@ OC.L10N.register(
     "Calendar" : "Kalender",
     "Personal info" : "Personlig informasjon",
     "Mobile & desktop" : "Mobil og skrivebord",
+    "Artificial Intelligence" : "Kunstig intelligens",
     "Email server" : "E-postserver",
     "Mail Providers" : "Epost-tilbydere",
     "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Epost-tilbyder åpner for sending av epost direkte via brukerens personlige epost-konto. På nåværende tidspunkt er denne funskjonen begrenset til kalenderinvitasjoner. Krever Nextcloud Mail 4.1 og en epost-konto i Nextcloud Mail som er lik brukerens epost-adresse i Nextcloud.",
@@ -275,7 +276,6 @@ OC.L10N.register(
     "HTTP headers" : "HTTP-hoder",
     "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s'  er ikke satt til '%2$s'. Noen funksjoner fungerer kanskje ikke som de skal, da det anbefales å justere denne innstillingen tilsvarende.",
     "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s' er ikke satt til '%2$s'.  Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen tilsvarende.",
-    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s' inneholder ikke '%2$s'. Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen tilsvarende.",
     "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP-hodet '%1$s' er ikke satt til  '%2$s', '%3$s', '%4$s', '%5$s' eller '%6$s'. Dette kan lekke referanseinformasjon. Se {w3c-recommendation}.",
     "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "HTTP-hodet 'Strict-Transport-Security' er ikke satt til minst '%d' sekunder (gjeldende verdi: '%d'). For økt sikkerhet anbefales det å bruke en lang HSTS-policy.",
     "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- HTTP-hodet 'Strict-Transport-Security' er misformet: '%s'. For forbedret sikkerhet anbefales det å aktivere HSTS.",
@@ -318,7 +318,6 @@ OC.L10N.register(
     "Nextcloud settings" : "Nextcloud innstillinger",
     "Unified task processing" : "Enhetlig oppgavebehandling",
     "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI-oppgaver kan implementeres av forskjellige apper. Her kan du angi hvilken app som skal brukes til hvilken oppgave.",
-    "Task:" : "Oppgave:",
     "Enable" : "Aktiver",
     "None of your currently installed apps provide Task processing functionality" : "Ingen av appene du installerte for øyeblikket, har oppgavebehandlingsfunksjonalitet",
     "Machine translation" : "Maskinoversettelse",
@@ -328,6 +327,7 @@ OC.L10N.register(
     "None of your currently installed apps provide image generation functionality" : "Ingen av de installerte appene dine har bildegenereringsfunksjonalitet",
     "Text processing" : "Tekstbehandling",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Tekstbehandlingsoppgaver kan implementeres av forskjellige apper. Her kan du angi hvilken app som skal brukes til hvilken oppgave.",
+    "Task:" : "Oppgave:",
     "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Ingen av de installerte appene dine har tekstbehandlingsfunksjonalitet ved hjelp av API-en for tekstbehandling.",
     "Here you can decide which group can access certain sections of the administration settings." : "Her kan du bestemme hvilken gruppe som kan få tilgang til bestemte deler av administrasjonsinnstillingene.",
     "Unable to modify setting" : "Kan ikke endre innstilling",
@@ -364,10 +364,7 @@ OC.L10N.register(
     "Default expiration time of shares in days" : "Standard utløpstid for delinger i dager",
     "Privacy settings for sharing" : "Personverninnstillinger for deling",
     "Allow account name autocompletion in share dialog and allow access to the system address book" : "Tillat automatisk fullføring av kontonavn i delingsdialogen og gi tilgang til systemets adressebok",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Hvis autofullføring \"samme gruppe\" og \"telefonnummerintegrasjon\" er aktivert, er en match i begge nok til å vise brukeren.",
     "Restrict account name autocompletion and system address book access to users within the same groups" : "Begrens automatisk fullføring av kontonavn og tilgang til systemadressebok til brukere i de samme gruppene",
-    "Restrict account name autocompletion to users based on phone number integration" : "Begrens automatisk fullføring av kontonavn til brukere basert på integrering av telefonnummer",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillat autofullføring når du skriver inn fullt navn eller e-postadresse (ignorerer manglende telefonbok-treff og er i samme gruppe)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Vis ansvarsfraskrivelse på den offentlige lenkeopplastingssiden (vises bare når fillisten er skjult)",
     "Disclaimer text" : "Ansvarsfraskrivelse tekst",
     "This text will be shown on the public link upload page when the file list is hidden." : "Denne teksten vises på den offentlig opplastingssiden når fillisten er tom.",
@@ -383,6 +380,10 @@ OC.L10N.register(
     "Excluded groups" : "Utelukkede grupper",
     "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Når grupper velges/ekskluderes, bruker de følgende logikk for å avgjøre om en konto har 2FA håndhevet: Hvis ingen grupper er valgt, aktiveres 2FA for alle unntatt medlemmer av de ekskluderte gruppene. Hvis grupper velges, er 2FA aktivert for alle medlemmer av disse. Hvis en konto er både i en valgt og ekskludert gruppe, har den valgte forrang og 2FA håndheves.",
     "Save changes" : "Lagre endringer",
+    "Default" : "Forvalg",
+    "Registered Deploy daemons list" : "Registrert liste over distribuerings-daemoner",
+    "No Deploy daemons configured" : "Ingen distribuerings-daemoner konfigurert",
+    "Register a custom one or setup from available templates" : "Registrer en tilpasset en eller sett opp fra tilgjengelige maler",
     "Show details for {appName} app" : "Vis detaljer for {appName}-app",
     "Update to {update}" : "Oppdater til {update}",
     "Remove" : "Fjern",
@@ -441,8 +442,6 @@ OC.L10N.register(
     "Update to {version}" : "Oppdater til {version}",
     "Default Deploy daemon is not accessible" : "Standard distribuerings-daemon er ikke tilgjengelig.",
     "Delete data on remove" : "Slett data ved fjerning",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen minimumversjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen høyeste versjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Denne appen kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt:",
     "Latest updated" : "Sist oppdatert",
     "Author" : "Forfatter",
@@ -471,7 +470,7 @@ OC.L10N.register(
     "Marked for remote wipe" : "Markert for fjernsletting",
     "Device settings" : "Enhetsinnstillinger",
     "Allow filesystem access" : "Tillatt filsystemtilgang",
-    "Rename" : "Gi nytt navn",
+    "Rename" : "Endre navn",
     "Revoke" : "Avslå",
     "Wipe device" : "Slett enhet",
     "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Hvis du opphever dette tokenet, kan det forhindre sletting av enheten hvis det ikke har startet slettingen enda.",
@@ -480,7 +479,7 @@ OC.L10N.register(
     "Devices & sessions" : "Enheter og økter",
     "Web, desktop and mobile clients currently logged in to your account." : "Følgende nett, skrivebord og mobile klienter er for øyeblikket logget på din konto.",
     "Error while creating device token" : "Feil under opprettelse av enhetsnøkkel",
-    "App name" : "Appnavn",
+    "App name" : "App-navn",
     "Create new app password" : "Lag nytt apppassord",
     "App password copied!" : "App-passord kopiert!",
     "Copy app password" : "Kopier app-passord",
@@ -592,6 +591,7 @@ OC.L10N.register(
     "he/him" : "han/ham",
     "they/them" : "de/dem",
     "Your role" : "Din rolle",
+    "Timezone" : "Tidssone",
     "Your X (formerly Twitter) handle" : "Ditt X- (tidligere Twitter) brukernavn",
     "Your website" : "Din nettside",
     "Invalid value" : "Ugyldig verdi",
@@ -602,10 +602,11 @@ OC.L10N.register(
     "Unable to update federation scope of additional {property}" : "Kan ikke oppdatere føderasjonsomfanget for ytterligere {property}",
     "Add additional email" : "Legg til ekstra e-post",
     "Add" : "Legg til",
-    "Create" : "Ny",
+    "Create" : "Opprett",
     "Change" : "Endre",
     "Delete" : "Slett",
     "Reshare" : "Videredele",
+    "School" : "Skole",
     "Default language" : "Standard språk",
     "Common languages" : "Vanlige språk",
     "Other languages" : "Andre språk",
@@ -652,7 +653,6 @@ OC.L10N.register(
     "Disable account" : "Deaktiver konto",
     "Enable account" : "Aktiver konto",
     "Resend welcome email" : "Send velkomst-epost igjen",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfelle man har mistet enheter eller skal ut av organisasjonen, så kan dette fjernslette Nextcloud data fra alle enheter tilknyttet bruker med {userid}. Dette fungerer kun dersom enhetene er tilkoblet internett.",
     "Remote wipe of devices" : "Fjernsletting av enheter",
     "Wipe {userid}'s devices" : "Tøm enhetene til {userid}",
     "Wiped {userid}'s devices" : "Slettet {userid}s enheter",
@@ -704,6 +704,11 @@ OC.L10N.register(
     "No devices configured." : "Ingen enheter konfigurert.",
     "The following devices are configured for your account:" : "Følgende enheter er konfigurert for kontoen din:",
     "Your browser does not support WebAuthn." : "Nettleseren din støtter ikke WebAuthn.",
+    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
+    "Try again" : "Prøv igjen",
+    "All checks passed." : "Alle sjekker bestått.",
+    "There are some errors regarding your setup." : "Det er noen feil angående oppsettet ditt.",
+    "There are some warnings regarding your setup." : "Det er noen advarsler angående oppsettet ditt.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administrator kan du fininnstille delingsoppførselen. Se dokumentasjonen for mer informasjon.",
     "You need to enable the File sharing App." : "Du trenger å aktivere fildelingsappen.",
     "App Store" : "Appbutikk",
@@ -712,6 +717,7 @@ OC.L10N.register(
     "Developer documentation ↗" : "Utviklerdokumentasjon ↗",
     "Version {version}, {license}-licensed" : "Versjon {version}, {license}-lisensiert",
     "Version {version}" : "Versjon {version}",
+    "Apply" : "Bruk",
     "All accounts" : "Alle kontoer",
     "Admins" : "Administratorer",
     "Account group: {group}" : "Kontogruppe: {group}",
@@ -754,7 +760,6 @@ OC.L10N.register(
     "Disable" : "Deaktiver ",
     "Allow untested app" : "Tillatt utestet app",
     "The app will be downloaded from the App Store" : "Appen vil bli lastet ned fra app-butikken",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Denne appen er ikke merket som kompatibel med Nextcloud-versjonen. Hvis du fortsetter, vil du fortsatt kunne installere appen. Vær oppmerksom på at appen kanskje ikke fungerer som forventet.",
     "Unknown" : "Ukjent",
     "Never" : "Aldri",
     "Could not register device: Network error" : "Kunne ikke registrere enheten: nettverksfeil",
@@ -797,14 +802,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP-passord",
     "Save" : "Lagre",
     "Test and verify email settings" : "Test og bekreft e-postinnstillinger",
-    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det er viktig for sikkerheten og ytelsen på din installasjon at alt er satt opp rett. For å hjelpe deg er det satt i verk noen automatiske sjekker. Se vedlagt lenke for å lese mer i dokumentasjonen.",
-    "All checks passed." : "Alle sjekker bestått.",
-    "There are some errors regarding your setup." : "Det er noen feil angående oppsettet ditt.",
-    "There are some warnings regarding your setup." : "Det er noen advarsler angående oppsettet ditt.",
-    "Checking for system and security issues." : "Sjekker for system- og sikkerhetsfeil.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dobbeltsjekk <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installasjonsguidene ↗</a> og se etter feil eller advarsler i <a href=\"%2$s\">loggen</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Sjekk sikkerheten til din Nextcloud med <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår sikkerhetsskanning ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Grunner til å bruke Nextcloud i organisasjonen din",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utviklet av {communityopen}Nextcloud-miljøet{linkclose},  {githubopen}kildekoden{linkclose} er lisensiert under {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Lik vår Facebook-side",
@@ -822,10 +819,22 @@ OC.L10N.register(
     "The PHP memory limit is below the recommended value of %s." : "PHP-minnegrensen er under den anbefalte verdien på %s.",
     "for WebAuthn passwordless login" : "for WebAuthn-passordfripålogging",
     "for WebAuthn passwordless login, and SFTP storage" : "for WebAuthn-passordfripålogging og SFTP-lagring",
+    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s' inneholder ikke '%2$s'. Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen tilsvarende.",
     "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL-versjon \"%s\" oppdaget. PostgreSQL >=12 og <=16 foreslås for best ytelse, stabilitet og funksjonalitet med denne versjonen av Nextcloud.",
     "Set default expiration date for shares" : "Angi standard utløpsdato for delinger",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Hvis autofullføring \"samme gruppe\" og \"telefonnummerintegrasjon\" er aktivert, er en match i begge nok til å vise brukeren.",
+    "Restrict account name autocompletion to users based on phone number integration" : "Begrens automatisk fullføring av kontonavn til brukere basert på integrering av telefonnummer",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillat autofullføring når du skriver inn fullt navn eller e-postadresse (ignorerer manglende telefonbok-treff og er i samme gruppe)",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen minimumversjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen høyeste versjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
     "Your biography" : "Din biografi",
     "You are using <strong>{usage}</strong>" : "Du bruker <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du bruker <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)"
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du bruker <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfelle man har mistet enheter eller skal ut av organisasjonen, så kan dette fjernslette Nextcloud data fra alle enheter tilknyttet bruker med {userid}. Dette fungerer kun dersom enhetene er tilkoblet internett.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Denne appen er ikke merket som kompatibel med Nextcloud-versjonen. Hvis du fortsetter, vil du fortsatt kunne installere appen. Vær oppmerksom på at appen kanskje ikke fungerer som forventet.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det er viktig for sikkerheten og ytelsen på din installasjon at alt er satt opp rett. For å hjelpe deg er det satt i verk noen automatiske sjekker. Se vedlagt lenke for å lese mer i dokumentasjonen.",
+    "Checking for system and security issues." : "Sjekker for system- og sikkerhetsfeil.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dobbeltsjekk <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installasjonsguidene ↗</a> og se etter feil eller advarsler i <a href=\"%2$s\">loggen</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Sjekk sikkerheten til din Nextcloud med <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår sikkerhetsskanning ↗</a>."
 },
 "nplurals=2; plural=(n != 1);");
