@@ -101,7 +101,6 @@ OC.L10N.register(
     "Administration" : "Quản trị viên",
     "Users" : "Người dùng",
     "Additional settings" : "Cài đặt bổ sung",
-    "Artificial Intelligence" : "Trí tuệ nhân tạo",
     "Administration privileges" : "Đặc quyền quản trị",
     "Groupware" : "Phần mềm nhóm",
     "Overview" : "Tổng quan",
@@ -111,6 +110,7 @@ OC.L10N.register(
     "Calendar" : "Lịch",
     "Personal info" : "Thông tin cá nhân",
     "Mobile & desktop" : "Điện thoại di động và máy tính để bàn",
+    "Artificial Intelligence" : "Trí tuệ nhân tạo",
     "Email server" : "Máy chủ mail",
     "Background jobs" : "Các công việc trong nền",
     "Unlimited" : "Không giới hạn",
@@ -138,7 +138,6 @@ OC.L10N.register(
     "Profile information" : "Thông tin cá nhân",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Ảnh hồ sơ, tên đầy đủ, email, số điện thoại, địa chỉ, trang web, Twitter, tổ chức, vai trò, tiêu đề, tiểu sử và liệu hồ sơ của bạn có được bật hay không",
     "Nextcloud settings" : "Cài đặt Cloud",
-    "Task:" : "Tác vụ:",
     "Enable" : "Bật",
     "Machine translation" : "Dịch máy",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Dịch máy có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây, bạn có thể xác định mức độ ưu tiên của ứng dụng dịch máy mà bạn đã cài đặt vào lúc này.",
@@ -147,6 +146,7 @@ OC.L10N.register(
     "None of your currently installed apps provide image generation functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng tạo hình ảnh",
     "Text processing" : "Xử lý văn bản",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Các tác vụ xử lý mở rộng có thể được thực hiện bởi các ứng dụng khác nhau. Tại đây bạn có thể đặt ứng dụng nào sẽ được sử dụng cho tác vụ nào.",
+    "Task:" : "Tác vụ:",
     "Here you can decide which group can access certain sections of the administration settings." : "Tại đây bạn có thể quyết định nhóm nào có thể truy cập các phần nhất định của cài đặt quản trị.",
     "Unable to modify setting" : "Không thể sửa đổi cài đặt",
     "None" : "Không gì cả",
@@ -160,8 +160,6 @@ OC.L10N.register(
     "Enforce password protection" : "Thực thi bảo vệ mật khẩu",
     "Enforce expiration date" : "Buộc có ngày hết hạn",
     "Set default expiration date for shares to other servers" : "Đặt ngày hết hạn mặc định cho việc chia sẻ sang các máy chủ khác",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Nếu tính năng tự động hoàn thành \"cùng nhóm\" và \"tích hợp số điện thoại\" được bật thì kết quả khớp trong cả hai đều đủ để hiển thị cho người dùng.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Cho phép tự động điền khi nhập họ tên hoặc địa chỉ email (bỏ qua trùng danh bạ bị thiếu và thuộc cùng một nhóm)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Hiển thị văn bản từ chối trách nhiệm trên trang tải lên liên kết công khai (chỉ hiển thị khi danh sách tệp bị ẩn)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Văn bản này sẽ được hiển thị trên trang tải lên liên kết công khai khi danh sách tệp bị ẩn.",
     "Default share permissions" : "Quyền chia sẻ mặc định",
@@ -191,6 +189,10 @@ OC.L10N.register(
     "No apps found for your version" : "Không tìm thấy ứng dụng nào cho phiên bản của bạn",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n ứng dụng có sẵn bản cập nhật"],
     "_Update_::_Update all_" : ["Cập nhật tất cả"],
+    "Failed to create group" : "Không tạo được nhóm",
+    "Create group" : "Tạo nhóm",
+    "Group name" : "Tên nhóm",
+    "Please enter a valid group name" : "Vui lòng nhập tên nhóm hợp lệ",
     "Loading" : "Đang tải",
     "Type" : "Loại",
     "Learn more" : "Đọc nhiều hơn",
@@ -201,13 +203,11 @@ OC.L10N.register(
     "Visit website" : "Truy cập trang web",
     "Admin documentation" : "Tài liệu quản trị",
     "Developer documentation" : "Tài liệu dành cho nhà phát triển",
-    "Details" : "Thông tin",
+    "Details" : "Chi tiết",
     "All" : "Tất cả",
     "Limit app usage to groups" : "Giới hạn sử dụng ứng dụng cho các nhóm",
     "No results" : "Không có kết quả",
     "Update to {version}" : "Cập nhật tới {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ứng dụng này không thể được cài đặt vì các điều kiện phụ thuộc sau không được đáp ứng:",
     "Categories" : "Các hạng mục",
     "Resources" : "Các nguồn lực",
@@ -264,14 +264,11 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Xin lưu ý rằng mã hóa luôn làm tăng kích thước tệp.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Việc tạo bản sao lưu thường xuyên cho dữ liệu của bạn luôn là điều tốt, trong trường hợp mã hóa, hãy đảm bảo sao lưu các khóa mã hóa cùng với dữ liệu của bạn.",
     "This is the final warning: Do you really want to enable encryption?" : "Cảnh báo lần cuối: Bạn có thực sự muốn kích hoạt tính năng mã hoá?",
-    "Failed to remove group \"{group}\"" : "Không xóa được nhóm \"{group}\"",
     "Please confirm the group removal" : "Vui lòng xác nhận việc xóa nhóm",
     "Submit" : "Gửi đi",
     "Rename group" : "Đổi tên nhóm",
-    "Remove group" : "Xóa nhóm",
     "Current password" : "Mật khẩu cũ",
     "New password" : "Mật khẩu mới",
-    "Change password" : "Đổi mật khẩu",
     "Choose your profile picture" : "Chọn ảnh hồ sơ của bạn",
     "Please select a valid png or jpg file" : "Vui lòng chọn tệp png hoặc jpg hợp lệ",
     "Error setting profile picture" : "Lỗi cài đặt ảnh hồ sơ",
@@ -317,6 +314,7 @@ OC.L10N.register(
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Cài đặt hạn chế hơn về khả năng hiển thị hoặc phạm vi được tôn trọng trên Hồ sơ của bạn. Ví dụ: nếu mức độ hiển thị được đặt thành \"Hiển thị cho mọi người\" và phạm vi được đặt thành \"Riêng tư\" thì \"Riêng tư\" sẽ được tôn trọng.",
     "Unable to update visibility of {displayId}" : "Không thể cập nhật mức độ hiển thị của {displayId}",
     "Your role" : "Vai trò của bạn",
+    "Timezone" : "Múi giờ",
     "Your website" : "Trang web của bạn",
     "Unable to update {property}" : "Không thể cập nhật {property}",
     "No {property} set" : "Không có  {property} nào được đặt",
@@ -325,8 +323,8 @@ OC.L10N.register(
     "Unable to update federation scope of additional {property}" : "Không thể cập nhật phạm vi liên kết của {property} bổ sung",
     "Add additional email" : "Thêm email bổ sung",
     "Add" : "Thêm",
-    "Create" : "Tạo mới",
-    "Change" : "Chỉnh sửa",
+    "Create" : "Tạo",
+    "Change" : "Thay đổi",
     "Delete" : "Xóa",
     "Reshare" : "Chia sẻ lại",
     "Default language" : "Ngôn ngữ mặc định",
@@ -334,7 +332,6 @@ OC.L10N.register(
     "Other languages" : "Những ngôn ngữ khác",
     "Password change is disabled because the master key is disabled" : "Thay đổi mật khẩu bị vô hiệu hóa vì khóa chính bị vô hiệu hóa",
     "Manager" : "Giám đốc",
-    "Display name" : "Tên hiển thị",
     "Either password or email is required" : "Cần có mật khẩu hoặc email",
     "Password (required)" : "Mật khẩu (được yêu câu)",
     "Email (required)" : "Email (bắt buộc)",
@@ -342,7 +339,7 @@ OC.L10N.register(
     "Quota" : "Hạn ngạch",
     "Language" : "Ngôn ngữ",
     "Set default language" : "Đặt ngôn ngữ mặc định",
-    "Total rows summary" : "Tóm tắt tổng số hàng",
+    "Total rows summary" : "Tổng số hàng",
     "Scroll to load more rows" : "Cuộn để tải thêm hàng",
     "Password or insufficient permissions message" : "Mật khẩu hoặc thông báo không đủ quyền",
     "Avatar" : "Hình đại diện",
@@ -354,7 +351,6 @@ OC.L10N.register(
     "{size} used" : "{size} đã sử dụng",
     "Delete account" : "Xóa tài khoản",
     "Resend welcome email" : "Gửi lại email chào mừng",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Trong trường hợp thiết bị bị mất hoặc thoát khỏi tổ chức, thao tác này có thể xóa từ xa dữ liệu Nextcloud khỏi tất cả các thiết bị được liên kết với {userid}. Chỉ hoạt động nếu các thiết bị được kết nối với internet.",
     "Remote wipe of devices" : "Xóa thiết bị từ xa",
     "Wipe {userid}'s devices" : "Xóa thiết bị của {userid}",
     "Wiped {userid}'s devices" : "Đã xóa thiết bị của {userid}",
@@ -369,7 +365,7 @@ OC.L10N.register(
     "Set new password" : "Đặt mật khẩu mới",
     "Set new email address" : "Đặt địa chỉ email mới",
     "Set the language" : "Đặt ngôn ngữ",
-    "Done" : "Hoàn thành",
+    "Done" : "Hoàn tất",
     "Edit" : "Chỉnh sửa",
     "Visibility" : "Hiển thị",
     "Show language" : "Hiển thị ngôn ngữ",
@@ -390,13 +386,15 @@ OC.L10N.register(
     "No devices configured." : "Không có thiết bị nào được định cấu hình.",
     "The following devices are configured for your account:" : "Các thiết bị sau được định cấu hình cho tài khoản của bạn:",
     "Your browser does not support WebAuthn." : "Trình duyệt của bạn không hỗ trợ WebAuthn.",
+    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
+    "Try again" : "Thử lại",
+    "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
+    "There are some errors regarding your setup." : "Có một số lỗi liên quan đến thiết lập của bạn.",
+    "There are some warnings regarding your setup." : "Có một số cảnh báo liên quan đến thiết lập của bạn.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Với tư cách là quản trị viên, bạn có thể tinh chỉnh hành vi chia sẻ. Vui lòng xem tài liệu để biết thêm thông tin.",
     "You need to enable the File sharing App." : "Bạn cần kích hoạt Ứng dụng chia sẻ tệp.",
+    "Apply" : "Áp dụng",
     "Admins" : "Quản trị viên",
-    "Failed to create group" : "Không tạo được nhóm",
-    "Create group" : "Tạo nhóm",
-    "Group name" : "Tên nhóm",
-    "Please enter a valid group name" : "Vui lòng nhập tên nhóm hợp lệ",
     "Sending…" : "Đang gửi...",
     "Email sent" : "Email đã được gửi",
     "Location" : "Vị trí",
@@ -425,7 +423,6 @@ OC.L10N.register(
     "Disable" : "Tắt",
     "Allow untested app" : "Cho phép ứng dụng chưa được kiểm tra",
     "The app will be downloaded from the App Store" : "Ứng dụng sẽ được tải xuống từ App Store",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
     "Unknown" : "Không xác định",
     "Never" : "Không bao giờ",
     "An error occurred during the request. Unable to proceed." : "Đã xảy ra lỗi trong quá trình yêu cầu. Không thể tiếp tục.",
@@ -458,45 +455,18 @@ OC.L10N.register(
     "SMTP Password" : "Mật khẩu SMTP",
     "Save" : "Lưu",
     "Test and verify email settings" : "Kiểm tra và xác minh cài đặt email",
-    "Security & setup warnings" : "Bảo mật và thiết lập cảnh báo",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Điều quan trọng đối với tính bảo mật và hiệu suất của phiên bản của bạn là mọi thứ đều được đặt cấu hình chính xác. Để giúp bạn điều đó, chúng tôi đang thực hiện một số kiểm tra tự động. Vui lòng xem tài liệu được liên kết để biết thêm thông tin.",
-    "All checks passed." : "Tất cả các kiểm tra đã thoả điều kiện",
-    "There are some errors regarding your setup." : "Có một số lỗi liên quan đến thiết lập của bạn.",
-    "There are some warnings regarding your setup." : "Có một số cảnh báo liên quan đến thiết lập của bạn.",
-    "Checking for system and security issues." : "Kiểm tra các vấn đề về hệ thống và bảo mật.",
     "Use a second factor besides your password to increase security for your account." : "Sử dụng yếu tố thứ hai ngoài mật khẩu để tăng tính bảo mật cho tài khoản của bạn.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Cơ sở dữ liệu thiếu một số mục. Do thực tế là việc thêm mục trên các bảng lớn có thể mất một chút thời gian, chúng không được thêm tự động. Bằng cách chạy \"occ db:add-missing-indices\", các mục bị thiếu đó có thể được thêm thủ công trong khi phiên bản tiếp tục chạy. Sau khi các mục được thêm vào, các truy vấn vào các bảng đó thường nhanh hơn nhiều.",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Bạn hiện đang chạy PHP %s. PHP 8.0 hiện không được dùng nữa trong Nextcloud 27. Nextcloud 28 có thể yêu cầu ít nhất PHP 8.1. Vui lòng nâng cấp lên một trong các phiên bản PHP được hỗ trợ chính thức do Nhóm PHP cung cấp càng sớm càng tốt.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Phiên bản MariaDB \"%s\" được sử dụng. Nextcloud 21 trở lên không hỗ trợ phiên bản này và yêu cầu MariaDB 10.2 trở lên.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Phiên bản MySQL \"%s\" được sử dụng. Nextcloud 21 trở lên không hỗ trợ phiên bản này và yêu cầu MySQL 8.0 hoặc MariaDB 10.2 trở lên.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Phiên bản PostgreSQL \"%s\" được sử dụng. Nextcloud 21 trở lên không hỗ trợ phiên bản này và yêu cầu PostgreSQL 9.6 trở lên.",
-    "Speech-To-Text" : "Chuyển giọng nói thành văn bản",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Chuyển giọng nói thành văn bản có thể được triển khai bởi các ứng dụng khác nhau. Tại đây bạn có thể đặt ứng dụng nào sẽ được sử dụng.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng Chuyển giọng nói thành văn bản",
-    "None of your currently installed apps provide Text processing functionality" : "Không có ứng dụng nào bạn cài đặt hiện tại cung cấp chức năng xử lý văn bản",
     "Set default expiration date for shares" : "Đặt ngày hết hạn mặc định cho cổ phiếu",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Cho phép tự động hoàn thành tên người dùng trong hộp thoại chia sẻ và cho phép truy cập vào sổ địa chỉ hệ thống",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Nếu tính năng tự động hoàn thành \"cùng nhóm\" và \"tích hợp số điện thoại\" được bật thì kết quả khớp trong cả hai đều đủ để hiển thị cho người dùng.",
+    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Cho phép tự động điền khi nhập họ tên hoặc địa chỉ email (bỏ qua trùng danh bạ bị thiếu và thuộc cùng một nhóm)",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối thiểu được chỉ định. Đây sẽ là một lỗi trong tương lai.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ứng dụng này không có phiên bản Nextcloud tối đa được chỉ định. Đây sẽ là một lỗi trong tương lai.",
     "Your biography" : "Tiểu sử của bạn",
     "You are using <strong>{usage}</strong>" : "Bạn đang sử dụng {usage}",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Bạn đang sử dụng {usage} trên {totalSpace} ({usageRelative}%)",
-    "Set user manager" : "Đặt trình quản lý người dùng",
-    "Username will be autogenerated" : "Tên người dùng sẽ được tạo tự động",
-    "Username (required)" : "Tên người dùng (bắt buộc)",
-    "New user" : "Người dùng mới",
-    "Groups (required)" : "Nhóm (bắt buộc)",
-    "Set user groups" : "Đặt nhóm người dùng",
-    "Administered groups" : "Nhóm được quản lý",
-    "Set user as admin for …" : "Đặt người dùng làm quản trị viên cho…",
-    "Set user quota" : "Đặt hạn ngạch người dùng",
-    "Add new user" : "Thêm người dùng mới",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} người dùng…"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} người dùng"],
-    "Loading users …" : "Đang tải người dùng…",
-    "Username" : "Tên đăng nhập",
-    "User backend" : "Trang cài đặt người dùng",
-    "User actions" : "Hành động của người dùng",
-    "Add user to group" : "Thêm người dùng vào nhóm",
-    "Server error while trying to add WebAuthn device" : "Lỗi máy chủ khi cố gắng thêm thiết bị WebAuthn",
-    "Name your device" : "Đặt tên cho thiết bị của bạn"
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Trong trường hợp thiết bị bị mất hoặc thoát khỏi tổ chức, thao tác này có thể xóa từ xa dữ liệu Nextcloud khỏi tất cả các thiết bị được liên kết với {userid}. Chỉ hoạt động nếu các thiết bị được kết nối với internet.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ứng dụng này không được đánh dấu là tương thích với phiên bản Nextcloud của bạn. Nếu bạn tiếp tục, bạn vẫn có thể cài đặt ứng dụng. Lưu ý rằng ứng dụng có thể không hoạt động như mong đợi.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Điều quan trọng đối với tính bảo mật và hiệu suất của phiên bản của bạn là mọi thứ đều được đặt cấu hình chính xác. Để giúp bạn điều đó, chúng tôi đang thực hiện một số kiểm tra tự động. Vui lòng xem tài liệu được liên kết để biết thêm thông tin.",
+    "Checking for system and security issues." : "Kiểm tra các vấn đề về hệ thống và bảo mật."
 },
 "nplurals=1; plural=0;");
