@@ -7,6 +7,7 @@ OC.L10N.register(
     "File not found" : "ফাইল খুঁজে পাওয়া গেল না",
     "Translate" : "Translate",
     "Reload" : "পূনরায় লোড কর",
+    "you" : "তুমি",
     "guest" : "অতিথি",
     "Saved" : "সংরক্ষণ করা হলো",
     "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
@@ -17,6 +18,7 @@ OC.L10N.register(
     "Edit" : "সম্পাদনা",
     "Done" : "শেষ হলো",
     "Details" : "বিসতারিত",
+    "Choose" : "বেছে নিন",
     "Info" : "Info",
     "Warning" : "সতর্কবাণী"
 },
