@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "نوع الملف غير معروف",
     "An error occurred. Please contact your admin." : "حدث خطأ، يرجى مراجعة المسؤول.",
     "Invalid image" : "الصورة غير صالحة",
-    "No temporary profile picture available, try again" : "لا تتوفر صورة ملف شخصي مؤقتة، حاول مرة أخرى",
-    "No crop data provided" : "لم يتم تحديد قص البيانات.",
-    "No valid crop data provided" : "تحديد قص البيانات غير صحيح.",
-    "Crop is not square" : "القص ليس مربعا",
     "State token does not match" : "حالة Token غير مطابقة",
     "Invalid app password" : "كلمة المرور للتطبيق غير صحيحه",
     "Could not complete login" : "لا يمكن إكمال عملية تسجيل الدخول",
@@ -51,6 +47,11 @@ OC.L10N.register(
     "No translation provider available" : "لا توجد خدمة للترجمة",
     "Could not detect language" : "لم يُمكن اكتشاف اللغة",
     "Unable to translate" : "لم يُمكن الترجمة",
+    "[%d / %d]: %s" : "[%d/%d]: %s",
+    "Repair step:" : "خطوة صيانة:",
+    "Repair info:" : "معلومات صيانة:",
+    "Repair warning:" : "تحذير صيانة:",
+    "Repair error:" : "خطأ صيانة:",
     "Nextcloud Server" : "خادم نكست كلاود",
     "Some of your link shares have been removed" : "تم ازالة البعض من مشاركة الروابط الخاصة بك.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "نظرا لسبب آمني تم ازالة البعض من روابط المشاركة الخاصة بك. يرجى مراجعة الرابط التالي لمزيد من التفاصيل.",
@@ -58,11 +59,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "أدخِل مفتاح الاشتراك الخاص بك في تطبيق الدعم لزيادة حد الأقصى من الحسابات. يمنحك هذا أيضًا جميع المزايا الإضافية التي يقدمها Nextcloud Enterprise ويوصى به بشدة للشركات و المؤسسات.",
     "Learn more ↗" : "تعلم المزيد ↗",
     "Preparing update" : "جارٍ تهيئة التحديث",
-    "[%d / %d]: %s" : "[%d/%d]: %s",
-    "Repair step:" : "خطوة صيانة:",
-    "Repair info:" : "معلومات صيانة:",
-    "Repair warning:" : "تحذير صيانة:",
-    "Repair error:" : "خطأ صيانة:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "يرجى الترقية من خلال سطر الأوامر command line updater حيث أن الترقية من المستعرض معطلة في ملف config.php.",
     "Turned on maintenance mode" : "تشغيل وضع الصيانة.",
     "Turned off maintenance mode" : "تعطيل وضع الصيانة.",
@@ -79,8 +75,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (غير متوافق)",
     "The following apps have been disabled: %s" : "التطبيقات التاليه غير مفعله: %s",
     "Already up to date" : "محدّثة مسبقاً",
-    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
+    "Unknown" : "غير معروف",
+    "PNG image" : "صورة PNG",
     "unknown text" : "النص غير معروف",
     "Hello world!" : "مرحبا بالعالم!",
     "sunny" : "مشمس",
@@ -109,7 +105,6 @@ OC.L10N.register(
     "Federated user" : "مستخدم السحابة الموحدة",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "إنشاء مشاركة",
-    "Direct link copied to clipboard" : "تمّ نسخ الرابط المباشر إلى الحافظة",
     "Please copy the link manually:" : "يرجى نسخ الرابط يدوياً:",
     "Custom date range" : "نطاق زمني مخصص",
     "Pick start date" : "إختر تاريخ البدء",
@@ -146,23 +141,23 @@ OC.L10N.register(
     "Account name" : "اسم الحساب",
     "Server side authentication failed!" : "رفض الخادم المصادقة!",
     "Please contact your administrator." : "يرجى التواصل مع مسؤول النظام.",
-    "Temporary error" : "خطأ مؤقت",
-    "Please try again." : "يرجى المحاولة مرة أخرى.",
+    "Session error" : "خطأ في الجلسة",
+    "It appears your session token has expired, please refresh the page and try again." : "يبدو أن أَمَارَة جلستك قد انتهت صلاحيتها. رجاءً، حدِّث الصفحة ثم حاول مرة أخرى.",
     "An internal error occurred." : "حدث خطأ داخلي.",
     "Please try again or contact your administrator." : "حاول مجددا أو تواصل مع مسؤول النظام.",
     "Password" : "كلمة المرور",
     "Log in with a device" : "سجل دخولك عن طريق جهاز",
     "Login or email" : "تسجيل الدخول أو البريد الإلكتروني",
     "Your account is not setup for passwordless login." : "لم يتم إعداد حسابك لتسجيل الدخول بدون كلمة مرور.",
-    "Browser not supported" : "المتصفح غير مدعوم",
-    "Passwordless authentication is not supported in your browser." : "المصادقة بدون كلمة مرور غير مدعومة في متصفحك.",
     "Your connection is not secure" : "اتصالك غير آمن",
     "Passwordless authentication is only available over a secure connection." : "المصادقة بدون كلمة مرور متاحة فقط عبر اتصال آمن.",
+    "Browser not supported" : "المتصفح غير مدعوم",
+    "Passwordless authentication is not supported in your browser." : "المصادقة بدون كلمة مرور غير مدعومة في متصفحك.",
     "Reset password" : "تعديل كلمة السر",
+    "Back to login" : "العودة إلى تسجيل الدخول",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "إذا كان هذا الحساب موجودًا، فسيتم إرسال رسالة إعادة تعيين كلمة المرور إلى عنوان البريد الإلكتروني الخاص به. إذا لم تستلمها، فتحقق من عنوان بريدك الإلكتروني و/أو تسجيل الدخول، وتحقق من مجلدات البريد العشوائي عندك أو اطلب المساعدة من مسؤول النظام لديك.",
     "Couldn't send reset email. Please contact your administrator." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. يرجى مراجعة المسؤول.",
     "Password cannot be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تواصل مع مسؤول النظام.",
-    "Back to login" : "العودة إلى تسجيل الدخول",
     "New password" : "كلمات سر جديدة",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "المحتوى الخاص بك مشفر. لن تكون هناك طريقة لاستعادة محتوياتك وبياناتك بعد إعادة تعيين كلمة مرورك. إذا لم تكن متأكدًا مما يجب فعله ، فيرجى الاتصال بالمسؤول قبل المتابعة. هل حقا تريد الاستمرار؟",
     "I know what I'm doing" : "أعرف ماذا أفعل",
@@ -207,6 +202,42 @@ OC.L10N.register(
     "Login form is disabled." : "نموذج تسجيل الدخول معطل",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "نموذج تسجيل الدخول إلى نكست كلاود مُعطّل. استخدم خيار تسجيل دخول آخر إذا كان متاحًا أو اتصل بمسؤول النظام.",
     "More actions" : "إجراءات إضافية",
+    "Password is too weak" : "كلمة المرور ضعيفة جدّاً",
+    "Password is weak" : "كلمة المرور ضعيفة",
+    "Password is average" : "كلمة المرور متوسطة القوة",
+    "Password is strong" : "كلمة المرور قوية",
+    "Password is very strong" : "كلمة المرور قوية جدّاً",
+    "Password is extremely strong" : "كلمة المرور قوية جدّاً جدّاً",
+    "Unknown password strength" : "يتعذّر تقييم قوة كلمة المرور ",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "على الأرجح أن بيانات ملفاتك ومجلداتك يمكن الوصول إليها من الإنترنت لأن الملف <code>.htaccess</code>لايعمل.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "لمعلومات أكثر حول كيفية تهيئة خادومك، رجاءً،{linkStart}أنظُر التوثيق {linkEnd}",
+    "Autoconfig file detected" : "تمّ اكتشاف ملف التهيئة التلقائية Autoconfig",
+    "The setup form below is pre-filled with the values from the config file." : "نموذج الإعدادات أدناه تمّت تعبئته بقيم من ملف التهيئة.",
+    "Security warning" : "تحذير الأمان",
+    "Create administration account" : "إنشاء حساب إدارة",
+    "Administration account name" : "اسم حساب الإدارة",
+    "Administration account password" : "كلمة مرور حساب الإدارة",
+    "Storage & database" : "التخزين و قاعدة البيانات",
+    "Data folder" : "مجلد المعلومات",
+    "Database configuration" : "تهيئة قاعدة البيانات",
+    "Only {firstAndOnlyDatabase} is available." : "فقط {firstAndOnlyDatabase} متوفرة.",
+    "Install and activate additional PHP modules to choose other database types." : "ثبت وفعل مودلات PHP اضافية لاستخدام قاعدة بيانات مختلفة.",
+    "For more details check out the documentation." : "للمزيد من التفاصيل، يرجى الإطلاع على الدليل.",
+    "Performance warning" : "تحذير حول الأداء",
+    "You chose SQLite as database." : "لقد اخترت SQLite كقاعدة بيانات.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "يجب استخدام SQLite فقط في حالات الحد الأدنى من التطوير. للنسخة النهائية، نوصي باستخدام خلفية قاعدة بيانات مختلفة.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "إذا كنت تستخدم عملاء لمزامنة الملفات ، فإن استخدام SQLite لا ينصح به بشدة.",
+    "Database user" : "مستخدم قاعدة البيانات",
+    "Database password" : "كلمة سر مستخدم قاعدة البيانات",
+    "Database name" : "اسم قاعدة البيانات",
+    "Database tablespace" : "مساحة جدول قاعدة البيانات",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "يرجى تحديد رقم المنفذ مع اسم المضيف (على سبيل المثال ، mycloud:5432).",
+    "Database host" : "خادم قاعدة البيانات",
+    "localhost" : "localhost جهازك المُضِيف المحلي",
+    "Installing …" : "جاري التثبيت...",
+    "Install" : "تثبيت",
+    "Need help?" : "تحتاج إلى مساعدة؟",
+    "See the documentation" : "اطلع على التعليمات",
     "{name} version {version} and above" : "المستعرض {name} من النسخة {version} فما فوق",
     "This browser is not supported" : "المستعرض غير مدعوم",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "المستعرض غير مدعوم. رجاءً قم بالترقية إلى نسخة أحدث أو إلى  مستعرض آخر مدعوم.",
@@ -247,31 +278,19 @@ OC.L10N.register(
     "Type to search for existing projects" : "اكتب هنا للبحث عن مشاريع مسجلة",
     "New in" : "الجديد في",
     "View changelog" : "اعرض سجل التغييرات",
-    "Very weak password" : "كلمة السر ضعيفة جدا",
-    "Weak password" : "كلمة السر ضعيفة",
-    "So-so password" : "كلمة سر غير فعالة",
-    "Good password" : "كلمة السر جيدة",
-    "Strong password" : "كلمة السر قوية",
     "No action available" : "لا يتوفر أي إجراء",
     "Error fetching contact actions" : "حدث خطأ أثناء جلب إجراءات جهات الاتصال",
     "Close \"{dialogTitle}\" dialog" : "أغلق الحوار \"{dialogTitle}\"",
     "Email length is at max (255)" : "طول رسالة الإيميل وصل أقصى المسموح ( 255)",
-    "Non-existing tag #{tag}" : "وسم غير موجود #{tag}",
-    "Restricted" : "مقيد",
-    "Invisible" : "مخفي",
-    "Delete" : "إلغاء",
-    "Rename" : "إعادة التسمية",
-    "Collaborative tags" : "أوسمة تعاونية",
-    "No tags found" : "لم يُعثَر على أي وسم",
     "Clipboard not available, please copy manually" : "الحافظة غير متاحة. رجاءً، قم بالنسخ يدويّاً",
     "Personal" : "شخصي",
     "Accounts" : "الحسابات",
     "Admin" : "المدير",
     "Help" : "المساعدة",
     "Access forbidden" : "الوصول محظور",
+    "Back to %s" : "العودة إلى %s",
     "Page not found" : "الصفحة غير موجودة",
     "The page could not be found on the server or you may not be allowed to view it." : "لم يُمكن إيجاد الصفحة على الخادم أو ربما غير مسموح لك بالوصول إليها.",
-    "Back to %s" : "العودة إلى %s",
     "Too many requests" : "الطلبات أقصى من الحد المسموح",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "يوجد طلبات أقصى من الحد المسموح به في الشبكة. أعد المحاولة أو اتصل بمسؤول النظام.",
     "Error" : "خطأ",
@@ -289,34 +308,6 @@ OC.L10N.register(
     "File: %s" : "ملف : %s",
     "Line: %s" : "السطر: %s",
     "Trace" : "متابعة",
-    "Security warning" : "تحذير الأمان",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "للحصول على معلومات حول كيفية تكوين الخادم الخاص بك، يرجى الاطلاع على <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">التعليمات</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>إنشاء حساب مُشرِف</strong>",
-    "New admin account name" : "اسم حساب المشرف الجديد",
-    "New admin password" : "كلمة مرور المشرف الجديد",
-    "Show password" : "اظهر كلمة المرور",
-    "Toggle password visibility" : "تبديل قراءة كلمة المرور",
-    "Storage & database" : "التخزين و قاعدة البيانات",
-    "Data folder" : "مجلد المعلومات",
-    "Configure the database" : "إعداد قاعدة البيانات",
-    "Only %s is available." : "لم يتبقى إلّا %s.",
-    "Install and activate additional PHP modules to choose other database types." : "ثبت وفعل مودلات PHP اضافية لاستخدام قاعدة بيانات مختلفة.",
-    "For more details check out the documentation." : "للمزيد من التفاصيل، يرجى الإطلاع على الدليل.",
-    "Database account" : "حساب قاعدة البيانات",
-    "Database password" : "كلمة سر مستخدم قاعدة البيانات",
-    "Database name" : "اسم قاعدة البيانات",
-    "Database tablespace" : "مساحة جدول قاعدة البيانات",
-    "Database host" : "خادم قاعدة البيانات",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "يرجى تحديد رقم المنفذ مع اسم المضيف (على سبيل المثال ، mycloud:5432).",
-    "Performance warning" : "تحذير حول الأداء",
-    "You chose SQLite as database." : "لقد اخترت SQLite كقاعدة بيانات.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "يجب استخدام SQLite فقط في حالات الحد الأدنى من التطوير. للنسخة النهائية، نوصي باستخدام خلفية قاعدة بيانات مختلفة.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "إذا كنت تستخدم عملاء لمزامنة الملفات ، فإن استخدام SQLite لا ينصح به بشدة.",
-    "Install" : "تثبيت",
-    "Installing …" : "جاري التثبيت...",
-    "Need help?" : "تحتاج إلى مساعدة؟",
-    "See the documentation" : "اطلع على التعليمات",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "يبدو أنك تحاول إعادة تثبيت نكست كلاود الخاص بك. ومع ذلك ، فإن الملف CAN_INSTALL مفقود من دليل التثبيت الخاص بك. يرجى إنشاء الملف CAN_INSTALL في مجلد التثبيت الخاص بك للمتابعة.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "تعذر إزالة CAN_INSTALL من مجلد التكوين. الرجاء إزالة هذا الملف يدويا.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "هذا التطبيق يتطلب JavaScript ليتم تشغيله بالطريقة الصحيحة. يرجى {linkstart}تفعيل JavaScript{linkend} وتحديث الصفحة.",
@@ -375,17 +366,42 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "هذا %s في وضع الصيانة، قد يستغرق ذلك بعض الوقت.",
     "This page will refresh itself when the instance is available again." : "سوف يتم تحديث الصفحة في حين الخادم جاهز للاستخدام مجددا.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "تواصل مع مسؤول النظام اذا استمرت هذه الرسالة بالظهور دائما أو بشكل مفاجئ.",
-    "Currently open" : "مفتوح حاليّاً ",
-    "Login with username or email" : "الدخول باسم المستخدم أو البريد الإلكتروني",
-    "Login with username" : "الدخول باسم المستخدم",
+    "No temporary profile picture available, try again" : "لا تتوفر صورة ملف شخصي مؤقتة، حاول مرة أخرى",
+    "No crop data provided" : "لم يتم تحديد قص البيانات.",
+    "No valid crop data provided" : "تحديد قص البيانات غير صحيح.",
+    "Crop is not square" : "القص ليس مربعا",
+    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "الدردشة ومكالمات الفيديو ومشاركة الشاشة والإجتماعات عبر الإنترنت ومؤتمرات الويب - في متصفحك ومع تطبيق للهاتف المحمول.",
     "You have not added any info yet" : "لم تقم بإضافة أي معلومات حتى الآن",
     "{user} has not added any info yet" : "لم يقم المستخدم {user} بإضافة أي معلومات بعد",
     "Error opening the user status modal, try hard refreshing the page" : "خطأ في فتح حالة المستخدم ، حاول تحديث الصفحة",
     "Edit Profile" : "تعديل الملف الشخصي",
     "The headline and about sections will show up here" : "سيظهر هنا العنوان والأقسام الخاصة بالملف الشخصي",
-    "Error loading message template: {error}" : "حصل خطأ في القالب: {error}",
+    "Very weak password" : "كلمة السر ضعيفة جدا",
+    "Weak password" : "كلمة السر ضعيفة",
+    "So-so password" : "كلمة سر غير فعالة",
+    "Good password" : "كلمة السر جيدة",
+    "Strong password" : "كلمة السر قوية",
+    "Non-existing tag #{tag}" : "وسم غير موجود #{tag}",
+    "Restricted" : "مقيد",
+    "Invisible" : "مخفي",
+    "Delete" : "إلغاء",
+    "Rename" : "إعادة التسمية",
+    "Collaborative tags" : "أوسمة تعاونية",
+    "No tags found" : "لم يُعثَر على أي وسم",
     "Profile not found" : "ملف المستخدم غير موجود",
-    "The profile does not exist." : "الملف الشخصي غير موجود."
+    "The profile does not exist." : "الملف الشخصي غير موجود.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "للحصول على معلومات حول كيفية تكوين الخادم الخاص بك، يرجى الاطلاع على <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">التعليمات</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>إنشاء حساب مُشرِف</strong>",
+    "New admin account name" : "اسم حساب المشرف الجديد",
+    "New admin password" : "كلمة مرور المشرف الجديد",
+    "Show password" : "اظهر كلمة المرور",
+    "Toggle password visibility" : "تبديل قراءة كلمة المرور",
+    "Configure the database" : "إعداد قاعدة البيانات",
+    "Only %s is available." : "لم يتبقى إلّا %s.",
+    "Database account" : "حساب قاعدة البيانات",
+    "Direct link copied to clipboard" : "تمّ نسخ الرابط المباشر إلى الحافظة"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
