@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tipus de fitxer desconegut",
     "An error occurred. Please contact your admin." : "S'ha produït un error. Contacteu amb l'administrador.",
     "Invalid image" : "La imatge no és vàlida",
-    "No temporary profile picture available, try again" : "No hi ha cap imatge temporal de perfil disponible; torneu-ho a provar",
-    "No crop data provided" : "No s'han proporcionat dades de retall",
-    "No valid crop data provided" : "Les dades de retall proporcionades no són vàlides",
-    "Crop is not square" : "El retall no és quadrat",
     "State token does not match" : "El testimoni d'estat no coincideix",
     "Invalid app password" : "La contrasenya de l'aplicació no és vàlida",
     "Could not complete login" : "No s'ha pogut completar l'inici de sessió",
@@ -51,6 +47,11 @@ OC.L10N.register(
     "No translation provider available" : "No hi ha cap proveïdor de traduccions disponible",
     "Could not detect language" : "No s'ha pogut detectar la llengua",
     "Unable to translate" : "No s'ha pogut traduir",
+    "[%d / %d]: %s" : "[%d/%d]: %s",
+    "Repair step:" : "Pas de reparació:",
+    "Repair info:" : "Informació de reparació:",
+    "Repair warning:" : "Avís de reparació:",
+    "Repair error:" : "Error de reparació:",
     "Nextcloud Server" : "Servidor del Nextcloud",
     "Some of your link shares have been removed" : "S'han suprimit alguns dels vostres enllaços compartits",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d'un error de seguretat, hem suprimit alguns dels vostres enllaços compartits. Consulteu l'enllaç per a obtenir més informació.",
@@ -58,11 +59,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduïu la vostra clau de subscripció a l'aplicació de suport per augmentar el límit del compte. Això també us atorga tots els avantatges addicionals que ofereix Nextcloud Enterprise i és molt recomanable per al funcionament en empreses.",
     "Learn more ↗" : "Més informació ↗",
     "Preparing update" : "S'està preparant l'actualització",
-    "[%d / %d]: %s" : "[%d/%d]: %s",
-    "Repair step:" : "Pas de reparació:",
-    "Repair info:" : "Informació de reparació:",
-    "Repair warning:" : "Avís de reparació:",
-    "Repair error:" : "Error de reparació:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilitzeu l'actualitzador de línia d'ordres; l'actualització mitjançant el navegador està inhabilitada en el fitxer config.php.",
     "Turned on maintenance mode" : "S'ha activat el mode de manteniment",
     "Turned off maintenance mode" : "S'ha desactivat el mode de manteniment",
@@ -79,8 +75,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (no compatible)",
     "The following apps have been disabled: %s" : "S'han inhabilitat les aplicacions següents: %s",
     "Already up to date" : "Ja teniu la versió més recent",
-    "Error occurred while checking server setup" : "S'ha produït un error en comprovar la configuració del servidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Per a conèixer més detalls, consulteu la {linkstart}documentació ↗{linkend}.",
+    "Unknown" : "Desconegut",
+    "PNG image" : "Imatge PNG",
     "unknown text" : "text desconegut",
     "Hello world!" : "Hola a tothom!",
     "sunny" : "assolellat",
@@ -109,7 +105,6 @@ OC.L10N.register(
     "Federated user" : "Usuari federat",
     "user@your-nextcloud.org" : "usuari@el-teu-nextcloud.org",
     "Create share" : "Crea l'element compartit",
-    "Direct link copied to clipboard" : "Enllaç directe copiat al porta-retalls",
     "Please copy the link manually:" : "Copieu l'enllaç manualment:",
     "Custom date range" : "Interval de dates personalitzat",
     "Pick start date" : "Trieu la data d'inici",
@@ -146,8 +141,6 @@ OC.L10N.register(
     "Account name" : "Nom de compte",
     "Server side authentication failed!" : "S'ha produït un error en l'autenticació del servidor!",
     "Please contact your administrator." : "Contacteu amb l'administrador.",
-    "Temporary error" : "Error temporal",
-    "Please try again." : "Torneu-ho a provar.",
     "An internal error occurred." : "S'ha produït un error intern.",
     "Please try again or contact your administrator." : "Torneu-ho a provar o contacteu amb l'administrador.",
     "Password" : "Contrasenya",
@@ -287,22 +280,15 @@ OC.L10N.register(
     "Error fetching contact actions" : "S'ha produït un error en carregar les accions del contacte",
     "Close \"{dialogTitle}\" dialog" : "Tanca el quadre de diàleg «{dialogTitle}»",
     "Email length is at max (255)" : "La longitud del correu electrònic és màxima (255)",
-    "Non-existing tag #{tag}" : "L'etiqueta #{tag} no existeix",
-    "Restricted" : "Restringit",
-    "Invisible" : "Invisible",
-    "Delete" : "Suprimeix",
-    "Rename" : "Canvia el nom",
-    "Collaborative tags" : "Etiquetes col·laboratives",
-    "No tags found" : "No s'ha trobat cap etiqueta",
     "Clipboard not available, please copy manually" : "El porta-retalls no està disponible; copieu-lo manualment",
     "Personal" : "Personal",
     "Accounts" : "Comptes",
     "Admin" : "Administració",
     "Help" : "Ajuda",
     "Access forbidden" : "Accés prohibit",
+    "Back to %s" : "Torna a %s",
     "Page not found" : "No s'ha trobat la pàgina",
     "The page could not be found on the server or you may not be allowed to view it." : "No s'ha trobat la pàgina en el servidor o és possible que no tingueu permís per a visualitzar-la.",
-    "Back to %s" : "Torna a %s",
     "Too many requests" : "Excés de sol·licituds",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "La vostra xarxa ha enviat un excés de sol·licituds. Torneu-ho a provar més tard o contacte amb l'administrador si és un error.",
     "Error" : "Error",
@@ -378,21 +364,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància del %s està actualment en mode de manteniment i podria estar-ho una estona.",
     "This page will refresh itself when the instance is available again." : "Aquesta pàgina s'actualitzarà automàticament quan la instància torni a estar disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacteu amb l'administrador del sistema si aquest missatge persisteix o si apareix inesperadament.",
-    "Currently open" : "Oberta actualment",
-    "Login with username or email" : "Inici de sessió amb nom d'usuari o correu electrònic",
-    "Login with username" : "Inici de sessió amb el nom d'usuari",
+    "No temporary profile picture available, try again" : "No hi ha cap imatge temporal de perfil disponible; torneu-ho a provar",
+    "No crop data provided" : "No s'han proporcionat dades de retall",
+    "No valid crop data provided" : "Les dades de retall proporcionades no són vàlides",
+    "Crop is not square" : "El retall no és quadrat",
+    "Error occurred while checking server setup" : "S'ha produït un error en comprovar la configuració del servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Per a conèixer més detalls, consulteu la {linkstart}documentació ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Xat, videotrucades, pantalla compartida, reunions en línia i conferències per Internet; en el navegador i amb aplicacions mòbils.",
     "You have not added any info yet" : "Encara no heu afegit cap informació",
     "{user} has not added any info yet" : "{user} encara no ha afegit cap informació",
     "Error opening the user status modal, try hard refreshing the page" : "S'ha produït un error en obrir el quadre de diàleg modal d'estat de l'usuari, proveu d'actualitzar la pàgina",
     "Edit Profile" : "Edita el perfil",
     "The headline and about sections will show up here" : "La capçalera i les seccions d'informació es mostraran aquí",
-    "Error loading message template: {error}" : "S'ha produït un error en carregar la plantilla del missatge: {error}",
     "Very weak password" : "Contrasenya molt feble",
     "Weak password" : "Contrasenya feble",
     "So-so password" : "Contrasenya justa",
     "Good password" : "Contrasenya bona",
     "Strong password" : "Contrasenya forta",
+    "Non-existing tag #{tag}" : "L'etiqueta #{tag} no existeix",
+    "Restricted" : "Restringit",
+    "Invisible" : "Invisible",
+    "Delete" : "Suprimeix",
+    "Rename" : "Canvia el nom",
+    "Collaborative tags" : "Etiquetes col·laboratives",
+    "No tags found" : "No s'ha trobat cap etiqueta",
     "Profile not found" : "No s'ha trobat el perfil",
     "The profile does not exist." : "El perfil no existeix.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els fitxers probablement són accessibles des d'Internet perquè el fitxer .htaccess no funciona.",
@@ -404,6 +399,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Canvia la visibilitat de la contrasenya",
     "Configure the database" : "Configuració de la base de dades",
     "Only %s is available." : "Només hi ha disponible %s.",
-    "Database account" : "Compte de base de dades"
+    "Database account" : "Compte de base de dades",
+    "Direct link copied to clipboard" : "Enllaç directe copiat al porta-retalls"
 },
 "nplurals=2; plural=(n != 1);");
