@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Άγνωστος τύπος αρχείου",
     "An error occurred. Please contact your admin." : "Προέκυψε σφάλμα. Παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
     "Invalid image" : "Μη έγκυρη εικόνα",
-    "No temporary profile picture available, try again" : "Δεν υπάρχει προσωρινή φωτογραφία προφίλ, δοκιμάστε ξανά",
-    "No crop data provided" : "Δεν δόθηκαν δεδομένα περικοπής",
-    "No valid crop data provided" : "Έχουν δοθεί μη έγκυρα δεδομένα περικοπής",
-    "Crop is not square" : "Η περικοπή δεν έχει τετράγωνο σχήμα",
     "State token does not match" : "Το αναγνωριστικό κατάστασης δεν ταιριάζει",
     "Invalid app password" : "Λανθασμένο συνθηματικό εφαρμογής",
     "Could not complete login" : "Αδυναμία ολοκλήρωσης σύνδεσης",
     "State token missing" : "Το αναγνωριστικό κατάστασης απουσιάζει",
     "Your login token is invalid or has expired" : "Το αναγνωριστικό (token) σύνδεσής σας δεν είναι έγκυρο ή έχει λήξει",
+    "Please use original client" : "Παρακαλούμε χρησιμοποιήστε τον αρχικό πελάτη",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Αυτή η κοινοτική έκδοση του Nextcloud δεν υποστηρίζεται και οι ειδοποιήσεις push είναι περιορισμένες.",
     "Login" : "Σύνδεση",
     "Unsupported email length (>255)" : "Μη υποστηριζόμενο μήκος email (>255)",
@@ -39,9 +36,12 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Κάντε κλικ στο παρακάτω κουμπί για να επαναφέρετε το συνθηματικό σας. Εάν δεν αιτηθήκατε επαναφορά συνθηματικού, αγνοήστε αυτό το μήνυμα αλληλογραφίας.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Κάντε κλικ στο παρακάτω σύνδεσμο για να επαναφέρετε το συνθηματικό σας. Εάν δεν αιτηθήκατε επαναφορά συνθηματικού, αγνοήστε αυτό το μήνυμα αλληλογραφίας.",
     "Reset your password" : "Επαναφορά συνθηματικού",
+    "The given provider is not available" : "Ο πάροχος που δώσατε δεν είναι διαθέσιμος",
     "Task not found" : "Η εργασία δε βρέθηκε",
     "Internal error" : "Εσωτερικό σφάλμα",
     "Not found" : "Δεν βρέθηκε",
+    "Node is locked" : "Ο κόμβος είναι κλειδωμένος",
+    "Bad request" : "Εσφαλμένο αίτημα",
     "Requested task type does not exist" : "Ο ζητούμενος τύπος εργασίας δεν υφίσταται",
     "Necessary language model provider is not available" : "Ο απαραίτητος πάροχος γλωσσικού μοντέλου δεν είναι διαθέσιμος",
     "No text to image provider is available" : "Δεν υπάρχει διαθέσιμος πάροχος μετατροπής κειμένου σε εικόνα",
@@ -57,6 +57,8 @@ OC.L10N.register(
     "Nextcloud Server" : "Διακομιστής Nextcloud",
     "Some of your link shares have been removed" : "Μερικοί από τους κοινόχρηστους συνδέσμους σας έχουν καταργηθεί",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Λόγω σφάλματος ασφαλείας έπρεπε να αφαιρέσουμε κοινόχρηστους συνδέσμους σας. Παρακαλούμε δείτε τον παρακάτω σύνδεσμο για πληροφορίες.",
+    "The account limit of this instance is reached." : "Το όριο λογαριασμών αυτού του instance έχει επιτευχθεί.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Εισάγετε το κλειδί συνδρομής σας στην εφαρμογή υποστήριξης για να αυξήσετε το όριο λογαριασμών. Αυτό σας παρέχει επίσης όλα τα πρόσθετα πλεονεκτήματα που προσφέρει το Nextcloud Enterprise και συνιστάται ιδιαίτερα για λειτουργία σε εταιρείες.",
     "Learn more ↗" : "Μάθετε περισσότερα ↗",
     "Preparing update" : "Προετοιμασία ενημέρωσης",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Παρακαλούμε χρησιμοποιήστε το πρόγραμμα ενημέρωσης γραμμής εντολών, επειδή η ενημέρωση μέσω του προγράμματος περιήγησης είναι απενεργοποιημένη στο αρχείο config.php.",
@@ -75,10 +77,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ασύμβατη)",
     "The following apps have been disabled: %s" : "Οι ακόλουθες εφαρμογές έχουν απενεργοποιηθεί: %s",
     "Already up to date" : "Ενημερωμένο ήδη",
+    "Windows Command Script" : "Script Εντολών Windows",
+    "Electronic book document" : "Έγγραφο ηλεκτρονικού βιβλίου",
+    "TrueType Font Collection" : "Συλλογή γραμματοσειρών TrueType",
+    "Web Open Font Format" : "Μορφότυπος ανοιχτής γραμματοσειράς web",
+    "GPX geographic data" : "Γεωγραφικά δεδομένα GPX",
+    "Gzip archive" : "Αρχείο Gzip",
+    "Adobe Illustrator document" : "Έγγραφο Adobe Illustrator",
+    "Java source code" : "Πηγαίος κώδικας Java",
+    "JavaScript source code" : "Πηγαίος κώδικας JavaScript",
+    "JSON document" : "Έγγραφο JSON",
+    "Microsoft Access database" : "Βάση δεδομένων Microsoft Access",
+    "Microsoft OneNote document" : "Έγγραφο Microsoft OneNote",
+    "Microsoft Word document" : "Έγγραφο Microsoft Word",
     "Unknown" : "Άγνωστο",
+    "PDF document" : "Έγγραφο PDF",
+    "PostScript document" : "Έγγραφο PostScript",
+    "RSS summary" : "Περίληψη RSS",
+    "Android package" : "Πακέτο Android",
+    "KML geographic data" : "Γεωγραφικά δεδομένα KML",
+    "KML geographic compressed data" : "Συμπιεσμένα γεωγραφικά δεδομένα KML",
+    "Lotus Word Pro document" : "Έγγραφο Lotus Word Pro",
+    "Excel spreadsheet" : "Υπολογιστικό φύλλο Excel",
+    "Excel add-in" : "Πρόσθετο Excel",
+    "Excel 2007 binary spreadsheet" : "Δυαδικό υπολογιστικό φύλλο Excel 2007",
+    "Excel spreadsheet template" : "Πρότυπο υπολογιστικού φύλλου Excel",
+    "Outlook Message" : "Μήνυμα Outlook",
+    "PowerPoint presentation" : "Παρουσίαση PowerPoint",
+    "PowerPoint add-in" : "Πρόσθετο PowerPoint",
+    "PowerPoint presentation template" : "Πρότυπο παρουσίασης PowerPoint",
+    "Word document" : "Έγγραφο Word",
+    "ODF formula" : "Τύπος ODF",
+    "ODG drawing" : "Σχέδιο ODG",
+    "ODG drawing (Flat XML)" : "Σχέδιο ODG (Flat XML)",
+    "ODG template" : "Πρότυπο ODG",
+    "ODP presentation" : "Παρουσίαση ODP",
+    "ODP presentation (Flat XML)" : "Παρουσίαση ODP (Flat XML)",
+    "ODP template" : "Πρότυπο ODP",
+    "ODS spreadsheet" : "Υπολογιστικό φύλλο ODS",
+    "ODS spreadsheet (Flat XML)" : "Υπολογιστικό φύλλο ODS (Flat XML)",
+    "ODS template" : "Πρότυπο ODS",
+    "ODT document" : "Έγγραφο ODT",
+    "ODT document (Flat XML)" : "Έγγραφο ODT (Flat XML)",
+    "ODT template" : "Πρότυπο ODT",
+    "PowerPoint 2007 presentation" : "Παρουσίαση PowerPoint 2007",
+    "PowerPoint 2007 show" : "Παρουσίαση PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Πρότυπο παρουσίασης PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Υπολογιστικό φύλλο Excel 2007",
+    "Excel 2007 spreadsheet template" : "Πρότυπο υπολογιστικού φύλλου Excel 2007",
+    "Word 2007 document" : "Έγγραφο Word 2007",
+    "Word 2007 document template" : "Πρότυπο εγγράφου Word 2007",
+    "Microsoft Visio document" : "Έγγραφο Microsoft Visio",
+    "WordPerfect document" : "Έγγραφο WordPerfect",
+    "7-zip archive" : "Αρχείο 7-zip",
+    "Blender scene" : "Σκηνή Blender",
+    "Bzip2 archive" : "Αρχείο Bzip2",
+    "Debian package" : "Πακέτο Debian",
+    "FictionBook document" : "Έγγραφο FictionBook",
+    "Unknown font" : "Άγνωστη γραμματοσειρά",
+    "Krita document" : "Έγγραφο Krita",
+    "Mobipocket e-book" : "Ηλεκτρονικό βιβλίο Mobipocket",
+    "Windows Installer package" : "Πακέτο Windows Installer",
+    "Perl script" : "Perl script",
+    "PHP script" : "PHP script",
+    "Tar archive" : "Αρχείο Tar",
+    "XML document" : "Έγγραφο XML",
+    "YAML document" : "Έγγραφο YAML",
+    "Zip archive" : "Αρχείο Zip",
+    "Zstandard archive" : "Αρχείο Zstandard",
+    "AAC audio" : "Ήχος AAC",
+    "FLAC audio" : "Ήχος FLAC",
+    "MPEG-4 audio" : "Ήχος MPEG-4",
+    "MP3 audio" : "Ήχος MP3",
+    "Ogg audio" : "Ήχος Ogg",
+    "RIFF/WAVe standard Audio" : "Πρότυπο ήχου RIFF/WAVe",
+    "WebM audio" : "Ήχος WebM",
+    "MP3 ShoutCast playlist" : "Λίστα αναπαραγωγής MP3 ShoutCast",
+    "Windows BMP image" : "Εικόνα Windows BMP",
+    "Better Portable Graphics image" : "Εικόνα Better Portable Graphics",
+    "EMF image" : "Εικόνα EMF",
+    "GIF image" : "Εικόνα GIF",
+    "HEIC image" : "Εικόνα HEIC",
+    "HEIF image" : "Εικόνα HEIF",
+    "JPEG-2000 JP2 image" : "Εικόνα JPEG-2000 JP2",
+    "JPEG image" : "Εικόνα JPEG",
     "PNG image" : "Εικόνα PNG",
-    "Error occurred while checking server setup" : "Παρουσιάστηκε σφάλμα κατά τον έλεγχο των ρυθμίσεων του διακομιστή σας",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Για περισσότερες λεπτομέρειες, ανατρέξτε στη {linkstart}τεκμηρίωση ↗{linkend}.",
+    "SVG image" : "Εικόνα SVG",
+    "Truevision Targa image" : "Εικόνα Truevision Targa",
+    "TIFF image" : "Εικόνα TIFF",
+    "WebP image" : "Εικόνα WebP",
+    "Digital raw image" : "Ψηφιακή ακατέργαστη εικόνα",
+    "Windows Icon" : "Εικονίδιο Windows",
+    "Email message" : "Μήνυμα email",
+    "VCS/ICS calendar" : "Ημερολόγιο VCS/ICS",
+    "CSS stylesheet" : "Φύλλο στυλ CSS",
+    "CSV document" : "Έγγραφο CSV",
+    "HTML document" : "Έγγραφο HTML",
+    "Markdown document" : "Έγγραφο Markdown",
+    "Org-mode file" : "Αρχείο Org-mode",
+    "Plain text document" : "Έγγραφο απλού κειμένου",
+    "Rich Text document" : "Έγγραφο Rich Text",
+    "Electronic business card" : "Ηλεκτρονική επαγγελματική κάρτα",
+    "C++ source code" : "Πηγαίος κώδικας C++",
+    "LDIF address book" : "Βιβλίο διευθύνσεων LDIF",
+    "NFO document" : "Έγγραφο NFO",
+    "PHP source" : "Πηγαίος κώδικας PHP",
+    "Python script" : "Python script",
+    "ReStructuredText document" : "Έγγραφο ReStructuredText",
+    "3GPP multimedia file" : "Πολυμεσικό αρχείο 3GPP",
+    "MPEG video" : "Βίντεο MPEG",
+    "DV video" : "Βίντεο DV",
+    "MPEG-2 transport stream" : "Ροή μεταφοράς MPEG-2",
+    "MPEG-4 video" : "Βίντεο MPEG-4",
+    "Ogg video" : "Βίντεο Ogg",
+    "QuickTime video" : "Βίντεο QuickTime",
+    "WebM video" : "Βίντεο WebM",
+    "Flash video" : "Βίντεο Flash",
+    "Matroska video" : "Βίντεο Matroska",
+    "Windows Media video" : "Βίντεο Windows Media",
+    "AVI video" : "Βίντεο AVI",
     "unknown text" : "άγνωστο κείμενο",
     "Hello world!" : "Γεια σου κόσμε!",
     "sunny" : "ηλιόλουστη",
@@ -101,9 +218,14 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} ειδοποίηση","{count} ειδοποιήσεις"],
     "No" : "Όχι",
     "Yes" : "Ναι",
+    "The remote URL must include the user." : "Η απομακρυσμένη URL πρέπει να περιλαμβάνει τον χρήστη.",
+    "Invalid remote URL." : "Μη έγκυρη απομακρυσμένη URL.",
     "Failed to add the public link to your Nextcloud" : "Αποτυχία στην πρόσθεση του κοινού συνδέσμου στο Nextcloud σας",
+    "Federated user" : "Ομοσπονδιακός χρήστης",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Δημιουργήστε κοινή χρήση",
+    "Direct link copied" : "Αντιγράφηκε ο άμεσος σύνδεσμος",
+    "Please copy the link manually:" : "Παρακαλώ αντιγράψτε τον σύνδεσμο χειροκίνητα:",
     "Custom date range" : "Προσαρμοσμένο διάστημα ημερομηνιών",
     "Pick start date" : "Επιλέξτε ημερομηνία έναρξης",
     "Pick end date" : "Επιλέξτε ημερομηνία λήξης",
@@ -111,42 +233,51 @@ OC.L10N.register(
     "Search in current app" : "Αναζήτηση στην τρέχουσα εφαρμογή",
     "Clear search" : "Εκκαθάριση αναζήτησης",
     "Search everywhere" : "Αναζητήστε παντού",
-    "Searching …" : "Αναζήτηση ...",
+    "Searching …" : "Γίνεται αναζήτηση ...",
     "Start typing to search" : "Ξεκινήστε την πληκτρολόγηση για αναζήτηση",
+    "No matching results" : "Δεν υπάρχουν αποτελέσματα που να ταιριάζουν",
     "Today" : "Σήμερα",
     "Last 7 days" : "Τελευταίες 7 ημέρες",
     "Last 30 days" : "Τελευταίες 30 ημέρες",
     "This year" : "Αυτό το έτος",
     "Last year" : "Προηγούμενος χρόνος",
+    "Between {startDate} and {endDate}" : "Μεταξύ {startDate} και {endDate}",
     "Unified search" : "Ενιαία αναζήτηση",
     "Search apps, files, tags, messages" : "Αναζήτηση εφαρμογών, αρχείων, ετικετών, μηνυμάτων",
     "Places" : "Τοποθεσίες",
     "Date" : "Ημερομηνία",
     "Search people" : "Αναζήτηση ατόμων",
     "People" : "Άτομα",
+    "Filter in current view" : "Φιλτράρισμα στην τρέχουσα προβολή",
+    "Search connected services" : "Αναζήτηση συνδεδεμένων υπηρεσιών",
     "Results" : "Αποτελέσματα",
     "Load more results" : "Φόρτωση περισσοτέρων αποτελεσμάτων",
     "Search in" : "Αναζήτηση σε",
     "Log in" : "Είσοδος",
-    "Logging in …" : "Σύνδεση …",
+    "Logging in …" : "Πραγματοποιείται είσοδος …",
     "Log in to {productName}" : "Συνδεθείτε στο {productName}",
+    "Wrong login or password." : "Εσφαλμένο όνομα χρήστη ή συνθηματικό.",
     "This account is disabled" : "Αυτός ο λογαριασμός είναι απενεργοποιημένος",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Εντοπίστηκαν πολλές λανθασμένες προσπάθειες εισόδου από την ΙΡ σας. Η επόμενη προσπάθεια εισόδου σας μπορεί να γίνει σε 30 δεύτερα.",
     "Account name or email" : "Όνομα λογαριασμού ή email",
     "Account name" : "Όνομα λογαριασμού",
     "Server side authentication failed!" : "Αποτυχημένη πιστοποίηση από πλευράς διακομιστή!",
     "Please contact your administrator." : "Παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
+    "Session error" : "Σφάλμα συνεδρίας",
+    "It appears your session token has expired, please refresh the page and try again." : "Φαίνεται ότι το διακριτικό συνεδρίας σας έχει λήξει, παρακαλούμε ανανεώστε τη σελίδα και δοκιμάστε ξανά.",
     "An internal error occurred." : "Παρουσιάστηκε ένα εσωτερικό σφάλμα.",
     "Please try again or contact your administrator." : "Παρακαλούμε δοκιμάστε ξανά ή επικοινωνήστε με τον διαχειριστή.",
     "Password" : "Συνθηματικό",
     "Log in with a device" : "Συνδεθείτε με συσκευή",
-    "Your account is not setup for passwordless login." : "Ο λογαριασμός σας δεν έχει ρυθμιστεί για σύνδεση χωρίς κωδικό πρόσβασης.",
+    "Login or email" : "Όνομα χρήστη ή email",
+    "Your account is not setup for passwordless login." : "Ο λογαριασμός σας δεν έχει ρυθμιστεί για σύνδεση χωρίς συνθηματικό.",
     "Your connection is not secure" : "Η σύνδεσή σας δεν είναι ασφαλής",
     "Passwordless authentication is only available over a secure connection." : "Η σύνδεση χωρίς κωδικό πρόσβασης υποστηρίζεται μόνο από ασφαλή σύνδεση.",
     "Browser not supported" : "Το πρόγραμμα περιήγησης δεν υποστηρίζεται",
     "Passwordless authentication is not supported in your browser." : "Η σύνδεση χωρίς κωδικό πρόσβασης δεν υποστηρίζεται από τον περιηγητή σας.",
     "Reset password" : "Επαναφορά συνθηματικού",
     "Back to login" : "Πίσω στην είσοδο",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Εάν αυτός ο λογαριασμός υπάρχει, ένα μήνυμα επαναφοράς συνθηματικού έχει αποσταλεί στη διεύθυνση email του. Εάν δεν το λάβετε, επαληθεύστε τη διεύθυνση email και/ή το Όνομα χρήστη, ελέγξτε τους φακέλους spam/junk ή ζητήστε βοήθεια από τον τοπικό διαχειριστή σας.",
     "Couldn't send reset email. Please contact your administrator." : "Αδυναμία αποστολής ηλεκτρονικού μηνύματος επαναφοράς. Παρακαλώ επικοινωνήστε με το διαχειριστή.",
     "Password cannot be changed. Please contact your administrator." : "Ο κωδικός πρόσβασης δεν μπορεί να αλλάξει. Παρακαλώ επικοινωνήστε με τον διαχειριστή σας.",
     "New password" : "Νέο συνθηματικό",
@@ -156,10 +287,11 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Προγραμματισμένες εργασίες & συναντήσεις, συγχρονίζονται με όλες τις συσκευές σας.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Κρατήστε συνεργάτες και φίλους σε ένα μέρος χωρίς να κινδυνεύουν τα προσωπικά δεδομένα τους.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Απλή εφαρμογή ηλ.ταχυδρομείου που ενσωματώνει Αρχεία, Επαφές και Ημερολόγιο.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Συνομιλίες, βιντεοκλήσεις, κοινή χρήση οθόνης, διαδικτυακές συναντήσεις και διαδικτυακές συσκέψεις – στο πρόγραμμα περιήγησής σας και με εφαρμογές για κινητά.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Συνεργατικά έγγραφα, λογιστικά φύλλα και παρουσιάσεις, βασισμένα στο Collabora Online.",
     "Distraction free note taking app." : "Εφαρμογή λήψης σημειώσεων χωρίς περισπασμούς.",
     "Recommended apps" : "Προτεινόμενες εφαρμογές",
-    "Loading apps …" : "Φόρτωση εφαρμογών …",
+    "Loading apps …" : "Γίνεται φόρτωση εφαρμογών …",
     "Could not fetch list of apps from the App Store." : "Δεν μπορεί να ληφθεί η λίστα εφαρμογών από το App Store.",
     "App download or installation failed" : "Η εγκατάσταση ή η λήψη εφαρμογής απέτυχε",
     "Cannot install this app because it is not compatible" : "Δεν είναι δυνατή η εγκατάσταση αυτής της εφαρμογής επειδή δεν είναι συμβατή",
@@ -167,8 +299,9 @@ OC.L10N.register(
     "Skip" : "Παράλειψη",
     "Installing apps …" : "Εγκατάσταση εφαρμογών …",
     "Install recommended apps" : "Εγκατάσταση προτεινόμενων εφαρμογών",
+    "Avatar of {displayName}" : "Avatar του {displayName}",
     "Settings menu" : "Μενού ρυθμίσεων",
-    "Loading your contacts …" : "Φόρτωση των επαφών σας …",
+    "Loading your contacts …" : "Γίνεται φόρτωση των επαφών σας …",
     "Looking for {term} …" : "Αναζήτηση για {term} …",
     "Search contacts" : "Αναζήτηση επαφών",
     "Reset search" : "Επαναφορά αναζήτησης",
@@ -183,22 +316,38 @@ OC.L10N.register(
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Παρακαλούμε προσθέστε τουλάχιστον {minSearchLength} χαρακτήρα ή περισσότερους για αναζήτηση","Παρακαλούμε προσθέστε τουλάχιστον {minSearchLength} χαρακτήρες ή περισσότερους για αναζήτηση"],
     "An error occurred while searching for {type}" : "Παρουσιάστηκε σφάλμα κατά την αναζήτηση για {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Η αναζήτηση ξεκινά μόλις αρχίσετε να πληκτρολογείτε και μπορείτε να επιλέξετε τα αποτελέσματα με τα πλήκτρα βέλους",
-    "Search for {name} only" : "Αναζήτηση για {name} μόνο",
+    "Search for {name} only" : "Αναζήτηση μόνο για {name}",
     "Loading more results …" : "Γίνεται φόρτωση περισσότερων αποτελεσμάτων …",
     "Forgot password?" : "Ξεχάσατε το συνθηματικό;",
     "Back to login form" : "Επιστροφή στη φόρμα σύνδεσης",
     "Back" : "Πίσω",
     "Login form is disabled." : "Η φόρμα σύνδεσης είναι απενεργοποιημένη.",
+    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Η φόρμα σύνδεσης του Nextcloud είναι απενεργοποιημένη. Χρησιμοποιήστε μια άλλη επιλογή σύνδεσης εάν είναι διαθέσιμη ή επικοινωνήστε με τον διαχειριστή σας.",
     "More actions" : "Περισσότερες ενέργειες",
-    "Password is too weak" : "Ο κωδικός πρόσβασης είναι πολύ αδύναμος",
-    "Password is weak" : "Ο κωδικός πρόσβασης είναι αδύναμος",
-    "Password is average" : "Ο κωδικός πρόσβασης είναι μέτριος",
-    "Password is strong" : "Ο κωδικός πρόσβασης είναι ισχυρός",
-    "Password is very strong" : "Ο κωδικός πρόσβασης είναι πολύ ισχυρός",
-    "Password is extremely strong" : "Ο κωδικός πρόσβασης είναι εξαιρετικά ισχυρός",
+    "User menu" : "Μενού χρήστη",
+    "Your guest name: {user}" : "Το όνομα επισκέπτη σας: {user}",
+    "You are currently not identified." : "Προς το παρόν δεν είστε αναγνωρισμένος.",
+    "Set public name" : "Ορισμός δημόσιου ονόματος",
+    "Change public name" : "Αλλαγή δημόσιου ονόματος",
+    "Password is too weak" : "Το συνθηματικό είναι πολύ αδύναμο",
+    "Password is weak" : "Το συνθηματικό είναι αδύναμο",
+    "Password is average" : "Το συνθηματικό είναι μέτριο",
+    "Password is strong" : "Το συνθηματικό είναι ισχυρό",
+    "Password is very strong" : "Το συνθηματικό είναι πολύ ισχυρό",
+    "Password is extremely strong" : "Το συνθηματικό είναι εξαιρετικά ισχυρό",
+    "Unknown password strength" : "Άγνωστη ισχύς συνθηματικού",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ο κατάλογος δεδομένων και τα αρχεία σας είναι πιθανώς προσβάσιμα από το διαδίκτυο επειδή το αρχείο <code>.htaccess</code> δεν λειτουργεί.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Για πληροφορίες σχετικά με τον σωστό ρυθμισμό του διακομιστή σας, παρακαλούμε {linkStart}δείτε την τεκμηρίωση{linkEnd}",
+    "Autoconfig file detected" : "Εντοπίστηκε αρχείο αυτόματης ρύθμισης",
+    "The setup form below is pre-filled with the values from the config file." : "Η παρακάτω φόρμα ρύθμισης είναι προ-συμπληρωμένη με τις τιμές από το αρχείο ρυθμίσεων.",
     "Security warning" : "Προειδοποίηση ασφαλείας",
+    "Create administration account" : "Δημιουργία λογαριασμού διαχείρισης",
+    "Administration account name" : "Όνομα λογαριασμού διαχείρισης",
+    "Administration account password" : "Συνθηματικό λογαριασμού διαχείρισης",
     "Storage & database" : "Αποθηκευτικός χώρος & βάση δεδομένων",
     "Data folder" : "Φάκελος δεδομένων",
+    "Database configuration" : "Ρύθμιση βάσης δεδομένων",
+    "Only {firstAndOnlyDatabase} is available." : "Μόνο η {firstAndOnlyDatabase} είναι διαθέσιμη.",
     "Install and activate additional PHP modules to choose other database types." : "Εγκαταστήστε και ενεργοποιείστε επιπλέον αρθρώματα της PHP για να επιλέξετε άλλους τύπους βάσεων δεδομένων.",
     "For more details check out the documentation." : "Για περισσότερες πληροφορίες ανατρέξτε στην τεκμηρίωση.",
     "Performance warning" : "Προειδοποίηση απόδοσης",
@@ -211,7 +360,8 @@ OC.L10N.register(
     "Database tablespace" : "Κενά πινάκων βάσης δεδομένων",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Παρακαλώ καθορίστε τον αριθμό της θύρας μαζί με το όνομα διακομιστή (πχ localhost: 5432).",
     "Database host" : "Διακομιστής βάσης δεδομένων",
-    "Installing …" : "Εγκατάσταση …",
+    "localhost" : "localhost",
+    "Installing …" : "Γίνεται εγκατάσταση …",
     "Install" : "Εγκατάσταση",
     "Need help?" : "Θέλετε βοήθεια;",
     "See the documentation" : "Δείτε την τεκμηρίωση",
@@ -258,18 +408,14 @@ OC.L10N.register(
     "No action available" : "Καμία διαθέσιμη ενέργεια",
     "Error fetching contact actions" : "Σφάλμα κατά την λήψη ενεργειών της επαφής",
     "Close \"{dialogTitle}\" dialog" : "Κλείσιμο του διαλόγου \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Μη υπάρχουσα ετικέτα #{tag}",
-    "Restricted" : "Περιορισμένο",
-    "Invisible" : "Αόρατο",
-    "Delete" : "Διαγραφή",
-    "Rename" : "Μετονομασία",
-    "Collaborative tags" : "Συνεργατικές ετικέτες",
-    "No tags found" : "Δεν βρέθηκαν ετικέτες",
+    "Email length is at max (255)" : "Το μήκος του email είναι στο μέγιστο (255)",
+    "Clipboard not available, please copy manually" : "Το πρόχειρο δεν είναι διαθέσιμο, παρακαλούμε αντιγράψτε χειροκίνητα",
     "Personal" : "Προσωπικά",
     "Accounts" : "Λογαριασμοί",
     "Admin" : "Διαχειριστής",
     "Help" : "Βοήθεια",
     "Access forbidden" : "Απαγορεύεται η πρόσβαση",
+    "You are not allowed to access this page." : "Δεν επιτρέπεται η πρόσβαση σε αυτή τη σελίδα.",
     "Back to %s" : "Πίσω στο %s",
     "Page not found" : "Δεν βρέθηκε η σελίδα",
     "The page could not be found on the server or you may not be allowed to view it." : "Δεν ήταν δυνατή η εύρεση της σελίδας στον διακομιστή ή ενδέχεται να μην σας επιτρέπεται να την προβάλετε.",
@@ -295,12 +441,14 @@ OC.L10N.register(
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Αυτή η εφαρμογή απαιτεί JavaScript για σωστή λειτουργία. Παρακαλώ {linkstart}ενεργοποιήστε τη JavaScrip{linkend} και φορτώστε ξανά τη σελίδα.",
     "Skip to main content" : "Μετάβαση στο κύριο περιεχόμενο",
     "Skip to navigation of app" : "Μεταβείτε στην πλοήγηση της εφαρμογής",
-    "Go to %s" : "Πηγαίνετε στο %s",
+    "Go to %s" : "Μετάβαση στο %s",
     "Get your own free account" : "Αποκτήστε τον δωρεάν λογαριασμό σας",
     "Connect to your account" : "Σύνδεση στον λογαριασμό σας",
-    "Please log in before granting %1$s access to your %2$s account." : "Παρακαλώ συνδεθείτε πρίν χορηγήσετε %1$s πρόσβαση στον λογαριασμό σας %2$s.",
+    "Please log in before granting %1$s access to your %2$s account." : "Παρακαλούμε συνδεθείτε πρίν χορηγήσετε %1$s πρόσβαση στον λογαριασμό σας %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Εάν δεν προσπαθείτε να ρυθμίσετε μια νέα συσκευή ή εφαρμογή, κάποιος προσπαθεί να σας εξαπατήσει ώστε να του παραχωρήσετε πρόσβαση στα δεδομένα σας. Σε αυτήν την περίπτωση μην προχωρήσετε και επικοινωνήστε με τον διαχειριστή του συστήματός σας.",
+    "App password" : "Συνθηματικό εφαρμογής",
     "Grant access" : "Παροχή άδειας πρόσβασης",
+    "Alternative log in using app password" : "Εναλλακτική σύνδεση με χρήση συνθηματικό εφαρμογής",
     "Account access" : "Πρόσβαση λογαριασμού",
     "Currently logged in as %1$s (%2$s)." : "Αυτήν τη στιγμή έχετε συνδεθεί ως %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Πρόκειται να χορηγήσετε άδεια %1$s στον λογαριασμό σας %2$s.",
@@ -309,11 +457,11 @@ OC.L10N.register(
     "You can close this window." : "Μπορείτε να κλείσετε το παράθυρο.",
     "Previous" : "Προηγούμενο",
     "This share is password-protected" : "Το κοινόχρηστο έχει προστασία κωδικού",
-    "The password is wrong or expired. Please try again or request a new one." : "Ο κωδικός πρόσβασης είναι λάθος ή έχει λήξει. Δοκιμάστε ξανά ή ζητήστε νέο.",
+    "The password is wrong or expired. Please try again or request a new one." : "Το συνθηματικό είναι λάθος ή έχει λήξει. Δοκιμάστε ξανά ή ζητήστε νέο.",
     "Please type in your email address to request a temporary password" : "Πληκτρολογήστε τη διεύθυνση email σας για να ζητήσετε έναν προσωρινό κωδικό πρόσβασης",
     "Email address" : "Διεύθυνση αλληλογραφίας",
-    "Password sent!" : "Ο κωδικός εστάλη!",
-    "You are not authorized to request a password for this share" : "Δεν είστε εξουσιοδοτημένοι να ζητήσετε κωδικό πρόσβασης για αυτό το κοινόχρηστο στοιχείο",
+    "Password sent!" : "Το συνθηματικό εστάλη!",
+    "You are not authorized to request a password for this share" : "Δεν είστε εξουσιοδοτημένοι να ζητήσετε συνθηματικό για αυτό το κοινόχρηστο στοιχείο",
     "Two-factor authentication" : "Πιστοποίηση Δύο-Παραγόντων",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Έχει ενεργοποιηθεί η βελτιωμένη ασφάλεια για τον λογαριασμό σας. Παρακαλώ επιλέξτε δεύτερο παράγοντα αυθεντικοποίησης:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Δεν ήταν δυνατή η φόρτωση τουλάχιστον μιας από τις ενεργοποιημένες μεθόδους αυθεντικοποίησης με δύο παράγοντες. Επικοινωνήστε με το διαχειριστή σας.",
@@ -338,6 +486,7 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Για να αποφύγετε τη λήξη χρόνου με μεγαλύτερες εγκαταστάσεις, μπορείτε αντί αυτού να εκτελέσετε την ακόλουθη εντολή στον κατάλογο εγκατάστασης:",
     "Detailed logs" : "Λεπτομερές ιστορικό",
     "Update needed" : "Απαιτείται ενημέρωση",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Χρησιμοποιήστε το πρόγραμμα ενημέρωσης της γραμμής εντολών, επειδή έχετε μια μεγάλη εγκατάσταση με περισσότερους από 50 λογαριασμούς.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Για βοήθεια, δείτε στην  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Γνωρίζω ότι συνεχίζοντας την ενημέρωση μέσω web UI αποτελεί ρίσκο, το χρονικό όριο του αιτήματος μπορεί να εξαντληθεί με συνέπεια το χάσιμο δεδομένων, αλλά έχω πραγματοποιήσει αντίγραφο ασφαλείας και γνωρίζω πως να κάνω αποκατάσταση σε περίπτωση αποτυχίας.",
     "Upgrade via web on my own risk" : "Αναβάθμιση μέσω ιστού με δική μου ευθύνη",
@@ -345,24 +494,42 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Αυτή %s η εγκατάσταση είναι σε λειτουργία συντήρησης, η οποία μπορεί να διαρκέσει κάποιο χρόνο.",
     "This page will refresh itself when the instance is available again." : "Η σελίδα θα ανανεωθεί αυτόματα όταν η υπηρεσία είναι διαθέσιμη ξανά.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Επικοινωνήστε με το διαχειριστή του συστήματος αν αυτό το μήνυμα συνεχίζει να εμφανίζεται ή εμφανίστηκε απρόσμενα.",
+    "No temporary profile picture available, try again" : "Δεν υπάρχει προσωρινή φωτογραφία προφίλ, δοκιμάστε ξανά",
+    "No crop data provided" : "Δεν δόθηκαν δεδομένα περικοπής",
+    "No valid crop data provided" : "Έχουν δοθεί μη έγκυρα δεδομένα περικοπής",
+    "Crop is not square" : "Η περικοπή δεν έχει τετράγωνο σχήμα",
+    "Error occurred while checking server setup" : "Παρουσιάστηκε σφάλμα κατά τον έλεγχο των ρυθμίσεων του διακομιστή σας",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Για περισσότερες λεπτομέρειες, ανατρέξτε στη {linkstart}τεκμηρίωση ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Μηνύματα, κλήσεις βίντεο, κοινή χρήση οθόνης, συναντήσεις και τηλεδιασκέψεις - στον περιηγητή σας και με εφαρμογές κινητού.",
     "You have not added any info yet" : "Δεν έχετε προσθέσει ακόμα πληροφορίες",
     "{user} has not added any info yet" : "{user} δεν έχει προσθέσει ακόμη πληροφορίες",
     "Error opening the user status modal, try hard refreshing the page" : "Σφάλμα κατά το άνοιγμα της κατάστασης χρήστη, δοκιμάστε να ανανεώσετε τη σελίδα",
     "Edit Profile" : "Επεξεργασία προφίλ",
-    "The headline and about sections will show up here" : "Ο \"τίτλος\" και οι ενότητες \"σχετικά με\" θα εμφανιστούν εδώ",
+    "The headline and about sections will show up here" : "Ο «τίτλος» και οι ενότητες «σχετικά με» θα εμφανιστούν εδώ",
     "Very weak password" : "Πολύ αδύναμο συνθηματικό",
     "Weak password" : "Αδύναμο συνθηματικό",
     "So-so password" : "Μέτριο συνθηματικό",
     "Good password" : "Καλό συνθηματικό",
     "Strong password" : "Δυνατό συνθηματικό",
+    "Non-existing tag #{tag}" : "Μη υπάρχουσα ετικέτα #{tag}",
+    "Restricted" : "Περιορισμένο",
+    "Invisible" : "Αόρατο",
+    "Delete" : "Διαγραφή",
+    "Rename" : "Μετονομασία",
+    "Collaborative tags" : "Συνεργατικές ετικέτες",
+    "No tags found" : "Δεν βρέθηκαν ετικέτες",
     "Profile not found" : "Το προφίλ δε βρέθηκε",
     "The profile does not exist." : "Το προφίλ δεν υπάρχει.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ο κατάλογος δεδομένων και τα αρχεία σας είναι πιθανό να είναι προσβάσιμα από το διαδίκτυο διότι δεν δουλεύει το αρχείο .htaccess.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Για πληροφορίες πως μπορείτε να ρυθμίσετε σωστά τον διακομιστή, παρακαλούμε δείτε την <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">τεκμηρίωση</a>.",
-    "Show password" : "Εμφάνιση κωδικού",
-    "Toggle password visibility" : "Εναλλαγή ορατότητας κωδικού πρόσβασης",
+    "<strong>Create an admin account</strong>" : "<strong>Δημιουργία λογαριασμού διαχειριστή</strong>",
+    "New admin account name" : "Νέο όνομα λογαριασμού διαχειριστή",
+    "New admin password" : "Νέο συνθηματικό διαχειριστή",
+    "Show password" : "Εμφάνιση συνθηματικού",
+    "Toggle password visibility" : "Εναλλαγή ορατότητας συνθηματικού",
     "Configure the database" : "Ρύθμιση της βάσης δεδομένων",
-    "Only %s is available." : "Μόνο %s είναι διαθέσιμο."
+    "Only %s is available." : "Μόνο %s είναι διαθέσιμο.",
+    "Database account" : "Λογαριασμός βάσης δεδομένων",
+    "Direct link copied to clipboard" : "Ο άμεσος σύνδεσμος αντιγράφηκε στο πρόχειρο"
 },
 "nplurals=2; plural=(n != 1);");
