@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Unknown filetype",
     "An error occurred. Please contact your admin." : "An error occurred. Please contact your admin.",
     "Invalid image" : "Invalid image",
-    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
-    "No crop data provided" : "No crop data provided",
-    "No valid crop data provided" : "No valid crop data provided",
-    "Crop is not square" : "Crop is not square",
     "State token does not match" : "State token does not match",
     "Invalid app password" : "Invalid app password",
     "Could not complete login" : "Could not complete login",
     "State token missing" : "State token missing",
     "Your login token is invalid or has expired" : "Your login token is invalid or has expired",
+    "Please use original client" : "Please use original client",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "This community release of Nextcloud is unsupported and push notifications are limited.",
     "Login" : "Login",
     "Unsupported email length (>255)" : "Unsupported email length (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Task not found",
     "Internal error" : "Internal error",
     "Not found" : "Not found",
+    "Node is locked" : "Node is locked",
     "Bad request" : "Bad request",
     "Requested task type does not exist" : "Requested task type does not exist",
     "Necessary language model provider is not available" : "Necessary language model provider is not available",
@@ -51,6 +49,11 @@ OC.L10N.register(
     "No translation provider available" : "No translation provider available",
     "Could not detect language" : "Could not detect language",
     "Unable to translate" : "Unable to translate",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Repair step:",
+    "Repair info:" : "Repair info:",
+    "Repair warning:" : "Repair warning:",
+    "Repair error:" : "Repair error:",
     "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Some of your link shares have been removed",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
@@ -58,11 +61,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies.",
     "Learn more ↗" : "Learn more ↗",
     "Preparing update" : "Preparing update",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Repair step:",
-    "Repair info:" : "Repair info:",
-    "Repair warning:" : "Repair warning:",
-    "Repair error:" : "Repair error:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php.",
     "Turned on maintenance mode" : "Turned on maintenance mode",
     "Turned off maintenance mode" : "Turned off maintenance mode",
@@ -79,8 +77,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "The following apps have been disabled: %s",
     "Already up to date" : "Already up to date",
-    "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
+    "Windows Command Script" : "Windows Command Script",
+    "Electronic book document" : "Electronic book document",
+    "TrueType Font Collection" : "TrueType Font Collection",
+    "Web Open Font Format" : "Web Open Font Format",
+    "GPX geographic data" : "GPX geographic data",
+    "Gzip archive" : "Gzip archive",
+    "Adobe Illustrator document" : "Adobe Illustrator document",
+    "Java source code" : "Java source code",
+    "JavaScript source code" : "JavaScript source code",
+    "JSON document" : "JSON document",
+    "Microsoft Access database" : "Microsoft Access database",
+    "Microsoft OneNote document" : "Microsoft OneNote document",
+    "Microsoft Word document" : "Microsoft Word document",
+    "Unknown" : "Unknown",
+    "PDF document" : "PDF document",
+    "PostScript document" : "PostScript document",
+    "RSS summary" : "RSS summary",
+    "Android package" : "Android package",
+    "KML geographic data" : "KML geographic data",
+    "KML geographic compressed data" : "KML geographic compressed data",
+    "Lotus Word Pro document" : "Lotus Word Pro document",
+    "Excel spreadsheet" : "Excel spreadsheet",
+    "Excel add-in" : "Excel add-in",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 binary spreadsheet",
+    "Excel spreadsheet template" : "Excel spreadsheet template",
+    "Outlook Message" : "Outlook Message",
+    "PowerPoint presentation" : "PowerPoint presentation",
+    "PowerPoint add-in" : "PowerPoint add-in",
+    "PowerPoint presentation template" : "PowerPoint presentation template",
+    "Word document" : "Word document",
+    "ODF formula" : "ODF formula",
+    "ODG drawing" : "ODG drawing",
+    "ODG drawing (Flat XML)" : "ODG drawing (Flat XML)",
+    "ODG template" : "ODG template",
+    "ODP presentation" : "ODP presentation",
+    "ODP presentation (Flat XML)" : "ODP presentation (Flat XML)",
+    "ODP template" : "ODP template",
+    "ODS spreadsheet" : "ODS spreadsheet",
+    "ODS spreadsheet (Flat XML)" : "ODS spreadsheet (Flat XML)",
+    "ODS template" : "ODS template",
+    "ODT document" : "ODT document",
+    "ODT document (Flat XML)" : "ODT document (Flat XML)",
+    "ODT template" : "ODT template",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 presentation",
+    "PowerPoint 2007 show" : "PowerPoint 2007 show",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 presentation template",
+    "Excel 2007 spreadsheet" : "Excel 2007 spreadsheet",
+    "Excel 2007 spreadsheet template" : "Excel 2007 spreadsheet template",
+    "Word 2007 document" : "Word 2007 document",
+    "Word 2007 document template" : "Word 2007 document template",
+    "Microsoft Visio document" : "Microsoft Visio document",
+    "WordPerfect document" : "WordPerfect document",
+    "7-zip archive" : "7-zip archive",
+    "Blender scene" : "Blender scene",
+    "Bzip2 archive" : "Bzip2 archive",
+    "Debian package" : "Debian package",
+    "FictionBook document" : "FictionBook document",
+    "Unknown font" : "Unknown font",
+    "Krita document" : "Krita document",
+    "Mobipocket e-book" : "Mobipocket e-book",
+    "Windows Installer package" : "Windows Installer package",
+    "Perl script" : "Perl script",
+    "PHP script" : "PHP script",
+    "Tar archive" : "Tar archive",
+    "XML document" : "XML document",
+    "YAML document" : "YAML document",
+    "Zip archive" : "Zip archive",
+    "Zstandard archive" : "Zstandard archive",
+    "AAC audio" : "AAC audio",
+    "FLAC audio" : "FLAC audio",
+    "MPEG-4 audio" : "MPEG-4 audio",
+    "MP3 audio" : "MP3 audio",
+    "Ogg audio" : "Ogg audio",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe standard Audio",
+    "WebM audio" : "WebM audio",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
+    "Windows BMP image" : "Windows BMP image",
+    "Better Portable Graphics image" : "Better Portable Graphics image",
+    "EMF image" : "EMF image",
+    "GIF image" : "GIF image",
+    "HEIC image" : "HEIC image",
+    "HEIF image" : "HEIF image",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 image",
+    "JPEG image" : "JPEG image",
+    "PNG image" : "PNG image",
+    "SVG image" : "SVG image",
+    "Truevision Targa image" : "Truevision Targa image",
+    "TIFF image" : "TIFF image",
+    "WebP image" : "WebP image",
+    "Digital raw image" : "Digital raw image",
+    "Windows Icon" : "Windows Icon",
+    "Email message" : "Email message",
+    "VCS/ICS calendar" : "VCS/ICS calendar",
+    "CSS stylesheet" : "CSS stylesheet",
+    "CSV document" : "CSV document",
+    "HTML document" : "HTML document",
+    "Markdown document" : "Markdown document",
+    "Org-mode file" : "Org-mode file",
+    "Plain text document" : "Plain text document",
+    "Rich Text document" : "Rich Text document",
+    "Electronic business card" : "Electronic business card",
+    "C++ source code" : "C++ source code",
+    "LDIF address book" : "LDIF address book",
+    "NFO document" : "NFO document",
+    "PHP source" : "PHP source",
+    "Python script" : "Python script",
+    "ReStructuredText document" : "ReStructuredText document",
+    "3GPP multimedia file" : "3GPP multimedia file",
+    "MPEG video" : "MPEG video",
+    "DV video" : "DV video",
+    "MPEG-2 transport stream" : "MPEG-2 transport stream",
+    "MPEG-4 video" : "MPEG-4 video",
+    "Ogg video" : "Ogg video",
+    "QuickTime video" : "QuickTime video",
+    "WebM video" : "WebM video",
+    "Flash video" : "Flash video",
+    "Matroska video" : "Matroska video",
+    "Windows Media video" : "Windows Media video",
+    "AVI video" : "AVI video",
     "unknown text" : "unknown text",
     "Hello world!" : "Hello world!",
     "sunny" : "sunny",
@@ -109,7 +224,7 @@ OC.L10N.register(
     "Federated user" : "Federated user",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Create share",
-    "Direct link copied to clipboard" : "Direct link copied to clipboard",
+    "Direct link copied" : "Direct link copied",
     "Please copy the link manually:" : "Please copy the link manually:",
     "Custom date range" : "Custom date range",
     "Pick start date" : "Pick start date",
@@ -126,6 +241,7 @@ OC.L10N.register(
     "Last 30 days" : "Last 30 days",
     "This year" : "This year",
     "Last year" : "Last year",
+    "Between {startDate} and {endDate}" : "Between {startDate} and {endDate}",
     "Unified search" : "Unified search",
     "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
     "Places" : "Places",
@@ -133,6 +249,7 @@ OC.L10N.register(
     "Search people" : "Search people",
     "People" : "People",
     "Filter in current view" : "Filter in current view",
+    "Search connected services" : "Search connected services",
     "Results" : "Results",
     "Load more results" : "Load more results",
     "Search in" : "Search in",
@@ -146,8 +263,8 @@ OC.L10N.register(
     "Account name" : "Account name",
     "Server side authentication failed!" : "Server side authentication failed!",
     "Please contact your administrator." : "Please contact your administrator.",
-    "Temporary error" : "Temporary error",
-    "Please try again." : "Please try again.",
+    "Session error" : "Session error",
+    "It appears your session token has expired, please refresh the page and try again." : "It appears your session token has expired, please refresh the page and try again.",
     "An internal error occurred." : "An internal error occurred.",
     "Please try again or contact your administrator." : "Please try again or contact your administrator.",
     "Password" : "Password",
@@ -207,6 +324,11 @@ OC.L10N.register(
     "Login form is disabled." : "Login form is disabled.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "The Nextcloud login form is disabled. Use another login option if available or contact your administration.",
     "More actions" : "More actions",
+    "User menu" : "User menu",
+    "Your guest name: {user}" : "Your guest name: {user}",
+    "You are currently not identified." : "You are currently not identified.",
+    "Set public name" : "Set public name",
+    "Change public name" : "Change public name",
     "Password is too weak" : "Password is too weak",
     "Password is weak" : "Password is weak",
     "Password is average" : "Password is average",
@@ -287,22 +409,16 @@ OC.L10N.register(
     "Error fetching contact actions" : "Error fetching contact actions",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialogue",
     "Email length is at max (255)" : "Email length is at max (255)",
-    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
-    "Restricted" : "Restricted",
-    "Invisible" : "Invisible",
-    "Delete" : "Delete",
-    "Rename" : "Rename",
-    "Collaborative tags" : "Collaborative tags",
-    "No tags found" : "No tags found",
     "Clipboard not available, please copy manually" : "Clipboard not available, please copy manually",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
     "Admin" : "Admin",
     "Help" : "Help",
     "Access forbidden" : "Access denied",
+    "You are not allowed to access this page." : "You are not allowed to access this page.",
+    "Back to %s" : "Back to %s",
     "Page not found" : "Page not found",
     "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
-    "Back to %s" : "Back to %s",
     "Too many requests" : "Too many requests",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
     "Error" : "Error",
@@ -378,21 +494,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
-    "Currently open" : "Currently open",
-    "Login with username or email" : "Login with username or email",
-    "Login with username" : "Login with username",
+    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
+    "No crop data provided" : "No crop data provided",
+    "No valid crop data provided" : "No valid crop data provided",
+    "Crop is not square" : "Crop is not square",
+    "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
     "You have not added any info yet" : "You have not added any info yet",
     "{user} has not added any info yet" : "{user} has not added any info yet",
     "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
     "Edit Profile" : "Edit Profile",
     "The headline and about sections will show up here" : "The headline and about sections will show up here",
-    "Error loading message template: {error}" : "Error loading message template: {error}",
     "Very weak password" : "Very weak password",
     "Weak password" : "Weak password",
     "So-so password" : "So-so password",
     "Good password" : "Good password",
     "Strong password" : "Strong password",
+    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
+    "Restricted" : "Restricted",
+    "Invisible" : "Invisible",
+    "Delete" : "Delete",
+    "Rename" : "Rename",
+    "Collaborative tags" : "Collaborative tags",
+    "No tags found" : "No tags found",
     "Profile not found" : "Profile not found",
     "The profile does not exist." : "The profile does not exist.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
@@ -404,6 +529,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Toggle password visibility",
     "Configure the database" : "Configure the database",
     "Only %s is available." : "Only %s is available.",
-    "Database account" : "Database account"
+    "Database account" : "Database account",
+    "Direct link copied to clipboard" : "Direct link copied to clipboard"
 },
 "nplurals=2; plural=(n != 1);");
