@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Óþekkt skráartegund",
     "An error occurred. Please contact your admin." : "Villa kom upp. Hafðu samband við kerfisstjóra.",
     "Invalid image" : "Ógild mynd",
-    "No temporary profile picture available, try again" : "Engin bráðabirgða-auðkennismynd er tiltæk, reyndu aftur",
-    "No crop data provided" : "Enginn gögn um utanskurð gefin",
-    "No valid crop data provided" : "Enginn gild gögn um utanskurð gefin",
-    "Crop is not square" : "Utanskurður er ekki ferningslaga",
     "State token does not match" : "Stöðuteikn samsvarar ekki",
     "Invalid app password" : "Ógilt lykilorð forrits",
     "Could not complete login" : "Gat ekki lokið innskráningu",
@@ -51,6 +47,11 @@ OC.L10N.register(
     "No translation provider available" : "Engin þýðingaþjónusta tiltæk",
     "Could not detect language" : "Gat ekki greint tungumálið",
     "Unable to translate" : "Næ ekki að þýða",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Þrep viðgerðar:",
+    "Repair info:" : "Viðgerðarupplýsingar:",
+    "Repair warning:" : "Viðvörun vegna viðgerðar:",
+    "Repair error:" : "Villa í viðgerð:",
     "Nextcloud Server" : "Nextcloud þjónn",
     "Some of your link shares have been removed" : "Sumir tenglar þínir á sameignir hafa verið fjarlægðir",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Vegna öryggisgalla hafa sumir tenglar þínir á sameignir hafa verið fjarlægðir. Skoðaðu tengilinn til að sjá frekari upplýsingar.",
@@ -58,11 +59,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Settu inn áskriftarlykilinn þinn í aðstoðarforritið til að lyfta takmörkum á aðgangnum þínum. Þetta gefur þér einnig alla viðbótareiginleikana sem Nextcloud Enterprise fyrirtækjaáskrift býður, enda er sterklega mælt með þeim fyrir verklag í fyrirtækjum.",
     "Learn more ↗" : "Kanna nánar ↗",
     "Preparing update" : "Undirbý uppfærslu",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Þrep viðgerðar:",
-    "Repair info:" : "Viðgerðarupplýsingar:",
-    "Repair warning:" : "Viðvörun vegna viðgerðar:",
-    "Repair error:" : "Villa í viðgerð:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Endilega notaðu uppfærslutólið af skipanalínu, því uppfærslur í vafra eru gerðar óvirkar í config.php.",
     "Turned on maintenance mode" : "Kveikt á viðhaldsham",
     "Turned off maintenance mode" : "Slökkt á viðhaldsham",
@@ -79,8 +75,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ósamhæft)",
     "The following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
     "Already up to date" : "Allt uppfært nú þegar",
-    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Frekari upplýsingar má sjá í {linkstart}hjálparskjölunum ↗{linkend}.",
+    "Unknown" : "Óþekkt",
+    "PNG image" : "PNG-mynd",
     "unknown text" : "óþekktur texti",
     "Hello world!" : "Halló heimur!",
     "sunny" : "sólríkt",
@@ -109,7 +105,6 @@ OC.L10N.register(
     "Federated user" : "Notandi í skýjasambandi",
     "user@your-nextcloud.org" : "notandi@þitt-nextcloud.org",
     "Create share" : "Búa til sameign",
-    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald",
     "Please copy the link manually:" : "Afritaðu tengilinn handvirkt:",
     "Custom date range" : "Sérsniðið dagsetningabil",
     "Pick start date" : "Veldu upphafsdagsetningu",
@@ -146,6 +141,7 @@ OC.L10N.register(
     "Account name" : "Heiti notandaaðgangs",
     "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
     "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
+    "Session error" : "Villa í setu",
     "An internal error occurred." : "Innri villa kom upp.",
     "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
     "Password" : "Lykilorð",
@@ -205,9 +201,24 @@ OC.L10N.register(
     "Login form is disabled." : "Innskráningarform er óvirkt.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Innskráningarform Nextcloud er óvirkt. Notaðu aðra aðferð til innskráningar ef slíkt er í boði eða hafðu samband við kerfisstjórnanda.",
     "More actions" : "Fleiri aðgerðir",
+    "Password is too weak" : "Lykilorð er of veikt",
+    "Password is weak" : "Lykilorð er veikt",
+    "Password is average" : "Lykilorð er í meðallagi",
+    "Password is strong" : "Lykilorð er sterkt",
+    "Password is very strong" : "Lykilorð er mjög sterkt",
+    "Password is extremely strong" : "Lykilorð er einstaklega sterkt",
+    "Unknown password strength" : "Óþekktur styrkur lykilorðs",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að <code>.htaccess</code> skráin er ekki virk.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Til að fá upplýsingar hvernig á að stilla miðlara almennilega, skaltu skoða {linkStart}hjálparskjölin{linkEnd}",
+    "Autoconfig file detected" : "Fann autoconfig-uppsetningarskrá",
     "Security warning" : "Öryggisviðvörun",
+    "Create administration account" : "Búa til stjórnunaraðgang",
+    "Administration account name" : "Heiti kerfisstjóraaðgangs",
+    "Administration account password" : "Lykilorð kerfisstjóraaðgangs",
     "Storage & database" : "Geymsla & gagnagrunnur",
     "Data folder" : "Gagnamappa",
+    "Database configuration" : "Uppsetning gagnagrunns",
+    "Only {firstAndOnlyDatabase} is available." : "Aðeins {firstAndOnlyDatabase} er laust.",
     "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
     "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
     "Performance warning" : "Afkastaviðvörun",
@@ -220,6 +231,7 @@ OC.L10N.register(
     "Database tablespace" : "Töflusvæði gagnagrunns",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
     "Database host" : "Netþjónn gagnagrunns",
+    "localhost" : "localhost",
     "Installing …" : "Set upp…",
     "Install" : "Setja upp",
     "Need help?" : "Þarftu hjálp?",
@@ -268,22 +280,15 @@ OC.L10N.register(
     "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
     "Close \"{dialogTitle}\" dialog" : "Loka \"{dialogTitle}\"-glugga",
     "Email length is at max (255)" : "Lengd tölvupósts er að hámarki (255)",
-    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
-    "Restricted" : "Takmarkað",
-    "Invisible" : "Ósýnilegt",
-    "Delete" : "Eyða",
-    "Rename" : "Endurnefna",
-    "Collaborative tags" : "Samstarfsmerkingar",
-    "No tags found" : "Engin merki fundust",
     "Clipboard not available, please copy manually" : "Klippispjald er ekki tiltækt, afritaðu handvirkt",
     "Personal" : "Einka",
     "Accounts" : "Notandaaðgangar",
     "Admin" : "Stjórnun",
     "Help" : "Hjálp",
     "Access forbidden" : "Aðgangur bannaður",
+    "Back to %s" : "Til baka í %s",
     "Page not found" : "Síða fannst ekki",
     "The page could not be found on the server or you may not be allowed to view it." : "Síðan fannst ekki á netþjóninum eða að þér er ekki heimilt að skoða hana.",
-    "Back to %s" : "Til baka í %s",
     "Too many requests" : "Of margar beiðnir",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
     "Error" : "Villa",
@@ -359,21 +364,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
     "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
-    "Currently open" : "Opið núna",
-    "Login with username or email" : "Skrá inn með notandanafni eða tölvupóstfangi",
-    "Login with username" : "Skrá inn með notandanafni",
+    "No temporary profile picture available, try again" : "Engin bráðabirgða-auðkennismynd er tiltæk, reyndu aftur",
+    "No crop data provided" : "Enginn gögn um utanskurð gefin",
+    "No valid crop data provided" : "Enginn gild gögn um utanskurð gefin",
+    "Crop is not square" : "Utanskurður er ekki ferningslaga",
+    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Frekari upplýsingar má sjá í {linkstart}hjálparskjölunum ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
     "You have not added any info yet" : "Þú hefur ekki bætt við neinum upplýsingum ennþá",
     "{user} has not added any info yet" : "{user} hefur ekki bætt við neinum upplýsingum ennþá",
     "Error opening the user status modal, try hard refreshing the page" : "Villa við að opna stöðuglugga notandans, prófaðu að þvinga endurlestur síðunnar",
     "Edit Profile" : "Breyta sniði",
     "The headline and about sections will show up here" : "Fyrirsögnin og hlutar um hugbúnaðinn munu birtast hér",
-    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
     "Very weak password" : "Mjög veikt lykilorð",
     "Weak password" : "Veikt lykilorð",
     "So-so password" : "Miðlungs lykilorð",
     "Good password" : "Gott lykilorð",
     "Strong password" : "Sterkt lykilorð",
+    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
+    "Restricted" : "Takmarkað",
+    "Invisible" : "Ósýnilegt",
+    "Delete" : "Eyða",
+    "Rename" : "Endurnefna",
+    "Collaborative tags" : "Samstarfsmerkingar",
+    "No tags found" : "Engin merki fundust",
     "Profile not found" : "Sniðið finnst ekki",
     "The profile does not exist." : "Sniðið er ekki til.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
@@ -385,6 +399,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Breyta sýnileika lykilorðs",
     "Configure the database" : "Stilla gagnagrunninn",
     "Only %s is available." : "Aðeins %s eru laus.",
-    "Database account" : "Gagnagrunnsaðgangur"
+    "Database account" : "Gagnagrunnsaðgangur",
+    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
