@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "알려지지 않은 파일 형식",
     "An error occurred. Please contact your admin." : "오류가 발생했습니다. 시스템 관리자에게 연락하십시오.",
     "Invalid image" : "잘못된 사진",
-    "No temporary profile picture available, try again" : "사용 가능한 프로필 사진이 없습니다. 다시 시도하십시오.",
-    "No crop data provided" : "선택된 데이터가 없습니다.",
-    "No valid crop data provided" : "올바른 잘라내기 데이터가 지정되지 않음",
-    "Crop is not square" : "잘라내는 영역이 사각형이 아님",
     "State token does not match" : "상태 토큰이 일치하지 않습니다.",
     "Invalid app password" : "앱 암호가 잘못됨",
     "Could not complete login" : "로그인을 완료할 수 없음",
     "State token missing" : "상태 토큰 누락",
     "Your login token is invalid or has expired" : "로그인 토큰이 잘못되었거나 만료되었습니다.",
+    "Please use original client" : "원본 클라이언트를 사용해주십시오.",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "이 Nextcloud 커뮤니티 릴리즈는 지원하지 않는 버전이며, 푸시 알림은 제한됩니다.",
     "Login" : "로그인",
     "Unsupported email length (>255)" : "지원하지 않는 이메일 길이 (255자 초과)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "작업을 찾을 수 없습니다",
     "Internal error" : "내부 오류",
     "Not found" : "찾을 수 없음",
+    "Node is locked" : "노트가 잠김",
     "Bad request" : "잘못된 요청",
     "Requested task type does not exist" : "요청한 작업 타입이 존재하지 않음",
     "Necessary language model provider is not available" : "필요한 언어 모델 제공자를 사용할 수 없습니다",
@@ -51,6 +49,11 @@ OC.L10N.register(
     "No translation provider available" : "이용 가능한 번역 제공자 없음",
     "Could not detect language" : "언어를 감지할 수 없음",
     "Unable to translate" : "번역할 수 없음",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "수리 단계:",
+    "Repair info:" : "수리 정보:",
+    "Repair warning:" : "수리 경고:",
+    "Repair error:" : "수리 오류:",
     "Nextcloud Server" : "Nextcloud 서버",
     "Some of your link shares have been removed" : "일부 링크 공유가 제거되었습니다.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "보안 버그로 인하여 일부 링크 공유를 삭제했습니다. 링크를 눌러서 더 많은 정보를 볼 수 있습니다.",
@@ -58,11 +61,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "지원 앱에서 가입 키를 입력하여 계정 한도를 늘리세요. 이는 Nextcloud Enterprise의 모든 혜택을 제공하며, 기업에서의 운영에 적극 권장됩니다.",
     "Learn more ↗" : "더 알아보기 ↗",
     "Preparing update" : "업데이트 준비 중",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "수리 단계:",
-    "Repair info:" : "수리 정보:",
-    "Repair warning:" : "수리 경고:",
-    "Repair error:" : "수리 오류:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "당신의 config.php에서 브라우저를 통한 업데이트가 비활성화 되어 있으므로, 명령줄 업데이터를 사용하세요.",
     "Turned on maintenance mode" : "유지 보수 모드 켜짐",
     "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
@@ -79,8 +77,107 @@ OC.L10N.register(
     "%s (incompatible)" : "%s(호환 불가)",
     "The following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
     "Already up to date" : "최신 상태임",
-    "Error occurred while checking server setup" : "서버 설정을 확인하는 중 오류 발생",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "더 자세한 사항은 {linkstart}문서 ↗{linkend}를 참조하십시오.",
+    "Windows Command Script" : "Windows 명령 스크립트",
+    "Electronic book document" : "전자책 문서",
+    "TrueType Font Collection" : "TrueType 글꼴 모음",
+    "Web Open Font Format" : "웹 오픈 글꼴 형식",
+    "GPX geographic data" : "GPX 지리 데이터",
+    "Gzip archive" : "Gzip 압축 파일",
+    "Adobe Illustrator document" : "Adobe Illustrator 문서",
+    "Java source code" : "Java 소스 코드",
+    "JavaScript source code" : "JavaScript 소스 코드",
+    "JSON document" : "JSON  문서",
+    "Microsoft Access database" : "Microsoft Access 데이터베이스",
+    "Microsoft OneNote document" : "Microsoft OneNote 문서",
+    "Microsoft Word document" : "Microsoft Word 문서",
+    "Unknown" : "알 수 없음",
+    "PDF document" : "PDF 문서",
+    "PostScript document" : "PostScript 문서",
+    "RSS summary" : "RSS 요약",
+    "Android package" : "Android 패키지",
+    "KML geographic data" : "KML  지리 데이터",
+    "KML geographic compressed data" : "KML 지리 압축 데이터",
+    "Lotus Word Pro document" : "Lotus Word Pro 문서",
+    "Excel spreadsheet" : "Excel 스프레드시트",
+    "Excel add-in" : "Excel 추가 기능",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 바이너리 스프레드시트",
+    "Excel spreadsheet template" : "Excel 스프레드시트 템플릿",
+    "Outlook Message" : "Outlook 메시지",
+    "PowerPoint presentation" : "PowerPoint 프리젠테이션",
+    "PowerPoint add-in" : "PowerPoint 추가 기능",
+    "PowerPoint presentation template" : "PowerPoint 프리젠테이션 템플릿",
+    "Word document" : "Word  문서",
+    "ODF formula" : "ODF 공식",
+    "ODG drawing" : "ODG 도면",
+    "ODG drawing (Flat XML)" : "ODG 도면(플랫 XML)",
+    "ODG template" : "ODG 템플릿",
+    "ODP presentation" : "ODP 프리젠테이션",
+    "ODP presentation (Flat XML)" : "ODP 프리젠테이션(플랫 XML)",
+    "ODP template" : "ODP 템플릿",
+    "ODS spreadsheet" : "ODS 스프레드시트",
+    "ODS spreadsheet (Flat XML)" : "ODS 스프레드시트(플랫 XML)",
+    "ODS template" : "ODS 템플릿",
+    "ODT document" : "ODT 문서",
+    "ODT document (Flat XML)" : "ODT 문서(플랫 XML)",
+    "ODT template" : "ODT 템플릿",
+    "Bzip2 archive" : "Bzip2 압축 파일",
+    "Debian package" : "Debian 패키지",
+    "FictionBook document" : "FictionBook 문서",
+    "Unknown font" : "알 수 없는 글꼴",
+    "Krita document" : "Krita 문서",
+    "Mobipocket e-book" : " Mobipocket 전자책",
+    "Windows Installer package" : "Windows Installer 패키지",
+    "Perl script" : "Perl 스크립트",
+    "PHP script" : "PHP 스크립트",
+    "Tar archive" : "Tar 압축 파일",
+    "XML document" : "XML 문서",
+    "YAML document" : "YAML 문서",
+    "Zip archive" : "Zip 압축 파일",
+    "Zstandard archive" : "Zstandard  압축 파일",
+    "AAC audio" : "AAC  오디오",
+    "FLAC audio" : "FLAC 오디오",
+    "MPEG-4 audio" : "MPEG-4 오디오",
+    "MP3 audio" : "MP3 오디오",
+    "Ogg audio" : "OGG 오디오",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe 표준 오디오",
+    "WebM audio" : "WebM 오디오",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast 재생 목록",
+    "Windows BMP image" : " Windows BMP 이미지",
+    "Better Portable Graphics image" : "더 나은 휴대용 그래픽 이미지",
+    "EMF image" : "EMF 이미지",
+    "GIF image" : "GIF 이미지",
+    "HEIC image" : "HEIC 이미지",
+    "HEIF image" : "HEIF 이미지",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 이미지",
+    "PNG image" : "PNG 이미지",
+    "Email message" : "이메일 메시지",
+    "VCS/ICS calendar" : "VCS/ICS 캘린더",
+    "CSS stylesheet" : "CSS 스타일시트",
+    "CSV document" : "CSV 문서",
+    "HTML document" : "HTML 문서",
+    "Markdown document" : "Markdown 문서",
+    "Org-mode file" : "Org-mode 파일",
+    "Plain text document" : "일반 텍스트 문서",
+    "Rich Text document" : "서식 있는 텍스트 문서",
+    "Electronic business card" : "전자 명함",
+    "C++ source code" : "C++ 소스 코드",
+    "LDIF address book" : "LDIF 주소록",
+    "NFO document" : "NFO  문서",
+    "PHP source" : "PHP 소스",
+    "Python script" : "Python 스크립트",
+    "ReStructuredText document" : "ReStructuredText  문서",
+    "3GPP multimedia file" : "3GPP  멀티미디어 파일",
+    "MPEG video" : "MPEG 비디오",
+    "DV video" : "DV 비디오",
+    "MPEG-2 transport stream" : "MPEG-2 전송 스트림",
+    "MPEG-4 video" : "MPEG-4 비디오",
+    "Ogg video" : "Ogg 비디오",
+    "QuickTime video" : "QuickTime 비디오",
+    "WebM video" : "WebM 비디오",
+    "Flash video" : "Flash 비디오",
+    "Matroska video" : "Matroska 비디오",
+    "Windows Media video" : "Windows Media 비디오",
+    "AVI video" : "AVI 비디오",
     "unknown text" : "알 수 없는 텍스트",
     "Hello world!" : "Hello world!",
     "sunny" : "맑음",
@@ -109,7 +206,7 @@ OC.L10N.register(
     "Federated user" : "연합 사용자",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "공유 만들기",
-    "Direct link copied to clipboard" : "직접 링크가 클립보드에 복사됨",
+    "Direct link copied" : "직접 링크가 복사됨",
     "Please copy the link manually:" : "링크를 수동으로 복사해 주세요:",
     "Custom date range" : "맞춤 날짜 범위",
     "Pick start date" : "시작일 선택",
@@ -133,6 +230,7 @@ OC.L10N.register(
     "Search people" : "사람 검색",
     "People" : "사람들",
     "Filter in current view" : "현재 화면을 필터",
+    "Search connected services" : "연결된 서비스 검색",
     "Results" : "결과들",
     "Load more results" : "더 많은 결과 불러오기",
     "Search in" : "다음에서 검색",
@@ -207,6 +305,9 @@ OC.L10N.register(
     "Login form is disabled." : "로그인 양식이 비활성화 되었습니다.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 로그인 양식이 비활성화 되었습니다. 이용 가능한 다른 방법으로 로그인 하거나, 관리자에게 문의하십시오.",
     "More actions" : "더 많은 동작",
+    "User menu" : "사용자 메뉴",
+    "You are currently not identified." : "현재 신원이 확인되지 않았습니다.",
+    "Set public name" : "공개 이름 설정",
     "Password is too weak" : "너무 약한 암호",
     "Password is weak" : "약한 암호",
     "Password is average" : "보통 암호",
@@ -287,22 +388,15 @@ OC.L10N.register(
     "Error fetching contact actions" : "연락처 동작을 가져오는 중 오류 발생",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" 대화 상자 닫기",
     "Email length is at max (255)" : "이메일 길이가 최대입니다 (255)",
-    "Non-existing tag #{tag}" : "존재하지 않는 태그 #{tag}",
-    "Restricted" : "제한됨",
-    "Invisible" : "숨겨짐",
-    "Delete" : "삭제",
-    "Rename" : "이름 바꾸기",
-    "Collaborative tags" : "협동 태그",
-    "No tags found" : "태그를 찾을 수 없음",
     "Clipboard not available, please copy manually" : "클립보드를 사용할 수 없으므로, 수동으로 복사해 주세요.",
     "Personal" : "개인",
     "Accounts" : "계정",
     "Admin" : "관리자",
     "Help" : "도움말",
     "Access forbidden" : "접근 금지됨",
+    "Back to %s" : "%s(으)로 돌아가기",
     "Page not found" : "페이지를 찾을 수 없음",
     "The page could not be found on the server or you may not be allowed to view it." : "페이지를 서버에서 찾을 수 없거나, 페이지를 보도록 허가되지 않았습니다.",
-    "Back to %s" : "%s(으)로 돌아가기",
     "Too many requests" : "요청이 너무 많음",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
     "Error" : "오류",
@@ -378,21 +472,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
     "This page will refresh itself when the instance is available again." : "인스턴스를 다시 사용할 수 있을 때 페이지를 자동으로 새로 고칩니다.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오.",
-    "Currently open" : "현재 열려있음",
-    "Login with username or email" : "아이디 또는 이메일로 로그인",
-    "Login with username" : "아이디로 로그인",
+    "No temporary profile picture available, try again" : "사용 가능한 프로필 사진이 없습니다. 다시 시도하십시오.",
+    "No crop data provided" : "선택된 데이터가 없습니다.",
+    "No valid crop data provided" : "올바른 잘라내기 데이터가 지정되지 않음",
+    "Crop is not square" : "잘라내는 영역이 사각형이 아님",
+    "Error occurred while checking server setup" : "서버 설정을 확인하는 중 오류 발생",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "더 자세한 사항은 {linkstart}문서 ↗{linkend}를 참조하십시오.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "당신의 브라우저와 모바일 앱 속의  채팅, 영상 통화, 화면 공유, 온라인 미팅 그리고 웹 회의",
     "You have not added any info yet" : "아직 아무 정보도 추가하지 않았습니다.",
     "{user} has not added any info yet" : "{user}님이 아직 아무 정보도 추가하지 않음",
     "Error opening the user status modal, try hard refreshing the page" : "사용자 상태 모달을 불러오는 데 실패했습니다, 페이지를 완전히 새로고침 해 보십시오.",
     "Edit Profile" : "프로필 수정",
     "The headline and about sections will show up here" : "표제와 기타 정보가 이곳에 나타납니다.",
-    "Error loading message template: {error}" : "메시지 템플릿을 불러오는 중 오류 발생: {error}",
     "Very weak password" : "매우 약한 암호",
     "Weak password" : "약한 암호",
     "So-so password" : "그저 그런 암호",
     "Good password" : "좋은 암호",
     "Strong password" : "강력한 암호",
+    "Non-existing tag #{tag}" : "존재하지 않는 태그 #{tag}",
+    "Restricted" : "제한됨",
+    "Invisible" : "숨겨짐",
+    "Delete" : "삭제",
+    "Rename" : "이름 바꾸기",
+    "Collaborative tags" : "협동 태그",
+    "No tags found" : "태그를 찾을 수 없음",
     "Profile not found" : "프로필 찾을 수 없음",
     "The profile does not exist." : "프로필이 존재하지 않습니다.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수도 있습니다.",
@@ -404,6 +507,7 @@ OC.L10N.register(
     "Toggle password visibility" : "암호 보이기/숨기기",
     "Configure the database" : "데이터베이스 설정",
     "Only %s is available." : "%s만 사용할 수 있습니다.",
-    "Database account" : "데이터베이스 계정"
+    "Database account" : "데이터베이스 계정",
+    "Direct link copied to clipboard" : "직접 링크가 클립보드에 복사됨"
 },
 "nplurals=1; plural=0;");
