@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Непознат тип на датотека",
     "An error occurred. Please contact your admin." : "Настана грешка. Контактирате со администраторот.",
     "Invalid image" : "Невалидна фотографија",
-    "No temporary profile picture available, try again" : "Не е достапна привремена профилна слика, пробајте повторно",
-    "No crop data provided" : "Не се доставени податоци за сечење",
-    "No valid crop data provided" : "Нема валидни податоци за сечење",
-    "Crop is not square" : "Сечењето не е квадратно",
     "State token does not match" : "Токенот не се совпаѓа",
     "Invalid app password" : "Погрешна лозинка за апликација",
     "Could not complete login" : "Неможе да се комплетира најавувањето",
@@ -42,16 +38,16 @@ OC.L10N.register(
     "Image not found" : "Сликата не е пронајдена",
     "Could not detect language" : "Неможе да се детектира јазикот",
     "Unable to translate" : "Неможе да се преведе",
-    "Nextcloud Server" : "Nextcloud Сервер",
-    "Some of your link shares have been removed" : "Некој од вашите линкови што ги споделивте се избришани",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради безбедносен ризик некој од вашите споделувања се избришани. Ве молиме видете го линкот за повеќе информации.",
-    "Learn more ↗" : "Научи повеќе ↗",
-    "Preparing update" : "Ја подготвувам надградбата",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Чекори за поправка:",
     "Repair info:" : "Инфо при поправка:",
     "Repair warning:" : "Предупредувања при поправка:",
     "Repair error:" : "Грешка при поправка:",
+    "Nextcloud Server" : "Nextcloud Сервер",
+    "Some of your link shares have been removed" : "Некој од вашите линкови што ги споделивте се избришани",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради безбедносен ризик некој од вашите споделувања се избришани. Ве молиме видете го линкот за повеќе информации.",
+    "Learn more ↗" : "Научи повеќе ↗",
+    "Preparing update" : "Ја подготвувам надградбата",
     "Turned on maintenance mode" : "Вклучен е модот за одржување",
     "Turned off maintenance mode" : "Ислкучен е модот за одржување",
     "Maintenance mode is kept active" : "Модот за одржување е уште активен",
@@ -67,8 +63,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (некомпатибилен)",
     "The following apps have been disabled: %s" : "Следниве апликации се оневозможени: %s",
     "Already up to date" : "Веќе ажурирано",
-    "Error occurred while checking server setup" : "Се случи грешка при проверката на параметрите на серверот",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За повеќе детали погледнете во {linkstart}документацијата ↗{linkend}.",
+    "Unknown" : "Непознат",
     "unknown text" : "непознат текст",
     "Hello world!" : "Здраво свету!",
     "sunny" : "сончево",
@@ -76,7 +71,7 @@ OC.L10N.register(
     "Hello {name}" : "Здраво {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ова се вашите резултати од пребарувањето<script>alert(1)</script></strong>",
     "new" : "ново",
-    "_download %n file_::_download %n files_" : ["преземи 1 датотека","преземи %n датотеки"],
+    "_download %n file_::_download %n files_" : ["преземи %n датотека","преземи %n датотеки"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Во тек е надградба на системот, доколку ја напуштите оваа страница може да дојде до прекин на некој процес во некој дел.",
     "Update to {version}" : "Надгради на {version}",
     "An error occurred." : "Се случи грешка",
@@ -94,13 +89,16 @@ OC.L10N.register(
     "Create share" : "Ново споделување",
     "Pick start date" : "Избери почетен датум",
     "Pick end date" : "Избери краен датум",
+    "Search everywhere" : "Барај насекаде",
     "Searching …" : "Пребарување ...",
     "Start typing to search" : "Напишете нешто за пребарување",
+    "No matching results" : "Нема соодветни резултати",
     "Today" : "Денес",
     "Last 7 days" : "Предходни 7 дена",
     "Last 30 days" : "Предходни 30 дена",
     "This year" : "Оваа година",
     "Last year" : "Предходна година",
+    "Unified search" : "Унифицирано пребарување",
     "Search apps, files, tags, messages" : "Барај апликации, датотеки, ознаки, пораки",
     "Places" : "Места",
     "Date" : "Датум",
@@ -115,24 +113,23 @@ OC.L10N.register(
     "This account is disabled" : "Оваа сметка е оневозможена",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Детектирани се повеќе неуспешни најавувања од вашата IP адреса. Затоа вашиот следен обид за најавување е одложено за 30 секунди.",
     "Account name or email" : "Корисничко име или е-пошта",
+    "Account name" : "Корисничко име",
     "Server side authentication failed!" : "Автентификацијата на серверската страна е неуспешна!",
     "Please contact your administrator." : "Ве молиме контактирајте го вашиот администратор.",
-    "Temporary error" : "Привремена грешка",
-    "Please try again." : "Ве молиме обидете се повторно.",
     "An internal error occurred." : "Се случи внатрешна грешка.",
     "Please try again or contact your administrator." : "Ве молиме обидете се повторно или контактирајте го вашиот администратор.",
     "Password" : "Лозинка",
     "Log in with a device" : "Најавете се со уред",
     "Login or email" : "Корисничко име или лозинка",
     "Your account is not setup for passwordless login." : "Вашата сметка не е поставена за најавување без лозинка.",
-    "Browser not supported" : "Вашиот прелистувач не е поддржан",
-    "Passwordless authentication is not supported in your browser." : "Вашиот прелистувач не поддржува автентикација без лозинка.",
     "Your connection is not secure" : "Конекцијата не е безбедна",
     "Passwordless authentication is only available over a secure connection." : "Автентикација без лозинка е достапно доколку користите безбедна конекција.",
+    "Browser not supported" : "Вашиот прелистувач не е поддржан",
+    "Passwordless authentication is not supported in your browser." : "Вашиот прелистувач не поддржува автентикација без лозинка.",
     "Reset password" : "Ресетирај лозинка",
+    "Back to login" : "Врати се на страната за најавување",
     "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
     "Password cannot be changed. Please contact your administrator." : "Лозинката не може да се промени. Ве молам контактирајте го вашиот администратор.",
-    "Back to login" : "Врати се на страната за најавување",
     "New password" : "Нова лозинка",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Вашите податоци се шифрирани. Не постои можност за враќање на податоците одкако вашата лозинка ќе биде ресетирана. Доколку незнаете што да правите, контактирајте го вашиот администратор пред да продолжите понатаму. Дали сте сигурни дека сакате да продолжите?",
     "I know what I'm doing" : "Знам што правам",
@@ -172,6 +169,25 @@ OC.L10N.register(
     "Back" : "Назад",
     "Login form is disabled." : "Формата за најава е оневозможена.",
     "More actions" : "Повеќе акции",
+    "Security warning" : "Безбедносно предупредување",
+    "Storage & database" : "Складиште & база на податоци",
+    "Data folder" : "Фолдер со податоци",
+    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте дополнителни PHP додатоци за да можете да изберете друг вид на база на податоци.",
+    "For more details check out the documentation." : "За повеќе детали проверете ја документацијата.",
+    "Performance warning" : "Предупредување за перформансите",
+    "You chose SQLite as database." : "Вие избравте SQLite како база на податоци.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за минимални и развојни цели. За користење, препорачуваме различен начин за база на податоци.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако користите клиент за синхронизација на датотеки, SQLite не е препорачливо.",
+    "Database user" : "Корисник на база",
+    "Database password" : "Лозинка на база",
+    "Database name" : "Име на база",
+    "Database tablespace" : "Табела во базата на податоци",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ве молиме, наведете го бројот на портата, заедно со името на серверот (на пример, localhost:5432).",
+    "Database host" : "Сервер со база",
+    "Installing …" : "Инсталирање ...",
+    "Install" : "Инсталирај",
+    "Need help?" : "Ви треба помош?",
+    "See the documentation" : "Види ја документацијата",
     "{name} version {version} and above" : "{name} верзија {version} и понови",
     "This browser is not supported" : "Овој прелистувач не е поддржан",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашиот прелистувач не е поддржан. Надградете на понова или поддржана верзија.",
@@ -212,29 +228,17 @@ OC.L10N.register(
     "Type to search for existing projects" : "Пребарувај за постоечки проекти",
     "New in" : "Ново во",
     "View changelog" : "Види ги промените",
-    "Very weak password" : "Многу слаба лозинка",
-    "Weak password" : "Слаба лозинка",
-    "So-so password" : "Така така лозинка",
-    "Good password" : "Добра лозинка",
-    "Strong password" : "Јака лозинка",
     "No action available" : "Нема акции достапни",
     "Error fetching contact actions" : "Грешка при преземање на контакт",
     "Close \"{dialogTitle}\" dialog" : "Затвори \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Непостоечка ознака #{tag}",
-    "Restricted" : "Ограничена",
-    "Invisible" : "Невидливо",
-    "Delete" : "Избриши",
-    "Rename" : "Преименувај",
-    "Collaborative tags" : "Колаборативна ознака",
-    "No tags found" : "Не се пронајдени ознаки",
     "Personal" : "Лично",
     "Accounts" : "Сметки",
     "Admin" : "Админ",
     "Help" : "Помош",
     "Access forbidden" : "Забранет пристап",
+    "Back to %s" : "Врати се на %s",
     "Page not found" : "Страницата не е пронајдена",
     "The page could not be found on the server or you may not be allowed to view it." : "Страната не е пронајдена на серверот или не ви е дозволен пристап.",
-    "Back to %s" : "Врати се на %s",
     "Too many requests" : "Премногу барања",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Има испратено премногу барање од вашата мрежа. Обидете се подоцна повторно или контактирајте го администраторот.",
     "Error" : "Грешка",
@@ -252,30 +256,6 @@ OC.L10N.register(
     "File: %s" : "Датотека: %s",
     "Line: %s" : "Линија: %s",
     "Trace" : "Следи",
-    "Security warning" : "Безбедносно предупредување",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашиот директориум со податоци и датотеки се веројатно достапни преку интенернт поради што .htaccess датотеката не функционира.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информации како правилно да го конфигурирате вашиот сервер, ве молиме погледнете ја <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацијата</a>.",
-    "Show password" : "Прикажи лозинка",
-    "Toggle password visibility" : "Вклучи видливост на лозинки",
-    "Storage & database" : "Складиште & база на податоци",
-    "Data folder" : "Фолдер со податоци",
-    "Configure the database" : "Конфигурирај ја базата",
-    "Only %s is available." : "Само %s е достапно.",
-    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте дополнителни PHP додатоци за да можете да изберете друг вид на база на податоци.",
-    "For more details check out the documentation." : "За повеќе детали проверете ја документацијата.",
-    "Database password" : "Лозинка на база",
-    "Database name" : "Име на база",
-    "Database tablespace" : "Табела во базата на податоци",
-    "Database host" : "Сервер со база",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ве молиме, наведете го бројот на портата, заедно со името на серверот (на пример, localhost:5432).",
-    "Performance warning" : "Предупредување за перформансите",
-    "You chose SQLite as database." : "Вие избравте SQLite како база на податоци.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за минимални и развојни цели. За користење, препорачуваме различен начин за база на податоци.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако користите клиент за синхронизација на датотеки, SQLite не е препорачливо.",
-    "Install" : "Инсталирај",
-    "Installing …" : "Инсталирање ...",
-    "Need help?" : "Ви треба помош?",
-    "See the documentation" : "Види ја документацијата",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Изгледа дека се обидувате да го преинсталирате Nextcloud. Како и да е, датотеката CAN_INSTALL недостасува во вашата конфигурациона папка. Креирајте празна датотека CAN_INSTALL во конфигурационата папка за да продолжите.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Неможе да се отстрани CAN_INSTALL датотеката од конфигурациската папка. Избришете ја рачно.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "За оваа апликација да работи исправно потребна е JavaScript. Ве молиме {linkstart}овозможете JavaScript{linkend} и превчитајте ја страницата.",
@@ -334,16 +314,37 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Истанцата %s моментално е во режим на одржување, што значи дека може да потрае некое време.",
     "This page will refresh itself when the instance is available again." : "Оваа веб страница ќе се рефрешира кога истанцата ќе биде повторно достапна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте го вашиот систем администратор до колку оваа порака продолжи да се појавува или пак се појавува ненадејно.",
-    "Currently open" : "Моментално отворено",
-    "Login with username or email" : "Најава со корисничко име или е-пошта",
-    "Login with username" : "Најава со корисничко име",
+    "No temporary profile picture available, try again" : "Не е достапна привремена профилна слика, пробајте повторно",
+    "No crop data provided" : "Не се доставени податоци за сечење",
+    "No valid crop data provided" : "Нема валидни податоци за сечење",
+    "Crop is not square" : "Сечењето не е квадратно",
+    "Error occurred while checking server setup" : "Се случи грешка при проверката на параметрите на серверот",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За повеќе детали погледнете во {linkstart}документацијата ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Разговори, видео повици, споделување на екранот, онлајн состаноци и веб конференции - на вашиот компјутер и на вашиот мобилен телефон.",
     "You have not added any info yet" : "Сè уште немате додадено никакви информации",
     "{user} has not added any info yet" : "{user} нема додадено никакви информации",
     "Edit Profile" : "Уреди профил",
     "The headline and about sections will show up here" : "Насловот и за секциите ќе се појават овде",
-    "Error loading message template: {error}" : "Грешка при вчитување на образецот за порака: {error}",
+    "Very weak password" : "Многу слаба лозинка",
+    "Weak password" : "Слаба лозинка",
+    "So-so password" : "Така така лозинка",
+    "Good password" : "Добра лозинка",
+    "Strong password" : "Јака лозинка",
+    "Non-existing tag #{tag}" : "Непостоечка ознака #{tag}",
+    "Restricted" : "Ограничена",
+    "Invisible" : "Невидливо",
+    "Delete" : "Избриши",
+    "Rename" : "Преименувај",
+    "Collaborative tags" : "Колаборативна ознака",
+    "No tags found" : "Не се пронајдени ознаки",
     "Profile not found" : "Профилот не е пронајден",
-    "The profile does not exist." : "Профилот на постои"
+    "The profile does not exist." : "Профилот на постои",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашиот директориум со податоци и датотеки се веројатно достапни преку интенернт поради што .htaccess датотеката не функционира.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информации како правилно да го конфигурирате вашиот сервер, ве молиме погледнете ја <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацијата</a>.",
+    "Show password" : "Прикажи лозинка",
+    "Toggle password visibility" : "Вклучи видливост на лозинки",
+    "Configure the database" : "Конфигурирај ја базата",
+    "Only %s is available." : "Само %s е достапно.",
+    "Direct link copied to clipboard" : "Линкот е копиран во клипборд"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
