@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de arquivo desconhecido",
     "An error occurred. Please contact your admin." : "Ocorreu um erro. Entre em contato com o administrador.",
     "Invalid image" : "Imagem inválida",
-    "No temporary profile picture available, try again" : "Nenhuma imagem temporária disponível no perfil, tente novamente",
-    "No crop data provided" : "Nenhum dado recortado fornecido",
-    "No valid crop data provided" : "Nenhum dado recortado válido",
-    "Crop is not square" : "Recorte não é quadrado",
     "State token does not match" : "O estado do token não coincide",
     "Invalid app password" : "Senha do aplicativo inválida",
     "Could not complete login" : "Não foi possível concluir o login",
     "State token missing" : "Falta o token de estado",
     "Your login token is invalid or has expired" : "Seu token de login é inválido ou expirou",
+    "Please use original client" : "Por favor, use o cliente original",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versão da comunidade do Nextcloud não é compatível e as notificações por push são limitadas.",
     "Login" : "Login",
     "Unsupported email length (>255)" : "Comprimento de e-mail não suportado (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Tarefa não encontrada",
     "Internal error" : "Erro interno",
     "Not found" : "Não encontrado",
+    "Node is locked" : "O nó está bloqueado",
     "Bad request" : "Requisição inválida",
     "Requested task type does not exist" : "O tipo de tarefa solicitado não existe",
     "Necessary language model provider is not available" : "O provedor de modelo de linguagem necessário não está disponível",
@@ -51,6 +49,11 @@ OC.L10N.register(
     "No translation provider available" : "Nenhum provedor de tradução disponível",
     "Could not detect language" : "Não foi possível detectar o idioma",
     "Unable to translate" : "Incapaz de traduzir",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Etapa do reparo:",
+    "Repair info:" : "Informação do reparo:",
+    "Repair warning:" : "Aviso do reparo:",
+    "Repair error:" : "Erro do reparo:",
     "Nextcloud Server" : "Servidor Nextcloud",
     "Some of your link shares have been removed" : "Alguns dos seus compartilhamentos por link foram removidos",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a um bug de segurança, tivemos que remover alguns dos seus compartilhamentos por link. Por favor, veja o link para mais informações.",
@@ -58,11 +61,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Digite sua chave de assinatura no aplicativo de suporte para aumentar o limite de contas. Isso também concede a você todos os benefícios adicionais que o Nextcloud Empresarial oferece e é altamente recomendado para operações em empresas.",
     "Learn more ↗" : "Saiba mais ↗",
     "Preparing update" : "Preparando a atualização",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Etapa do reparo:",
-    "Repair info:" : "Informação do reparo:",
-    "Repair warning:" : "Aviso do reparo:",
-    "Repair error:" : "Erro do reparo:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Por favor, use o atualizador de linha de comando porque a atualização via navegador está desativada em seu config.php.",
     "Turned on maintenance mode" : "Ativar o modo de manutenção",
     "Turned off maintenance mode" : "Desativar o modo de manutenção",
@@ -79,8 +77,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatível)",
     "The following apps have been disabled: %s" : "Os seguintes aplicativos foram desativados: %s",
     "Already up to date" : "Já está atualizado",
-    "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter mais detalhes, consulte a {linkstart}documentação ↗{linkend}.",
+    "Windows Command Script" : "Script de Comando do Windows",
+    "Electronic book document" : "Documento de livro eletrônico",
+    "TrueType Font Collection" : "Coleção de Fontes TrueType",
+    "Web Open Font Format" : "Formato de Fonte Aberta da Web",
+    "GPX geographic data" : "Dados geográficos GPX",
+    "Gzip archive" : "Arquivo gzip",
+    "Adobe Illustrator document" : "Documento do Adobe Illustrator",
+    "Java source code" : "Código-fonte Java",
+    "JavaScript source code" : "Código-fonte JavaScript",
+    "JSON document" : "Documento JSON",
+    "Microsoft Access database" : "Banco de dados do Microsoft Access",
+    "Microsoft OneNote document" : "Documento do Microsoft OneNote",
+    "Microsoft Word document" : "Documento do Microsoft Word",
+    "Unknown" : "Desconhecido",
+    "PDF document" : "Documento PDF",
+    "PostScript document" : "Documento PostScript",
+    "RSS summary" : "Resumo RSS",
+    "Android package" : "Pacote para Android",
+    "KML geographic data" : "Dados geográficos KML",
+    "KML geographic compressed data" : "Dados comprimidos geográficos KML",
+    "Lotus Word Pro document" : "Documento do Lotus Word Pro",
+    "Excel spreadsheet" : "Planilha do Excel",
+    "Excel add-in" : "Suplemento do Excel",
+    "Excel 2007 binary spreadsheet" : "Planilha binária do Excel 2007",
+    "Excel spreadsheet template" : "Modelo de planilha do Excel",
+    "Outlook Message" : "Mensagem do Outlook",
+    "PowerPoint presentation" : "Apresentação do PowerPoint",
+    "PowerPoint add-in" : "Suplemento do PowerPoint",
+    "PowerPoint presentation template" : "Modelo de apresentação do PowerPoint",
+    "Word document" : "Documento do Word",
+    "ODF formula" : "Fórmula ODF",
+    "ODG drawing" : "Desenho ODG",
+    "ODG drawing (Flat XML)" : "Desenho ODG (XML plano)",
+    "ODG template" : "Modelo ODG",
+    "ODP presentation" : "Apresentação ODP",
+    "ODP presentation (Flat XML)" : "Apresentação ODP (XML plano)",
+    "ODP template" : "Modelo ODP",
+    "ODS spreadsheet" : "Planilha ODS",
+    "ODS spreadsheet (Flat XML)" : "Planilha ODS (XML plano)",
+    "ODS template" : "Modelo ODS",
+    "ODT document" : "Documento ODT",
+    "ODT document (Flat XML)" : "Documento ODT (XML plano)",
+    "ODT template" : "Modelo ODT",
+    "PowerPoint 2007 presentation" : "Apresentação do Powerpoint 2007",
+    "PowerPoint 2007 show" : "Show do PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Modelo de apresentação do PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Planilha do Excel 2007",
+    "Excel 2007 spreadsheet template" : "Modelo de planilha do Excel 2007",
+    "Word 2007 document" : "Documento do Word 2007",
+    "Word 2007 document template" : "Modelo de documento do Word 2007",
+    "Microsoft Visio document" : "Documento do Microsoft Visio",
+    "WordPerfect document" : "Documento do WordPerfect",
+    "7-zip archive" : "Arquivo 7-zip",
+    "Blender scene" : "Cena do Blender",
+    "Bzip2 archive" : "Arquivo bzip2",
+    "Debian package" : "Pacote do Debian",
+    "FictionBook document" : "Documento do FictionBook",
+    "Unknown font" : "Fonte desconhecida",
+    "Krita document" : "Documento do Krita",
+    "Mobipocket e-book" : "Livro eletrônico Mobipocket",
+    "Windows Installer package" : "Pacote do Windows Installer",
+    "Perl script" : "Script Perl",
+    "PHP script" : "Script PHP",
+    "Tar archive" : "Arquivo tar",
+    "XML document" : "Documento XML",
+    "YAML document" : "Documento YAML",
+    "Zip archive" : "Arquivo zip",
+    "Zstandard archive" : "Arquivo zstandard",
+    "AAC audio" : "Áudio AAC",
+    "FLAC audio" : "Áudio FLAC",
+    "MPEG-4 audio" : "Áudio MPEG-4",
+    "MP3 audio" : "Áudio MP3",
+    "Ogg audio" : "Áudio ogg",
+    "RIFF/WAVe standard Audio" : "Áudio padrão RIFF/WAVe",
+    "WebM audio" : "Áudio WebM",
+    "MP3 ShoutCast playlist" : "Lista de reprodução do MP3 ShoutCast",
+    "Windows BMP image" : "Imagem BMP do Windows",
+    "Better Portable Graphics image" : "Imagem Better Portable Graphics",
+    "EMF image" : "Imagem EMF",
+    "GIF image" : "Imagem GIF",
+    "HEIC image" : "Imagem HEIC",
+    "HEIF image" : "Imagem HEIF",
+    "JPEG-2000 JP2 image" : "Imagem JPEG-2000 JP2",
+    "JPEG image" : "Imagem JPEG",
+    "PNG image" : "Imagem PNG",
+    "SVG image" : "Imagem SVG",
+    "Truevision Targa image" : "Imagem Truevision Targa",
+    "TIFF image" : "Imagem TIFF",
+    "WebP image" : "Imagem WebP",
+    "Digital raw image" : "Imagem digital bruta",
+    "Windows Icon" : "Ícone do Windows",
+    "Email message" : "Mensagem de e-mail",
+    "VCS/ICS calendar" : "Calendário VCS/ICS",
+    "CSS stylesheet" : "Folha de estilo CSS",
+    "CSV document" : "Documento CSV",
+    "HTML document" : "Documento HTML",
+    "Markdown document" : "Documento Markdown",
+    "Org-mode file" : "Arquivo org-mode",
+    "Plain text document" : "Documento de texto simples",
+    "Rich Text document" : "Documento Rich Text",
+    "Electronic business card" : "Cartão de visita eletrônico",
+    "C++ source code" : "Código-fonte C++",
+    "LDIF address book" : "Catálogo de endereços LDIF",
+    "NFO document" : "Documento NFO",
+    "PHP source" : "Código-fonte PHP",
+    "Python script" : "Script Python",
+    "ReStructuredText document" : "Documento ReStructuredText",
+    "3GPP multimedia file" : "Arquivo multimídia 3GPP",
+    "MPEG video" : "Vídeo MPEG",
+    "DV video" : "Vídeo DV",
+    "MPEG-2 transport stream" : "Fluxo de transporte MPEG-2",
+    "MPEG-4 video" : "Vídeo MPEG-4",
+    "Ogg video" : "Vídeo ogg",
+    "QuickTime video" : "Vídeo QuickTime",
+    "WebM video" : "Vídeo WebM",
+    "Flash video" : "Vídeo Flash",
+    "Matroska video" : "Vídeo Matroska",
+    "Windows Media video" : "Vídeo Windows Media",
+    "AVI video" : "Vídeo AVI",
     "unknown text" : "texto desconhecido",
     "Hello world!" : "Olá mundo!",
     "sunny" : "ensolarado",
@@ -88,7 +203,7 @@ OC.L10N.register(
     "Hello {name}" : "Olá {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes são os resultados de sua pesquisa<script>alert(1)</script></strong>",
     "new" : "novo",
-    "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n arquivos","baixar %n arquivos"],
+    "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n de arquivos","baixar %n arquivos"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento. Em alguns ambientes, se sair desta página o processo poderá ser interrompido.",
     "Update to {version}" : "Atualizar para {version}",
     "An error occurred." : "Ocorreu um erro.",
@@ -96,11 +211,11 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização não foi realizada com sucesso. Para mais informações <a href=\"{url}\">verifique nosso post no fórum</a> que abrange esta questão.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi realizada com sucesso. Por favor, informe este problema para  a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
     "Continue to {productName}" : "Continuar para {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n de segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
     "Applications menu" : "Menu de aplicativos",
     "Apps" : "Aplicativos",
     "More apps" : "Mais aplicativos",
-    "_{count} notification_::_{count} notifications_" : ["{count} notificação","{count} notificações","{count} notificações"],
+    "_{count} notification_::_{count} notifications_" : ["{count} notificação","{count} de notificações","{count} notificações"],
     "No" : "Não",
     "Yes" : "Sim",
     "The remote URL must include the user." : "A URL remota deve incluir o usuário.",
@@ -109,7 +224,7 @@ OC.L10N.register(
     "Federated user" : "Usuário federado",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Criar compartilhamento",
-    "Direct link copied to clipboard" : "Link direto copiado para a área de transferência",
+    "Direct link copied" : "Link direto copiado",
     "Please copy the link manually:" : "Copie o link manualmente:",
     "Custom date range" : "Intervalo personalizado",
     "Pick start date" : "Escolha uma data de início",
@@ -126,6 +241,7 @@ OC.L10N.register(
     "Last 30 days" : "Últimos 30 dias",
     "This year" : "Este ano",
     "Last year" : "Último ano",
+    "Between {startDate} and {endDate}" : "Entre {startDate} e {endDate}",
     "Unified search" : "Pesquisa unificada",
     "Search apps, files, tags, messages" : "Pesquise aplicativos, arquivos, etiquetas, mensagens",
     "Places" : "Lugares",
@@ -133,6 +249,7 @@ OC.L10N.register(
     "Search people" : "Pesquise pessoas",
     "People" : "Pessoas",
     "Filter in current view" : "Filtrar na visualização atual",
+    "Search connected services" : "Pesquisar serviços conectados",
     "Results" : "Resultados",
     "Load more results" : "Carregar mais resultados",
     "Search in" : "Pesquisar em",
@@ -196,7 +313,7 @@ OC.L10N.register(
     "Search" : "Pesquisar",
     "No results for {query}" : "Sem resultados para {query}",
     "Press Enter to start searching" : "Pressione Enter para iniciar a pesquisa",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digite {minSearchLength} caractere ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar"],
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digite {minSearchLength} caractere ou mais para pesquisar","Digite {minSearchLength} de caracteres ou mais para pesquisar","Digite {minSearchLength} caracteres ou mais para pesquisar"],
     "An error occurred while searching for {type}" : "Ocorreu um erro ao pesquisar por {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "A pesquisa iniciará assim que você começar a digitar e você pode navegar nos resultados com as teclas de seta",
     "Search for {name} only" : "Pesquisar somente por {name}",
@@ -207,6 +324,11 @@ OC.L10N.register(
     "Login form is disabled." : "O formulário de login está desativado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de login do Nextcloud está desabilitado. Use outra opção de login, se disponível, ou entre em contato com sua administração.",
     "More actions" : "Mais ações",
+    "User menu" : "Menu do usuário",
+    "Your guest name: {user}" : "Seu nome de convidado: {user}",
+    "You are currently not identified." : "No momento, você não está identificado.",
+    "Set public name" : "Definir nome público",
+    "Change public name" : "Mudar nome público",
     "Password is too weak" : "A senha é muito fraca",
     "Password is weak" : "A senha é fraca",
     "Password is average" : "A senha é média",
@@ -257,7 +379,7 @@ OC.L10N.register(
     "Move" : "Mover",
     "OK" : "OK",
     "read-only" : "somente leitura",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de arquivo","{count} arquivo conflita","{count} arquivo conflita"],
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de arquivo","{count} de conflitos de arquivo","{count} conflitos de arquivo"],
     "One file conflict" : "Conflito em um arquivo",
     "New Files" : "Novos arquivos",
     "Already existing files" : "Arquivos já existentes",
@@ -271,7 +393,7 @@ OC.L10N.register(
     "Saving …" : "Salvando...",
     "seconds ago" : "segundos atrás",
     "Connection to server lost" : "Conexão perdida com o servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n segundos","Problema no carregamento da página, recarregando em %n segundos"],
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n de segundos","Problema no carregamento da página, recarregando em %n segundos"],
     "Add to a project" : "Adicionar a um projeto",
     "Show details" : "Mostrar detalhes",
     "Hide details" : "Ocultar detalhes",
@@ -287,23 +409,17 @@ OC.L10N.register(
     "Error fetching contact actions" : "Erro ao obter as ações de contato",
     "Close \"{dialogTitle}\" dialog" : "Fechar a caixa de diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "O comprimento do e-mail é no máximo (255)",
-    "Non-existing tag #{tag}" : "Etiqueta inexistente #{tag}",
-    "Restricted" : "Restrita",
-    "Invisible" : "Invisível",
-    "Delete" : "Excluir",
-    "Rename" : "Renomear",
-    "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "Nenhuma etiqueta encontrada",
     "Clipboard not available, please copy manually" : "A área de transferência não está disponível, por favor, copie manualmente",
     "Personal" : "Pessoal",
     "Accounts" : "Contas",
     "Admin" : "Administração",
     "Help" : "Ajuda",
     "Access forbidden" : "Acesso proibido",
+    "You are not allowed to access this page." : "Você não tem permissão para acessar esta página.",
+    "Back to %s" : "Voltar para %s",
     "Page not found" : "Página não encontrada",
     "The page could not be found on the server or you may not be allowed to view it." : "A página não pôde ser encontrada no servidor ou talvez você não tenha permissão para visualizá-la.",
-    "Back to %s" : "Voltar para %s",
-    "Too many requests" : "Muitas requisições",
+    "Too many requests" : "Pedidos em Excesso",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houve muitas solicitações de sua rede. Tente novamente mais tarde ou entre em contato com o administrador se isso for um erro.",
     "Error" : "Erro",
     "Internal Server Error" : "Erro Interno do Servidor",
@@ -378,21 +494,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
     "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
-    "Currently open" : "Atualmente aberto",
-    "Login with username or email" : "Fazer login com o nome de usuário ou e-mail",
-    "Login with username" : "Fazer login com o nome de usuário",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões online e conferência na web - no seu navegador e com aplicativos móveis.",
+    "No temporary profile picture available, try again" : "Nenhuma imagem temporária disponível no perfil, tente novamente",
+    "No crop data provided" : "Nenhum dado recortado fornecido",
+    "No valid crop data provided" : "Nenhum dado recortado válido",
+    "Crop is not square" : "Recorte não é quadrado",
+    "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter mais detalhes, consulte a {linkstart}documentação ↗{linkend}.",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões on-line e conferência na web - no seu navegador e com aplicativos móveis.",
     "You have not added any info yet" : "Você ainda não adicionou nenhuma informação",
     "{user} has not added any info yet" : "{user} ainda não adicionou nenhuma informação",
     "Error opening the user status modal, try hard refreshing the page" : "Erro ao abrir o modal de status do usuário, tente forçar uma atualização da página sem cache",
     "Edit Profile" : "Editar Perfil ",
     "The headline and about sections will show up here" : "As seções de título e sobre serão exibidas aqui",
-    "Error loading message template: {error}" : "Erro carregando o modelo de mensagem: {error}",
     "Very weak password" : "Senha muito fraca",
     "Weak password" : "Senha fraca",
     "So-so password" : "Senha mais ou menos",
     "Good password" : "Senha boa",
     "Strong password" : "Senha forte",
+    "Non-existing tag #{tag}" : "Etiqueta inexistente #{tag}",
+    "Restricted" : "Restrita",
+    "Invisible" : "Invisível",
+    "Delete" : "Excluir",
+    "Rename" : "Renomear",
+    "Collaborative tags" : "Etiquetas colaborativas",
+    "No tags found" : "Nenhuma etiqueta encontrada",
     "Profile not found" : "Perfil não encontrado",
     "The profile does not exist." : "O perfil não existe. ",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela internet, porque o .htaccess não funciona.",
@@ -404,6 +529,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Alternar visibilidade da senha",
     "Configure the database" : "Configurar o banco de dados",
     "Only %s is available." : "Somente %s está disponível.",
-    "Database account" : "Conta de banco de dados"
+    "Database account" : "Conta de banco de dados",
+    "Direct link copied to clipboard" : "Link direto copiado para a área de transferência"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
