@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Neznámy typ súboru",
     "An error occurred. Please contact your admin." : "Vyskytla sa chyba.\nProsím, kontaktujte svojho správcu.\n\t",
     "Invalid image" : "Chybný obrázok",
-    "No temporary profile picture available, try again" : "Dočasný profilový obrázok nie je k dispozícii, skúste to znovu",
-    "No crop data provided" : "Dáta pre orezanie neboli zadané",
-    "No valid crop data provided" : "Neplatné dáta pre orezanie neboli zadané",
-    "Crop is not square" : "Orezanie nie je štvorcové",
     "State token does not match" : "Príznak stavu nesúhlasí",
     "Invalid app password" : "Neplatné heslo aplikácie",
     "Could not complete login" : "Nie je možné dokončiť prihlásenie",
     "State token missing" : "Chýba stavový token",
     "Your login token is invalid or has expired" : "Váš prihlasovací token je neplatný alebo jeho platnosť skončila",
+    "Please use original client" : "Použite prosím originálneho klienta",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Toto komunitné vydanie Nextcloud nie je podporované a push upozornenia nie sú k dispozícii.",
     "Login" : "Prihlásiť sa",
     "Unsupported email length (>255)" : "Dĺžka emailovej správy nie je podporovaná (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Úloha nebola nájdená",
     "Internal error" : "Interná chyba",
     "Not found" : "Nenájdené",
+    "Node is locked" : "Uzol je uzamknutý",
     "Bad request" : "Neplatná požiadavka",
     "Requested task type does not exist" : "Vyžiadaný typ úlohy neexistuje",
     "Necessary language model provider is not available" : "Potrebný poskytovateľ jazykového modelu nie je dostupný",
@@ -51,6 +49,11 @@ OC.L10N.register(
     "No translation provider available" : "Nie je dostupný žiadny poskytovateľ prekladu",
     "Could not detect language" : "Nepodarilo sa zistiť jazyk",
     "Unable to translate" : "Nie je možné preložiť",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Krok opravy:",
+    "Repair info:" : "Informácie o oprave:",
+    "Repair warning:" : "Varovanie o oprave:",
+    "Repair error:" : "Chyba opravy:",
     "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Niektoré odkazy so sprístupnením boli odstránené.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvôli bezpečnostnej chyba sme museli odstrániť niektoré z vašich odkazov pre zdieľanie. Pre viac informácií nasledujte tento link.",
@@ -58,11 +61,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Zadajte svoj kľúč predplatného v aplikácii podpory, aby ste zvýšili limit pre množstvo účtov. To vám tiež poskytuje všetky ďalšie výhody, ktoré Nextcloud Enterprise ponúka a je vysoko odporúčaný pre prevádzku vo firemnom prostredí.",
     "Learn more ↗" : "Viac informácií ↗",
     "Preparing update" : "Pripravuje sa aktualizácia",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Krok opravy:",
-    "Repair info:" : "Informácie o oprave:",
-    "Repair warning:" : "Varovanie o oprave:",
-    "Repair error:" : "Chyba opravy:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Prosím, použite aktualizáciu z príkazového riadka, pretože aktualizácia cez prehliadač je zakázaná vo vašom config.php.",
     "Turned on maintenance mode" : "Mód údržby je zapnutý",
     "Turned off maintenance mode" : "Mód údržby je vypnutý",
@@ -79,8 +77,81 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekompatibilná)",
     "The following apps have been disabled: %s" : "Nasledujúce aplikácie boli vypnuté: %s",
     "Already up to date" : "Už aktuálne",
-    "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
+    "Electronic book document" : "Dokument elektronickej knihy",
+    "TrueType Font Collection" : "Kolekcia fontov TrueType",
+    "GPX geographic data" : "GPX geografické dáta",
+    "Gzip archive" : "Gzip archív",
+    "Adobe Illustrator document" : "Dokument Adobe Illustrator",
+    "Java source code" : "Zdrojový kód Java",
+    "JavaScript source code" : "Zdrojový kód Javascriptu",
+    "JSON document" : "Dokument JSON",
+    "Microsoft Access database" : "Databáza Microsoft Access",
+    "Microsoft OneNote document" : "Dokument Microsoft OneNote",
+    "Microsoft Word document" : "Dokument Microsoft Word",
+    "Unknown" : "Neznámy",
+    "PDF document" : "PDF dokument",
+    "PostScript document" : "Dokument PostScriptu",
+    "RSS summary" : "Zhrnutie RSS",
+    "Android package" : "Balík pre Android",
+    "KML geographic data" : "KML geografické dáta",
+    "KML geographic compressed data" : "KML komprimované geografické dáta",
+    "Lotus Word Pro document" : "Dokument Lotus Word Pro",
+    "Excel spreadsheet" : "Tabuľka Excelu",
+    "Excel add-in" : "Rozšírenie Excelu",
+    "Excel 2007 binary spreadsheet" : "Binárna tabuľka Excel 2007",
+    "Excel spreadsheet template" : "Šablóna tabuľky Excel",
+    "Outlook Message" : "Správa Outlooku",
+    "PowerPoint presentation" : "PowerPoint prezentácia",
+    "PowerPoint add-in" : "Rozšírenie PowerPointu",
+    "PowerPoint presentation template" : "Šablóna prezentácie PowerPoint",
+    "Word document" : "Dokument Wordu",
+    "ODF formula" : "Vzorec ODF",
+    "ODG drawing" : "Kresba ODG",
+    "ODG drawing (Flat XML)" : "Výkres ODG (Čisté XML)",
+    "ODG template" : "Šablóna ODG",
+    "ODP presentation" : "Prezentácia ODP",
+    "ODP presentation (Flat XML)" : "Prezentácia ODP (Čisté XML)",
+    "ODP template" : "Šablóna ODP",
+    "ODS spreadsheet" : "Tabuľka ODS",
+    "ODS spreadsheet (Flat XML)" : "Tabuľka ODS (Čisté XML)",
+    "ODS template" : "Šablóna ODS",
+    "ODT document" : "Dokument ODT",
+    "ODT document (Flat XML)" : "Dokument ODT (Čisté XML)",
+    "ODT template" : "Šablóna ODT",
+    "PowerPoint 2007 presentation" : "Prezentácia PowerPointu 2007",
+    "PowerPoint 2007 show" : "Prezentácia PowerPointu 2007",
+    "PowerPoint 2007 presentation template" : "Šablóna prezentácie PowerPointu 2007",
+    "Excel 2007 spreadsheet" : "Tabuľka Excelu 2007",
+    "Excel 2007 spreadsheet template" : "Šablóna tabuľky Excelu 2007",
+    "Word 2007 document" : "Dokument Wordu 2007",
+    "Word 2007 document template" : "Šablóna dokumentu Wordu 2007",
+    "Microsoft Visio document" : "Dokument Microsoft Visio",
+    "WordPerfect document" : "Dokument WordPerfectu",
+    "7-zip archive" : "7-zip archív",
+    "Blender scene" : "Scéna Blenderu",
+    "Bzip2 archive" : "Bzip2 archív",
+    "Debian package" : "Balík Debianu",
+    "FictionBook document" : "Dokument FictionBook",
+    "Unknown font" : "Neznáme písmo",
+    "Krita document" : "Dokument Krita",
+    "Mobipocket e-book" : "E-kniha Mobipocket",
+    "Windows Installer package" : "Inštalačný balík Windows",
+    "Perl script" : "Skript Perlu",
+    "PHP script" : "Skript PHP",
+    "Tar archive" : "Archív TAR",
+    "XML document" : "Dokument XML",
+    "YAML document" : "Dokument YAML",
+    "Zip archive" : "Zip archív",
+    "Zstandard archive" : "Zstandartd archív",
+    "AAC audio" : "AAC audio",
+    "FLAC audio" : "FLAC audio",
+    "MPEG-4 audio" : "MPEG-4 audio",
+    "MP3 audio" : "MP3 audio",
+    "Ogg audio" : "Ogg audio",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe standard Audio",
+    "WebM audio" : "WebM audio",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
+    "Windows BMP image" : "Obrázok Windows BMP",
     "unknown text" : "neznámy text",
     "Hello world!" : "Ahoj svet!",
     "sunny" : "slnečno",
@@ -109,7 +180,6 @@ OC.L10N.register(
     "Federated user" : "Združený užívateľ",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Vytvoriť zdieľanie",
-    "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky",
     "Please copy the link manually:" : "Prosím skopírujte odkaz manuálne:",
     "Custom date range" : "Vlastné rozpätie dátumov",
     "Pick start date" : "Vyberte dátum začiatku",
@@ -146,23 +216,23 @@ OC.L10N.register(
     "Account name" : "Názov účtu",
     "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
     "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
-    "Temporary error" : "Dočasná chyba",
-    "Please try again." : "Prosím skúste to znova.",
+    "Session error" : "Chyba relácie",
+    "It appears your session token has expired, please refresh the page and try again." : "Zdá sa, že platnosť vášho tokenu relácie vypršala, obnovte stránku a skúste to znova.",
     "An internal error occurred." : "Došlo k vnútornej chybe.",
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
     "Password" : "Heslo",
     "Log in with a device" : "Prihlásiť sa pomocou zariadenia",
     "Login or email" : "Prihlasovacie meno alebo email",
     "Your account is not setup for passwordless login." : "Váš účet nie je nastavený pre bezheslové overovanie.",
-    "Browser not supported" : "Prehliadač nie je podporovaný",
-    "Passwordless authentication is not supported in your browser." : "Bezheslové overovanie nie je vo vašom prehliadači podporované.",
     "Your connection is not secure" : "Pripojenie nie je bezpečné",
     "Passwordless authentication is only available over a secure connection." : "Bezheslové overovanie je dostupné len pomocou šifrovaného pripojenia.",
+    "Browser not supported" : "Prehliadač nie je podporovaný",
+    "Passwordless authentication is not supported in your browser." : "Bezheslové overovanie nie je vo vašom prehliadači podporované.",
     "Reset password" : "Obnovenie hesla",
+    "Back to login" : "Späť na prihlásenie",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ak tento účet existuje, na jeho e-mailovú adresu bola odoslaná správa pre obnovenie hesla. Ak ju nedostanete, overte si svoju e-mailovú adresu a/alebo Login, skontrolujte svoje spam/junk priečinky alebo požiadajte o pomoc miestneho administrátora.",
     "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
     "Password cannot be changed. Please contact your administrator." : "Heslo nemožno zmeniť. Kontaktujte prosím vášho administrátora.",
-    "Back to login" : "Späť na prihlásenie",
     "New password" : "Nové heslo",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše súbory sú šifrované. Po obnovení hesla nebude možné dostať sa k vašim údajom. Ak neviete, čo robíte, kontaktujte vášho administrátora a až potom pokračujte. Naozaj chcete pokračovať?",
     "I know what I'm doing" : "Viem, čo robím",
@@ -207,6 +277,42 @@ OC.L10N.register(
     "Login form is disabled." : "Prihlasovací formulár je vypnutý.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prihlasovanie do Nextcloud je zakázané. Použite inú možnosť prihlásenia, ak je k dispozícii, alebo kontaktujte svojho administrátora.",
     "More actions" : "Viac akcií",
+    "Password is too weak" : "Heslo je príliš jednoduché",
+    "Password is weak" : "Heslo je jednoduché",
+    "Password is average" : "Heslo je priemerné",
+    "Password is strong" : "Heslo je silné",
+    "Password is very strong" : "Heslo je veľmi silné",
+    "Password is extremely strong" : "Heslo je extrémne silné",
+    "Unknown password strength" : "Neznáma sila hesla",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Váš priečinok s dátami a súbormi je pravdepodobne dostupný z internetu, pretože súbor <code>.htaccess</code> nefunguje.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pre informácie o tom, ako správne nakonfigurovať server, prosím navštívte {linkStart} dokumentáciu {linkEnd}",
+    "Autoconfig file detected" : "Detekovaný súbor automatickej konfigurácie",
+    "The setup form below is pre-filled with the values from the config file." : "Inštalačný formulár nižšie je vopred vyplnený hodnotami z konfiguračného súboru.",
+    "Security warning" : "Bezpečnostné varovanie",
+    "Create administration account" : "Vytvoriť účet administrátora",
+    "Administration account name" : "Názov účtu administrátora",
+    "Administration account password" : "Heslo účtu administrátora",
+    "Storage & database" : "Úložisko & databáza",
+    "Data folder" : "Priečinok dát",
+    "Database configuration" : "Konfigurácia Databáze",
+    "Only {firstAndOnlyDatabase} is available." : "Je dostupná iba {firstAndOnlyDatabase}",
+    "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
+    "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
+    "Performance warning" : "Varovanie o výkone",
+    "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
+    "Database user" : "Používateľ databázy",
+    "Database password" : "Heslo databázy",
+    "Database name" : "Meno databázy",
+    "Database tablespace" : "Tabuľkový priestor databázy",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
+    "Database host" : "Server databázy",
+    "localhost" : "localhost",
+    "Installing …" : "Inštalujem ...",
+    "Install" : "Inštalovať",
+    "Need help?" : "Potrebujete pomoc?",
+    "See the documentation" : "Pozri dokumentáciu",
     "{name} version {version} and above" : "{name} verzie {version} alebo vyššej",
     "This browser is not supported" : "Tento prehliadač nie je podporovaný",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Váš prehliadač nie je podporovaný. Inovujte na novšiu alebo podporovanú verziu.",
@@ -247,31 +353,19 @@ OC.L10N.register(
     "Type to search for existing projects" : "Hľadajte v existujúcich projektoch",
     "New in" : "Nové v",
     "View changelog" : "Zobraziť súhrn zmien",
-    "Very weak password" : "Veľmi slabé heslo",
-    "Weak password" : "Slabé heslo",
-    "So-so password" : "Priemerné heslo",
-    "Good password" : "Dobré heslo",
-    "Strong password" : "Silné heslo",
     "No action available" : "NIe sú dostupné žiadne akcie",
     "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
     "Close \"{dialogTitle}\" dialog" : "Zatvoriť okno \"{dialogTitle}\"",
     "Email length is at max (255)" : "E-mailová správa má maximálnu veľkosť (255)",
-    "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
-    "Restricted" : "Obmedzené",
-    "Invisible" : "Neviditeľný",
-    "Delete" : "Zmazať",
-    "Rename" : "Premenovať",
-    "Collaborative tags" : "Štítky pre spoluprácu",
-    "No tags found" : "Štítky sa nenašli",
     "Clipboard not available, please copy manually" : "Schránka nie je k dispozícii, prosím skopírujte ručne",
     "Personal" : "Osobné",
     "Accounts" : "Účty",
     "Admin" : "Administrácia",
     "Help" : "Pomoc",
     "Access forbidden" : "Prístup odmietnutý",
+    "Back to %s" : "Späť na %s",
     "Page not found" : "Stránka nenájdená",
     "The page could not be found on the server or you may not be allowed to view it." : "Túto stránku sa nepodarilo na serveri nájsť alebo nemáte oprávnenie na jej zobrazenie.",
-    "Back to %s" : "Späť na %s",
     "Too many requests" : "Priveľa požiadavok",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
     "Error" : "Chyba",
@@ -289,34 +383,6 @@ OC.L10N.register(
     "File: %s" : "Súbor: %s",
     "Line: %s" : "Riadok: %s",
     "Trace" : "Trasa",
-    "Security warning" : "Bezpečnostné varovanie",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Vytvoriť účet administrátora</strong>",
-    "New admin account name" : "Názov nového účtu administrátora",
-    "New admin password" : "Nové heslo administrátora",
-    "Show password" : "Zobraziť heslo",
-    "Toggle password visibility" : "Prepnúť viditeľnosť hesla",
-    "Storage & database" : "Úložisko & databáza",
-    "Data folder" : "Priečinok dát",
-    "Configure the database" : "Nastaviť databázu",
-    "Only %s is available." : "Je dostupný len %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
-    "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
-    "Database account" : "Databázový účet",
-    "Database password" : "Heslo databázy",
-    "Database name" : "Meno databázy",
-    "Database tablespace" : "Tabuľkový priestor databázy",
-    "Database host" : "Server databázy",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
-    "Performance warning" : "Varovanie o výkone",
-    "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
-    "Install" : "Inštalovať",
-    "Installing …" : "Inštalujem ...",
-    "Need help?" : "Potrebujete pomoc?",
-    "See the documentation" : "Pozri dokumentáciu",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Vyzerá, že sa snažíte preinštalovať svoj Nextcloud. Avšak v priečinku s konfiguráciou chýba súbor CAN_INSTALL. Ak chcete pokračovať, tak ho vytvorte.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nie je možné odstrániť súbor CAN_INSTALL z priečinka s konfiguráciou. Je potrebné ho odstrániť ručne.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Táto aplikácia vyžaduje JavaScript, aby správne fungovala. Prosím, {linkstart}zapnite si JavaScript{linkend} a obnovte stránku",
@@ -331,7 +397,7 @@ OC.L10N.register(
     "Grant access" : "Povoliť prístup",
     "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
     "Account access" : "Prístup k účtu",
-    "Currently logged in as %1$s (%2$s)." : "Momentálne prihlásený ako %1$s (%2$s).",
+    "Currently logged in as %1$s (%2$s)." : "Momentálne ste prihlásený ako %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
     "Account connected" : "Účet pripojený",
     "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
@@ -375,17 +441,42 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
     "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
-    "Currently open" : "V súčasnosti otvorené",
-    "Login with username or email" : "Prihlásiť sa pomocou užívateľského mena alebo e-mailu",
-    "Login with username" : "Prihlásiť sa s užívateľským menom",
+    "No temporary profile picture available, try again" : "Dočasný profilový obrázok nie je k dispozícii, skúste to znovu",
+    "No crop data provided" : "Dáta pre orezanie neboli zadané",
+    "No valid crop data provided" : "Neplatné dáta pre orezanie neboli zadané",
+    "Crop is not square" : "Orezanie nie je štvorcové",
+    "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Četovanie, videohovory, zdieľanie obrazovky, online stretnutia a webové konferencie - vo vašom prehliadači a pomocou mobilných aplikácií.",
     "You have not added any info yet" : "Zatiaľ ste nepridali žiadne informácie",
     "{user} has not added any info yet" : "{user} zatiaľ nepridal žiadne informácie",
     "Error opening the user status modal, try hard refreshing the page" : "Chyba pri otváraní modálneho okna stavu používateľa, skúste stránku obnoviť",
     "Edit Profile" : "Upraviť rofil",
     "The headline and about sections will show up here" : "Tu sa zobrazí titul a sekcia Informácie",
-    "Error loading message template: {error}" : "Chyba pri nahrávaní šablóny správy: {error}",
+    "Very weak password" : "Veľmi slabé heslo",
+    "Weak password" : "Slabé heslo",
+    "So-so password" : "Priemerné heslo",
+    "Good password" : "Dobré heslo",
+    "Strong password" : "Silné heslo",
+    "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
+    "Restricted" : "Obmedzené",
+    "Invisible" : "Neviditeľný",
+    "Delete" : "Zmazať",
+    "Rename" : "Premenovať",
+    "Collaborative tags" : "Štítky pre spoluprácu",
+    "No tags found" : "Štítky sa nenašli",
     "Profile not found" : "Profil nenájdený",
-    "The profile does not exist." : "Profil neexistuje."
+    "The profile does not exist." : "Profil neexistuje.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Vytvoriť účet administrátora</strong>",
+    "New admin account name" : "Názov nového účtu administrátora",
+    "New admin password" : "Nové heslo administrátora",
+    "Show password" : "Zobraziť heslo",
+    "Toggle password visibility" : "Prepnúť viditeľnosť hesla",
+    "Configure the database" : "Nastaviť databázu",
+    "Only %s is available." : "Je dostupný len %s.",
+    "Database account" : "Databázový účet",
+    "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
