@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Neznana vrsta datoteke",
     "An error occurred. Please contact your admin." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
     "Invalid image" : "Neveljavna slika",
-    "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
-    "No crop data provided" : "Ni podanih podatkov obreza",
-    "No valid crop data provided" : "Podani so neveljavni podatki za obrez slike ",
-    "Crop is not square" : "Obrez ni pravokoten",
     "State token does not match" : "Žeton stanja ni skladen",
     "Invalid app password" : "Neveljavno geslo programa",
     "Could not complete login" : "Prijave ni mogoče dokončati",
@@ -175,8 +171,6 @@ OC.L10N.register(
     "MPEG video" : "Video MPEG",
     "DV video" : "Video DV",
     "MPEG-4 video" : "Video MPEG-4",
-    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Za več podrobnosti preverite {linkstart}dokumentacijo ↗{linkend}.",
     "unknown text" : "neznano besedilo",
     "Hello world!" : "Pozdravljen svet!",
     "sunny" : "sončno",
@@ -205,7 +199,6 @@ OC.L10N.register(
     "Federated user" : "Zvezni uporabnik",
     "user@your-nextcloud.org" : "uporabnik@oblak-nextcloud.org",
     "Create share" : "Ustvari predmet souporabe",
-    "Direct link copied to clipboard" : "Povezava je kopirana v odložišče.",
     "Please copy the link manually:" : "Povezave je treba kopirati ročno.",
     "Custom date range" : "Obseg datuma po meri",
     "Pick start date" : "Izbor začetnega datuma",
@@ -383,13 +376,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
     "Close \"{dialogTitle}\" dialog" : "Zapri pogovorno okno »{dialogTitle}«",
     "Email length is at max (255)" : "Dolžina sporočila je dosegla omejitev (255)",
-    "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
-    "Restricted" : "Omejeno",
-    "Invisible" : "Drugim nevidno",
-    "Delete" : "Izbriši",
-    "Rename" : "Preimenuj",
-    "Collaborative tags" : "Sodelovalne oznake",
-    "No tags found" : "Ni najdenih oznak",
     "Clipboard not available, please copy manually" : "Odložišče ni na voljo, kopirajte ročno",
     "Personal" : "Osebno",
     "Accounts" : "Računi",
@@ -474,6 +460,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v vzdrževalnem načinu, kar onemogoča prijavo.",
     "This page will refresh itself when the instance is available again." : "Stran bo samodejno osvežena, ko bo okolje spet pripravljeno za delo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Če se bo to sporočilo še naprej nepričakovano pojavljalo, stopite v stik s skrbnikom sistema.",
+    "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
+    "No crop data provided" : "Ni podanih podatkov obreza",
+    "No valid crop data provided" : "Podani so neveljavni podatki za obrez slike ",
+    "Crop is not square" : "Obrez ni pravokoten",
+    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Za več podrobnosti preverite {linkstart}dokumentacijo ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Klepet, video klici, souporaba zaslonske slike, spletni sestanki in konference – znotraj brskalnika in z mobilnimi napravami.",
     "You have not added any info yet" : "Ni še vpisanih podrobnosti",
     "{user} has not added any info yet" : "Oseba {user} še ni dodala nobenih podrobnosti.",
@@ -485,6 +477,13 @@ OC.L10N.register(
     "So-so password" : "Slabo geslo",
     "Good password" : "Dobro geslo",
     "Strong password" : "Odlično geslo",
+    "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
+    "Restricted" : "Omejeno",
+    "Invisible" : "Drugim nevidno",
+    "Delete" : "Izbriši",
+    "Rename" : "Preimenuj",
+    "Collaborative tags" : "Sodelovalne oznake",
+    "No tags found" : "Ni najdenih oznak",
     "Profile not found" : "Profila ni mogoče najti",
     "The profile does not exist." : "Profil ne obstaja.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni v omrežju, ker datoteka .htaccess ni ustrezno nastavljena.",
@@ -496,6 +495,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Preklopi vidnost gesla",
     "Configure the database" : "Nastavi podatkovno zbirko",
     "Only %s is available." : "Na voljo je le %s.",
-    "Database account" : "Račun podatkovne zbirke"
+    "Database account" : "Račun podatkovne zbirke",
+    "Direct link copied to clipboard" : "Povezava je kopirana v odložišče."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
