@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
     "An error occurred. Please contact your admin." : "เกิดข้อผิดพลาด กรุณาติดต่อผู้ดูแลระบบของคุณ",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
-    "No temporary profile picture available, try again" : "ไม่มีรูปภาพโปรไฟล์ชั่วคราว กรุณาลองใหม่อีกครั้ง",
-    "No crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัด",
-    "No valid crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัดที่ถูกต้อง",
-    "Crop is not square" : "การครอบตัดไม่เป็นสี่เหลี่ยม",
     "State token does not match" : "โทเค็นสถานะไม่ตรงกัน",
     "Invalid app password" : "รหัสผ่านแอปไม่ถูกต้อง",
     "Could not complete login" : "ไม่สามารถดำเนินการเข้าสู่ระบบ",
@@ -48,17 +44,17 @@ OC.L10N.register(
     "No translation provider available" : "ไม่มีผู้ให้บริการแปลที่พร้อมใช้งาน",
     "Could not detect language" : "ไม่สามารถตรวจจับภาษา",
     "Unable to translate" : "ไม่สามารถแปล",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "ขั้นตอนการซ่อมแซม:",
+    "Repair info:" : "ข้อมูลการซ่อมแซม:",
+    "Repair warning:" : "คำเตือนการซ่อมแซม:",
+    "Repair error:" : "ข้อผิดพลาดการซ่อมแซม:",
     "Nextcloud Server" : "เซิร์ฟเวอร์ Nextcloud",
     "Some of your link shares have been removed" : "ลิงก์แชร์บางลิงก์ของคุณถูกลบออก",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "เนื่องจากข้อบกพร่องความปลอดภัย เราจำเป็นต้องลบลิงก์แชร์บางลิงก์ของคุณออก โปรดดูที่ลิงก์สำหรับข้อมูลเพิ่มเติม",
     "The account limit of this instance is reached." : "ถึงขีดจำกัดจำนวนบัญชีของเซิร์ฟเวอร์นี้แล้ว",
     "Learn more ↗" : "เรียนรู้เพิ่มเติม ↗",
     "Preparing update" : "กำลังเตรียมอัปเดต",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "ขั้นตอนการซ่อมแซม:",
-    "Repair info:" : "ข้อมูลการซ่อมแซม:",
-    "Repair warning:" : "คำเตือนการซ่อมแซม:",
-    "Repair error:" : "ข้อผิดพลาดการซ่อมแซม:",
     "Turned on maintenance mode" : "เปิดโหมดการบำรุงรักษาแล้ว",
     "Turned off maintenance mode" : "ปิดโหมดการบำรุงรักษาแล้ว",
     "Maintenance mode is kept active" : "โหมดการบำรุงรักษาถูกเปิดไว้",
@@ -74,8 +70,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (เข้ากันไม่ได้)",
     "The following apps have been disabled: %s" : "แอปต่อไปนี้ถูกปิดการใช้งาน: %s",
     "Already up to date" : "ล่าสุดแล้ว",
-    "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะตรวจสอบการติดตั้งเซิร์ฟเวอร์",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "สำหรับข้อมูลเพิ่มเติม โปรดดู{linkstart}เอกสารประกอบ ↗{linkend}",
+    "Unknown" : "ไม่ทราบ",
     "unknown text" : "ข้อความที่ไม่รู้จัก",
     "Hello world!" : "สวัสดีทุกคน!",
     "sunny" : "แดดมาก",
@@ -126,8 +121,6 @@ OC.L10N.register(
     "Account name" : "ชื่อบัญชี",
     "Server side authentication failed!" : "การรับรองความถูกต้องฝั่งเซิร์ฟเวอร์ล้มเหลว!",
     "Please contact your administrator." : "กรุณาติดต่อผู้ดูแลระบบ",
-    "Temporary error" : "ข้อผิดพลาดชั่วคราว",
-    "Please try again." : "กรุณาลองอีกครั้ง",
     "An internal error occurred." : "เกิดข้อผิดพลาดภายใน",
     "Please try again or contact your administrator." : "กรุณาลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
     "Password" : "รหัสผ่าน",
@@ -241,21 +234,14 @@ OC.L10N.register(
     "No action available" : "ไม่มีการกระทำที่ใช้ได้",
     "Error fetching contact actions" : "เกิดข้อผิดพลาดในการดึงการกระทำรายชื่อ",
     "Close \"{dialogTitle}\" dialog" : "ปิดกล่องโต้ตอบ \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "แท็ก #{tag} ไม่มีอยู่",
-    "Restricted" : "ถูกจำกัด",
-    "Invisible" : "มองไม่เห็น",
-    "Delete" : "ลบ",
-    "Rename" : "เปลี่ยนชื่อ",
-    "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
-    "No tags found" : "ไม่พบแท็ก",
     "Personal" : "ส่วนตัว",
     "Accounts" : "บัญชี",
     "Admin" : "ผู้ดูแลระบบ",
     "Help" : "ช่วยเหลือ",
     "Access forbidden" : "ไม่ได้รับอนุญาตให้เข้าถึง",
+    "Back to %s" : "กลับสู่ %s",
     "Page not found" : "ไม่พบหน้า",
     "The page could not be found on the server or you may not be allowed to view it." : "ไม่พบหน้านี้บนเซิร์ฟเวอร์ หรือคุณอาจไม่ได้รับอนุญาตให้ดูหน้านี้",
-    "Back to %s" : "กลับสู่ %s",
     "Too many requests" : "มีคำขอมากเกินไป",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "มีการส่งคำขอจากเครือข่ายของคุณมากเกินไป กรุณาลองอีกครั้งในภายหลัง หรือติดต่อผู้ดูแลระบบหากเป็นข้อผิดพลาด",
     "Error" : "ข้อผิดพลาด",
@@ -329,16 +315,27 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "เซิร์ฟเวอร์ %s นี้อยู่ในโหมดการบำรุงรักษา ซึ่งอาจใช้เวลาสักครู่",
     "This page will refresh itself when the instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อเซิร์ฟเวอร์สามารถใช้ได้อีกครั้ง",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ติดต่อผู้ดูแลระบบของคุณหากข้อความนี้ยังคงอยู่หรือปรากฏโดยไม่คาดคิด",
-    "Currently open" : "เปิดอยู่ในขณะนี้",
+    "No temporary profile picture available, try again" : "ไม่มีรูปภาพโปรไฟล์ชั่วคราว กรุณาลองใหม่อีกครั้ง",
+    "No crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัด",
+    "No valid crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัดที่ถูกต้อง",
+    "Crop is not square" : "การครอบตัดไม่เป็นสี่เหลี่ยม",
+    "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะตรวจสอบการติดตั้งเซิร์ฟเวอร์",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "สำหรับข้อมูลเพิ่มเติม โปรดดู{linkstart}เอกสารประกอบ ↗{linkend}",
     "You have not added any info yet" : "คุณยังไม่ได้เพิ่มข้อมูลใด ๆ",
     "{user} has not added any info yet" : "{user} ยังไม่ได้เพิ่มข้อมูลใด ๆ",
     "Edit Profile" : "แก้ไขโปรไฟล์",
-    "Error loading message template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดเทมเพลตข้อความ: {error} ",
     "Very weak password" : "รหัสผ่านระดับต่ำมาก",
     "Weak password" : "รหัสผ่านระดับต่ำ",
     "So-so password" : "รหัสผ่านระดับปกติ",
     "Good password" : "รหัสผ่านระดับดี",
     "Strong password" : "รหัสผ่านระดับดีมาก",
+    "Non-existing tag #{tag}" : "แท็ก #{tag} ไม่มีอยู่",
+    "Restricted" : "ถูกจำกัด",
+    "Invisible" : "มองไม่เห็น",
+    "Delete" : "ลบ",
+    "Rename" : "เปลี่ยนชื่อ",
+    "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
+    "No tags found" : "ไม่พบแท็ก",
     "Profile not found" : "ไม่พบโปรไฟล์",
     "The profile does not exist." : "โปรไฟล์นี้ไม่มีอยู่",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ไดเรกทอรี data และไฟล์ของคุณอาจเข้าถึงได้จากอินเทอร์เน็ต เพราะไฟล์ .htaccess ไม่ทำงาน",
