@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "نامەلۇم ھۆججەت شەكلى",
     "An error occurred. Please contact your admin." : "خاتالىق كۆرۈلدى. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
     "Invalid image" : "ئىناۋەتسىز رەسىم",
-    "No temporary profile picture available, try again" : "ۋاقىتلىق ئارخىپ رەسىمى يوق ، قايتا سىناڭ",
-    "No crop data provided" : "زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
-    "No valid crop data provided" : "ئۈنۈملۈك زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
-    "Crop is not square" : "زىرائەت چاسا ئەمەس",
     "State token does not match" : "دۆلەت بەلگىسى ماس كەلمەيدۇ",
     "Invalid app password" : "ئىناۋەتلىك ئەپ مەخپىي نومۇرى",
     "Could not complete login" : "كىرىشنى تاماملىيالمىدى",
@@ -51,6 +47,11 @@ OC.L10N.register(
     "No translation provider available" : "تەرجىمە تەمىنلىگۈچى يوق",
     "Could not detect language" : "تىلنى بايقىيالمىدى",
     "Unable to translate" : "تەرجىمە قىلالمىدى",
+    "[%d / %d]: %s" : "[% d /% d]:% s",
+    "Repair step:" : "رېمونت قىلىش باسقۇچى:",
+    "Repair info:" : "رېمونت ئۇچۇرى:",
+    "Repair warning:" : "رېمونت ئاگاھلاندۇرۇشى:",
+    "Repair error:" : "رېمونت خاتالىقى:",
     "Nextcloud Server" : "Nextcloud مۇلازىمىتىرى",
     "Some of your link shares have been removed" : "بەزى ئۇلىنىشلىرىڭىز ئۆچۈرۈلدى",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "بىخەتەرلىك خاتالىقى سەۋەبىدىن بەزى ئۇلىنىشلىرىڭىزنى ئۆچۈرۈۋەتتۇق. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن ئۇلىنىشنى كۆرۈڭ.",
@@ -58,11 +59,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "ھېسابات چەكلىمىسىنى ئاشۇرۇش ئۈچۈن مۇشتەرىلىك ئاچقۇچىڭىزنى قوللاش دېتالىغا كىرگۈزۈڭ. بۇ سىزگە Nextcloud كارخانا تەمىنلىگەن بارلىق قوشۇمچە پايدىلارنى بېرىدۇ ھەمدە شىركەتلەردە مەشغۇلات قىلىشقا تەۋسىيە قىلىنىدۇ.",
     "Learn more ↗" : "تەپسىلاتى ↗",
     "Preparing update" : "يېڭىلاش تەييارلىقى",
-    "[%d / %d]: %s" : "[% d /% d]:% s",
-    "Repair step:" : "رېمونت قىلىش باسقۇچى:",
-    "Repair info:" : "رېمونت ئۇچۇرى:",
-    "Repair warning:" : "رېمونت ئاگاھلاندۇرۇشى:",
-    "Repair error:" : "رېمونت خاتالىقى:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ ، چۈنكى config.php دا توركۆرگۈ ئارقىلىق يېڭىلاش چەكلەنگەن.",
     "Turned on maintenance mode" : "ئاسراش ھالىتىنى ئاچتى",
     "Turned off maintenance mode" : "ئاسراش ھالىتىنى ئېتىۋەتتى",
@@ -79,8 +75,7 @@ OC.L10N.register(
     "%s (incompatible)" : "% s (ماس كەلمەيدۇ)",
     "The following apps have been disabled: %s" : "تۆۋەندىكى ئەپلەر چەكلەنگەن:% s",
     "Already up to date" : "ئاللىبۇرۇن يېڭىلاندى",
-    "Error occurred while checking server setup" : "مۇلازىمېتىرنىڭ تەڭشىكىنى تەكشۈرگەندە خاتالىق كۆرۈلدى",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "تېخىمۇ كۆپ تەپسىلاتلارنى {linkstart} ھۆججەت ↗ {linkend} see دىن كۆرۈڭ.",
+    "Unknown" : "نامەلۇم",
     "unknown text" : "نامەلۇم تېكىست",
     "Hello world!" : "ياخشىمۇسىز دۇنيا!",
     "sunny" : "ئاپتاپپەرەس",
@@ -106,7 +101,6 @@ OC.L10N.register(
     "Federated user" : "فېدېراتسىيە ئىشلەتكۈچى",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "ئورتاقلىشىش",
-    "Direct link copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن بىۋاسىتە ئۇلىنىش",
     "Please copy the link manually:" : "ئۇلىنىشنى قولدا كۆچۈرۈڭ:",
     "Custom date range" : "ئىختىيارى چېسلا دائىرىسى",
     "Pick start date" : "باشلىنىش ۋاقتىنى تاللاڭ",
@@ -261,21 +255,14 @@ OC.L10N.register(
     "Error fetching contact actions" : "ئالاقىلىشىش ھەرىكىتىنى ئېلىپ بېرىشتا خاتالىق",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" سۆزلىشىش رامكىسىنى تاقاڭ",
     "Email length is at max (255)" : "ئېلېكترونلۇق خەتنىڭ ئۇزۇنلۇقى ئەڭ يۇقىرى بولغاندا (255)",
-    "Non-existing tag #{tag}" : "مەۋجۇت بولمىغان بەلگە # {tag}",
-    "Restricted" : "چەكلەنگەن",
-    "Invisible" : "كۆرۈنمەيدۇ",
-    "Delete" : "ئۆچۈر",
-    "Rename" : "ئات ئۆزگەرت",
-    "Collaborative tags" : "ھەمكارلىق بەلگىسى",
-    "No tags found" : "خەتكۈچ تېپىلمىدى",
     "Personal" : "شەخسىي",
     "Accounts" : "ھېسابات",
     "Admin" : "باشقۇرغۇچى",
     "Help" : "ياردەم",
     "Access forbidden" : "زىيارەت قىلىش چەكلەنگەن",
+    "Back to %s" : "% S گە قايتىش",
     "Page not found" : "بەت تېپىلمىدى",
     "The page could not be found on the server or you may not be allowed to view it." : "بۇ بەتنى مۇلازىمېتىردىن تاپقىلى بولمايدۇ ياكى ئۇنى كۆرۈشكە رۇخسەت قىلىنماسلىقىڭىز مۇمكىن.",
-    "Back to %s" : "% S گە قايتىش",
     "Too many requests" : "بەك كۆپ تەلەپ",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "تورىڭىزدىن بەك كۆپ تەلەپلەر بار ئىدى. كېيىن قايتا سىناڭ ياكى باشقۇرغۇچى بىلەن ئالاقىلىشىڭ.",
     "Error" : "خاتالىق",
@@ -351,21 +338,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "بۇ% s مىسال ھازىر ئاسراش ھالىتىدە بولۇپ ، بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
     "This page will refresh itself when the instance is available again." : "مىسال قايتا بولغاندا بۇ بەت ئۆزىنى يېڭىلايدۇ.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ئەگەر بۇ ئۇچۇر داۋاملاشسا ياكى ئويلىمىغان يەردىن سىستېما باشقۇرغۇچى بىلەن ئالاقىلىشىڭ.",
-    "Currently open" : "نۆۋەتتە ئېچىلدى",
-    "Login with username or email" : "ئىشلەتكۈچى ئىسمى ياكى ئېلېكترونلۇق خەت بىلەن كىرىڭ",
-    "Login with username" : "ئىشلەتكۈچى ئىسمى بىلەن كىرىڭ",
+    "No temporary profile picture available, try again" : "ۋاقىتلىق ئارخىپ رەسىمى يوق ، قايتا سىناڭ",
+    "No crop data provided" : "زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
+    "No valid crop data provided" : "ئۈنۈملۈك زىرائەت سانلىق مەلۇماتلىرى تەمىنلەنمىدى",
+    "Crop is not square" : "زىرائەت چاسا ئەمەس",
+    "Error occurred while checking server setup" : "مۇلازىمېتىرنىڭ تەڭشىكىنى تەكشۈرگەندە خاتالىق كۆرۈلدى",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "تېخىمۇ كۆپ تەپسىلاتلارنى {linkstart} ھۆججەت ↗ {linkend} see دىن كۆرۈڭ.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "تور كۆرگۈڭىزدە ۋە كۆچمە ئەپلەر بىلەن پاراڭلىشىش ، سىنلىق سۆزلىشىش ، ئېكراندىن ئورتاقلىشىش ، توردىكى ئۇچرىشىش ۋە تور يىغىنى.",
     "You have not added any info yet" : "سىز تېخى ھېچقانداق ئۇچۇر قوشمىدىڭىز",
     "{user} has not added any info yet" : "{user} تېخى ھېچقانداق ئۇچۇر قوشمىدى",
     "Error opening the user status modal, try hard refreshing the page" : "ئىشلەتكۈچى ھالىتى ھالىتىنى ئېچىشتا خاتالىق ، بەتنى يېڭىلاشنى سىناپ بېقىڭ",
     "Edit Profile" : "ئارخىپنى تەھرىرلەش",
     "The headline and about sections will show up here" : "ماۋزۇ ۋە بۆلەكلەر بۇ يەردە كۆرسىتىلىدۇ",
-    "Error loading message template: {error}" : "ئۇچۇر قېلىپىنى يۈكلەشتە خاتالىق: {error}",
     "Very weak password" : "پارول بەك ئاجىز",
     "Weak password" : "پارول ئاجىز",
     "So-so password" : "شۇڭا مەخپىي نومۇر",
     "Good password" : "ياخشى پارول",
     "Strong password" : "كۈچلۈك پارول",
+    "Non-existing tag #{tag}" : "مەۋجۇت بولمىغان بەلگە # {tag}",
+    "Restricted" : "چەكلەنگەن",
+    "Invisible" : "كۆرۈنمەيدۇ",
+    "Delete" : "ئۆچۈر",
+    "Rename" : "ئات ئۆزگەرت",
+    "Collaborative tags" : "ھەمكارلىق بەلگىسى",
+    "No tags found" : "خەتكۈچ تېپىلمىدى",
     "Profile not found" : "ئارخىپ تېپىلمىدى",
     "The profile does not exist." : "ئارخىپ مەۋجۇت ئەمەس.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".Htaccess ھۆججىتى ئىشلىمىگەچكە ، سانلىق مەلۇمات مۇندەرىجىسىڭىز ۋە ھۆججەتلىرىڭىزنى توردىن زىيارەت قىلىشىڭىز مۇمكىن.",
@@ -374,6 +370,7 @@ OC.L10N.register(
     "Toggle password visibility" : "پارولنىڭ كۆرۈنۈشچانلىقىنى توغرىلاڭ",
     "Configure the database" : "سانداننى سەپلەڭ",
     "Only %s is available." : "پەقەت% s نىلا ئىشلەتكىلى بولىدۇ.",
-    "Database account" : "ساندان ھېساباتى"
+    "Database account" : "ساندان ھېساباتى",
+    "Direct link copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن بىۋاسىتە ئۇلىنىش"
 },
 "nplurals=2; plural=(n != 1);");
