@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "檔案類型不詳",
     "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
     "Invalid image" : "圖像無效",
-    "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
-    "No crop data provided" : "未提供剪裁設定",
-    "No valid crop data provided" : "未提供有效的剪裁設定",
-    "Crop is not square" : "剪裁設定不是正方形",
     "State token does not match" : "狀態權杖不相符",
     "Invalid app password" : "無效的應用程式密碼",
     "Could not complete login" : "無法完成登錄",
     "State token missing" : "找不到狀態權杖",
     "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
+    "Please use original client" : "請使用原先的客戶端",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "這個社群版的 Nextcloud 是不受支援的，且推送通知功能有限。",
     "Login" : "登入",
     "Unsupported email length (>255)" : "不受支援的電郵地址長度（>255）",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "找不到任務",
     "Internal error" : "內部錯誤",
     "Not found" : "找不到",
+    "Node is locked" : "節點已上鎖",
     "Bad request" : "請求無效",
     "Requested task type does not exist" : "請求的任務類型不存在",
     "Necessary language model provider is not available" : "沒有可用的語言模型提供者",
@@ -51,6 +49,11 @@ OC.L10N.register(
     "No translation provider available" : "沒有可用翻譯提供者",
     "Could not detect language" : "無法檢測語言",
     "Unable to translate" : "無法翻譯",
+    "[%d / %d]: %s" : "[%d / %d]：%s",
+    "Repair step:" : "修復步驟：",
+    "Repair info:" : "修復資訊：",
+    "Repair warning:" : "修復警告：",
+    "Repair error:" : "修復錯誤：",
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
@@ -58,11 +61,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加帳戶限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
     "Learn more ↗" : "了解更多",
     "Preparing update" : "正在準備更新",
-    "[%d / %d]: %s" : "[%d / %d]：%s",
-    "Repair step:" : "修復步驟：",
-    "Repair info:" : "修復資訊：",
-    "Repair warning:" : "修復警告：",
-    "Repair error:" : "修復錯誤：",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "由於更新功能已在 config.php 中設定停用，請使用命令列（command line）更新系統。",
     "Turned on maintenance mode" : "已啟用維護模式",
     "Turned off maintenance mode" : "停用維護模式",
@@ -79,8 +77,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s （不相容）",
     "The following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
     "Already up to date" : "此版本為最新版本",
-    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkend}。",
+    "Windows Command Script" : "Windows 命令腳本",
+    "Electronic book document" : "電子書文件",
+    "TrueType Font Collection" : "TrueType 字體集",
+    "Web Open Font Format" : "網絡開放字體格式",
+    "GPX geographic data" : "GPX 地理數據",
+    "Gzip archive" : "Gzip 封存檔",
+    "Adobe Illustrator document" : "Adobe Illustrator 文件",
+    "Java source code" : "Java 源碼",
+    "JavaScript source code" : "JavaScript 源碼",
+    "JSON document" : "JSON 文件",
+    "Microsoft Access database" : "Microsoft Access 數據庫",
+    "Microsoft OneNote document" : "Microsoft OneNote 文件",
+    "Microsoft Word document" : "Microsoft Word 文件",
+    "Unknown" : "不詳",
+    "PDF document" : "PDF 文件",
+    "PostScript document" : "PostScript 文件",
+    "RSS summary" : "RSS 摘要",
+    "Android package" : "Android 軟體包",
+    "KML geographic data" : "KML 地理數據",
+    "KML geographic compressed data" : "KML 壓縮地理數據",
+    "Lotus Word Pro document" : "Lotus Word Pro 文件",
+    "Excel spreadsheet" : "Excel 試算表",
+    "Excel add-in" : "Excel 附加元件",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 二進制試算表",
+    "Excel spreadsheet template" : "Excel 試算表模板",
+    "Outlook Message" : "Outlook 郵件",
+    "PowerPoint presentation" : "PowerPoint 演示文稿",
+    "PowerPoint add-in" : "PowerPoint 附加元件",
+    "PowerPoint presentation template" : "PowerPoint 演示文稿模板",
+    "Word document" : "Word 文件",
+    "ODF formula" : "ODF 公式",
+    "ODG drawing" : "ODG 繪圖",
+    "ODG drawing (Flat XML)" : "ODG 繪圖（扁平 XML）",
+    "ODG template" : "ODG 模板",
+    "ODP presentation" : "ODP 演示文稿",
+    "ODP presentation (Flat XML)" : "ODP 演示文稿（扁平 XML）",
+    "ODP template" : "ODP 模板",
+    "ODS spreadsheet" : "ODS 試算表",
+    "ODS spreadsheet (Flat XML)" : "ODS 試算表（扁平 XML）",
+    "ODS template" : "ODS 模板",
+    "ODT document" : "ODT 文件",
+    "ODT document (Flat XML)" : "ODT 文件（扁平 XML）",
+    "ODT template" : "ODT 模板",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 演示文稿",
+    "PowerPoint 2007 show" : "PowerPoint 2007 放映",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 演示文稿模板",
+    "Excel 2007 spreadsheet" : "Excel 2007 試算表",
+    "Excel 2007 spreadsheet template" : "Excel 2007 試算表模板",
+    "Word 2007 document" : "Word 2007 文件",
+    "Word 2007 document template" : "Word 2007 文件模板",
+    "Microsoft Visio document" : "Microsoft Visio 文件",
+    "WordPerfect document" : "WordPerfect 文件",
+    "7-zip archive" : "7-zip 壓縮檔",
+    "Blender scene" : "Blender 場景",
+    "Bzip2 archive" : "Bzip2 壓縮檔",
+    "Debian package" : "Debian 包",
+    "FictionBook document" : "FictionBook 文件",
+    "Unknown font" : "未知字體",
+    "Krita document" : "Krita 文件",
+    "Mobipocket e-book" : "Mobipocket 電子書",
+    "Windows Installer package" : "Windows 安裝包",
+    "Perl script" : "Perl 腳本",
+    "PHP script" : "PHP 腳本",
+    "Tar archive" : "Tar 壓縮檔",
+    "XML document" : "XML 文件",
+    "YAML document" : "YAML 文件",
+    "Zip archive" : "Zip 封存檔",
+    "Zstandard archive" : "Zstandard 封存檔",
+    "AAC audio" : "AAC 音頻",
+    "FLAC audio" : "FLAC 音頻",
+    "MPEG-4 audio" : "MPEG-4 音頻",
+    "MP3 audio" : "MP3 音頻",
+    "Ogg audio" : "Ogg 音頻",
+    "RIFF/WAVe standard Audio" : "RIFF/WAV 標準音頻",
+    "WebM audio" : "WebM 音頻",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast 播放列表",
+    "Windows BMP image" : "Windows BMP 圖像",
+    "Better Portable Graphics image" : "Better Portable Graphics 圖像",
+    "EMF image" : "EMF 圖像",
+    "GIF image" : "GIF 圖像",
+    "HEIC image" : "HEIC 圖像",
+    "HEIF image" : "HEIF 圖像",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 圖像",
+    "JPEG image" : "JPEG 圖像",
+    "PNG image" : "PNG 圖像",
+    "SVG image" : "SVG 圖像",
+    "Truevision Targa image" : "Truevision Targa 圖像",
+    "TIFF image" : "TIFF 圖像",
+    "WebP image" : "WebP 圖像",
+    "Digital raw image" : "數碼原始圖像",
+    "Windows Icon" : "Windows 圖標",
+    "Email message" : "電子郵件消息",
+    "VCS/ICS calendar" : "VCS/ICS 日曆",
+    "CSS stylesheet" : "CSS 樣式表",
+    "CSV document" : "CSV 文件",
+    "HTML document" : "HTML 文件",
+    "Markdown document" : "Markdown 文件",
+    "Org-mode file" : "Org-mode 文件",
+    "Plain text document" : "純文本文件",
+    "Rich Text document" : "富文本文件",
+    "Electronic business card" : "電子名片",
+    "C++ source code" : "C++ 源碼",
+    "LDIF address book" : "LDIF 通訊錄",
+    "NFO document" : "NFO 文件",
+    "PHP source" : "PHP 源碼",
+    "Python script" : "Python 腳本",
+    "ReStructuredText document" : "ReStructuredText 文件",
+    "3GPP multimedia file" : "3GPP 多媒體文件",
+    "MPEG video" : "MPEG 視頻",
+    "DV video" : "DV 視頻",
+    "MPEG-2 transport stream" : "MPEG-2 傳輸流",
+    "MPEG-4 video" : "MPEG-4 視頻",
+    "Ogg video" : "Ogg 視頻",
+    "QuickTime video" : "QuickTime 視頻",
+    "WebM video" : "WebM 視頻",
+    "Flash video" : "Flash 視頻",
+    "Matroska video" : "Matroska 視頻",
+    "Windows Media video" : "Windows Media 視頻",
+    "AVI video" : "AVI 視頻",
     "unknown text" : "文字不詳",
     "Hello world!" : "哈囉，世界！",
     "sunny" : "晴朗的",
@@ -109,7 +224,7 @@ OC.L10N.register(
     "Federated user" : "聯盟用戶",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "創建分享",
-    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Direct link copied" : "已複製直接連結",
     "Please copy the link manually:" : "請手動複製連結：",
     "Custom date range" : "自訂日期範圍",
     "Pick start date" : "挑選開始日期",
@@ -126,6 +241,7 @@ OC.L10N.register(
     "Last 30 days" : "過去30日",
     "This year" : "今年",
     "Last year" : "去年",
+    "Between {startDate} and {endDate}" : "{startDate} 到 {endDate} 之間",
     "Unified search" : "統一搜尋",
     "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
     "Places" : "地點",
@@ -133,6 +249,7 @@ OC.L10N.register(
     "Search people" : "搜尋人仕",
     "People" : "人物",
     "Filter in current view" : "目前檢視裡的篩選條件",
+    "Search connected services" : "搜尋已連結的服務",
     "Results" : "結果",
     "Load more results" : "載入更多結果",
     "Search in" : "搜尋",
@@ -146,23 +263,23 @@ OC.L10N.register(
     "Account name" : "帳戶名稱",
     "Server side authentication failed!" : "伺服器端認證失敗！",
     "Please contact your administrator." : "請聯絡系統管理員。",
-    "Temporary error" : "暫時出現錯誤",
-    "Please try again." : "請再試一次。",
+    "Session error" : "工作階段錯誤",
+    "It appears your session token has expired, please refresh the page and try again." : "您的工作階段權杖似乎已過期，請重新整理頁面並重試。",
     "An internal error occurred." : "發生內部錯誤。",
     "Please try again or contact your administrator." : "請重試或聯絡系統管理員。",
     "Password" : "密碼",
     "Log in with a device" : "使用免密碼裝置登入",
     "Login or email" : "帳戶或電子郵件",
     "Your account is not setup for passwordless login." : "你的賬號尚未設定免密碼登入。",
-    "Browser not supported" : "不支持該瀏覽器",
-    "Passwordless authentication is not supported in your browser." : "你使用的瀏覽器不支援無密碼身分驗證。",
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身分驗證僅支援經加密的連線。",
+    "Browser not supported" : "不支持該瀏覽器",
+    "Passwordless authentication is not supported in your browser." : "你使用的瀏覽器不支援無密碼身分驗證。",
     "Reset password" : "重設密碼",
+    "Back to login" : "回到登入畫面",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "如果此帳戶存在，密碼重置郵件已發送到其電郵地址。如果您沒有收到，請驗證您的電郵地址和/或帳戶，檢查您的垃圾郵件/垃圾資料夾或向您當地的管理員協助。",
     "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼電郵。請聯絡您的管理員。",
     "Password cannot be changed. Please contact your administrator." : "無法重設密碼，請聯絡管理員。",
-    "Back to login" : "回到登入畫面",
     "New password" : "新密碼",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請與管理員聯繫。確定要繼續嗎？",
     "I know what I'm doing" : "我知道我在做什麼",
@@ -207,6 +324,47 @@ OC.L10N.register(
     "Login form is disabled." : "登入表格已停用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
     "More actions" : "更多操作",
+    "User menu" : "用戶選項單",
+    "Your guest name: {user}" : "您的訪客名稱：{user}",
+    "You are currently not identified." : "目前無法辨識您的身分。",
+    "Set public name" : "設定公開名稱",
+    "Change public name" : "變更公開名稱",
+    "Password is too weak" : "密碼強度非常弱",
+    "Password is weak" : "密碼強度弱",
+    "Password is average" : "密碼強度一般",
+    "Password is strong" : "密碼強度高",
+    "Password is very strong" : "密碼強度非常強",
+    "Password is extremely strong" : "密碼強度極其強勁",
+    "Unknown password strength" : "密碼強度未知",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "您的數據目錄和檔案可能可以從互聯網存取，因為 <code>.htaccess</code> 不起作用。",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "有關如何正確配置伺服器的資訊，請參閱{linkStart}說明書{linkEnd}",
+    "Autoconfig file detected" : "偵測到自動配置檔案",
+    "The setup form below is pre-filled with the values from the config file." : "下面的設置表格已根據配置檔案的值自動填充。",
+    "Security warning" : "安全性警示",
+    "Create administration account" : "建立管理員帳戶",
+    "Administration account name" : "管理員帳戶名稱",
+    "Administration account password" : "管理員帳戶密碼",
+    "Storage & database" : "儲存空間和數據庫",
+    "Data folder" : "資料儲存位置",
+    "Database configuration" : "數據庫配置",
+    "Only {firstAndOnlyDatabase} is available." : "僅 {firstAndOnlyDatabase} 可用。",
+    "Install and activate additional PHP modules to choose other database types." : "安裝並啟動相關 PHP 模組來使用其他種數據庫",
+    "For more details check out the documentation." : "要取得更多細節資訊，請參閱說明書。",
+    "Performance warning" : "性能警告",
+    "You chose SQLite as database." : "您選擇了 SQLite 作為數據庫",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他數據庫後端。",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
+    "Database user" : "數據庫用戶",
+    "Database password" : "數據庫密碼",
+    "Database name" : "數據庫名稱",
+    "Database tablespace" : "數據庫資料表空間",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
+    "Database host" : "數據庫主機",
+    "localhost" : "localhost",
+    "Installing …" : "正在安裝 …",
+    "Install" : "安裝",
+    "Need help?" : "需要協助嗎？",
+    "See the documentation" : "閱讀說明文件",
     "{name} version {version} and above" : "{name} 的版本 {version} 及更新",
     "This browser is not supported" : "不支援此瀏覽器",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
@@ -247,31 +405,20 @@ OC.L10N.register(
     "Type to search for existing projects" : "搜尋現有專案",
     "New in" : "新加入",
     "View changelog" : "檢視版本更新紀錄",
-    "Very weak password" : "密碼安全性極弱",
-    "Weak password" : "密碼安全性弱",
-    "So-so password" : "密碼安全性普通",
-    "Good password" : "密碼安全性佳",
-    "Strong password" : "密碼強度極佳",
     "No action available" : "沒有可用的操作",
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Close \"{dialogTitle}\" dialog" : "關閉 \"{dialogTitle}\" 對話",
     "Email length is at max (255)" : "電子郵件已達到最大長度（255 個字元）",
-    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
-    "Restricted" : "受限",
-    "Invisible" : "隱藏",
-    "Delete" : "刪除",
-    "Rename" : "重新命名",
-    "Collaborative tags" : "協作標籤",
-    "No tags found" : "查無標籤",
     "Clipboard not available, please copy manually" : "剪貼板不可用，請人手複製",
     "Personal" : "個人",
     "Accounts" : "帳戶",
     "Admin" : "管理",
     "Help" : "說明",
     "Access forbidden" : "存取被拒",
+    "You are not allowed to access this page." : "您無法存取此頁面。",
+    "Back to %s" : "回到 %s",
     "Page not found" : "沒有找到頁面",
     "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無法查看它。",
-    "Back to %s" : "回到 %s",
     "Too many requests" : "太多要求",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
     "Error" : "錯誤",
@@ -289,34 +436,6 @@ OC.L10N.register(
     "File: %s" : "檔案：%s",
     "Line: %s" : "行數：%s",
     "Trace" : "追蹤",
-    "Security warning" : "安全性警示",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄可能可以從互聯網存取，因為 .htaccess 不起作用。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "有關如何正確配置伺服器的信息，請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明書</a>。",
-    "<strong>Create an admin account</strong>" : "<strong>創建管理員帳戶</strong>",
-    "New admin account name" : "新管理員帳戶名稱",
-    "New admin password" : "新管理員密碼",
-    "Show password" : "顯示密碼",
-    "Toggle password visibility" : "切換密碼可見性",
-    "Storage & database" : "儲存空間和數據庫",
-    "Data folder" : "資料儲存位置",
-    "Configure the database" : "設定數據庫",
-    "Only %s is available." : "僅 %s 可使用。",
-    "Install and activate additional PHP modules to choose other database types." : "安裝並啟動相關 PHP 模組來使用其他種數據庫",
-    "For more details check out the documentation." : "要取得更多細節資訊，請參閱說明書。",
-    "Database account" : "數據庫帳戶",
-    "Database password" : "數據庫密碼",
-    "Database name" : "數據庫名稱",
-    "Database tablespace" : "數據庫資料表空間",
-    "Database host" : "數據庫主機",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
-    "Performance warning" : "性能警告",
-    "You chose SQLite as database." : "您選擇了 SQLite 作為數據庫",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他數據庫後端。",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
-    "Install" : "安裝",
-    "Installing …" : "正在安裝 …",
-    "Need help?" : "需要協助嗎？",
-    "See the documentation" : "閱讀說明文件",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "您似乎正在嘗試重新安裝您的Nextcloud。然而，檔案 CAN_INSTALL 並未在您的config目錄中。請在您的config目錄中建立 CAN_INSTALL檔以繼續。",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "無法從您的 config 資料夾中移除 CAN_INSTALL 檔案。請人手移除此檔案。",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "這個應用程式需要啟用 Javascript 才能正常運作，請{linkstart}啟用Javascript{linkend}然後重新整理頁面。",
@@ -375,17 +494,42 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "此 %s 實例目前處於維護模式，可能需要一段時間才能完成。",
     "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "Currently open" : "目前開啟",
-    "Login with username or email" : "以用戶名稱或電郵地址登入",
-    "Login with username" : "以用戶名稱登入",
+    "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
+    "No crop data provided" : "未提供剪裁設定",
+    "No valid crop data provided" : "未提供有效的剪裁設定",
+    "Crop is not square" : "剪裁設定不是正方形",
+    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "有關更多細節，請參見 {linkstart} 說明書↗{linkend}。",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
     "You have not added any info yet" : "您尚未新增任何資訊",
     "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
     "Error opening the user status modal, try hard refreshing the page" : "打開用戶狀態模式時出錯，請嘗試刷新頁面",
     "Edit Profile" : "編輯個人設定",
     "The headline and about sections will show up here" : "標題與關於部份將在此顯示",
-    "Error loading message template: {error}" : "載入訊息模板時出錯： {error}",
+    "Very weak password" : "密碼安全性極弱",
+    "Weak password" : "密碼安全性弱",
+    "So-so password" : "密碼安全性普通",
+    "Good password" : "密碼安全性佳",
+    "Strong password" : "密碼強度極佳",
+    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
+    "Restricted" : "受限",
+    "Invisible" : "隱藏",
+    "Delete" : "刪除",
+    "Rename" : "重新命名",
+    "Collaborative tags" : "協作標籤",
+    "No tags found" : "查無標籤",
     "Profile not found" : "找不到個人資料",
-    "The profile does not exist." : "個人資料不存在"
+    "The profile does not exist." : "個人資料不存在",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄可能可以從互聯網存取，因為 .htaccess 不起作用。",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "有關如何正確配置伺服器的信息，請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明書</a>。",
+    "<strong>Create an admin account</strong>" : "<strong>創建管理員帳戶</strong>",
+    "New admin account name" : "新管理員帳戶名稱",
+    "New admin password" : "新管理員密碼",
+    "Show password" : "顯示密碼",
+    "Toggle password visibility" : "切換密碼可見性",
+    "Configure the database" : "設定數據庫",
+    "Only %s is available." : "僅 %s 可使用。",
+    "Database account" : "數據庫帳戶",
+    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿"
 },
 "nplurals=1; plural=0;");
