@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "未知的檔案類型",
     "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
     "Invalid image" : "無效的圖片",
-    "No temporary profile picture available, try again" : "沒有臨時用的個人檔案圖片，請再試一次",
-    "No crop data provided" : "未設定剪裁",
-    "No valid crop data provided" : "未提供有效的剪裁設定",
-    "Crop is not square" : "剪裁設定不是正方形",
     "State token does not match" : "狀態代符不相符",
     "Invalid app password" : "無效的應用程式密碼",
     "Could not complete login" : "嘗試登入時發生錯誤",
     "State token missing" : "狀態代符遺失",
     "Your login token is invalid or has expired" : "您的登入代符無效或已過期",
+    "Please use original client" : "請使用原始客戶端",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "這個 Nextcloud 的社群版本沒有得到支援，而且推播通知會有所限制。",
     "Login" : "登入",
     "Unsupported email length (>255)" : "不支援的電子郵件長度 (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "找不到任務",
     "Internal error" : "內部錯誤",
     "Not found" : "找不到",
+    "Node is locked" : "節點已鎖定",
     "Bad request" : "錯誤的請求",
     "Requested task type does not exist" : "請求的任務類型不存在",
     "Necessary language model provider is not available" : "沒有可用的語言模型程式",
@@ -51,6 +49,12 @@ OC.L10N.register(
     "No translation provider available" : "沒有可用的翻譯提供者",
     "Could not detect language" : "無法偵測語言",
     "Unable to translate" : "無法翻譯",
+    "No valid filters provided" : "未提供有效的篩選條件",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "修復步驟：",
+    "Repair info:" : "修復資訊：",
+    "Repair warning:" : "修復警告：",
+    "Repair error:" : "修復錯誤：",
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "出於安全性問題，我們必須移除您一部分的分享連結。查看更多資訊請點選連結。",
@@ -58,11 +62,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加帳號限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
     "Learn more ↗" : "深入瞭解 ↗",
     "Preparing update" : "準備更新",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "修復步驟：",
-    "Repair info:" : "修復資訊：",
-    "Repair warning:" : "修復警告：",
-    "Repair error:" : "修復錯誤：",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。",
     "Turned on maintenance mode" : "啟用維護模式",
     "Turned off maintenance mode" : "停用維護模式",
@@ -79,8 +78,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s（不相容）",
     "The following apps have been disabled: %s" : "以下應用程式已被停用：%s",
     "Already up to date" : "已是最新版本",
-    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "詳細資訊請參閱 {linkstart} 文件 ↗{linkend}。",
+    "Windows Command Script" : "Windows 命令稿",
+    "Electronic book document" : "電子書文件",
+    "TrueType Font Collection" : "TrueType 字型集合",
+    "Web Open Font Format" : "Web 開放字型格式",
+    "GPX geographic data" : "GPX 地理資料",
+    "Gzip archive" : "Gzip 封存檔",
+    "Adobe Illustrator document" : "Adobe Illustrator 文件",
+    "Java source code" : "Java 原始碼",
+    "JavaScript source code" : "JavaScript 原始碼",
+    "JSON document" : "JSON 文件",
+    "Microsoft Access database" : "Microsoft Access 資料庫",
+    "Microsoft OneNote document" : "Microsoft OneNote 文件",
+    "Microsoft Word document" : "Microsoft Word 文件",
+    "Unknown" : "未知",
+    "PDF document" : "PDF 文件",
+    "PostScript document" : "PostScript 文件",
+    "RSS summary" : "RSS 摘要",
+    "Android package" : "Android 軟體包",
+    "KML geographic data" : "KML 地理資料",
+    "KML geographic compressed data" : "KML 地理壓縮資料",
+    "Lotus Word Pro document" : "Lotus Word Pro 文件",
+    "Excel spreadsheet" : "Excel 試算表",
+    "Excel add-in" : "Excel 增益集",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 二進位試算表",
+    "Excel spreadsheet template" : "Excel 試算表範本",
+    "Outlook Message" : "Outlook 訊息",
+    "PowerPoint presentation" : "PowerPoint 簡報",
+    "PowerPoint add-in" : "PowerPoint 增益集",
+    "PowerPoint presentation template" : "PowerPoint 簡報範本",
+    "Word document" : "Word 文件",
+    "ODF formula" : "ODF 公式",
+    "ODG drawing" : "ODG 繪圖",
+    "ODG drawing (Flat XML)" : "ODG 繪圖 (Flat XML)",
+    "ODG template" : "ODG 範本",
+    "ODP presentation" : "ODP 簡報",
+    "ODP presentation (Flat XML)" : "ODP 簡報 (Flat XML)",
+    "ODP template" : "ODP 範本",
+    "ODS spreadsheet" : "ODS 試算表",
+    "ODS spreadsheet (Flat XML)" : "ODS 試算表 (Flat XML)",
+    "ODS template" : "ODS 範本",
+    "ODT document" : "ODT 文件",
+    "ODT document (Flat XML)" : "ODT 文件 (Flat XML)",
+    "ODT template" : "ODT 範本",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 簡報",
+    "PowerPoint 2007 show" : "PowerPoint 2007 自動放映",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 簡報範本",
+    "Excel 2007 spreadsheet" : "Excel 2007 試算表",
+    "Excel 2007 spreadsheet template" : "Excel 2007 試算表範本",
+    "Word 2007 document" : "Word 2007 文件",
+    "Word 2007 document template" : "Word 2007 文件範本",
+    "Microsoft Visio document" : "Microsoft Visio 文件",
+    "WordPerfect document" : "WordPerfect 文件",
+    "7-zip archive" : "7-zip 封存檔",
+    "Blender scene" : "Blender 場景",
+    "Bzip2 archive" : "Bzip2 封存檔",
+    "Debian package" : "Debian 軟體包",
+    "FictionBook document" : "FictionBook 文件",
+    "Unknown font" : "未知字型",
+    "Krita document" : "Krita 文件",
+    "Mobipocket e-book" : "Mobipocket 電子書",
+    "Windows Installer package" : "Windows 安裝程式包",
+    "Perl script" : "Perl 命令稿",
+    "PHP script" : "PHP 命令稿",
+    "Tar archive" : "Tar 封存檔",
+    "XML document" : "XML 文件",
+    "YAML document" : "YAML 文件",
+    "Zip archive" : "Zip 封存檔",
+    "Zstandard archive" : "Zstandard 封存檔",
+    "AAC audio" : "AAC 音訊",
+    "FLAC audio" : "FLAC 音訊",
+    "MPEG-4 audio" : "MPEG-4 音訊",
+    "MP3 audio" : "MP3 音訊",
+    "Ogg audio" : "Ogg 音訊",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe 標準音訊",
+    "WebM audio" : "WebM 音訊",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast 播放清單",
+    "Windows BMP image" : "Windows BMP 影像",
+    "Better Portable Graphics image" : "BPG 影像",
+    "EMF image" : "EMF 影像",
+    "GIF image" : "GIF 影像",
+    "HEIC image" : "HEIC 影像",
+    "HEIF image" : "HEIF 影像",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 影像",
+    "JPEG image" : "JPEG 影像",
+    "PNG image" : "PNG 圖檔",
+    "SVG image" : "SVG 影像",
+    "Truevision Targa image" : "Truevision Targa 影像",
+    "TIFF image" : "TIFF 影像",
+    "WebP image" : "WebP 影像",
+    "Digital raw image" : "數位原始影像",
+    "Windows Icon" : "Windows 圖示",
+    "Email message" : "電子郵件訊息",
+    "VCS/ICS calendar" : "VCS/ICS 行事曆",
+    "CSS stylesheet" : "CSS 樣式表",
+    "CSV document" : "CSV 文件",
+    "HTML document" : "HTML 文件",
+    "Markdown document" : "Markdown 文件",
+    "Org-mode file" : "Org-mode 檔案",
+    "Plain text document" : "純文字文件",
+    "Rich Text document" : "RTF 文件",
+    "Electronic business card" : "電子名片",
+    "C++ source code" : "C++ 原始碼",
+    "LDIF address book" : "LDIF 通訊錄",
+    "NFO document" : "NFO 文件",
+    "PHP source" : "PHP 原始碼",
+    "Python script" : "Python 命令稿",
+    "ReStructuredText document" : "ReStructuredText 文件",
+    "3GPP multimedia file" : "3GPP 多媒體檔案",
+    "MPEG video" : "MPEG 視訊",
+    "DV video" : "DV 視訊",
+    "MPEG-2 transport stream" : "MPEG2 傳輸串流",
+    "MPEG-4 video" : "MPEG-4 視訊",
+    "Ogg video" : "Ogg 視訊",
+    "QuickTime video" : "QuickTime 視訊",
+    "WebM video" : "WebM 視訊",
+    "Flash video" : "Flash 視訊",
+    "Matroska video" : "Matroska 視訊",
+    "Windows Media video" : "Windows 媒體視訊",
+    "AVI video" : "AVI 視訊",
     "unknown text" : "未知的文字",
     "Hello world!" : "哈囉，世界！",
     "sunny" : "晴朗",
@@ -109,7 +225,7 @@ OC.L10N.register(
     "Federated user" : "聯盟使用者",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "建立分享",
-    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Direct link copied" : "已複製直接連結",
     "Please copy the link manually:" : "請手動複製連結：",
     "Custom date range" : "自訂日期範圍",
     "Pick start date" : "挑選開始日期",
@@ -120,12 +236,14 @@ OC.L10N.register(
     "Search everywhere" : "到處搜尋",
     "Searching …" : "正在搜尋…",
     "Start typing to search" : "開始輸入以搜尋",
+    "Minimum search length is {minSearchLength} characters" : "最小搜尋長度為 {minSearchLength} 個字元",
     "No matching results" : "無相符結果",
     "Today" : "今天",
     "Last 7 days" : "過去 7 天",
     "Last 30 days" : "過去 30 天",
     "This year" : "今年",
     "Last year" : "去年",
+    "Between {startDate} and {endDate}" : "在 {startDate} 至 {endDate} 間",
     "Unified search" : "統一搜尋",
     "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
     "Places" : "地點",
@@ -133,6 +251,7 @@ OC.L10N.register(
     "Search people" : "搜尋人物",
     "People" : "人物",
     "Filter in current view" : "目前檢視中的篩選條件",
+    "Search connected services" : "搜尋已連結的服務",
     "Results" : "結果",
     "Load more results" : "載入更多結果",
     "Search in" : "搜尋條件",
@@ -146,8 +265,8 @@ OC.L10N.register(
     "Account name" : "帳號名稱",
     "Server side authentication failed!" : "伺服器端認證失敗！",
     "Please contact your administrator." : "請聯絡系統管理員。",
-    "Temporary error" : "暫時錯誤",
-    "Please try again." : "請再試一次。",
+    "Session error" : "工作階段錯誤",
+    "It appears your session token has expired, please refresh the page and try again." : "您的工作階段權杖似乎已過期，請重新整理頁面並重試。",
     "An internal error occurred." : "發生內部錯誤。",
     "Please try again or contact your administrator." : "請重試，或聯絡您的系統管理員。",
     "Password" : "密碼",
@@ -207,6 +326,11 @@ OC.L10N.register(
     "Login form is disabled." : "登入表單已停用。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
     "More actions" : "更多動作",
+    "User menu" : "使用者選單",
+    "Your guest name: {user}" : "您的訪客名稱：{user}",
+    "You are currently not identified." : "目前無法辨識您的身份。",
+    "Set public name" : "設定公開名稱",
+    "Change public name" : "變更公開名稱",
     "Password is too weak" : "非常弱密碼",
     "Password is weak" : "弱密碼",
     "Password is average" : "一般密碼",
@@ -287,22 +411,16 @@ OC.L10N.register(
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
     "Email length is at max (255)" : "電子郵件長度最長 (255)",
-    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
-    "Restricted" : "受限",
-    "Invisible" : "隱藏",
-    "Delete" : "刪除",
-    "Rename" : "重新命名",
-    "Collaborative tags" : "協作標籤",
-    "No tags found" : "找不到標籤",
     "Clipboard not available, please copy manually" : "無法使用剪貼簿，請手動複製",
     "Personal" : "個人",
     "Accounts" : "帳號",
     "Admin" : "管理",
     "Help" : "說明",
     "Access forbidden" : "存取被拒",
+    "You are not allowed to access this page." : "您無法存取此頁面。",
+    "Back to %s" : "返回 %s",
     "Page not found" : "找不到頁面",
     "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無權檢視。",
-    "Back to %s" : "返回 %s",
     "Too many requests" : "太多請求",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自您的網路，請稍後再試。若您認為這不該發生，請聯絡系統管理員這是錯誤。",
     "Error" : "錯誤",
@@ -378,21 +496,30 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 站台目前處於維護模式，需要一段時間恢復。",
     "This page will refresh itself when the instance is available again." : "在站台恢復可用之後，本頁會自動重新整理。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "Currently open" : "目前開啟",
-    "Login with username or email" : "以使用者名稱或電子郵件登入",
-    "Login with username" : "以使用者名稱登入",
+    "No temporary profile picture available, try again" : "沒有臨時用的個人檔案圖片，請再試一次",
+    "No crop data provided" : "未設定剪裁",
+    "No valid crop data provided" : "未提供有效的剪裁設定",
+    "Crop is not square" : "剪裁設定不是正方形",
+    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "詳細資訊請參閱 {linkstart} 文件 ↗{linkend}。",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議、網路研討會等 - 在您的瀏覽器與手機應用程式之中實現。",
     "You have not added any info yet" : "您尚未新增任何資訊",
     "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
     "Error opening the user status modal, try hard refreshing the page" : "開啟使用者狀態的模組時發生問題，嘗試重新整理頁面",
     "Edit Profile" : "編輯個人檔案",
     "The headline and about sections will show up here" : "標題與關於區段將在此顯示",
-    "Error loading message template: {error}" : "載入訊息範本時發生錯誤：{error}",
     "Very weak password" : "密碼安全性極弱",
     "Weak password" : "密碼安全性弱",
     "So-so password" : "密碼安全性普通",
     "Good password" : "密碼安全性佳",
     "Strong password" : "密碼安全性極佳",
+    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
+    "Restricted" : "受限",
+    "Invisible" : "隱藏",
+    "Delete" : "刪除",
+    "Rename" : "重新命名",
+    "Collaborative tags" : "協作標籤",
+    "No tags found" : "找不到標籤",
     "Profile not found" : "找不到個人檔案",
     "The profile does not exist." : "個人檔案不存在。",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 .htaccess 檔案並未生效。",
@@ -404,6 +531,7 @@ OC.L10N.register(
     "Toggle password visibility" : "切換密碼可見性",
     "Configure the database" : "設定資料庫組態",
     "Only %s is available." : "剩下 %s 可使用。",
-    "Database account" : "資料庫帳號"
+    "Database account" : "資料庫帳號",
+    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿"
 },
 "nplurals=1; plural=0;");
