@@ -2,8 +2,8 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "¡No se puede escribir en la carpeta \"config\"!",
-    "This can usually be fixed by giving the web server write access to the config directory." : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta config.",
-    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Pero, si prefieres mantener el archivo config.php como solo de lectura, establece la opción \"config_is_read_only\" a true en él.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Esto usualmente se puede corregir dándole al servidor web acceso de escritura a la carpeta config.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Pero, si prefiere mantener el archivo config.php como solo de lectura, establezca la opción \"config_is_read_only\" a true en el mismo.",
     "See %s" : "Ver %s",
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "La aplicación %1$s no está presente o tiene una versión que no es compatible con este servidor. Por favor, chequee la carpeta de apps.",
     "Sample configuration detected" : "Configuración de ejemplo detectada",
@@ -11,22 +11,22 @@ OC.L10N.register(
     "The page could not be found on the server." : "La página no se ha encontrado en el servidor.",
     "%s email verification" : "%s verificación del correo electrónico",
     "Email verification" : "Verificación del correo electrónico",
-    "Click the following button to confirm your email." : "Haz clic en el siguiente botón para confirmar tu correo electrónico.",
-    "Click the following link to confirm your email." : "Haz clic en el siguiente enlace para confirmar tu correo electrónico.",
-    "Confirm your email" : "Confirma tu correo electrónico",
+    "Click the following button to confirm your email." : "Haga clic en el siguiente botón para confirmar su correo electrónico.",
+    "Click the following link to confirm your email." : "Haga clic en el siguiente enlace para confirmar su correo electrónico.",
+    "Confirm your email" : "Confirme su correo electrónico",
     "Other activities" : "Otras actividades",
     "%1$s and %2$s" : "%1$s y %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s, y %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
     "Education bundle" : "Paquete educativo",
-    "Enterprise bundle" : "Pack para empresas",
-    "Groupware bundle" : "Pack groupware",
-    "Hub bundle" : "Pack para Hub",
-    "Public sector bundle" : "Paquete del sector público",
-    "Social sharing bundle" : "Pack para compartir en redes",
+    "Enterprise bundle" : "Paquete empresarial",
+    "Groupware bundle" : "Paquete groupware",
+    "Hub bundle" : "Paquete de Hub",
+    "Public sector bundle" : "Paquete para sector público",
+    "Social sharing bundle" : "Paquete para compartir en redes",
     "PHP %s or higher is required." : "Se requiere PHP %s o superior.",
-    "PHP with a version lower than %s is required." : "Se necesita una versión de PHP inferior a %s",
+    "PHP with a version lower than %s is required." : "Se requiere una versión de PHP inferior a %s.",
     "%sbit or higher PHP required." : "Se requiere PHP %sbit o superior.",
     "The following architectures are supported: %s" : "Las siguientes arquitecturas están soportadas: %s",
     "The following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
@@ -35,64 +35,66 @@ OC.L10N.register(
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Se requiere la biblioteca %1$s con una versión mayor que %2$s. Está disponible la versión %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Se requiere la biblioteca %1$s con una versión menor que %2$s. Está disponible la versión %3$s.",
     "The following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
-    "Server version %s or higher is required." : "Se necesita la versión %s o superior del servidor.",
-    "Server version %s or lower is required." : "Se necesita la versión %s o inferior del servidor.  ",
+    "Server version %s or higher is required." : "Se requiere la versión %s o superior del servidor.",
+    "Server version %s or lower is required." : "Se requiere la versión %s o inferior del servidor.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un sub-administrador o haber obtenido permisos especiales para acceder a esta configuración",
     "Your current IP address doesn't allow you to perform admin actions" : "Su dirección IP actual no le permite ejecutar funciones de administrador",
     "Logged in account must be an admin or sub admin" : "La cuenta conectada debe ser de un administrador o un sub-administrador",
     "Logged in account must be an admin" : "La cuenta conectada debe ser un administrador",
-    "Wiping of device %s has started" : "El borrado del dispositivo %s ha empezado",
-    "Wiping of device »%s« has started" : "El borrado del dispositivo »%s« ha empezado",
-    "»%s« started remote wipe" : "»%s« ha empezado el borrado a distancia",
-    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositivo o la aplicación »%s« ha empezado el proceso de borrado a distancia. Vas a recibir otro mensaje por correo una vez que el proceso haya concluido.",
-    "Wiping of device %s has finished" : "El borrado del dispositivo %s ha concluido",
-    "Wiping of device »%s« has finished" : "El borrado del dispositivo »%s« ha concluido",
-    "»%s« finished remote wipe" : "»%s« ha acabado el borrado a distancia",
-    "Device or application »%s« has finished the remote wipe process." : "El dispositivo o la aplicación »%s« ha concluido el proceso de borrado a distancia.",
-    "Remote wipe started" : "Borrado remoto comenzado.",
-    "A remote wipe was started on device %s" : "Se ha iniciado un borrado remoto en el dispositivo %s.",
-    "Remote wipe finished" : "Borrado remoto finalizado",
-    "The remote wipe on %s has finished" : "El borrado remoto en %s ha finalizado",
+    "Wiping of device %s has started" : "La limpieza del dispositivo %s ha iniciado",
+    "Wiping of device »%s« has started" : "La limpieza del dispositivo »%s« ha iniciado",
+    "»%s« started remote wipe" : "»%s« ha iniciado la limpieza remota",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositivo o la aplicación »%s« ha iniciado el proceso de limpieza remoto. Recibirá otro mensaje por correo electrónico una vez que el proceso haya finalizado.",
+    "Wiping of device %s has finished" : "La limpieza del dispositivo %s ha finalizado",
+    "Wiping of device »%s« has finished" : "La limpieza del dispositivo »%s« ha finalizado",
+    "»%s« finished remote wipe" : "»%s« finalizó la limpieza remota",
+    "Device or application »%s« has finished the remote wipe process." : "El dispositivo o la aplicación »%s« ha finalizado el proceso de limpieza remoto.",
+    "Remote wipe started" : "Limpieza remota iniciada.",
+    "A remote wipe was started on device %s" : "Se ha iniciado una limpieza remota en el dispositivo %s",
+    "Remote wipe finished" : "Limpieza remota finalizada",
+    "The remote wipe on %s has finished" : "La limpieza remota en %s ha finalizado",
     "Authentication" : "Autentificación",
     "Unknown filetype" : "Tipo de archivo desconocido",
-    "Invalid image" : "Imagen no válida",
+    "Invalid image" : "Imagen inválida",
     "Avatar image is not square" : "La imagen de avatar no es cuadrada",
     "Files" : "Archivos",
     "View profile" : "Ver perfil",
     "same time" : "al mismo tiempo",
     "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
     "_%nm_::_%nm_" : ["%n m","%n m","%n m"],
-    "%s ahead" : "%s adelantado",
-    "%s behind" : "%s atrasado",
+    "%s ahead" : "%s por delante",
+    "%s behind" : "%s por detrás",
     "Local time: %s" : "Hora local: %s",
     "today" : "hoy",
     "tomorrow" : "mañana",
     "yesterday" : "ayer",
     "_in %n day_::_in %n days_" : ["dentro de %n día","dentro de %n días","dentro de %n días"],
-    "_%n day ago_::_%n days ago_" : ["Hace %n día","hace %n días","hace %n días"],
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "next month" : "mes siguiente",
-    "last month" : "mes pasado",
+    "last month" : "mes anterior",
     "_in %n month_::_in %n months_" : ["dentro de %n mes","dentro de %n meses","dentro de %n meses"],
-    "_%n month ago_::_%n months ago_" : ["Hace %n mes","hace %n meses","hace %n meses"],
+    "_%n month ago_::_%n months ago_" : ["hace %n mes","hace %n meses","hace %n meses"],
     "next year" : "año que viene",
     "last year" : "año pasado",
     "_in %n year_::_in %n years_" : ["dentro de %n año","dentro de %n años","dentro de %n años"],
-    "_%n year ago_::_%n years ago_" : ["Hace %n año","hace %n años","hace %n años"],
+    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años","hace %n años"],
     "_in %n hour_::_in %n hours_" : ["dentro de %n hora","dentro de %n horas","dentro de %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","hace %n horas","hace %n horas"],
+    "_%n hour ago_::_%n hours ago_" : ["hace %n hora","hace %n horas","hace %n horas"],
     "_in %n minute_::_in %n minutes_" : ["dentro de %n minuto","dentro de %n minutos","dentro de %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","hace %n minutos","hace %n minutos"],
+    "_%n minute ago_::_%n minutes ago_" : ["hace %n minuto","hace %n minutos","hace %n minutos"],
     "in a few seconds" : "en unos segundos",
     "seconds ago" : "hace segundos",
     "Empty file" : "Archivo vacío",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID %s no existe. Por favor, actívalo en la configuración de apps o contacta con tu administrador.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID %s no existe. Por favor, habilite el mismo en la configuración de apps o contacte a su administrador.",
     "No file conversion providers available" : "No hay proveedores de conversión de archivos disponibles",
-    "File is too large to convert" : "El archivo es demasiado grande para convertir",
+    "File is too large to convert" : "El archivo es demasiado grande para ser convertido",
     "Destination does not match conversion extension" : "El destino no coincide con la extensión convertida",
     "Could not convert file" : "No se ha podido convertir el archivo",
     "Destination does not exist" : "El destino no existe",
     "Destination is not creatable" : "El destino no se puede crear",
-    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
+    "Dot files are not allowed" : "Los archivos cuyo nombre comienza por \".\" no están permitidos",
+    "%1$s (renamed)" : "%1$s (renombrado)",
+    "renamed file" : "archivo renombrado",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" Es un nombre de archivo o carpeta no permitido.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "%1$s es un prefijo prohibido para nombres de archivo o carpeta.",
     "\"%1$s\" is not allowed inside a file or folder name." : "«%1$s» no se permite en el nombre de un archivo o carpeta.",
@@ -100,7 +102,7 @@ OC.L10N.register(
     "Filenames must not end with \"%1$s\"." : "Los nombres de archivos no deben terminar con \"%1$s\".",
     "Invalid parent path" : "Ruta de nivel superior inválida",
     "File already exists" : "El archivo ya existe",
-    "Invalid path" : "Ruta no válida",
+    "Invalid path" : "Ruta inválida",
     "Failed to create file from template" : "Fallo al crear el archivo desde plantilla",
     "Templates" : "Plantillas",
     "Storage %s cannot be moved" : "El almacenamiento %s no ha podido moverse",
@@ -114,11 +116,11 @@ OC.L10N.register(
     "Filename is a reserved word" : "El nombre de archivo es una palabra reservada",
     "Filename contains at least one invalid character" : "El nombre de archivo contiene al menos un carácter inválido",
     "Filename is too long" : "El nombre del archivo es demasiado largo",
-    "Empty filename is not allowed" : "No se puede dejar el nombre en blanco.",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "No se puede instalar la app \"%s\" debido a que no se puede leer la información de la app.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "No se puede instalar la aplicación \"%s\" porque no es compatible con esta versión del servidor.",
+    "Empty filename is not allowed" : "No está permitido un nombre de archivo en blanco",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "No se puede instalar la app \"%s\" debido a que no se puede leer el archivo appinfo.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "No se puede instalar la aplicación \"%s\" debido a que no es compatible con esta versión del servidor.",
     "__language_name__" : "Español (España)",
-    "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no responda.",
+    "This is an automatically sent email, please do not reply." : "Este es un correo electrónico enviado automáticamente, por favor, no responda.",
     "Help & privacy" : "Ayuda y privacidad",
     "Appearance and accessibility" : "Apariencia y accesibilidad",
     "Apps" : "Aplicaciones",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Ajustes",
     "Log out" : "Cerrar sesión",
     "Accounts" : "Cuentas",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Ver %s en Bluesky",
     "Email" : "Correo electrónico",
     "Mail %s" : "Correo %s",
     "Fediverse" : "Fediverso",
@@ -136,30 +140,30 @@ OC.L10N.register(
     "Twitter" : "Twitter",
     "View %s on Twitter" : "Ver %s en Twitter",
     "Website" : "Sitio web",
-    "Visit %s" : "Visita %s",
+    "Visit %s" : "Visitar %s",
     "Address" : "Dirección",
-    "Profile picture" : "Imagen de perfil",
+    "Profile picture" : "Imagen del perfil",
     "About" : "Acerca de",
-    "Display name" : "Nombre para mostrar",
-    "Headline" : "Titular",
-    "Organisation" : "Organización",
-    "Role" : "Puesto",
+    "Display name" : "Nombre mostrado",
+    "Headline" : "Título",
+    "Organization" : "Organización",
+    "Role" : "Cargo",
     "Pronouns" : "Pronombres",
     "Unknown account" : "Cuenta desconocida",
     "Additional settings" : "Configuración adicional",
     "Enter the database Login and name for %s" : "Ingrese el usuario y el nombre para la base de datos %s",
     "Enter the database Login for %s" : "Ingrese el usuario de la base de datos para %s",
     "Enter the database name for %s" : "Introduzca el nombre de la base de datos %s",
-    "You cannot use dots in the database name %s" : "No puede utilizar puntos para el nombre de base de datos %s",
+    "You cannot use dots in the database name %s" : "No puede utilizar puntos en el nombre de base de datos %s",
     "MySQL Login and/or password not valid" : "Usuario y/o contraseña de MySQL inválidos",
     "You need to enter details of an existing account." : "Necesita introducir los datos de una cuenta existente.",
     "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
     "Oracle Login and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
     "PostgreSQL Login and/or password not valid" : "Usuario y/o contraseña de PostgreSQL inválidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X no está soportado y %s no funcionará bien en esta plataforma. ¡Úsela bajo su propio riesgo! ",
-    "For the best results, please consider using a GNU/Linux server instead." : "Para obtener los mejores resultados, considera utilizar un servidor GNU/Linux.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con archivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
+    "For the best results, please consider using a GNU/Linux server instead." : "Para obtener los mejores resultados, por favor considere en su lugar utilizar un servidor GNU/Linux.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el parámetro open_basedir se ha configurado en php.ini. Esto acarreará problemas con archivos de tamaño superior a 4GB y está totalmente desaconsejado.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir dentro de su php.ini o cambie a PHP de 64 bits.",
     "Set an admin Login." : "Establecer un usuario administrador.",
     "Set an admin password." : "Configurar la contraseña del administrador.",
     "Cannot create or write into the data directory %s" : "No se puede crear o escribir en la carpeta de datos %s",
@@ -273,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Se debe proporcionar un usuario válido",
     "Login contains whitespace at the beginning or at the end" : "El usuario contiene espacios en blanco al inicio o al final",
     "Login must not consist of dots only" : "El usuario no debe consistir sólo de puntos",
+    "Username is too long" : "El nombre de usuario es demasiado largo",
     "Login is invalid because files already exist for this user" : "El nombre de inicio de sesión es inválido porque ya existen archivos para este usuario",
     "Account disabled" : "Cuenta deshabilitada",
     "Login canceled by app" : "Login cancelado por la app",
@@ -285,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "No se puede escribir en la carpeta \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta config.%s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, si prefieres mantener el archivo config.php como de solo lectura, marca la opción \"config_is_read_only\" a 'true' en él. Ver %s",
-    "Cannot write into \"apps\" directory." : "No se puede escribir en la carpeta \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta de apps o deshabilitando el App Store en el archivo de configuración.",
     "Cannot create \"data\" directory." : "No se puede crear la carpeta \"data\"",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta raíz. Véase %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Los permisos pueden arreglase usualmente dando al servidor web acceso de escritura a la carpeta raíz. Véase %s.",
@@ -297,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Consulte al administrador de su servidor para instalar el módulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "La opción PHP \"%s\" no es \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar esta configuración en php.ini hará que Nextcloud funcione de nuevo",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está establecido como <code>%s</code> en lugar del valor esperado: <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para arreglar este problema, establezca <code>mbstring.func_overload</code> en<code>0</code> en su php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales estén inaccesibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Los módulos PHP se han instalado, pero aparecen listados como si faltaran",
@@ -323,25 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "El almacenamiento no esta disponible temporalmente",
     "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Para permitir que este chequeo se lleve a cabo, debe asegurarse que su servidor pueda conectarse a sí mismo. Por tanto, este debe poder resolver y conectarse a alguno de sus `trusted_domains` o al url definido en `overwrite.cli.url`. Este fallo puede ser resultado de una inconsistencia DNS del lado del servidor o una regla de salida del cortafuegos.",
+    "Analyze images" : "Analizar imágenes",
+    "Ask a question about the given images." : "Haga una pregunta acerca de las imágenes proporcionadas.",
+    "Images" : "Imágenes",
+    "Images to ask a question about" : "Imágenes sobre las cuales se formulará una pregunta",
+    "Question" : "Pregunta",
+    "What to ask about the images." : "Que preguntar sobre las imágenes.",
+    "Generated response" : "Respuesta generada",
+    "The answer to the question" : "La respuesta a la pregunta",
+    "Audio chat" : "Chat de audio",
+    "Voice chat with the assistant" : "Chat de voz con el asistente",
+    "System prompt" : "Prompt del sistema",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir las reglas y supuestos que el asistente debe seguir durante la conversación.",
+    "Chat voice message" : "Mensaje de voz del chat",
+    "Describe a task that you want the assistant to do or ask a question." : "Describa una tarea que desea que el asistente realice o haga una pregunta.",
+    "Chat history" : "Historial de la conversación",
+    "The history of chat messages before the current message, starting with a message by the user." : "El historial de mensajes de chat anterior al mensaje actual, comenzando con un mensaje de parte del usuario.",
+    "Input transcript" : "Transcripción de entrada",
+    "Transcription of the audio input" : "Transcripción de la entrada de audio",
+    "Response voice message" : "Mensaje de voz de respuesta",
+    "The generated voice response as part of the conversation" : "La respuesta de voz generada como parte de la conversación",
+    "Output transcript" : "Transcripción de salida",
+    "Transcription of the audio output" : "Transcripción de la salida de audio",
     "Transcribe audio" : "Transcribir audio",
     "Transcribe the things said in an audio" : "Transcribir las cosas que se dicen en un audio",
     "Audio input" : "Entrada de audio",
     "The audio to transcribe" : "El audio a transcribir",
     "Transcription" : "Transcripción",
     "The transcribed text" : "El texto transcrito",
-    "Chat with an agent" : "Chatea con un agente",
-    "Chat message" : "Mensaje de chat",
-    "A chat message to send to the agent." : "Un mensaje de chat a escribir al agente",
+    "Chat by voice with an agent" : "Chatear a través de voz con un agente",
+    "Describe a task that you want the agent to do or ask a question." : "Describa una tarea que desea que el asistente realice o haga una pregunta.",
     "Confirmation" : "Confirmación",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Si se deben confirmar acciones solicitadas anteriormente: 0 para denegar y 1 para confirmar.",
     "Conversation token" : "Token de conversación",
     "A token representing the conversation." : "Un token que representa la conversación.",
-    "Generated response" : "Respuesta generada",
-    "The response from the chat model." : "La respuesta del modelo de chat.",
     "The new conversation token" : "El nuevo token de conversación",
     "Send this along with the next interaction." : "Envía esto junto a la siguiente interacción.",
     "Requested actions by the agent" : "Acciones solicitadas por el agente",
     "Actions that the agent would like to carry out in JSON format." : "Acciones que el agente quiere realizar en formato JSON.",
+    "Chat with an agent" : "Chatea con un agente",
+    "Chat message" : "Mensaje de chat",
+    "A chat message to send to the agent." : "Un mensaje de chat a escribir al agente",
+    "The response from the chat model." : "La respuesta del modelo de chat.",
     "Context write" : "Escribir contexto",
     "Writes text in a given style based on the provided source material." : "Escribe el texto en un estilo dado basándose en el material fuente proporcionado.",
     "Writing style" : "Estilo de escritura",
@@ -363,6 +387,11 @@ OC.L10N.register(
     "How many images to generate" : "Cuántas imágenes se generarán",
     "Output images" : "Imágenes de salida",
     "The generated images" : "Las imágenes generadas",
+    "Generate speech" : "Generar dictado",
+    "Generate speech from a transcript" : "Generar dictado desde una transcripción",
+    "Write transcript that you want the assistant to generate speech from" : "Escriba la transcripción desde la que desea que el asistente genere un dictado",
+    "Output speech" : "Dictado de salida",
+    "The generated speech" : "El dictado generado",
     "Free text to text prompt" : "Texto libre a prompt de texto",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Ejecuta un prompt arbitrario a través de un modelo de lenguaje que retorna una respuesta",
     "Describe a task that you want the assistant to do or ask a question" : "Describa una tarea que quiere que el asistente realice, o, haga una pregunta",
@@ -376,9 +405,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "El texto reescrito en el tono deseado, escrito por el asistente:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Chatear con el asistente",
-    "System prompt" : "Prompt del sistema",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir las reglas y supuestos que el asistente debe seguir durante la conversación.",
-    "Chat history" : "Historial de la conversación",
     "The history of chat messages before the current message, starting with a message by the user" : "El historial de mensajes del chat antes del mensaje actual, empezando con un mensaje del usuario",
     "Response message" : "Mensaje de respuesta",
     "The generated response as part of the conversation" : "La respuesta generada como parte de la conversación",
@@ -396,11 +422,11 @@ OC.L10N.register(
     "Write a text that you want the assistant to formalize" : "Escriba un texto que quiere que el asistente formalice",
     "Formalized text" : "Texto formalizado",
     "The formalized text" : "El texto formalizado",
-    "Generate a headline" : "Generar un titular",
-    "Generates a possible headline for a text." : "Genera un posible titular para un texto.",
+    "Generate a headline" : "Generar un título",
+    "Generates a possible headline for a text." : "Genera un posible título para un texto.",
     "Original text" : "Texto original",
-    "The original text to generate a headline for" : "El texto original para el cual generar un titular",
-    "The generated headline" : "El titular generado",
+    "The original text to generate a headline for" : "El texto original para el cual generar un título",
+    "The generated headline" : "El título generado",
     "Proofread" : "Corregir",
     "Proofreads a text and lists corrections" : "Corrige un texto y muestra sugerencias",
     "Text" : "Texto",
@@ -439,23 +465,16 @@ OC.L10N.register(
     "The translated text" : "El texto traducido",
     "Free prompt" : "Prompt libre",
     "Runs an arbitrary prompt through the language model." : "Ejecuta un prompt arbitrario mediante el modelo de lenguaje.",
-    "Generate headline" : "Generar titular",
+    "Generate headline" : "Generar título",
     "Summarizes text by reducing its length without losing key information." : "Resume el texto reduciendo su longitud sin perder información clave.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae los tópicos de un texto y genera una salida separada por comas. ",
-    "Education Edition" : "Edición Educación",
-    "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
-    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
-    "File name is too long" : "El nombre del archivo es demasiado largo",
-    "Users" : "Usuarios",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartido «%2$s» contigo y quiere añadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartido «%2$s» contigo y quiere añadir",
-    "»%s« added a note to a file shared with you" : "«%s» ha añadido una nota a un archivo compartido contigo",
-    "Open »%s«" : "Abrir »%s« ",
-    "%1$s shared »%2$s« with you" : "%1$s ha compartido «%2$s» contigo",
-    "%1$s shared »%2$s« with you." : "%1$s ha compartido «%2$s» contigo.",
-    "Click the button below to open it." : "Haz clic en el botón de abajo para abrirlo.",
+    "Organisation" : "Organización",
     "File is currently busy, please try again later" : "El archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
     "Cannot download file" : "No se puede descargar el archivo",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que existe un archivo llamado \".ocdata\" en la raíz del directorio de datos."
+    "Cannot write into \"apps\" directory." : "No se puede escribir en la carpeta \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Esto usualmente se puede arreglar dándole al servidor web acceso de escritura a la carpeta de apps o deshabilitando el App Store en el archivo de configuración.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está establecido como <code>%s</code> en lugar del valor esperado: <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para arreglar este problema, establezca <code>mbstring.func_overload</code> en<code>0</code> en su php.ini.",
+    "Login is too long" : "El nombre de inicio de sesión es demasiado largo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
