@@ -7,16 +7,20 @@
  */
 namespace OC\Files\Storage;
 
+use OCP\Files;
+use OCP\ITempManager;
+use OCP\Server;
+
 /**
  * local storage backend in temporary folder for testing purpose
  */
 class Temporary extends Local {
 	public function __construct(array $parameters = []) {
-		parent::__construct(['datadir' => \OC::$server->getTempManager()->getTemporaryFolder()]);
+		parent::__construct(['datadir' => Server::get(ITempManager::class)->getTemporaryFolder()]);
 	}
 
 	public function cleanUp(): void {
-		\OC_Helper::rmdirr($this->datadir);
+		Files::rmdirr($this->datadir);
 	}
 
 	public function __destruct() {
